package hanalife.a.cl.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.a.cl.cl.mapper.VochReptReadMapper;
import hanalife.a.cl.cl.mapper.dto.VochReptReadDSSD01DTO;
import hanalife.a.cl.cl.mapper.dto.VochReptReadDSSD02DTO;
import hanalife.a.cl.cl.mapper.dto.VochReptReadDSSD_DRCRDTO;
import hanalife.a.cl.cl.mapper.dto.VochReptReadDSSEARCH01DTO;
import hanalife.a.cl.cl.mapper.dto.VochReptReadDSSEARCHDTO;
import hanalife.a.cl.service.ACLCLM05Service;
import hanalife.a.cl.vo.ACLCLM05DSSD01VO;
import hanalife.a.cl.vo.ACLCLM05DSSD02VO;
import hanalife.a.cl.vo.ACLCLM05DSSDCRVO;
import hanalife.a.cl.vo.ACLCLM05DSSDDRVO;
import hanalife.a.cl.vo.ACLCLM05S01InVO;
import hanalife.a.cl.vo.ACLCLM05S01OutVO;
import hanalife.a.cl.vo.ACLCLM05S02InVO;
import hanalife.a.cl.vo.ACLCLM05S02OutVO;
import hanalife.a.cl.vo.ACLCLM05S03OutVo;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BLMLMM0601ServiceImpl.java Class
 * 클래스설명   :  자동전표현황조회(ACLCLM05) Service Implements
 * 작성일자     : 2023. 05. 03.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getACLCLM05S01 : 자동전표내역조회
 *                  getACLCLM05S02 : 자동전표내역조회된 아이템에 대하여 차번,대변 조회
 *                  getACLCLM05S03 : 일반전표 내역 조회
 * </pre>
 */
@Service("ACLCLM05Service")
public class ACLCLM05ServiceImpl implements ACLCLM05Service{

    private static final Logger LOGGER = LoggerFactory.getLogger(ACLCLM05ServiceImpl.class);

    @Autowired
    private VochReptReadMapper VochReptReadMapper;

    @Override
    public ACLCLM05S01OutVO getACLCLM05S01(ACLCLM05S01InVO inVo) throws Exception {

        ACLCLM05S01OutVO resultVo = new ACLCLM05S01OutVO();

        VochReptReadDSSEARCHDTO searchDto = new VochReptReadDSSEARCHDTO();
        searchDto.setAcctDtFr(inVo.getaCLCLM05DSSEARCHVO().getAcctDtFr());                                                                                           /** 회계_일자_시작일자*/
        searchDto.setAcctDtTo(inVo.getaCLCLM05DSSEARCHVO().getAcctDtTo());                                                                                           /** 회계_일자_종료일자*/
        searchDto.setOccrIamtFr(! inVo.getaCLCLM05DSSEARCHVO().getOccrIamtFr().equals("")?Long.parseLong(inVo.getaCLCLM05DSSEARCHVO().getOccrIamtFr()) : 0);         /** 발생_금액_시작*/
        searchDto.setOccrIamtTo(! inVo.getaCLCLM05DSSEARCHVO().getOccrIamtTo().equals("")?Long.parseLong(inVo.getaCLCLM05DSSEARCHVO().getOccrIamtTo()) : 0);         /** 발생_금액_종료*/
        searchDto.setLoanNo(inVo.getaCLCLM05DSSEARCHVO().getLoanNo());                                                                                               /** 대출_번호 */
        searchDto.setLoanSeq(inVo.getaCLCLM05DSSEARCHVO().getLoanSeq());                                                                                             /** 대출_순서 */
        searchDto.setFrstRegEmpNo(inVo.getaCLCLM05DSSEARCHVO().getFrstRegEmpNo());                                                                                       /** 최초_등록_사원_번호*/
        searchDto.setFrstRegEmpNm(inVo.getaCLCLM05DSSEARCHVO().getFrstRegEmpNm());                                                                                       /** 최초_등록_사원_명*/
        searchDto.setAcctDeptCd(inVo.getaCLCLM05DSSEARCHVO().getAcctDeptCd());                                                                                       /** 회계_부서_코드*/
        searchDto.setAcctDeptNm(inVo.getaCLCLM05DSSEARCHVO().getAcctDeptNm());                                                                                       /** 회계_부서_명*/
        searchDto.setTrTpCd(inVo.getaCLCLM05DSSEARCHVO().getTrTpCd());                                                                                               /** 이체_유형_코드*/
        searchDto.setVochNo(inVo.getaCLCLM05DSSEARCHVO().getVochNo());                                                                                               /** 전표_번호*/
        searchDto.setAcctCd(inVo.getaCLCLM05DSSEARCHVO().getAcctCd());                                                                                               /** 계정_코드*/
        searchDto.setAcctNm(inVo.getaCLCLM05DSSEARCHVO().getAcctNm());                                                                                               /** 계정_명*/
        searchDto.setAcctUnitCd(inVo.getaCLCLM05DSSEARCHVO().getAcctUnitCd());                                                                                       /**회계_단위_코드*/

        List<VochReptReadDSSD01DTO> queryResult =  VochReptReadMapper.searchVochReptList(searchDto);
        for(VochReptReadDSSD01DTO q : queryResult ) {
            ACLCLM05DSSD01VO dsSd01Vo = new  ACLCLM05DSSD01VO();

            dsSd01Vo.setAcctDt(q.getAcctDt());                                /** 회계_일자*/
            dsSd01Vo.setTrDescNo(q.getTrDescNo());                          /**거래_내역_번호*/
            dsSd01Vo.setTrSnum(q.getTrSnum());                              /**거래_일련번호*/
            dsSd01Vo.setIsrtDt(q.getIsrtDt());                                 /** 입력_일자*/
            dsSd01Vo.setAcctUnitNm(q.getAcctUnitNm());                    /**회계_단위_명*/
            dsSd01Vo.setAcctDeptNm(q.getAcctDeptNm());                     /**회계_부서_명*/
            dsSd01Vo.setAcctDeptCd(q.getAcctDeptCd());                    /**회계_부서_코드*/
            dsSd01Vo.setTrTpNm(q.getTrTpNm());                            /**거래_유형*/
            dsSd01Vo.setVochNo(q.getVochNo());                            /**전표_번호*/
            dsSd01Vo.setPrdtLrgeClasCd(q.getPrdtLrgeClasCd());            /** 상품_대분류_코드*/
            dsSd01Vo.setPrdtMidClasCd(q.getPrdtMidClasCd());              /** 상품_중분류_코드*/
            dsSd01Vo.setClasNm(q.getClasNm());                            /**상품*/
            dsSd01Vo.setDrAmt(q.getDrAmt());                              /**대변_금액*/
            dsSd01Vo.setCrAmt(q.getCrAmt());                              /**차변_금액*/
            dsSd01Vo.setLoanNo(q.getLoanNo());                            /** 대출_번호*/
            dsSd01Vo.setLoanSeq(q.getLoanSeq());                          /**대출_순서*/
            dsSd01Vo.setCustNm(q.getCustNm());                            /**이용자*/
            dsSd01Vo.setOccrDeptCd(q.getOccrDeptCd());                    /**발생_부서_코드*/
            dsSd01Vo.setMngDeptCd(q.getMngDeptCd());                      /**관리_부서_코드*/
            dsSd01Vo.setAcntNo(q.getAcntNo());                            /**계좌번호*/
            dsSd01Vo.setCprtComNo(q.getCprtComNo());                      /**제휴사_번호*/
            dsSd01Vo.setFrstRegEmpNm(q.getFrstRegEmpNm());                /**작성_사원_명*/
            dsSd01Vo.setFrstRegEmpNo(q.getFrstRegEmpNo());                /**작성_사원_번호*/
            dsSd01Vo.setOccrAcctUnitCd(q.getOccrAcctUnitCd());            /***/
            dsSd01Vo.setMngAcctUnitCd(q.getMngAcctUnitCd());              /** 관리_회계_단위_코드*/
            dsSd01Vo.setLastProcEmpNo(q.getLastProcEmpNo());              /** 발생_회계_단위_코드*/
            dsSd01Vo.setAcctUnitCd(q.getAcctUnitCd());                    /** 회계_단위_코드*/

            resultVo.getListACLCLM05DSSD01VO().add(dsSd01Vo);
        }

        return resultVo;
    }

    @Override
    public ACLCLM05S02OutVO getACLCLM05S02(ACLCLM05S02InVO inVo) throws Exception {

        ACLCLM05S02OutVO resultOutVo = new ACLCLM05S02OutVO();

        VochReptReadDSSEARCH01DTO dssearch01Dto = new VochReptReadDSSEARCH01DTO();

        dssearch01Dto.setAcctDeptCd(inVo.getaCLCLM05DSSEARCH01VO().getAcctDeptCd());
        dssearch01Dto.setAcctDt(inVo.getaCLCLM05DSSEARCH01VO().getAcctDt());
        dssearch01Dto.setTrDescNo(! inVo.getaCLCLM05DSSEARCH01VO().getTrDescNo().equals("")?Long.parseLong(inVo.getaCLCLM05DSSEARCH01VO().getTrDescNo()) : 0);
        dssearch01Dto.setTrSnum(!inVo.getaCLCLM05DSSEARCH01VO().getTrSnum().equals("") ? Long.parseLong(inVo.getaCLCLM05DSSEARCH01VO().getTrSnum()) : 0);
        dssearch01Dto.setAcctUnitCd(inVo.getaCLCLM05DSSEARCH01VO().getAcctUnitCd());


        List<VochReptReadDSSD_DRCRDTO> listSqlResult = VochReptReadMapper.searchSubDescList(dssearch01Dto);

        for(VochReptReadDSSD_DRCRDTO item : listSqlResult) {
            if(item.getDcDivCd().equals("D")) {         /**SQL 쿼리 결과 데이터에서 차대_구분코드가 "D" */
                ACLCLM05DSSDDRVO sddrVO = new ACLCLM05DSSDDRVO();
                sddrVO.setAcctCd(item.getAcctCd());                   /** 계정_코드*/
                sddrVO.setAcctNm(item.getAcctNm());                   /**계정_명*/
                sddrVO.setAcntNo(item.getAcntNo());                   /**전표_금액*/
                sddrVO.setVochAmt(item.getVochAmt());                 /**계좌번호*/

                resultOutVo.getListACLCLM05DSSDDRVO().add(sddrVO);
            }else {
                ACLCLM05DSSDCRVO sdcrVO = new ACLCLM05DSSDCRVO();
                sdcrVO.setAcctCd(item.getAcctCd());              /** 계정_코드*/
                sdcrVO.setAcctNm(item.getAcctNm());              /**계정_명*/
                sdcrVO.setAcntNo(item.getAcntNo());              /**전표_금액*/
                sdcrVO.setVochAmt(item.getVochAmt());            /**계좌번호*/

                resultOutVo.getListACLCLM05DSSDCRVO().add(sdcrVO);
            }
        }

        return resultOutVo;
    }

    @Override
    public ACLCLM05S03OutVo getACLCLM05S03(ACLCLM05S01InVO inVo) throws Exception {

        ACLCLM05S03OutVo resultOutVo = new ACLCLM05S03OutVo();

        VochReptReadDSSEARCHDTO dssearchDto = new VochReptReadDSSEARCHDTO();

        dssearchDto.setAcctDtFr(inVo.getaCLCLM05DSSEARCHVO().getAcctDtFr());                                                                                    /** 회계_일자_시작일자*/
        dssearchDto.setAcctDtTo(inVo.getaCLCLM05DSSEARCHVO().getAcctDtTo());                                                                                    /** 회계_일자_종료일자*/
        dssearchDto.setOccrIamtFr(!inVo.getaCLCLM05DSSEARCHVO().getOccrIamtFr().equals("") ? Long.parseLong(inVo.getaCLCLM05DSSEARCHVO().getOccrIamtFr()) : 0); /** 발생_금액_시작*/
        dssearchDto.setOccrIamtTo(!inVo.getaCLCLM05DSSEARCHVO().getOccrIamtTo().equals("") ? Long.parseLong(inVo.getaCLCLM05DSSEARCHVO().getOccrIamtTo()) : 0); /** 발생_금액_종료*/
        dssearchDto.setLoanNo(inVo.getaCLCLM05DSSEARCHVO().getLoanNo());                                                                                        /** 대출_번호 */
        dssearchDto.setLoanSeq(inVo.getaCLCLM05DSSEARCHVO().getLoanSeq());                                                                                      /** 대출_순서 */
        dssearchDto.setFrstRegEmpNo(inVo.getaCLCLM05DSSEARCHVO().getFrstRegEmpNo());                                                                                /** 최초_등록_사원_번호*/
        dssearchDto.setFrstRegEmpNm(inVo.getaCLCLM05DSSEARCHVO().getFrstRegEmpNm());                                                                                /** 최초_등록_사원_명*/
        dssearchDto.setAcctDeptCd(inVo.getaCLCLM05DSSEARCHVO().getAcctDeptCd());                                                                                /** 회계_부서_코드*/
        dssearchDto.setAcctDeptNm(inVo.getaCLCLM05DSSEARCHVO().getAcctDeptNm());                                                                                /** 회계_부서_명*/
        dssearchDto.setTrTpCd(inVo.getaCLCLM05DSSEARCHVO().getTrTpCd());                                                                                        /** 이체_유형_코드*/
        dssearchDto.setVochNo(inVo.getaCLCLM05DSSEARCHVO().getVochNo());                                                                                        /** 전표_번호*/
        dssearchDto.setAcctCd(inVo.getaCLCLM05DSSEARCHVO().getAcctCd());                                                                                        /** 계정_코드*/
        dssearchDto.setAcctNm(inVo.getaCLCLM05DSSEARCHVO().getAcctNm());                                                                                        /** 계정_명*/
        dssearchDto.setAcctUnitCd(inVo.getaCLCLM05DSSEARCHVO().getAcctUnitCd());                                                                                /**회계_단위_코드*/

        List<VochReptReadDSSD02DTO> listSqlResult = VochReptReadMapper.searchVochList(dssearchDto);

        for(VochReptReadDSSD02DTO item : listSqlResult) {
            ACLCLM05DSSD02VO vo = new ACLCLM05DSSD02VO();

            vo.setAcctDt(item.getAcctDt());                   /**회계_일자*/
            vo.setVochNo(item.getVochNo());                   /**전표_번호*/
            vo.setVochSnum(item.getVochSnum());                   /** 전표_일련번호*/
            vo.setLoanNo(item.getLoanNo());                   /**대출_번호*/
            vo.setLoanSeq(item.getLoanSeq());                 /**대출_순서*/
            vo.setDcDivNm(item.getDcDivNm());                 /** 차대_구분_코드*/
            vo.setdAmt(item.getdAmt());                       /** 차변_금액*/
            vo.setrAmt(item.getrAmt());                       /** 대변_금액*/
            vo.setAcctCd(item.getAcctCd());                   /** 계정_코드*/
            vo.setAcctNm(item.getAcctNm());                   /**계정_명*/
            vo.setAcctCd2(item.getAcctCd2());                  /** 계정_코드*/
            vo.setAcctNm2(item.getAcctNm2());                 /**계정_명*/
            vo.setRmk(item.getRmk());                                 /**적요*/
            vo.setSendFgNm(item.getSendFgNm());                   /** 전송_상태 */


            resultOutVo.getListACLCLM05DSSD02VO().add(vo);
        }

        return resultOutVo;
    }



}
