package hanalife.b.cm.kf.svc;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;

import org.apache.log4j.Logger;

/**
 * <p>파일명	  		: KfbErrDAO.java</p>
 * <p>버젼	  		: 1.1.1.0</p>
 * <p>작성일	  		: 2012.09.27</p>
 * <p>작성자	  		: 이창욱</p>
 * <p>Use Case명	  	: Kfb오류처리</p>
 * <p>프로그램명	  	: KfbErrDAO</p>
 * <p>내용	  		: Kfb오류처리를 위한 DAO </p>
 */
public class KfbErrDAO
{
	public final static int LOAN = 1;
	public final static int DEBT = 2;
	public final static int CRDT = 3; //은행연합회 연체 집중
	public final static int CRDT_MOD = 4;
	public final static int LOANCHG = 5;
    public final static int ENTLOAN = 6;
    public final static int ENTMRTG = 7;
    public final static int ENTGUAR = 8;
	private final static String BR = "\n";

	private Connection con;
	private String jobDt;
	private String empNo;
    private Logger log = Logger.getLogger(this.getClass().getName());

	public int[] executeRsltRefl(Connection con,String jobDt,String empNo,int tabOrd) throws Exception {

		log.info("BCMKF0413 >>> ??? :::executeRsltRefl:::");

		int[] cnt = null;

		try {
			this.con   = con;
			this.jobDt = jobDt;
			this.empNo = empNo;

			boolean procFg = this.checkJobDt(tabOrd);

			if(procFg) {

				//LN9011
				//if(tabOrd == LOAN || tabOrd == LOANCHG)
				if(tabOrd == LOAN ) {
					cnt = executeLoan(tabOrd);
				}
				else if(tabOrd == LOANCHG)	// LN9033
				{
					cnt = executeLoanChg(tabOrd);
				}
				//BF9011 은행연합회 연체 집중
				else if(tabOrd == CRDT)
				{
					cnt = executeCrdt();
                }
				else if(tabOrd == CRDT_MOD)
				{
					cnt = executeCrdtModify();
				}
			}
		} catch(Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
			throw e;
		}

		return cnt;
	}
	//LN9011
	private int[] executeLoan(int tabOrd) throws Exception
	{
		// 은행연합회 대출거래이력 정보 UPDATE LN9011, LN9033
		this.updateLoanTrHist();

		// 은행연합회 대출거래기본에 정보 반영
		return this.reflectLoanTrBase(tabOrd);
	}
	// LN9033
	private int[] executeLoanChg(int tabOrd) throws Exception
	{
		// 은행연합회 대출거래이력 정보 UPDATE LN9011, LN9033
		this.updateLoanTrChgHist();

		// 은행연합회 대출거래기본에 정보 반영
		return this.reflectLoanTrChgBase(tabOrd);
	}
	//BF9011
	private int[] executeCrdt() throws Exception
	{
		// 은행연합회 신용불량집중이력 정보 UPDATE BF9011
		this.updateCrdtBadCntrHist();
		// 은행연합회 신용불량집중기본에 정보 반영
		return this.reflectCrdtBadCntrBase();
	}
	//BF9044
	private int[] executeCrdtModify() throws Exception
	{
		// 은행연합회 신용불량집중이력 정보 UPDATE
		this.updateCrdtBadCntrModifyHist();
		// 은행연합회 신용불량집중기본에 정보 반영
		return this.reflectCrdtBadCntrBaseFromModify();
	}

	private boolean checkJobDt(int tabOrd) throws Exception
	{
		log.info("::: checkJobDt :::");
		String TABLE = "";
		String And = "";
		boolean procFg = true;

		if(tabOrd == LOAN)
		{
			TABLE = "EPLSADM.BT_KFB_LOAN_TR_HIST";
			And = "AND    REG_DIV_CD = '01'";
		}
		else if(tabOrd == DEBT)
		{
			TABLE = "EPLSADM.BT_KFB_DEBT_GUAR_HIST";
		}
		else if(tabOrd == CRDT)
		{
			TABLE = "EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST";
		}
		else if(tabOrd == CRDT_MOD)
		{
			TABLE = "EPLSADM.BT_KFB_CRDT_BAD_CNTR_MODI_HIST";
		}
		else if(tabOrd == LOANCHG)
		{
			TABLE = "EPLSADM.BT_KFB_LOAN_TRCHG_HIST";
			And = "AND    REG_DIV_CD = '01'";
		}else if(tabOrd == ENTLOAN)
	    {
	        TABLE = "EPLSADM.BT_KFB_ENT_LOAN_TR_HIST";
        }else if(tabOrd == ENTMRTG)
        {
            TABLE = "EPLSADM.BT_KFB_ENT_MRTG_HIST";
        }else if(tabOrd == ENTGUAR)
        {
            TABLE = "EPLSADM.BT_KFB_ENT_GUAR_HIST";
		}

		String query
		= "SELECT SUM(CASE WHEN PRGS_STAT_CD = '5' THEN 1 ELSE 0 END) OVER_CNT " + BR
		+ "      ,SUM(CASE WHEN JOB_DT = '" + this.jobDt + "'                  " + BR
		+ "                AND  PRGS_STAT_CD IN ('1','2')                      " + BR
		+ "                THEN 1 ELSE 0 END)                         CURR_CNT " + BR
		+ "FROM   " + TABLE                                          + BR
		+ "WHERE  JOB_DT >= '" + this.jobDt + "'                   " + BR
		+ And + BR;

		Statement stmt = null;
		ResultSet rs   = null;

		try {
			log.debug(query);
			stmt = con.createStatement();
			rs = stmt.executeQuery(query);
			rs.next();

	        log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
	        log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
			log.info("____jobDt:" + jobDt);
            log.info("____TABLE:" + TABLE);
			log.info("____OVER_CNT:" + rs.getInt("OVER_CNT"));
			log.info("____CURR_CNT:" + rs.getInt("CURR_CNT"));
	        log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
	        log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");

			if(rs.getInt("OVER_CNT") > 0){
				log.info("!!!!! 작업일자("+this.jobDt+") - 이미 결과 반영이 완료되었습니다. !!!!!");
				procFg = false;
				//throw new Exception("작업일자("+this.jobDt+") - 이미 결과 반영이 완료되었습니다.");
			}
			if(rs.getInt("CURR_CNT") == 0){
				log.info("!!!!! 작업일자("+this.jobDt+") - 결과 반영 대상이 없습니다. !!!!!");
				procFg = false;
				//throw new Exception("작업일자("+this.jobDt+") - 결과 반영 대상이 없습니다.");
			}
		} finally {
			this.closeResultSet(rs);
			this.closeStatement(stmt);
		}

		log.info("return procFg = " + procFg);
		return procFg;
	}
/**********************************************************************************************************************
 *   reflect
 **********************************************************************************************************************/

    private int[] reflectLoanTrBase(int tabOrd) throws Exception
    {
        int cCnt = this.insertLoanTrBase();
        int uCnt = this.updateLoanTrBase(tabOrd);
        int dCnt = this.deleteLoanTrBase();

        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        log.info("은행연합회 대출거래기본 반영건수 : 등록("+cCnt+") 수정("+uCnt+") 삭제("+dCnt+")");
        log.info("은행연합회 대출거래기본 반영건수 : 수정("+uCnt+") 삭제("+dCnt+")");
        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        return new int[]{cCnt,uCnt,dCnt};
    }

    private int[] reflectLoanTrChgBase(int tabOrd) throws Exception
    {
        int cCnt = this.insertLoanTrChgBase();
        int uCnt = this.updateLoanTrChgBase(tabOrd);
        //int dCnt = this.deleteLoanTrChgBase();
        int dCnt = 0;

        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        log.info("은행연합회 대출거래기본 반영건수 : 등록("+cCnt+") 수정("+uCnt+") 삭제("+dCnt+")");
        log.info("은행연합회 대출거래기본 반영건수 : 수정("+uCnt+") 삭제("+dCnt+")");
        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        return new int[]{cCnt,uCnt,dCnt};
    }

    private int[] reflectCrdtBadCntrBase() throws Exception
    {
        int cCnt = this.insertCrdtBadCntrBase();
        int uCnt = this.updateCrdtBadCntrBase();
        int dCnt = this.deleteCrdtBadCntrBase();
        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        log.info("은행연합회 신용불량집중기본 반영건수 : 등록("+cCnt+") 수정("+uCnt+") 삭제("+dCnt+")");
        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        return new int[]{cCnt,uCnt,dCnt};
    }

    private int[] reflectCrdtBadCntrBaseFromModify() throws Exception
    {
        int uCnt = this.updateCrdtBadCntrBaseFromModify();
        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        log.info("은행연합회 신용불량집중기본 반영건수 : 등록(0) 수정("+uCnt+") 삭제(0)");
        log.info("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        return new int[]{0,uCnt,0};
    }




/**********************************************************************************************************************
 *   HIST UPDATE
 **********************************************************************************************************************/
	private void updateLoanTrHist() throws Exception
	{
		String query
		= "UPDATE EPLSADM.BT_KFB_LOAN_TR_HIST                             " + BR
		+ "SET    PRGS_STAT_CD     = '5'                                  " + BR
		+ "      ,LAST_PROC_DT     = TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  " + BR
		+ "      ,LAST_PROC_TM     = TO_CHAR(CURRENT_DATE, 'HH24MISS')    " + BR
		+ "      ,LAST_PROC_EMP_NO = '" + this.empNo + "'                 " + BR
		+ "WHERE  JOB_DT       = ?                                        " + BR
		+ "AND    PRGS_STAT_CD <> '9'                                     " + BR;

		PreparedStatement pstmt = null;
		try
		{
			log.debug(query);
			pstmt = con.prepareStatement(query);
			pstmt.setString(1,this.jobDt);
			int cnt = pstmt.executeUpdate();
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
			log.debug("BT_KFB_LOAN_TR_HIST update CNT : " + cnt);
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
		}
		finally
		{
			this.closeStatement(pstmt);
		}
	}

    private void updateLoanTrChgHist() throws Exception
    {
        String query
        = "UPDATE EPLSADM.BT_KFB_LOAN_TRCHG_HIST                             " + BR
        + "SET    PRGS_STAT_CD     = '5'                                  " + BR
        + "      ,LAST_PROC_DT     = TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  " + BR
        + "      ,LAST_PROC_TM     = TO_CHAR(CURRENT_DATE, 'HH24MISS')    " + BR
        + "      ,LAST_PROC_EMP_NO = '" + this.empNo + "'                 " + BR
        + "WHERE  JOB_DT       = ?                                        " + BR
        + "AND    PRGS_STAT_CD <> '9'                                     " + BR;

        PreparedStatement pstmt = null;
        try
        {
            log.debug(query);
            pstmt = con.prepareStatement(query);
            pstmt.setString(1,this.jobDt);
            int cnt = pstmt.executeUpdate();
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("BT_KFB_LOAN_TRCHG_HIST update CNT : " + cnt);
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        }
        finally
        {
            this.closeStatement(pstmt);
        }
    }


    private void updateCrdtBadCntrHist() throws Exception
    {
        String uSql
        = "UPDATE EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST                       " + BR
        + "SET    PRGS_STAT_CD = '5'                                      " + BR
        + "      ,LAST_PROC_DT     = TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  " + BR
        + "      ,LAST_PROC_TM     = TO_CHAR(SYSDATE,'HHmiss')            " + BR
        + "      ,LAST_PROC_EMP_NO = '" + this.empNo + "'                 " + BR
        + "WHERE  JOB_DT       = ?                                        " + BR
        + "AND    PRGS_STAT_CD <> '9'                                     " + BR;

        PreparedStatement pstmt = null;
        try
        {
            log.debug(uSql);
            pstmt = con.prepareStatement(uSql);
            pstmt.setString(1,this.jobDt);
            int cnt = pstmt.executeUpdate();
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("BT_KFB_CRDT_BAD_CNTR_HIST update CNT : " + cnt);
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        }
        finally
        {
            this.closeStatement(pstmt);
        }
    }

    private void updateCrdtBadCntrModifyHist() throws Exception
    {
        String uSql
        = "UPDATE EPLSADM.BT_KFB_CRDT_BAD_CNTR_MODI_HIST                " + BR
        + "SET    PRGS_STAT_CD = '5'                                      " + BR
        + "      ,LAST_PROC_DT     = TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  " + BR
        + "      ,LAST_PROC_TM     = TO_CHAR(CURRENT_DATE, 'HH24MISS')  " + BR
        + "      ,LAST_PROC_EMP_NO = '" + this.empNo + "'                 " + BR
        + "WHERE  JOB_DT       = ?                                        " + BR
        + "AND    PRGS_STAT_CD <> '9'                                     " + BR;

        PreparedStatement pstmt = null;
        try
        {
            log.debug(uSql);
            pstmt = con.prepareStatement(uSql);
            pstmt.setString(1,this.jobDt);
            int cnt = pstmt.executeUpdate();
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("BT_KFB_CRDT_BAD_CNTR_MODI_HIST update CNT : " + cnt);
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
            log.debug("☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆☆");
        }
        finally
        {
            this.closeStatement(pstmt);
        }
    }




/**********************************************************************************************************************
 *   BASE UPDATE/INSERT/DELETE
 **********************************************************************************************************************/

	private int updateLoanTrBase(int tabOrd) throws Exception
	{
		String regDvCd = "";
		String regDvCd1 = "";

		if(tabOrd == LOAN){
			regDvCd = "AND    REG_DIV_CD = '01'";
			regDvCd1 = "AND    X.REG_DIV_CD = '01'";
		}else if(tabOrd == LOANCHG){
			regDvCd = "AND    REG_DIV_CD = '03'";
			regDvCd1 = "AND    X.REG_DIV_CD = '03'";
		}

		String query
		= "UPDATE EPLSADM.BT_KFB_LOAN_TR_BASE A                   " + BR
		+ "SET    (                                               " + BR
		+ "           A.CUST_NM                                   " + BR
		+ "          ,A.JOB_CD                                    " + BR
		+ "          ,A.REG_DT                                    " + BR
		+ "          ,A.REG_DIV_CD                                " + BR
		+ "          ,A.REG_AMT                                   " + BR
		+ "          ,A.LOAN_DT                                   " + BR
		+ "          ,A.BZIT_CD                                   " + BR
		+ "          ,A.VAR_DT                                    " + BR
		+ "          ,A.CHNG_AMT                                  " + BR
		+ "          ,A.HOUS_MRTG_LOAN_YN                         " + BR
		+ "          ,A.LAST_PROC_DT                              " + BR
		+ "          ,A.LAST_PROC_TM                              " + BR
		+ "          ,A.LAST_PROC_EMP_NO                          " + BR
		//추가
		+ "          ,A.LOAN_DIV_CD										" + BR
		+ "          ,A.SPCL_BND_MO_ACNT_NO								" + BR
		+ "          ,A.PP_FINC_DIV_CD									" + BR
		+ "          ,A.LOAN_DT_CHNG_BF									" + BR
		+ "          ,A.DSR_DIV_CD										" + BR
		+ "          ,A.DSR_DT_CHNG										" + BR
		+ "          ,A.DSR_LOAN_TERM									" + BR
		+ "          ,A.DSR_FRST_STND_INT_RT							" + BR
		+ "          ,A.DSR_RMBR_METH_CD								" + BR
		+ "          ,A.DSR_EPRT_DT										" + BR
		+ "          ,A.DSR_FACT_INT_RT									" + BR
		+ "          ,A.DSR_DEFR_DT_EN									" + BR
		+ "          ,A.DSR_DEFR_TERM									" + BR
		+ "          ,A.DSR_LOAN_AMT									" + BR
		+ "          ,A.DSR_YY_MM_PAMT									" + BR
		+ "          ,A.DSR_YY_MM_INT									" + BR
		+ "          ,A.DSR_DRT_STR_MNRT_AMT							" + BR
		+ "          ,A.DSR_EPRT_LOAN_TERM								" + BR
		+ "          ,A.DSR_DRT_YY_MM_AMT								" + BR
        + "          ,A.MRTG_SPEC_KIND                                  " + BR

		+ "       )                                               " + BR
		+ "       =                                               " + BR
		+ "       (                                               " + BR
		+ "           SELECT Z.CUST_NM                            " + BR
		+ "                 ,Z.JOB_CD                             " + BR
		+ "                 ,Z.JOB_DT                             " + BR
		+ "                 ,Z.REG_DIV_CD                         " + BR
		+ "                 ,Z.REG_AMT                            " + BR
		+ "                 ,Z.LOAN_DT                            " + BR
		+ "                 ,Z.BZIT_CD                            " + BR
		+ "                 ,Z.VAR_DT                             " + BR
		+ "                 ,Z.CHNG_AMT                           " + BR
		+ "                 ,Z.HOUS_MRTG_LOAN_YN                  " + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  " + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'HH24MISS')  " + BR
		+ "                 ,'" + this.empNo + "'                 " + BR
		//추가
		+ "          		,Z.LOAN_DIV_CD										" + BR
		+ "          		,Z.SPCL_BND_MO_ACNT_NO								" + BR
		+ "          		,Z.PP_FINC_DIV_CD									" + BR
		+ "          		,Z.LOAN_DT_CHNG_BF									" + BR
		+ "          		,Z.DSR_DIV_CD										" + BR
		+ "          		,Z.DSR_DT_CHNG										" + BR
		+ "          		,Z.DSR_LOAN_TERM									" + BR
		+ "          		,Z.DSR_FRST_STND_INT_RT							" + BR
		+ "          		,Z.DSR_RMBR_METH_CD								" + BR
		+ "          		,Z.DSR_EPRT_DT										" + BR
		+ "          		,Z.DSR_FACT_INT_RT									" + BR
		+ "          		,Z.DSR_DEFR_DT_EN									" + BR
		+ "          		,Z.DSR_DEFR_TERM									" + BR
		+ "          		,Z.DSR_LOAN_AMT									" + BR
		+ "          		,Z.DSR_YY_MM_PAMT									" + BR
		+ "          		,Z.DSR_YY_MM_INT									" + BR
		+ "          		,Z.DSR_DRT_STR_MNRT_AMT							" + BR
		+ "          		,Z.DSR_EPRT_LOAN_TERM								" + BR
		+ "          		,Z.DSR_DRT_YY_MM_AMT								" + BR
        + "                 ,Z.MRTG_SPEC_KIND                                   " + BR
		+ "           FROM   EPLSADM.BT_KFB_LOAN_TR_HIST Z        " + BR
		+ "           WHERE  TRIM(Z.CUST_NO) = TRIM(A.CUST_NO)    " + BR
		+ "           AND    Z.LOAN_NO = A.LOAN_NO                " + BR
		+ "           AND    Z.LOAN_SEQ = A.LOAN_SEQ              " + BR
		+ "           AND    Z.JOB_DT  = '" + this.jobDt + "'     " + BR
		//+                  regDvCd 				                    + BR
		+ "           AND    Z.REG_DIV_CD  IN ('03', '05') 				  " + BR
		+ "       )                                               " + BR
		+ "WHERE  A.CUST_NO||RTRIM(A.LOAN_NO)||RTRIM(A.LOAN_SEQ)  " + BR
		+ "       IN (SELECT X.CUST_NO||RTRIM(X.LOAN_NO)||RTRIM(X.LOAN_SEQ)" + BR
		+ "           FROM   EPLSADM.BT_KFB_LOAN_TR_HIST X        " + BR
		+ "                 ,EPLSADM.BT_KFB_LOAN_TR_BASE Y        " + BR
		+ "           WHERE  X.JOB_DT       = '" + this.jobDt + "'" + BR
		+ "           AND    X.PRGS_STAT_CD = '5'                 " + BR
		+ "           AND    TRIM(X.CUST_NO) = TRIM(A.CUST_NO)    " + BR
		//+                  regDvCd1 				                    + BR
		+ "           AND    X.REG_DIV_CD IN ('03', '05')               		" + BR
		+ "           AND    Y.CUST_NO = X.CUST_NO)               " + BR;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 대출거래기본 수정시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}
	private int insertLoanTrBase() throws Exception
	{
		String query
		= "INSERT INTO EPLSADM.BT_KFB_LOAN_TR_BASE                " + BR
		+ "(                                                      " + BR
		+ "     CUST_NO                                           " + BR
		+ "    ,CUST_NM                                           " + BR
		+ "    ,JOB_CD                                            " + BR
		+ "    ,REG_DT                                            " + BR
		+ "    ,REG_DIV_CD                                        " + BR
		+ "    ,REG_AMT                                           " + BR
		+ "    ,LOAN_DT                                           " + BR
		+ "    ,LOAN_NO                                           " + BR
		+ "    ,LOAN_SEQ                                          " + BR
		+ "    ,BZIT_CD                                           " + BR
		+ "    ,VAR_DT                                            " + BR
		+ "    ,CHNG_AMT                                          " + BR
		+ "    ,HOUS_MRTG_LOAN_YN                                 " + BR
		+ "    ,FRST_REG_DT                                       " + BR
		+ "    ,FRST_REG_TM                                       " + BR
		+ "    ,FRST_REG_EMP_NO                                   " + BR
		+ "    ,LAST_PROC_DT                                      " + BR
		+ "    ,LAST_PROC_TM                                      " + BR
		+ "    ,LAST_PROC_EMP_NO                                  " + BR
		+ "    ,PRDT_LRGE_CLAS_CD                                 " + BR
		+ "    ,LOAN_MRTG_YN                                   	  " + BR
		+ "    ,FINC_CD                                  	  	" + BR
		//추가
		+ "    ,LOAN_DIV_CD										" + BR
		+ "    ,SPCL_BND_MO_ACNT_NO								" + BR
		+ "    ,PP_FINC_DIV_CD									" + BR
		+ "    ,LOAN_DT_CHNG_BF									" + BR
		+ "    ,DSR_DIV_CD										" + BR
		+ "    ,DSR_DT_CHNG										" + BR
		+ "    ,DSR_LOAN_TERM									" + BR
		+ "    ,DSR_FRST_STND_INT_RT							" + BR
		+ "    ,DSR_RMBR_METH_CD								" + BR
		+ "    ,DSR_EPRT_DT										" + BR
		+ "    ,DSR_FACT_INT_RT									" + BR
		+ "    ,DSR_DEFR_DT_EN									" + BR
		+ "    ,DSR_DEFR_TERM									" + BR
		+ "    ,DSR_LOAN_AMT									" + BR
		+ "    ,DSR_YY_MM_PAMT									" + BR
		+ "    ,DSR_YY_MM_INT									" + BR
		+ "    ,DSR_DRT_STR_MNRT_AMT							" + BR
		+ "    ,DSR_EPRT_LOAN_TERM								" + BR
		+ "    ,DSR_DRT_YY_MM_AMT								" + BR
        + "    ,MRTG_SPEC_KIND                                  " + BR
		+ ")                                                      " + BR
		+ "SELECT CUST_NO                                         " + BR
		+ "      ,CUST_NM                                         " + BR
		+ "      ,JOB_CD                                          " + BR
		+ "      ,'" + this.jobDt + "'                            " + BR
		+ "      ,REG_DIV_CD                                      " + BR
		+ "      ,REG_AMT                                         " + BR
		+ "      ,LOAN_DT                                         " + BR
		+ "      ,LOAN_NO                                         " + BR
		+ "      ,LOAN_SEQ                                        " + BR
		+ "      ,BZIT_CD                                         " + BR
		+ "      ,VAR_DT                                          " + BR
		+ "      ,CHNG_AMT                                        " + BR
		+ "      ,HOUS_MRTG_LOAN_YN                               " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')             " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'HH24MISS')             " + BR
		+ "      ,'" + this.empNo + "'                            " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')             " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'HH24MISS')             " + BR
		+ "      ,'" + this.empNo + "'                            " + BR
		+ "      ,PRDT_LRGE_CLAS_CD                               " + BR
		+ "      ,LOAN_MRTG_YN                                    " + BR
		+ "      ,FINC_CD                                         " + BR
		//추가
		+ "    	 ,LOAN_DIV_CD										" + BR
		+ "      ,SPCL_BND_MO_ACNT_NO								" + BR
		+ "      ,PP_FINC_DIV_CD									" + BR
		+ "      ,LOAN_DT_CHNG_BF									" + BR
		+ "      ,DSR_DIV_CD										" + BR
		+ "      ,DSR_DT_CHNG										" + BR
		+ "      ,DSR_LOAN_TERM									" + BR
		+ "      ,DSR_FRST_STND_INT_RT							" + BR
		+ "      ,DSR_RMBR_METH_CD								" + BR
		+ "      ,DSR_EPRT_DT										" + BR
		+ "      ,DSR_FACT_INT_RT									" + BR
		+ "      ,DSR_DEFR_DT_EN									" + BR
		+ "      ,DSR_DEFR_TERM									" + BR
		+ "      ,DSR_LOAN_AMT									" + BR
		+ "      ,DSR_YY_MM_PAMT									" + BR
		+ "      ,DSR_YY_MM_INT									" + BR
		+ "      ,DSR_DRT_STR_MNRT_AMT							" + BR
		+ "      ,DSR_EPRT_LOAN_TERM								" + BR
		+ "      ,DSR_DRT_YY_MM_AMT								" + BR
        + "      ,MRTG_SPEC_KIND                                  " + BR
		+ " FROM EPLSADM.BT_KFB_LOAN_TR_HIST A                    " + BR
		+ "WHERE  JOB_DT       = '" + this.jobDt + "'             " + BR
		+ "AND    A.PRGS_STAT_CD = '5'                              " + BR

		//추가
		+ "AND    A.REG_DIV_CD = '01'                              " + BR

		+ "AND    NOT EXISTS (SELECT 1                            " + BR
		+ "                   FROM   EPLSADM.BT_KFB_LOAN_TR_BASE X" + BR
		+ "                   WHERE  TRIM(X.CUST_NO) = TRIM(A.CUST_NO)       " + BR
		+ "                     AND  TRIM(X.LOAN_NO)  = TRIM(A.LOAN_NO)       " + BR
		+ "                     AND  X.LOAN_SEQ = A.LOAN_SEQ)     " + BR;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			log.debug("EPLSADM.BT_KFB_LOAN_TR_BASE insert CNT : " + cnt);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 대출거래기본 등록시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int deleteLoanTrBase() throws Exception
	{
		String query
		= "DELETE                                                          " + BR
		+ "FROM   EPLSADM.BT_KFB_LOAN_TR_BASE                              " + BR
		+ "WHERE  LOAN_NO IN (SELECT LOAN_NO                               " + BR
		+ "                   FROM   EPLSADM.BT_KFB_LOAN_TR_HIST           " + BR
		+ "                   WHERE  JOB_DT       = '" + this.jobDt + "'   " + BR
		+ "                   AND    PRGS_STAT_CD = '5'                    " + BR
		+ "                   AND    CHNG_AMT     = 0                      " + BR
		+ "                   UNION                                        " + BR
		+ "                   SELECT H.LOAN_NO                             " + BR
		+ "                   FROM   EPLSADM.BT_KFB_LOAN_TR_CNTR_ERR E     " + BR
		+ "                         ,EPLSADM.BT_KFB_LOAN_TR_HIST     H     " + BR
		+ "                   WHERE  E.JOB_DT        = '" + this.jobDt + "'" + BR
		+ "                   AND    E.ERR_CD        = '531'               " + BR
		+ "                   AND    H.CHNG_AMT      = 0                   " + BR
		+ "                   AND    H.REG_DIV_CD    = '03'                " + BR
		+ "                   AND    H.JOB_DT        = E.JOB_DT            " + BR
		+ "                   AND    H.REG_BLCK_SNUM = E.REG_BLCK_SNUM     " + BR
		+ "                   AND    H.REG_SNUM      = E.REG_SNUM          " + BR
		+ "                   AND    H.DATA_SNUM     = E.DATA_SNUM)        " + BR;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			log.info("EPLSADM.BT_KFB_LOAN_TR_BASE DELETE CNT : " + cnt);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 대출거래기본 삭제시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int updateLoanTrChgBase(int tabOrd) throws Exception
	{

		String query
		= "UPDATE EPLSADM.BT_KFB_LOAN_TRCHG_BASE A                " + BR
		+ "SET    (                                               " + BR
		+ "           A.CUST_NM                                   " + BR
		+ "          ,A.JOB_CD                                    " + BR
		+ "          ,A.REG_DT                                    " + BR
		+ "          ,A.REG_DIV_CD                                " + BR
		+ "          ,A.REG_AMT                                   " + BR
		+ "          ,A.LOAN_DT                                   " + BR
		+ "          ,A.BZIT_CD                                   " + BR
		+ "          ,A.VAR_DT                                    " + BR
		+ "          ,A.CHNG_AMT                                  " + BR
		+ "          ,A.HOUS_MRTG_LOAN_YN                         " + BR
		+ "          ,A.LAST_PROC_DT                              " + BR
		+ "          ,A.LAST_PROC_TM                              " + BR
		+ "          ,A.LAST_PROC_EMP_NO                          " + BR
		+ "    		 ,A.PRDT_LRGE_CLAS_CD								" + BR
		+ "    		 ,A.LOAN_MRTG_YN									" + BR
		+ "    		 ,A.FINC_CD										 	" + BR
		+ "    		 ,A.LOAN_DIV_CD										" + BR
		+ "    		 ,A.SPCL_BND_MO_ACNT_NO								" + BR
		+ "    		 ,A.PP_FINC_DIV_CD									" + BR
		+ "    		 ,A.CUST_NO_BF										 " + BR
		+ "    		 ,A.LOAN_NO_BF										 " + BR
		+ "   		 ,A.LOAN_SEQ_BF										 " + BR
		+ "          ,A.MRTG_SPEC_KIND                                   " + BR
		+ "       )                                               	" + BR
		+ "       =                                               	" + BR
		+ "       (                                               	" + BR
		+ "           SELECT Z.CUST_NM                            	" + BR
		+ "                 ,Z.JOB_CD                             	" + BR
		+ "                 ,Z.JOB_DT                             	" + BR
		+ "                 ,Z.REG_DIV_CD                         	" + BR
		+ "                 ,Z.REG_AMT                            	" + BR
		+ "                 ,Z.LOAN_DT                            	" + BR
		+ "                 ,Z.BZIT_CD                            	" + BR
		+ "                 ,Z.VAR_DT                             	" + BR
		+ "                 ,Z.CHNG_AMT                           	" + BR
		+ "                 ,Z.HOUS_MRTG_LOAN_YN                  	" + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  	" + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'HH24MISS')  	" + BR
		+ "                 ,'" + this.empNo + "'                 	" + BR
		+ "    		 		,Z.PRDT_LRGE_CLAS_CD					" + BR
		+ "    		 		,Z.LOAN_MRTG_YN							" + BR
		+ "    		 		,Z.FINC_CD								" + BR
		+ "    		 		,Z.LOAN_DIV_CD							" + BR
		+ "    		 		,Z.SPCL_BND_MO_ACNT_NO					" + BR
		+ "    		 		,Z.PP_FINC_DIV_CD						" + BR
		+ "    		 		,Z.CUST_NO_BF							" + BR
		+ "    		 		,Z.LOAN_NO_BF							" + BR
		+ "   		 		,Z.LOAN_SEQ_BF							" + BR
		+ "                 ,Z.MRTG_SPEC_KIND                       " + BR
		+ "           FROM   EPLSADM.BT_KFB_LOAN_TRCHG_HIST Z       " + BR
		+ "           WHERE  TRIM(Z.CUST_NO) = TRIM(A.CUST_NO)    	" + BR
		+ "           AND    Z.LOAN_NO = A.LOAN_NO                	" + BR
		+ "           AND    Z.LOAN_SEQ = A.LOAN_SEQ              	" + BR
		+ "           AND    Z.JOB_DT  = '" + this.jobDt + "'     	" + BR
		+ "           AND    Z.DATA_DIV_CD  IN ('1') 				  " + BR
		+ "       )                                               " + BR
		+ "WHERE  A.CUST_NO||RTRIM(A.LOAN_NO)||RTRIM(A.LOAN_SEQ)  " + BR
		+ "       IN (SELECT X.CUST_NO||RTRIM(X.LOAN_NO)||RTRIM(X.LOAN_SEQ)" + BR
		+ "           FROM   EPLSADM.BT_KFB_LOAN_TRCHG_HIST X        " + BR
		+ "                 ,EPLSADM.BT_KFB_LOAN_TRCHG_BASE Y        " + BR
		+ "           WHERE  X.JOB_DT       = '" + this.jobDt + "'" + BR
		+ "           AND    X.PRGS_STAT_CD = '5'                 " + BR
		+ "           AND    TRIM(X.CUST_NO) = TRIM(A.CUST_NO)    " + BR
		+ "           AND    X.DATA_DIV_CD IN ('1')               		" + BR
		+ "           AND    Y.CUST_NO = X.CUST_NO)               " + BR;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 대출거래기본 정정 수정시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int insertLoanTrChgBase() throws Exception
	{
		String query
		= "INSERT INTO EPLSADM.BT_KFB_LOAN_TRCHG_BASE           " + BR
		+ "(                                                    " + BR
		+ "    CUST_NO											" + BR
		+ "    ,LOAN_NO											" + BR
		+ "    ,LOAN_SEQ										" + BR
		+ "    ,CUST_NM										 	" + BR
		+ "    ,JOB_CD										 	" + BR
		+ "    ,REG_DT										 	" + BR
		+ "    ,REG_DIV_CD										" + BR
		+ "    ,REG_AMT										 	" + BR
		+ "    ,LOAN_DT										 	" + BR
		+ "    ,BZIT_CD										 	" + BR
		+ "    ,VAR_DT										 	" + BR
		+ "    ,CHNG_AMT										" + BR
		+ "    ,HOUS_MRTG_LOAN_YN								" + BR
		+ "    ,FRST_REG_DT                                       " + BR
		+ "    ,FRST_REG_TM                                       " + BR
		+ "    ,FRST_REG_EMP_NO                                   " + BR
		+ "    ,LAST_PROC_DT                                      " + BR
		+ "    ,LAST_PROC_TM                                      " + BR
		+ "    ,LAST_PROC_EMP_NO                                  " + BR
		+ "    ,PRDT_LRGE_CLAS_CD								" + BR
		+ "    ,LOAN_MRTG_YN									" + BR
		+ "    ,FINC_CD										 	" + BR
		+ "    ,LOAN_DIV_CD										" + BR
		+ "    ,SPCL_BND_MO_ACNT_NO								" + BR
		+ "    ,PP_FINC_DIV_CD									" + BR
		+ "    ,CUST_NO_BF										 " + BR
		+ "    ,LOAN_NO_BF										 " + BR
		+ "    ,LOAN_SEQ_BF										 " + BR
		+ "    ,MRTG_SPEC_KIND                                   " + BR
		+ ")                                                      " + BR
		+ "SELECT A.CUST_NO                                         " + BR
		+ "      ,A.LOAN_NO                                         " + BR
		+ "      ,A.LOAN_SEQ                                        " + BR
		+ "      ,A.CUST_NM                                         " + BR
		+ "      ,A.JOB_CD                                          " + BR
		+ "      ,'" + this.jobDt + "' AS REG_DT                  " + BR
		+ "      ,A.REG_DIV_CD                                      " + BR
		+ "      ,A.REG_AMT                                         " + BR
		+ "      ,A.LOAN_DT                                         " + BR
		+ "      ,A.BZIT_CD                                         " + BR
		+ "      ,A.VAR_DT                                          " + BR
		+ "      ,A.CHNG_AMT                                        " + BR
		+ "      ,A.HOUS_MRTG_LOAN_YN                               " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')             " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'HH24MISS')             " + BR
		+ "      ,'" + this.empNo + "'                            " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')             " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'HH24MISS')             " + BR
		+ "      ,'" + this.empNo + "'                            " + BR
		+ "      ,A.PRDT_LRGE_CLAS_CD                               " + BR
		+ "      ,A.LOAN_MRTG_YN                                    " + BR
		+ "      ,A.FINC_CD                                         " + BR
		+ "      ,A.LOAN_DIV_CD										" + BR
		+ "      ,A.SPCL_BND_MO_ACNT_NO								" + BR
		+ "      ,A.PP_FINC_DIV_CD									" + BR
		+ "      ,A.CUST_NO_BF										 " + BR
		+ "      ,A.LOAN_NO_BF										 " + BR
		+ "      ,A.LOAN_SEQ_BF										 " + BR
		+ "      ,A.MRTG_SPEC_KIND                                   " + BR
		+ " FROM EPLSADM.BT_KFB_LOAN_TRCHG_HIST A                   " + BR
		+ "WHERE  JOB_DT       = '" + this.jobDt + "'             " + BR
		+ "AND    PRGS_STAT_CD = '5'                              " + BR
		//추가
		+ "AND    DATA_DIV_CD = '0'                              " + BR
		+ "AND    NOT EXISTS (SELECT 1                            " + BR
		+ "                   FROM   EPLSADM.BT_KFB_LOAN_TRCHG_BASE X" + BR
		+ "                   WHERE  TRIM(X.CUST_NO) = TRIM(A.CUST_NO)       " + BR
		+ "                     AND  TRIM(X.LOAN_NO)  = TRIM(A.LOAN_NO)       " + BR
		+ "                     AND  X.LOAN_SEQ = A.LOAN_SEQ)     " + BR;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			log.debug("EPLSADM.BT_KFB_LOAN_TRCHG_BASE insert CNT : " + cnt);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 대출거래 정정 기본 등록시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int updateCrdtBadCntrBase() throws Exception
	{
		String query
		= "UPDATE EPLSADM.BT_KFB_CRDT_BAD_BASE A                  " + BR
		+ "SET    (                                               " + BR
		+ "           A.REG_DIV_CD                                " + BR
		+ "          ,A.REG_RSN_CD                                " + BR
		+ "          ,A.RSN_DIV_CD                                " + BR
		+ "          ,A.CUST_TP_CD                                " + BR
		+ "          ,A.MTAL                                      " + BR
		+ "          ,A.CUST_NM                                   " + BR
		+ "          ,A.JOB_CD                                    " + BR
		+ "          ,A.BZIT_CD                                   " + BR
		+ "          ,A.SHOP_CD                                   " + BR
		+ "          ,A.BAD_OCCR_DT                               " + BR
		+ "          ,A.BAD_REG_DT                                " + BR
		+ "          ,A.CLOS_DT                                   " + BR
		+ "          ,A.REG_AMT                                   " + BR
		+ "          ,A.DLY_AMT                                   " + BR
		+ "          ,A.TRAN_SHOP                                 " + BR
		+ "          ,A.CORP_REG_NO                               " + BR
		+ "          ,A.CONT_DT                                   " + BR
		+ "          ,A.CLOS_DIV_CD                               " + BR
		+ "          ,A.LAST_PROC_DT                              " + BR
		+ "          ,A.LAST_PROC_TM                              " + BR
		+ "          ,A.LAST_PROC_EMP_NO                          " + BR
		+ "          ,A.PRE_WORK_OUT_SNCTAMT_FG                   " + BR
		+ "          ,A.LOAN_SEQ                                  " + BR
		+ "       )                                               " + BR
		+ "       =                                               " + BR
		+ "       (                                               " + BR
		+ "           SELECT Z.REG_DIV_CD                         " + BR
		+ "                 ,Z.REG_RSN_CD                         " + BR
		+ "                 ,Z.RSN_DIV_CD                         " + BR
		+ "                 ,Z.CUST_TP_CD                         " + BR
		+ "                 ,Z.MTAL                               " + BR
		+ "                 ,Z.CUST_NM                            " + BR
		+ "                 ,Z.JOB_CD                             " + BR
		+ "                 ,Z.BZIT_CD                            " + BR
		+ "                 ,Z.SHOP_CD                            " + BR
		+ "                 ,Z.BAD_OCCR_DT                        " + BR
		+ "                 ,Z.JOB_DT                             " + BR
		+ "                 ,Z.CLOS_DT                            " + BR
		+ "                 ,Z.REG_AMT                            " + BR
		+ "                 ,Z.DLY_AMT                            " + BR
		+ "                 ,Z.TRAN_SHOP                          " + BR
		+ "                 ,Z.CORP_REG_NO                        " + BR
		+ "                 ,Z.CONT_DT                            " + BR
		+ "                 ,Z.CLOS_DIV_CD                        " + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')  " + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'HH24MISS')    " + BR
		+ "                 ,'" + this.empNo + "'                 " + BR
		+ "                 ,Z.PRE_WORK_OUT_SNCTAMT_FG            " + BR
		+ "                 ,Z.LOAN_SEQ                           " + BR
		+ "           FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST Z  " + BR
		+ "           WHERE  TRIM(Z.CUST_NO)  = TRIM(A.CUST_NO)   " + BR
		+ "           AND    Z.LOAN_NO  = A.LOAN_NO               " + BR
		// + "           AND    Z.LOAN_SEQ = A.LOAN_SEQ              " + BR
		+ "           AND    Z.JOB_DT   = '" + this.jobDt + "'    " + BR
		+ "       )                                               " + BR
		+ "WHERE  (A.CUST_NO,A.LOAN_NO)                           " + BR
		+ "       IN (SELECT X.CUST_NO,X.LOAN_NO                  " + BR
		+ "           FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST X  " + BR
		+ "                 ,EPLSADM.BT_KFB_CRDT_BAD_BASE      Y  " + BR
		+ "           WHERE  X.JOB_DT       = '" + this.jobDt + "'" + BR
		+ "           AND    X.PRGS_STAT_CD = '5'                 " + BR
		+ "           AND    TRIM(X.CUST_NO) = TRIM(A.CUST_NO)    " + BR
		+ "           AND    X.LOAN_NO      = A.LOAN_NO           " + BR
		// + "           AND    X.LOAN_SEQ     = A.LOAN_SEQ        " + BR
		+ "           AND    TRIM(Y.CUST_NO) = TRIM(X.CUST_NO)     " + BR
		+ "           AND    Y.LOAN_NO      = X.LOAN_NO            " + BR
		// + "           AND    Y.LOAN_SEQ     = X.LOAN_SEQ)       " + BR;
/*
		+ "            UNION                                       " + BR
		+ "            SELECT X.CUST_NO,X.LOAN_NO                  " + BR
		+ "            FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST X  " + BR
		+ "                  ,EPLSADM.BT_KFB_CRDT_BAD_CNTR_ERR Z   " + BR
		+ "            WHERE  X.JOB_DT       = '" + this.jobDt + "'" + BR
		+ "            AND    X.PRGS_STAT_CD = '9'                 " + BR
		+ "            AND    X.CUST_NO      = A.CUST_NO           " + BR
		+ "            AND    X.LOAN_NO      = A.LOAN_NO           " + BR
		+ "            AND    X.JOB_DT        = Z.JOB_DT           " + BR
		+ "            AND    X.REG_BLCK_SNUM = Z.REG_BLCK_SNUM    " + BR
		+ "            AND    X.REG_SNUM      = Z.REG_SNUM         " + BR
		+ "            AND    X.DATA_SNUM     = Z.DATA_SNUM        " + BR
		+ "            AND    Z.ERR_CD        = '521'              " + BR
*/
		+ "            )                                           " ;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 신용불량집중기본 수정시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int updateCrdtBadCntrBaseFromModify() throws Exception
	{
		String query
		= "UPDATE EPLSADM.BT_KFB_CRDT_BAD_BASE A					    " + BR
		+ "SET    (													    " + BR
		+ "           A.RSN_DIV_CD									    " + BR
		+ "          ,A.REG_AMT										    " + BR
		+ "          ,A.DLY_AMT										    " + BR
		+ "          ,A.LAST_PROC_DT								    " + BR
		+ "          ,A.LAST_PROC_TM								    " + BR
		+ "          ,A.LAST_PROC_EMP_NO							    " + BR
		+ "       )													    " + BR
		+ "       =													    " + BR
		+ "       (														" + BR
		+ "					 SELECT 									" + BR
		+ "                  Z.AFT_RSN_DIV_CD							" + BR
		+ "                 ,Z.AFT_REG_AMT							    " + BR
		+ "                 ,Z.AFT_DLY_AMT								" + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')		" + BR
		+ "                 ,TO_CHAR(CURRENT_DATE, 'HH24MISS')		" + BR
		+ "                 ,'" + this.empNo + "'                		" + BR
		+ "           FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_MODI_HIST Z " + BR
		+ "           WHERE  TRIM(Z.AFT_CUST_NO)  = TRIM(A.CUST_NO)     " + BR
		+ "           AND    Z.BEF_LOAN_NO  = A.LOAN_NO					" + BR
		+ "           AND    Z.BEF_LOAN_SEQ = A.LOAN_SEQ              	" + BR
		+ "           AND    Z.JOB_DT   = '" + this.jobDt + "'			" + BR
		+ "       )                                               		" + BR
		+ "WHERE  (A.CUST_NO,A.LOAN_NO,A.LOAN_SEQ)                		" + BR
		+ "       IN (SELECT X.AFT_CUST_NO,X.BEF_LOAN_NO,X.BEF_LOAN_SEQ " + BR
		+ "           FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_MODI_HIST X " + BR
		+ "                 ,EPLSADM.BT_KFB_CRDT_BAD_BASE      Y  		" + BR
		+ "           WHERE  X.JOB_DT       = '" + this.jobDt + "'		" + BR
		+ "           AND    X.PRGS_STAT_CD = '5'                       " + BR
		+ "           AND    TRIM(Y.CUST_NO) = TRIM(X.AFT_CUST_NO)		" + BR
		+ "           AND    Y.LOAN_NO      = X.BEF_LOAN_NO           	" + BR
		+ "           AND    Y.LOAN_SEQ     = X.BEF_LOAN_SEQ			" + BR
		+ "					 AND    X.AFT_CUST_NO  = A.CUST_NO          " + BR
		+ "           AND    X.BEF_LOAN_NO  = A.LOAN_NO           		" + BR
		+ "           AND    X.BEF_LOAN_SEQ = A.LOAN_SEQ  )				" + BR;


		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 신용불량집중기본 수정시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int insertCrdtBadCntrBase() throws Exception
	{
		String query
		= "INSERT INTO EPLSADM.BT_KFB_CRDT_BAD_BASE                         " + BR
		+ "(                                                                " + BR
		+ "     LOAN_NO                                                     " + BR
		+ "    ,LOAN_SEQ                                                    " + BR
		+ "    ,REG_DIV_CD                                                  " + BR
		+ "    ,REG_RSN_CD                                                  " + BR
		+ "    ,CUST_NO                                                     " + BR
		+ "    ,RSN_DIV_CD                                                  " + BR
		+ "    ,CUST_TP_CD                                                  " + BR
		+ "    ,MTAL                                                        " + BR
		+ "    ,CUST_NM                                                     " + BR
		+ "    ,JOB_CD                                                      " + BR
		+ "    ,BZIT_CD                                                     " + BR
		+ "    ,SHOP_CD                                                     " + BR
		+ "    ,BAD_OCCR_DT                                                 " + BR
		+ "    ,BAD_REG_DT                                                  " + BR
		+ "    ,CLOS_DT                                                     " + BR
		+ "    ,REG_AMT                                                     " + BR
		+ "    ,DLY_AMT                                                     " + BR
		+ "    ,TRAN_SHOP                                                   " + BR
		+ "    ,CORP_REG_NO                                                 " + BR
		+ "    ,CONT_DT                                                     " + BR
		+ "    ,CLOS_DIV_CD                                                 " + BR
		+ "    ,FRST_REG_DT                                                 " + BR
		+ "    ,FRST_REG_TM                                                 " + BR
		+ "    ,FRST_REG_EMP_NO                                             " + BR
		+ "    ,LAST_PROC_DT                                                " + BR
		+ "    ,LAST_PROC_TM                                                " + BR
		+ "    ,LAST_PROC_EMP_NO                                            " + BR
		+ "    ,PRE_WORK_OUT_SNCTAMT_FG                                            " + BR
		+ ")                                                                " + BR
		+ "SELECT LOAN_NO                                                   " + BR
		+ "      ,LOAN_SEQ                                                  " + BR
		+ "      ,REG_DIV_CD                                                " + BR
		+ "      ,REG_RSN_CD                                                " + BR
		+ "      ,CUST_NO                                                   " + BR
		+ "      ,RSN_DIV_CD                                                " + BR
		+ "      ,CUST_TP_CD                                                " + BR
		+ "      ,MTAL                                                      " + BR
		+ "      ,CUST_NM                                                   " + BR
		+ "      ,JOB_CD                                                    " + BR
		+ "      ,BZIT_CD                                                   " + BR
		+ "      ,SHOP_CD                                                   " + BR
		+ "      ,BAD_OCCR_DT                                               " + BR
		+ "      ,'" + this.jobDt + "'                                      " + BR
		+ "      ,CLOS_DT                                                   " + BR
		+ "      ,REG_AMT                                                   " + BR
		+ "      ,DLY_AMT                                                   " + BR
		+ "      ,TRAN_SHOP                                                 " + BR
		+ "      ,CORP_REG_NO                                               " + BR
		+ "      ,CONT_DT                                                   " + BR
		+ "      ,CLOS_DIV_CD                                               " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')                       " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'HH24MISS')                         " + BR
		+ "      ,'" + this.empNo + "'                                      " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'YYYYMMDD')                       " + BR
		+ "      ,TO_CHAR(CURRENT_DATE, 'HH24MISS')                         " + BR
		+ "      ,'" + this.empNo + "'                                      " + BR
		+ "      ,PRE_WORK_OUT_SNCTAMT_FG                                   " + BR
		+ "FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST A                       " + BR
		+ "WHERE  JOB_DT = '" + this.jobDt + "'                             " + BR
		+ "AND    (    (PRGS_STAT_CD = '5'                                  " + BR
		+ "            AND NOT EXISTS (SELECT 1                             " + BR
		+ "                            FROM   EPLSADM.BT_KFB_CRDT_BAD_BASE X" + BR
		+ "                            WHERE  TRIM(X.CUST_NO)  = TRIM(A.CUST_NO)        " + BR
		+ "                            AND    X.LOAN_NO  = A.LOAN_NO))      " + BR
		// + "                            AND    X.LOAN_SEQ = A.LOAN_SEQ))     " + BR
		/* 20170906 박영민 중복오류 무슨의미 인지 몰라서 주석 처리
		+ "       OR   (PRGS_STAT_CD = '9'                                  " + BR
		+ "            AND EXISTS (SELECT 1                                 " + BR
		+ "                        FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_ERR X" + BR
		+ "                        WHERE  X.JOB_DT        = A.JOB_DT        " + BR
		+ "                        AND    X.REG_BLCK_SNUM = A.REG_BLCK_SNUM " + BR
		+ "                        AND    X.REG_SNUM      = A.REG_SNUM      " + BR
		+ "                        AND    X.DATA_SNUM     = A.DATA_SNUM     " + BR
		+ "                        AND    X.ERR_CD        = '521')) )       " + BR;
		*/
		+ "         )                                                       " + BR;
        /*
		+ "            AND NOT EXISTS (SELECT 1                             " + BR
		+ "                            FROM   EPLSADM.BT_KFB_CRDT_BAD_BASE X" + BR
		+ "                            WHERE  X.CUST_NO  = A.CUST_NO        " + BR
		+ "                            AND    X.LOAN_NO  = A.LOAN_NO)))      " ;
        */

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 신용불량집중기본 등록시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private int deleteCrdtBadCntrBase() throws Exception
	{
		String query
		= "DELETE                                                  " + BR
		+ "FROM   EPLSADM.BT_KFB_CRDT_BAD_BASE                     " + BR
		+ "WHERE  (CUST_NO,LOAN_NO,LOAN_SEQ)                       " + BR
		+ "       IN (SELECT CUST_NO                               " + BR
		+ "                 ,LOAN_NO                               " + BR
		 + "                ,LOAN_SEQ                             " + BR
		+ "           FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST     " + BR
		+ "           WHERE  JOB_DT       = '" + this.jobDt + "'   " + BR
		+ "           AND    PRGS_STAT_CD = '5'                    " + BR
		+ "           AND    CLOS_DT      <> ''                    " + BR
		+ "           AND    DLY_AMT      = 0                      " + BR
		+ "           UNION                                        " + BR
		+ "           SELECT H.CUST_NO                             " + BR
		+ "                 ,H.LOAN_NO                             " + BR
	    + "                 ,H.LOAN_SEQ                            " + BR
		+ "           FROM   EPLSADM.BT_KFB_CRDT_BAD_CNTR_ERR  E   " + BR
		+ "                 ,EPLSADM.BT_KFB_CRDT_BAD_CNTR_HIST H   " + BR
		+ "           WHERE  E.JOB_DT        = '" + this.jobDt + "'" + BR
		+ "           AND    E.ERR_CD        = '522'               " + BR
		+ "           AND    H.JOB_DT        = E.JOB_DT            " + BR
		+ "           AND    H.REG_BLCK_SNUM = E.REG_BLCK_SNUM     " + BR
		+ "           AND    H.REG_SNUM      = E.REG_SNUM          " + BR
		+ "           AND    H.DATA_SNUM     = E.DATA_SNUM)        " + BR;

		Statement stmt = null;
		try
		{
			log.debug(query);
			stmt = con.createStatement();
			int cnt = stmt.executeUpdate(query);
			return cnt;
		}
		catch(Exception e)
		{
			log.error(e.getMessage());
			throw new Exception("은행연합회 신용불량집중기본 삭제시 오류가 발생했습니다.");
		}
		finally
		{
			this.closeStatement(stmt);
		}
	}

	private void closeStatement(Statement stmt)
    {
        try
		{
            if (stmt != null)
            {
                stmt.close();
                stmt = null;
            }
        }
        catch(Exception e)
		{
            e.printStackTrace();
        }
    }

	private void closeResultSet(ResultSet rs)
    {
        try
		{
            if (rs != null)
            {
                rs.close();
                rs = null;
            }
        }
        catch (Exception e)
		{
            e.printStackTrace();
        }
    }
}
