package hanalife.b.cn.ui.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.SmsDlyrDescMapper;
import hanalife.b.cn.ui.mapper.SmsTotDlyrMapper;
import hanalife.b.cn.ui.mapper.SmsTxtMngMapper;
import hanalife.b.cn.ui.mapper.dto.SmsTotDlyrDSSDDO01;
import hanalife.b.cn.ui.mapper.dto.SmsTotDlyrDSSDDO02;
import hanalife.b.cn.ui.mapper.dto.SmsTotDlyrDSSMDO01;
import hanalife.b.cn.ui.service.BCNUIM03Service;
import hanalife.b.cn.ui.vo.BCNUIM03DSSDDO01VO;
import hanalife.b.cn.ui.vo.BCNUIM03DSSDDO03VO;
import hanalife.b.cn.ui.vo.BCNUIM03DSSMDO01VO;
import hanalife.b.cn.ui.vo.BCNUIM03InVO;
import hanalife.b.cn.ui.vo.BCNUIM03OutVO;
import hanalife.b.cn.ui.vo.BCNUIP02DSSDDO02VO;
import hanalife.c.bc.cc.mapper.UserMngMapper;
import hanalife.c.cm.sp.service.callSpService;
import hanalife.c.cm.sp.vo.sendSmsVO;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.BtSmsDlvrDescDTO;
import hanalife.c.co.mapper.dto.BtSmsTxtMngDTO;
import hanalife.c.co.util.DateUtil;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BLMLMM04ServiceImpl.java Class
 * 클래스설명   : todo1 (todo0) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70326 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIM01S01 : 연체리스트 목록조회
 * </pre>
 */
@Service("BCNUIM03Service")
public class BCNUIM03ServiceImpl implements BCNUIM03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM03ServiceImpl.class);
	@Autowired
	callSpService callSpService;

	@Autowired
	SmsDlyrDescMapper smsDlyrDescMapper;

	@Autowired
	SmsTotDlyrMapper smsTotDlyrMapper;

	@Autowired
	SmsTxtMngMapper smsTxtMngMapper;

	@Autowired
	UserMngMapper userMngMapper;

	/**
	* <pre>
	* 메소드명      : getBCNUIM03S01
	* 작성일자      : 2023. 4. 20.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 발송리스트 조회
	* 메소드인수1   : BCNUIM03InVO
	* 메소드리턴값  : BCNUIM03OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIM03OutVO getBCNUIM03S01(BCNUIM03InVO inVo) throws Exception {
		BCNUIM03OutVO resultVo = new BCNUIM03OutVO();

		// DTO, VO 생성
		SmsTotDlyrDSSMDO01 inDto = new SmsTotDlyrDSSMDO01();
		BCNUIM03DSSMDO01VO sourceVo = inVo.getBCNUIM03DSSMDO01VO();

		// VO to DTO
		inDto.setOrgCd(sourceVo.getOrgCd());                     /** 관리부서 */
		inDto.setEmpNo(sourceVo.getEmpNo());                     /** 담당자사번 */
		inDto.setProdLrgeClas(sourceVo.getProdLrgeClas());       /** 상품대 */
		inDto.setProdMidClas(sourceVo.getProdMidClas());         /** 상품중 */
		inDto.setDdcntSt(sourceVo.getDdcntSt());                 /** 연체회차 From */
		inDto.setDdcntEd(sourceVo.getDdcntEd());                 /** 연체회차 To */
		inDto.setSetldtSt(sourceVo.getSetldtSt());               /** 결제일자 From */
		inDto.setSetldtEd(sourceVo.getSetldtEd());               /** 결제일자 To */
		inDto.setLoanNo(sourceVo.getLoanNo());                   /** 대출번호 */
		inDto.setLoanSeq(sourceVo.getLoanSeq());                 /** 대출순번 */
		inDto.setChkCtdtbad(sourceVo.getChkCtdtbad());           /** 신용불량 여부 */
		inDto.setChkLeglactn(sourceVo.getChkLeglactn());         /** 법조치여부 */
		inDto.setDueMethCd(sourceVo.getDueMethCd());             /** 납입방법 코드 */
		inDto.setClosdtSt(sourceVo.getClosdtSt());               /** 만기일자 From */
		inDto.setClosdtEd(sourceVo.getClosdtEd());               /** 만기일자 To */
		inDto.setRecvTelNo(sourceVo.getRecvTelNo());             /** 수신전화번호 */
		inDto.setTxtRecvFg(sourceVo.getTxtRecvFg());             /** 문자수신 여부 */
		inDto.setSmClasDiv(sourceVo.getSmClasDiv());             /** 상품소 */
		inDto.setDlyTot1(sourceVo.getDlyTot1());                 /** 대상금액 From */
		inDto.setDlyTot2(sourceVo.getDlyTot2());                 /** 대상금액 To */
		inDto.setDlvrDiv(sourceVo.getDlvrDiv());                 /** 발송구분 */
		inDto.setAskDiv(sourceVo.getAskDiv());                   /** 청구방법 */
		inDto.setDlyDiv(sourceVo.getDlyDiv());                   /** 연체구분 */
		inDto.setCustTpCd(sourceVo.getCustTpCd());               /** 고객구분 */

		// SMS 일괄전송 리스트 조회
		List<SmsTotDlyrDSSDDO01> sourceList = smsTotDlyrMapper.selectSmsTotDlyr(inDto);
		List<BCNUIM03DSSDDO01VO> targetList = new ArrayList<BCNUIM03DSSDDO01VO>();

		for(SmsTotDlyrDSSDDO01 source : sourceList) {
			BCNUIM03DSSDDO01VO target = new BCNUIM03DSSDDO01VO();
			target.setChkFlg(source.getChkFlg());                       /** 체크여부 */
			target.setLoanNo(source.getLoanNo());                       /** 대출번호 */
			target.setLoanSeq(source.getLoanSeq());                     /** 대출순번 */
			target.setContManNo(source.getContManNo());                 /** 고객번호 */
			target.setMngDeptCd(source.getMngDeptCd());                 /** 관리부서 */
			target.setCustNm(source.getCustNm());                       /** 고객명 */
			target.setLoanRelCd(source.getLoanRelCd());                 /** 관계구분코드*/
			target.setLoanRelNm(source.getLoanRelNm());                 /** 관계구분명 */
			target.setMobile(source.getMobile());                       /** 전화번호 */
			target.setDueMeth(source.getDueMeth());                     /** 납입방법 */
			target.setThmmComgTims(source.getThmmComgTims());           /** 도래회차 */
			target.setDlyTcnt(source.getDlyTcnt());                     /** 연체회차 */
			target.setDlyTot(source.getDlyTot());                       /** 연체금액 */
			target.setDfee(source.getDfee());                           /** 연체료 */
			target.setSetlDd(source.getSetlDd());                       /** 결제일 */
			target.setEprtDt(source.getEprtDt());                       /** 만기일자 */
			target.setLoanPamtRamt(source.getLoanPamtRamt());           /** 대출원금잔액 */
			target.setLoanStatNm(source.getLoanStatNm());               /** 대출상태 */
			target.setBndStatNm(source.getBndStatNm());                 /** 채권상태 */
			target.setPrdtNm(source.getPrdtNm());                       /** 상품명 */
			target.setBndDivsEmpNm(source.getBndDivsEmpNm());           /** 채권담당자 */
			target.setDlyPamt(source.getDlyPamt());                     /** 연체원금 */
			target.setDlyInt(source.getDlyInt());                       /** 연체이자 */
			target.setLoanDt(source.getLoanDt());                       /** 대출일자 */
			target.setLoanTerm(source.getLoanTerm());                   /** 대출기간 */
			target.setDlyDdcnt(source.getDlyDdcnt());                   /** 연체일수 */
			target.setClasNm(source.getClasNm());                       /** 상품분류 - 상품 */
			target.setCustTpCd(source.getCustTpCd());                   /** 고객구분 */
			target.setLeglCountRamt(source.getLeglCountRamt());         /** 법비용 */
			target.setSumDlyAmt(source.getSumDlyAmt());                 /** 총연체금액 */
			target.setUnrcvRamt(source.getUnrcvRamt());                 /** 인지대 */
			target.setDlyAmt(source.getDlyAmt());                       /** 연체금액 */
			target.setLeglActnCostRamt(source.getLeglActnCostRamt());   /** 법적조치 비용잔액 */
			target.setUnrcvAmt(source.getUnrcvAmt());                   /** 미수금액 */
			target.setUncomgAmt(source.getUncomgAmt());                 /** 미도래금액 */
			target.setBfDlyAmt(source.getBfDlyAmt());                   /** 이전 연체금액 */
			target.setThmmComgAmt(source.getThmmComgAmt());             /** 도래금액 */
			target.setThmmComgDt(source.getThmmComgDt());               /** 도래일자 */
			target.setRcntSetlDt(source.getRcntSetlDt());               /** 최근결제일 */
			target.setImgAcntNo(source.getImgAcntNo());                 /** 가상계좌번호 */
			target.setExamJudgCd(source.getExamJudgCd());               /** 심사판정코드 */
			target.setCrdtStatNm(source.getCrdtStatNm());               /** 신용상태코드 */
			target.setLeglActsStatNm(source.getLeglActsStatNm());       /** 법적조치상태코드 */
			target.setRmbrFrmlNm(source.getRmbrFrmlNm());               /** 상환방식코드 */
			target.setLnDivsEmpNm(source.getLnDivsEmpNm());             /** 여신담당자코드 */
			target.setMngPlcDivNm(source.getMngPlcDivNm());             /** 관리처구분코드 */
			target.setReprTelNo(source.getReprTelNo());                 /** 대표전화 */
			target.setRlStrmDlyOccrDt(source.getRlStrmDlyOccrDt());     /** 연체발생날짜 */
			target.setCustTpNm(source.getCustTpNm());                   /** 고객구분명 */
			target.setCustAddr(source.getCustAddr());                   /** 고객주소 */

			targetList.add(target);
		}
		resultVo.setListBCNUIM03DSSDDO01(targetList);

		return resultVo;
	}

	/**
	* <pre>
	* 메소드명      : getBCNUIM03S03
	* 작성일자      : 2023. 4. 20.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 공통 메세지, 내 메세지 목록 조회
	* 메소드인수1   : BCNUIM03InVO
	* 메소드리턴값  : BCNUIM03OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIM03OutVO getBCNUIM03S03(BCNUIM03InVO inVO) throws Exception {

		/** 메세지목록 결과값 객체 생성 */
		BCNUIM03OutVO resultVo = new BCNUIM03OutVO();

		/** 공통 메세지 조회 */
		List<BCNUIP02DSSDDO02VO> resultList = new ArrayList<BCNUIP02DSSDDO02VO>();
		List<SmsTotDlyrDSSDDO02> sourceList = smsTotDlyrMapper.searchComMsg();

		for (SmsTotDlyrDSSDDO02 sourceIO : sourceList) {
			BCNUIP02DSSDDO02VO targetIO = new BCNUIP02DSSDDO02VO();
			targetIO.setEmpNo(sourceIO.getEmpNo());                  /** 담당자 사번 */
			targetIO.setSeq(sourceIO.getSeq());                      /** 메세지 순번 */
			targetIO.setCntn(sourceIO.getCntn());                    /** 메세지 내용 */
			targetIO.setProcDt(sourceIO.getProcDt());                /** 실행일자 */
			targetIO.setSndTelNo(sourceIO.getSndTelNo());          	 /** 발신자번호 */
			targetIO.setMsgTitleCtt(sourceIO.getMsgTitleCtt());		 /** 메세지 제목 */
			resultList.add(targetIO);
		}
		resultVo.setListBCNUIM03DSSDDO02(resultList);

		/** 내 메세지 조회 */
		BtSmsTxtMngDTO paramVo = new BtSmsTxtMngDTO();
		List<BCNUIM03DSSDDO03VO> resultList2 = new ArrayList<BCNUIM03DSSDDO03VO>();
		/** VO to DTO */
		paramVo.setEmpNo(inVO.getBCNUIM03DSSMDO01VO().getLogInEmpNo());
		List<BtSmsTxtMngDTO> sourceList2 = smsTxtMngMapper.searchSmsTxtMng(paramVo);

		for (BtSmsTxtMngDTO sourceIO : sourceList2) {
			BCNUIM03DSSDDO03VO targetIO = new BCNUIM03DSSDDO03VO();
			targetIO.setEmpNo(sourceIO.getEmpNo());                  /** 담당자 사번 */
			targetIO.setSeq(sourceIO.getSeq());                      /** 메세지 순번 */
			targetIO.setCntn(sourceIO.getCntn());                    /** 메세지 내용 */
			targetIO.setProcDt(sourceIO.getProcDt());                /** 실행일자 */
			targetIO.setDlvrObjCd(sourceIO.getDlvrObjCd());          /** 발송구분코드 */
			targetIO.setDlvrDeptCd(sourceIO.getDlvrDeptCd());        /** 관리부서코드 */
			resultList2.add(targetIO);
		}

		resultVo.setListBCNUIM03DSSDDO03(resultList2);


		return resultVo;
	}

	/**
	* <pre>
	* 메소드명      : registerBCNUIM03I01
	* 작성일자      : 2023. 4. 20.
	* 작성자(author): 70320 jaeho.jang
	* 설명          :
	* 메소드인수1   :
	* 메소드리턴값  :
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIM03OutVO registerBCNUIM03I01(BCNUIM03InVO inVo) throws Exception {
		BCNUIM03OutVO outVo = new BCNUIM03OutVO();
		String sendFlg = inVo.getBCNUIM03DSSMDO02VO().getSendFlg();
		String rsrvSndFlg = inVo.getBCNUIM03DSSMDO02VO().getRsrvSndFlg();

		// 내정보 저장 체크시 문자관리 INSERT TO-BE 미사용
//		if("1".equals(sendFlg)) {
//			BtSmsTxtMngDTO inDto = new BtSmsTxtMngDTO();
//			inDto.setEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//			inDto.setCntn(inVo.getBCNUIP02DSSDDO03().getCntn());
//			inDto.setProcDt(inVo.getBCNUIP02DSSDDO03().getProcDt());
//			inDto.setFrstRegEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//			inDto.setLastProcEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//			smsTxtMngMapper.insertSmsTxtMng(inDto);
//		}
		// 일괄저장 실패, 저장 카운트

		// SMS 전송 서비스 호출
		int succCnt = 0;
		int errCnt = 0;

		List<BCNUIM03DSSDDO01VO> listBCNUIM03DSSDDO01VO = inVo.getListBCNUIM03DSSDDO01VO();
		for (BCNUIM03DSSDDO01VO targetVO : listBCNUIM03DSSDDO01VO) {
			if(!"1".equals(targetVO.getChkFlg())) {
				continue;
			}
			sendSmsVO sendVo = new sendSmsVO();
			sendSmsVO returnVo;
			sendVo.setVfvSmsMsgCd(inVo.getBCNUIM03DSSDDO03VO().getSeq());					/** EAGLE.SMS_CD_MAST@D_BEST_HE테이블의 SMS_CD */
			//sendVo.setVfvSndTelNo(inVo.getBCNUIP02DSSDDO01().getRspnTelNo()); 			/** 송신자전화번호 */
			sendVo.setVfvJgno(new BigDecimal(targetVO.getLoanNo())); 						/** 대출번호 */
			sendVo.setVfvJhno(targetVO.getMobile());										/** 수신자전화번호 */
			sendVo.setVfvGgno(targetVO.getContManNo());										/** 고객번호 */
			sendVo.setVfvZCreateBy(inVo.getBCNUIM03DSSDDO03VO().getLogInEmpNo());			/** 로그인 사용자 */

			sendVo.setVfvBatchYn("N");
			if("1".equals(rsrvSndFlg)) {
				sendVo.setVfvReqdate(inVo.getBCNUIM03DSSMDO02VO().getRsrvSndTime());		/** 전송시간 */
			}
			// 구분별로 sms 파라미터 셋팅 작업
			String msg = this.setSmsParams(sendVo, targetVO, inVo.getBCNUIM03DSSDDO03VO().getSeq(), inVo.getBCNUIM03DSSDDO03VO().getCntn());

			String sendText = msg;
			// SMS 모듈 호출
			callSpService.sendSms(sendVo);

			if(Constants.SMS_RESULT_CODE.equals(sendVo.getVfvRtnCd())) {
				succCnt++;
			} else {
				errCnt++;
			}

			// 성공여부에 따라 발송내역 등록처리
			BtSmsDlvrDescDTO inDto = new BtSmsDlvrDescDTO();

			inDto.setDlvrDt(DateUtil.getServerDate(DateUtil.YYYYMMDD));                          /** 발송_일자 */
			inDto.setMngDeptCd(inVo.getBCNUIM03DSSDDO03VO().getDlvrDeptCd());                    /** 관리_부서_코드 */
			inDto.setDlvrEmpNo(inVo.getBCNUIM03DSSDDO03VO().getLogInEmpNo());                    /** 발송_사원번호 */
			inDto.setLoanNo(targetVO.getLoanNo());                                               /** 대출_번호 */
			inDto.setLoanSeq(targetVO.getLoanSeq());                                             /** 대출_순번 */
			inDto.setCustNo(targetVO.getContManNo());                                            /** 고객번호 */
			inDto.setSendDiv(rsrvSndFlg);                                                        /** 예약전송여부 */
			if("1".equals(rsrvSndFlg)) {
				inDto.setSendDttm(inVo.getBCNUIM03DSSMDO02VO().getRsrvSndTime());                /** 예약전송시각 */
			}
			inDto.setRecvTelNo(targetVO.getMobile());                                            /** 수신자번호 */
			inDto.setRspnTelNo(inVo.getBCNUIM03DSSMDO02VO().getSendTelNo());                     /** 발신자번호 */
			inDto.setSendTxt(sendText);                                                          /** 전송문구 */

			String sendRefKey = "";
			if(Constants.SMS_RESULT_CODE.equals(sendVo.getVfvRtnCd())) {
				String[] rtnCtt = sendVo.getVfvRtnCtt().split(":");
				sendRefKey = rtnCtt[1];
			}
			inDto.setSendRefKey(sendRefKey);
			inDto.setSendId(inVo.getBCNUIM03DSSMDO02VO().getRsrvSndTime().substring(0, 6));      /** 전송id */
			inDto.setDlvrObjCd(inVo.getBCNUIM03DSSDDO03VO().getDlvrObjCd());                     /** 발송구분코드 */
			inDto.setDlvrDeptCd(inVo.getBCNUIM03DSSDDO03VO().getDlvrDeptCd());                   /** 관리부서코드 */
			inDto.setFrstRegEmpNo(inVo.getBCNUIM03DSSDDO03VO().getLogInEmpNo());                 /** 로그인사번 */
			inDto.setLastProcEmpNo(inVo.getBCNUIM03DSSDDO03VO().getLogInEmpNo());                /** 로그인사번 */
			inDto.setSmsSendErrCd(sendVo.getVfvRtnCd());										 /** 결과코드 0000: 정상 그외 에러코드 */

			smsDlyrDescMapper.insertSmsDlyrDesc(inDto);

		}
		StringBuffer returnMsg = new StringBuffer();
		returnMsg.append("SMS 발송내역\n");
		returnMsg.append("\n");
		returnMsg.append("성공: " + succCnt + "건 \n");
		returnMsg.append("실패: " + errCnt + "건 \n");
		outVo.setRsltCntn(returnMsg.toString());

		return outVo;
	}

	/**
	* <pre>
	* 메소드명      : setSmsParams
	* 작성일자      : 2023. 4. 28.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : sendSmsVO에 파라미터 값을 설정함
	* 메소드인수    : sendSmsVO, BCNUIM03DSSDDO01VO, seq
	* 메소드리턴값  : void
	* 예외처리      : Exception
	* </pre>
	*/
	private String setSmsParams(sendSmsVO smsVo, BCNUIM03DSSDDO01VO paramVo, String seq, String msg) {

		if("00410".equals(seq)) {				/** 00410: 자유형식 양식 seq 번호 */
			smsVo.setVfvSmsMsgCtt(msg);			/** 사용자 입력 메세지 */
		} else if("106".equals(seq)) {
			// 예시로 생성한 코드 구분별로 작성
			// smsVo.setVfvParam01(paramVo.getBfDlyAmt());
			// msg.replace("%01", "test");
		}
		return msg;
	}

}
