package hanalife.b.cn.ui.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.CntcIpssManReadMapper;
import hanalife.b.cn.ui.mapper.dto.CntcIpssManReadDSSDDODTO;
import hanalife.b.cn.ui.mapper.dto.CntcIpssManReadDSSMDODTO;
import hanalife.b.cn.ui.service.BCNUIM06Service;
import hanalife.b.cn.ui.vo.BCNUIM06DSSDDOVO;
import hanalife.b.cn.ui.vo.BCNUIM06S01InVO;
import hanalife.b.cn.ui.vo.BCNUIM06S01OutVO;


/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRD0101ServiceImpl.java Class
 * 클래스설명   : todo1 (BCNUIM06) Service Implements
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70324 / 이웅희 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIM06S01 : 연락불능자목록조회
 * </pre>
 */
@Service("BCNUIM06Service")
public class BCNUIM06ServiceImpl implements BCNUIM06Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM06ServiceImpl.class);

	@Autowired
    private CntcIpssManReadMapper cntcIpssManReadMapper;

	/**
	 * <p>메소드명      : getBCNUIM06S01 : 연락불능자목록조회</p>
	 * <p>작성일자      : 2023. 3. 6.
	 * <p>작성자(author): 70324 / 이웅희
	 * <p>설명          : 연락불능자목록을 조회 한다.</p>
	 * <p>메소드인수    : BCNUIM06S01InVO </p>
	 * <p>메소드리턴값  : BCNUIM06S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public BCNUIM06S01OutVO getBCNUIM06S01(BCNUIM06S01InVO inVo) throws Exception {

        /** 연락불능자목록조회 서비스 결과값 객체 생성 */
		BCNUIM06S01OutVO resultVo = new BCNUIM06S01OutVO();

        /** 연락불능자목록조회 조건 입력값 객체 생성 및 대입 수행 */
		CntcIpssManReadDSSMDODTO dsSndiDto = new CntcIpssManReadDSSMDODTO();

		dsSndiDto.setMngDeptCd(inVo.getBCNUIM06DSSMDOVO().getMngDeptCd());             // 관리부서코드
		dsSndiDto.setProdLrgeClasCd(inVo.getBCNUIM06DSSMDOVO().getProdLrgeClasCd());   // 상품대분류코드
		dsSndiDto.setProdMidClasCd(inVo.getBCNUIM06DSSMDOVO().getProdMidClasCd());     // 상품중분류코드
		dsSndiDto.setCntSt(inVo.getBCNUIM06DSSMDOVO().getCntSt());                     // 연체회차 시작
		dsSndiDto.setCntEd(inVo.getBCNUIM06DSSMDOVO().getCntEd());                     // 연체회차 종료
		dsSndiDto.setEmpNo(inVo.getBCNUIM06DSSMDOVO().getEmpNo());                     // 상담직원번호
		dsSndiDto.setCntcStatCd(inVo.getBCNUIM06DSSMDOVO().getCntcStatCd());           // 연락상태

        /** 연락불능자목록조회 쿼리 Mapper 호출 수행 */
        List<CntcIpssManReadDSSDDODTO> resultDTO = cntcIpssManReadMapper.searchList(dsSndiDto);

        /** 연락불능자목록조회 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BCNUIM06DSSDDOVO> resultList = new ArrayList<BCNUIM06DSSDDOVO>();

        for (CntcIpssManReadDSSDDODTO sourceIO : resultDTO) {
            /** 연락불능자목록조회 VO에 조회된 Mapper DTO 값을 대입 */
        	BCNUIM06DSSDDOVO targetIO = new BCNUIM06DSSDDOVO();

            targetIO.setLoanNo(sourceIO.getLoanNo());              // 대출번호
            targetIO.setPrdtNm(sourceIO.getPrdtNm());              // 상품명
            targetIO.setCustNo(sourceIO.getCustNo());              // 고객번호
            targetIO.setCustNm(sourceIO.getCustNm());              // 고객명
            targetIO.setLoanRelNm(sourceIO.getLoanRelNm());        // 관계
            targetIO.setDlyTcnt(sourceIO.getDlyTcnt());            // 연체회차
            targetIO.setDlyAmt(sourceIO.getDlyAmt());              // 연체금액
            targetIO.setLoanAmt(sourceIO.getLoanAmt());            // 대출잔액
            targetIO.setRegDttm(sourceIO.getRegDttm());            // 통화일자
            targetIO.setMngDeptNm(sourceIO.getMngDeptNm());        // 관리부서
            targetIO.setLoanSeq(sourceIO.getLoanSeq());            // 대출일련번호
            targetIO.setDivsManEmpNm(sourceIO.getDivsManEmpNm());  // 상담직원명
            targetIO.setCustNoTran(sourceIO.getCustNoTran());      // 거래처명
            targetIO.setCntcPlcDivCd(sourceIO.getCntcPlcDivCd());  // 연락처구분
            targetIO.setCntcStatCd(sourceIO.getCntcStatCd());      // 연락상태

            /** 연락불능자목록조회 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 연체현황목록조회 화면 출력 결과값 대입 */
        resultVo.setBCNUIM06DSSDDOVO(resultList);

		return resultVo;

	}

}
