package hanalife.b.cn.ui.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.CustMainGuidMngMapper;
import hanalife.b.cn.ui.mapper.dto.CustMainGuidCustStatInfoPopUpDSSDDODTO;
import hanalife.b.cn.ui.service.BCNUIP01Service;
import hanalife.b.cn.ui.vo.BCNUIP01DSSDDO01SENDVO;
import hanalife.b.cn.ui.vo.BCNUIP01DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIP01S01InVO;
import hanalife.b.cn.ui.vo.BCNUIP01S01OutVO;


/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRD0101ServiceImpl.java Class
 * 클래스설명   : 고개정보상태 (BCNUIP01) Service Implements
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIP01S01 : 고개정보상태 목록조회
 *              registerBCNUIP01I01 : 고개정보상태 등록
 *              modifyBCNUIP01U01 : 고개정보상태 수정
 * </pre>
 */
@Service("BCNUIP01Service")
public class BCNUIP01ServiceImpl implements BCNUIP01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIP01ServiceImpl.class);

	@Autowired
	CustMainGuidMngMapper mapper;


	/**
	* <pre>
	* 메소드명      : getBCNUIP01S01
	* 작성일자      : 2023. 3. 28.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 고개정보상태 목록조회
	* 메소드인수1   : BCNUIP01S01InVO
	* 메소드리턴값  : BCNUIP01S01OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP01S01OutVO getBCNUIP01S01(BCNUIP01S01InVO inVo) throws Exception {
		// 리턴값, 초기 VO 설정
		BCNUIP01S01OutVO outVo = new BCNUIP01S01OutVO();
		List<BCNUIP01DSSDDO01SENDVO> listBCNUIP01DSSDDO01SENDVO = new ArrayList();
		BCNUIP01DSSMDOVO vo = inVo.getBCNUIP01DSSMDOVO();

		// 조회값 고객번호 DTO 설정
		CustMainGuidCustStatInfoPopUpDSSDDODTO dto = new CustMainGuidCustStatInfoPopUpDSSDDODTO();
		dto.setCustNo(vo.getCustNo());

		List<CustMainGuidCustStatInfoPopUpDSSDDODTO> rs = mapper.searchCustStatInfo(dto);
		// DTO를 VO 전환 로직
		for(CustMainGuidCustStatInfoPopUpDSSDDODTO sourceIO: rs) {
			BCNUIP01DSSDDO01SENDVO targetIO = new BCNUIP01DSSDDO01SENDVO();
			targetIO.setCustNo(sourceIO.getCustNo());
			targetIO.setForeclosRightFg(sourceIO.getForeclosRightFg());
			targetIO.setCustBnkruptFg(sourceIO.getCustBnkruptFg());
			targetIO.setDeadFg(sourceIO.getDeadFg());
			targetIO.setFraudFg(sourceIO.getFraudFg());
			targetIO.setBnkruptFg(sourceIO.getBnkruptFg());
			targetIO.setClsBizFg(sourceIO.getClsBizFg());
			listBCNUIP01DSSDDO01SENDVO.add(targetIO);
		}

		// 리턴VO에 조회결과값 설정
		outVo.setListBCNUIP01DSSDDO01SENDVO(listBCNUIP01DSSDDO01SENDVO);
		return outVo;
	}

	/**
	* <pre>
	* 메소드명      : registerBCNUIP01I01
	* 작성일자      : 2023. 3. 28.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 고개정보상태 등록
	* 메소드인수1   : BCNUIP01S01InVO
	* 메소드리턴값  : BCNUIP01S01OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP01S01OutVO registerBCNUIP01I01(BCNUIP01S01InVO inVo) throws Exception {
		// 리턴값, 초기 VO 설정
		BCNUIP01S01OutVO outVo = new BCNUIP01S01OutVO();
		BCNUIP01DSSDDO01SENDVO sourceIO = inVo.getBCNUIP01DSSDDO01SENDVO();
		CustMainGuidCustStatInfoPopUpDSSDDODTO targetIO = new CustMainGuidCustStatInfoPopUpDSSDDODTO();

		//insert 파라미터 설정
		targetIO.setCustNo(sourceIO.getCustNo());
		targetIO.setForeclosRightFg(sourceIO.getForeclosRightFg());
		targetIO.setCustBnkruptFg(sourceIO.getCustBnkruptFg());
		targetIO.setDeadFg(sourceIO.getDeadFg());
		targetIO.setFraudFg(sourceIO.getFraudFg());
		targetIO.setBnkruptFg(sourceIO.getBnkruptFg());
		targetIO.setClsBizFg(sourceIO.getClsBizFg());
		targetIO.setUserNo(sourceIO.getUserNo());
		mapper.insertCustStatInfo(targetIO);

		return outVo;
	}


	/**
	* <pre>
	* 메소드명      : modifyBCNUIP01U01
	* 작성일자      : 2023. 3. 28.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 고개정보상태 수정
	* 메소드인수1   : BCNUIP01S01InVO
	* 메소드리턴값  : BCNUIP01S01OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP01S01OutVO modifyBCNUIP01U01(BCNUIP01S01InVO inVo) throws Exception {
		// 리턴값, 초기 VO 설정
		BCNUIP01S01OutVO outVo = new BCNUIP01S01OutVO();
		BCNUIP01DSSDDO01SENDVO sourceIO = inVo.getBCNUIP01DSSDDO01SENDVO();
		CustMainGuidCustStatInfoPopUpDSSDDODTO targetIO = new CustMainGuidCustStatInfoPopUpDSSDDODTO();

		//update 파라미터 설정
		targetIO.setCustNo(sourceIO.getCustNo());
		targetIO.setForeclosRightFg(sourceIO.getForeclosRightFg());
		targetIO.setCustBnkruptFg(sourceIO.getCustBnkruptFg());
		targetIO.setDeadFg(sourceIO.getDeadFg());
		targetIO.setFraudFg(sourceIO.getFraudFg());
		targetIO.setBnkruptFg(sourceIO.getBnkruptFg());
		targetIO.setClsBizFg(sourceIO.getClsBizFg());
		targetIO.setUserNo(sourceIO.getUserNo());
		mapper.updateCustStatInfo(targetIO);

		return outVo;
	}

}
