package hanalife.b.cn.ui.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.SmsDlyrDescMapper;
import hanalife.b.cn.ui.mapper.SmsTotDlyrMapper;
import hanalife.b.cn.ui.mapper.SmsTxtMngMapper;
import hanalife.b.cn.ui.mapper.dto.SmsTotDlyrDSSDDO02;
import hanalife.b.cn.ui.mapper.dto.SmsTotDlyrDSSMDO01;
import hanalife.b.cn.ui.service.BCNUIP02Service;
import hanalife.b.cn.ui.vo.BCNUIP02DSSDDO02VO;
import hanalife.b.cn.ui.vo.BCNUIP02DSSDDO03VO;
import hanalife.b.cn.ui.vo.BCNUIP02DSSDDO04VO;
import hanalife.b.cn.ui.vo.BCNUIP02InVO;
import hanalife.b.cn.ui.vo.BCNUIP02OutVO;
import hanalife.c.bc.cc.mapper.UserMngMapper;
import hanalife.c.cm.sp.service.callSpService;
import hanalife.c.cm.sp.vo.sendSmsVO;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.BtSmsDlvrDescDTO;
import hanalife.c.co.mapper.dto.BtSmsTxtMngDTO;
import hanalife.c.co.util.DateUtil;


/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRD0101ServiceImpl.java Class
 * 클래스설명   : SMS 전송 (BCNUIP01) Service Implements
 * 작성일자     : 2023. 4.14.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4.14.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIP01S01 : 고개정보상태 목록조회
 *              registerBCNUIP01I01 : 고개정보상태 등록
 *              modifyBCNUIP01U01 : 고개정보상태 수정
 * </pre>
 */
@Service("BCNUIP02Service")
public class BCNUIP02ServiceImpl implements BCNUIP02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIP02ServiceImpl.class);

	@Autowired
	callSpService callSpService;

	@Autowired
	SmsDlyrDescMapper smsDlyrDescMapper;

	@Autowired
	SmsTotDlyrMapper smsTotDlyrMapper;

	@Autowired
	SmsTxtMngMapper smsTxtMngMapper;

	@Autowired
	UserMngMapper userMngMapper;

	/**
	* <pre>
	* 메소드명      : getBCNUIP02S01
	* 작성일자      : 2023. 4. 25.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 공통메세지를 조회한다.
	* 메소드인수1   : BCNUIP02InVO
	* 메소드리턴값  : BCNUIP02OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP02OutVO getBCNUIP02S01(BCNUIP02InVO inVo) throws Exception {

		/** 메세지목록 결과값 객체 생성 */
		BCNUIP02OutVO resultVo = new BCNUIP02OutVO();

		/** 공통 메세지 조회 */
		List<BCNUIP02DSSDDO02VO> resultList = new ArrayList<BCNUIP02DSSDDO02VO>();
		List<SmsTotDlyrDSSDDO02> sourceList = smsTotDlyrMapper.searchComMsg();

		for (SmsTotDlyrDSSDDO02 sourceIO : sourceList) {
			BCNUIP02DSSDDO02VO targetIO = new BCNUIP02DSSDDO02VO();
			targetIO.setEmpNo(sourceIO.getEmpNo());
			targetIO.setSeq(sourceIO.getSeq());
			targetIO.setCntn(sourceIO.getCntn());
			targetIO.setProcDt(sourceIO.getProcDt());
			targetIO.setSndTelNo(sourceIO.getSndTelNo());
			targetIO.setMsgTitleCtt(sourceIO.getMsgTitleCtt());
			resultList.add(targetIO);
		}

		resultVo.setListBCNUIP02DSSDDO02(resultList);

		/** 내 메세지 조회 */
		BtSmsTxtMngDTO paramVo = new BtSmsTxtMngDTO();
		List<BCNUIP02DSSDDO03VO> resultList2 = new ArrayList<BCNUIP02DSSDDO03VO>();
		/** VO to DTO */
		paramVo.setEmpNo(inVo.getBCNUIP02DSSMDO01().getLogInEmpNo());
		List<BtSmsTxtMngDTO> sourceList2 = smsTxtMngMapper.searchSmsTxtMng(paramVo);

		for (BtSmsTxtMngDTO sourceIO : sourceList2) {
			BCNUIP02DSSDDO03VO targetIO = new BCNUIP02DSSDDO03VO();
			targetIO.setEmpNo(sourceIO.getEmpNo());
			targetIO.setSeq(sourceIO.getSeq());
			targetIO.setCntn(sourceIO.getCntn());
			targetIO.setProcDt(sourceIO.getProcDt());
			targetIO.setDlvrObjCd(sourceIO.getDlvrObjCd());
			targetIO.setDlvrDeptCd(sourceIO.getDlvrDeptCd());
			resultList2.add(targetIO);
		}

		resultVo.setListBCNUIP02DSSDDO03(resultList2);

		return resultVo;
	}

	/**
	* <pre>
	* 메소드명      : getBCNUIP02S02
	* 작성일자      : 2023. 4. 25.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 담당자 번호 정보를 조회한다.
	* 메소드인수1   : BCNUIP02InVO
	* 메소드리턴값  : getBCNUIP02S02
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP02OutVO getBCNUIP02S02(BCNUIP02InVO inVo) throws Exception {
		/** 메세지목록 결과값 객체 생성 */
		BCNUIP02OutVO resultVo = new BCNUIP02OutVO();

		/** 공통 메세지 조회 */
		List<BCNUIP02DSSDDO04VO> resultList = new ArrayList<BCNUIP02DSSDDO04VO>();
		SmsTotDlyrDSSMDO01 paramVo = new SmsTotDlyrDSSMDO01();
		paramVo.setEmpNo(inVo.getBCNUIP02DSSMDO02().getLogInEmpNo());

		String HpNo = smsTotDlyrMapper.searchHp(paramVo);

		BCNUIP02DSSDDO04VO targetIO = new BCNUIP02DSSDDO04VO();
		targetIO.setHpNo(HpNo);
		resultList.add(targetIO);

		resultVo.setListBCNUIP02DSSDDO04(resultList);

		return resultVo;
	}

	/**
	* <pre>
	* 메소드명      : registerBCNUIP02I01
	* 작성일자      : 2023. 4. 25.
	* 작성자(author): 70320 jaeho.jang
	* 설명          :
	* 메소드인수1   :
	* 메소드리턴값  :
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP02OutVO registerBCNUIP02I01(BCNUIP02InVO inVo) throws Exception {
		BCNUIP02OutVO outVo = new BCNUIP02OutVO();
		String sendFlg = inVo.getBCNUIP02DSSMDO01().getSendFlg();
		String rsrvSndFlg = inVo.getBCNUIP02DSSMDO01().getRsrvSndFlg();

		// 내정보 저장 체크시 문자관리 INSERT TO-BE 미사용
//		if("1".equals(sendFlg)) {
//			BtSmsTxtMngDTO inDto = new BtSmsTxtMngDTO();
//			inDto.setEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//			inDto.setCntn(inVo.getBCNUIP02DSSDDO03().getCntn());
//			inDto.setProcDt(inVo.getBCNUIP02DSSDDO03().getProcDt());
//			inDto.setFrstRegEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//			inDto.setLastProcEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
//			smsTxtMngMapper.insertSmsTxtMng(inDto);
//		}

		// SMS 전송 서비스 호출
		sendSmsVO sendVo = new sendSmsVO();
		sendSmsVO returnVo;
		sendVo.setVfvSmsMsgCd(inVo.getBCNUIP02DSSDDO01().getSeq());					/** EAGLE.SMS_CD_MAST@D_BEST_HE테이블의 SMS_CD */
		sendVo.setVfvSndTelNo(inVo.getBCNUIP02DSSDDO01().getRspnTelNo()); 			/** 송신자전화번호 */
		sendVo.setVfvJgno(new BigDecimal(inVo.getBCNUIP02DSSDDO01().getLoanNo())); 	/** 대출번호 */
		sendVo.setVfvJhno(inVo.getBCNUIP02DSSDDO01().getRecvTelNo());				/** 수신자전화번호 */
		sendVo.setVfvGgno(inVo.getBCNUIP02DSSDDO01().getCustNo());					/** 고객번호 */
		sendVo.setVfvZCreateBy(inVo.getBCNUIP02DSSMDO01().getLogInEmpNo());			/** 고객번호 */

		sendVo.setVfvBatchYn("N");
		if("1".equals(rsrvSndFlg)) {
			sendVo.setVfvReqdate(inVo.getBCNUIP02DSSMDO01().getRsrvSndTime());		/** 전송시간 */
		}

		// 00410: 자유형식 양식 seq 번호
		if("00410".equals(inVo.getBCNUIP02DSSDDO01().getSeq())) {
			sendVo.setVfvSmsMsgCtt(inVo.getBCNUIP02DSSDDO01().getSendTxt());			/** 사용자 입력 메세지 */
		} else {
			sendVo.setVfvParam01(inVo.getBCNUIP02DSSDDO01().getVfvParam01());			/** 파라미터01 */
			sendVo.setVfvParam02(inVo.getBCNUIP02DSSDDO01().getVfvParam02());			/** 파라미터02 */
			sendVo.setVfvParam03(inVo.getBCNUIP02DSSDDO01().getVfvParam03());			/** 파라미터03 */
			sendVo.setVfvParam04(inVo.getBCNUIP02DSSDDO01().getVfvParam04());			/** 파라미터04 */
			sendVo.setVfvParam05(inVo.getBCNUIP02DSSDDO01().getVfvParam05());			/** 파라미터05 */
			sendVo.setVfvParam06(inVo.getBCNUIP02DSSDDO01().getVfvParam06());			/** 파라미터06 */
			sendVo.setVfvParam07(inVo.getBCNUIP02DSSDDO01().getVfvParam07());			/** 파라미터07 */
			sendVo.setVfvParam08(inVo.getBCNUIP02DSSDDO01().getVfvParam08());			/** 파라미터08 */
			sendVo.setVfvParam09(inVo.getBCNUIP02DSSDDO01().getVfvParam09());			/** 파라미터09 */
			sendVo.setVfvParam10(inVo.getBCNUIP02DSSDDO01().getVfvParam10());			/** 파라미터10 */
			sendVo.setVfvParam11(inVo.getBCNUIP02DSSDDO01().getVfvParam11());			/** 파라미터11 */
			sendVo.setVfvParam12(inVo.getBCNUIP02DSSDDO01().getVfvParam12());			/** 파라미터12 */
			sendVo.setVfvParam13(inVo.getBCNUIP02DSSDDO01().getVfvParam13());			/** 파라미터13 */
			sendVo.setVfvParam14(inVo.getBCNUIP02DSSDDO01().getVfvParam14());			/** 파라미터14 */
			sendVo.setVfvParam15(inVo.getBCNUIP02DSSDDO01().getVfvParam15());			/** 파라미터15 */
		}


		// SMS 모듈 호출
		callSpService.sendSms(sendVo);

		// 성공여부에 따라 발송내역 등록처리
		BtSmsDlvrDescDTO inDto = new BtSmsDlvrDescDTO();

		inDto.setDlvrDt(DateUtil.getServerDate(DateUtil.YYYYMMDD));
		inDto.setMngDeptCd(inVo.getBCNUIP02DSSDDO01().getMngDeptCd());
		inDto.setDlvrEmpNo(inVo.getBCNUIP02DSSDDO01().getDlvrEmpNo());
		inDto.setLoanNo(inVo.getBCNUIP02DSSDDO01().getLoanNo());
		inDto.setLoanSeq(inVo.getBCNUIP02DSSDDO01().getLoanSeq());
		inDto.setCustNo(inVo.getBCNUIP02DSSDDO01().getCustNo());
		inDto.setSendDiv(rsrvSndFlg);
		if("1".equals(rsrvSndFlg)) {
			inDto.setSendDttm(inVo.getBCNUIP02DSSMDO01().getRsrvSndTime());
		}
		inDto.setRecvTelNo(inVo.getBCNUIP02DSSDDO01().getRecvTelNo());
		inDto.setRspnTelNo(inVo.getBCNUIP02DSSDDO01().getRspnTelNo());
		inDto.setSendTxt(inVo.getBCNUIP02DSSDDO01().getSendTxt());
		String sendRefKey = "";
		if(Constants.SMS_RESULT_CODE.equals(sendVo.getVfvRtnCd())) {
			String[] rtnCtt = sendVo.getVfvRtnCtt().split(":");
			sendRefKey = rtnCtt[1];
		}
		inDto.setSendRefKey(sendRefKey);
		inDto.setSmsSendErrCd(sendVo.getVfvRtnCd());
		inDto.setSendId(inVo.getBCNUIP02DSSMDO01().getRsrvSndTime().substring(0, 6));
		inDto.setDlvrObjCd(inVo.getBCNUIP02DSSDDO03().getDlvrObjCd());
		inDto.setDlvrDeptCd(inVo.getBCNUIP02DSSDDO03().getDlvrDeptCd());
		inDto.setFrstRegEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());
		inDto.setLastProcEmpNo(inVo.getBCNUIP02DSSDDO03().getLogInEmpNo());


		smsDlyrDescMapper.insertSmsDlyrDesc(inDto);
		outVo.setSendSmsVO(sendVo);
		return outVo;
	}


}
