package hanalife.b.cn.ui.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cn.ui.mapper.CustCnslGuidMapper;
import hanalife.b.cn.ui.mapper.CustMainGuidMngMapper;
import hanalife.b.cn.ui.mapper.CustRefInfoMapper;
import hanalife.b.cn.ui.mapper.dto.BtCustCnslGuidDTO;
import hanalife.b.cn.ui.mapper.dto.BtCustRefInfoDTO;
import hanalife.b.cn.ui.service.BCNUIP04Service;
import hanalife.b.cn.ui.vo.BCNUIP04DSSDDO09SEND;
import hanalife.b.cn.ui.vo.BCNUIP04InVO;
import hanalife.b.cn.ui.vo.BCNUIP04OutVO;
import hanalife.c.co.util.StringUtil;


/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRD0101ServiceImpl.java Class
 * 클래스설명   : 상담관리 (BCNUIM06) Service Implements
 * 작성일자     : 2023. 3. 28.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * 2023. 3. 28.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBCNUIM06S01 : 연락불능자목록조회
 * </pre>
 */
@Service("BCNUIP04Service")
public class BCNUIP04ServiceImpl implements BCNUIP04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIP04ServiceImpl.class);

	@Autowired
	CustMainGuidMngMapper mapper;

	@Autowired
	CustCnslGuidMapper custCnslGuidMapper;

	@Autowired
	CustRefInfoMapper custRefInfoMapper;

	/**
	* <pre>
	* 메소드명      : getBCNUIP04S01
	* 작성일자      : 2023. 3. 28.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 상담관리 조회
	* 메소드인수1   : BCNUIP04InVO
	* 메소드리턴값  : BCNUIP04OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP04OutVO getBCNUIP04S01(BCNUIP04InVO inVo) throws Exception {
		// 초기 변수값 셋팅
		BCNUIP04DSSDDO09SEND vo = inVo.getBCNUIP04DSSDDO09SEND();
		BCNUIP04OutVO returnVo = new BCNUIP04OutVO();

		//삼당관리 조회 쿼리 실행
		List<BCNUIP04DSSDDO09SEND> dssddo09List = this.search9(vo.getLoanNo(), vo.getLoanSeq(), vo.getCustNo());
		returnVo.setListBCNUIP04DSSDDO09SEND(dssddo09List);
		return returnVo;
	}

	/**
	* <pre>
	* 메소드명      : createCnslGuid
	* 작성일자      : 2023. 3. 28.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 상담내역등록
	* 메소드인수1   : BCNUIP04InVO
	* 메소드리턴값  : BCNUIP04OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BCNUIP04OutVO registerBCNUIP04I01(BCNUIP04InVO inVo) throws Exception {
		// 초기 변수값 셋팅
		BCNUIP04DSSDDO09SEND vo = inVo.getBCNUIP04DSSDDO09SEND();
		BtCustCnslGuidDTO dto = new BtCustCnslGuidDTO();
		BCNUIP04OutVO returnVo = new BCNUIP04OutVO();

		// validation 체크
		if( vo.getTelcCntn().getBytes().length > 1999){
			throw new Exception("통화이력은 2000byte를 넘을수 없습니다.(" +vo.getTelcCntn().getBytes().length + " bytes)");
		}

		this.updateCntcPlc(vo); /* 연락처정보 update */
		this.updateCustTrnd(vo); /* 고객성향 update */
		this.updateTxtRecvFg(vo); /* [영업]문자_수신_여부 update */

		// VO to DTO
		dto.setLoanNo(vo.getLoanNo());
		dto.setLoanSeq(vo.getLoanSeq());
		dto.setCustNo(vo.getCustNo());
		dto.setGuidUrgeDivCd(vo.getGuidUrgeDivCd());
		dto.setTelcGuidTpCd(vo.getTelcGuidTpCd());
		dto.setDivsManNm(vo.getDivsManNm());
		dto.setCnslObjManNm(vo.getCnslObjManNm());
		dto.setCnslPlcDivCd(vo.getCnslPlcDivCd());
		dto.setLoanRelCd(vo.getLoanRelCd());
		dto.setDlyRsnCd(vo.getDlyRsnCd());
		dto.setDlyRsnDetlCd(vo.getDlyRsnDetlCd());
		dto.setPrmsDt(vo.getPrmsDt());
		dto.setPrmsAmt(vo.getPrmsAmt());
		dto.setTelcCntn(vo.getTelcCntn());
		dto.setRlTelcMan(vo.getRlTelcMan());
		dto.setPrmsDueMethCd(vo.getPrmsDueMethCd());
		dto.setCntcPlcDivCd(vo.getCntcPlcDivCd());
		dto.setCntcStatCd(vo.getCntcStatCd());
		dto.setTelcDebtManNo(vo.getTelcDebtManNo());
		dto.setInOutBoundDivCd(vo.getInOutBoundDivCd());
		dto.setLngsDlyDdcnt(vo.getLngsDlyDdcnt());
		dto.setPsgDdcnt(vo.getPsgDdcnt());
		dto.setDlyAmt(vo.getDlyAmt());
		dto.setDivsManEmpNo(vo.getDivsManEmpNo());
		dto.setLoanWdrwAmt(vo.getLoanWdrwAmt());
		dto.setPrtyCd(vo.getPrtyCd());
		dto.setRcptDeptCd(vo.getRcptDeptCd());
		dto.setIamtPrmsBankCd(vo.getIamtPrmsBankCd());
		dto.setFrstRegEmpNo(vo.getLogInEmpNo());
		dto.setTxtRecvFg(vo.getTxtRecvFg());
		dto.setTelcTelNo(vo.getTelcTelNo());
		dto.setCnslDivCd(vo.getCnslDivCd());

		dto.setPrmsAmt(StringUtil.nvl(vo.getPrmsAmt(),"0"));
		dto.setLngsDlyDdcnt(StringUtil.nvl(vo.getLngsDlyDdcnt(),"0"));
		dto.setPsgDdcnt(StringUtil.nvl(vo.getPsgDdcnt(),"0"));
		dto.setDlyAmt(StringUtil.nvl(vo.getDlyAmt(),"0"));
		dto.setLoanWdrwAmt(StringUtil.nvl(vo.getLoanWdrwAmt(),"0"));
		dto.setCnslPlcDivCd(StringUtil.nvl(vo.getCnslPlcDivCd(),""));
		dto.setCnslPlcDivNm(StringUtil.nvl(vo.getCnslPlcDivNm(),""));
		dto.setDlyRsnCd(StringUtil.nvl(vo.getDlyRsnCd(),""));
		dto.setDlyRsnDetlCd(StringUtil.nvl(vo.getDlyRsnDetlCd(),""));
		dto.setPrmsDt(StringUtil.nvl(vo.getPrmsDt(),""));
		dto.setPrmsDueMethCd(StringUtil.nvl(vo.getPrmsDueMethCd(),""));
		dto.setRlTelcMan(StringUtil.nvl(vo.getRlTelcMan(),""));
		dto.setTelcDebtManNo(StringUtil.nvl(vo.getTelcDebtManNo(),""));
		dto.setPrtyCd(StringUtil.nvl(vo.getPrtyCd(),""));
		dto.setRcptDeptCd(StringUtil.nvl(vo.getRcptDeptCd(),""));
		dto.setIamtPrmsBankCd(StringUtil.nvl(vo.getIamtPrmsBankCd(),""));
		dto.setTelcTelNo(StringUtil.nvl(vo.getTelcTelNo(),""));
		dto.setCnslDivCd(StringUtil.nvl(vo.getCnslDivCd(),""));

		// 상담내역 저장 실패시 exception 처리
		if(1 != custCnslGuidMapper.createCustCnslGuid(dto)) {
			throw new Exception("상담내역 저장실패");
		}

		// 중점사항 등록
		if("1".equals(vo.getImptRsnSaveFg())){
			BtCustRefInfoDTO custRefInfoTDO = new BtCustRefInfoDTO();
			custRefInfoTDO.setLoanNo(vo.getLoanNo());                        	//대출_번호
			custRefInfoTDO.setRegDt(vo.getRegDt()); 							//등록_일자
			custRefInfoTDO.setImptRsn("99");                      				//중점_사유
			custRefInfoTDO.setRefrCntn(dto.getTelcCntn());                    	//참고_내용
			custRefInfoTDO.setFrstRegEmpNo(vo.getLogInEmpNo());               	//최초_등록_사원번호
			custRefInfoTDO.setLastProcEmpNo(vo.getLogInEmpNo());              	//최종_처리_사원번호
			custRefInfoTDO.setDelYn("0");                          	//삭제_유무

			// 중점사항 등록 처리
			custRefInfoMapper.createCustRefInfo(custRefInfoTDO);
		}

		// 조회목록 return 처리
		List<BCNUIP04DSSDDO09SEND> dssddo09List = this.search9(dto.getLoanNo(), dto.getLoanSeq(), dto.getCustNo());
		returnVo.setListBCNUIP04DSSDDO09SEND(dssddo09List);
		return returnVo;
	}


	private void updateCntcPlc(BCNUIP04DSSDDO09SEND vo) throws Exception{
		BtCustCnslGuidDTO newDto = new BtCustCnslGuidDTO();

		if (vo.getCntcStatCd() == null) {
			newDto.setCntcStatCd("' '");
		}
		else {
			newDto.setCntcStatCd(vo.getCntcStatCd());
		}

		newDto.setCustNo(vo.getCustNo());

		if (vo.getCntcPlcDivCd() == null) {
			newDto.setCntcPlcDivCd(" ");
		}
		else {
			newDto.setCntcPlcDivCd(vo.getCntcPlcDivCd());
		}

		custCnslGuidMapper.updateCntcPlc(newDto);   /* 연락처정보 */
	}

	private void updateCustTrnd(BCNUIP04DSSDDO09SEND vo) throws Exception{
		BtCustCnslGuidDTO newDto = new BtCustCnslGuidDTO();

		if (vo.getCustTrndCd() == null) {
			newDto.setCustTrndCd(" ");
		}
		else {
			newDto.setCustTrndCd(vo.getCustTrndCd());
		}

		newDto.setCustNo(vo.getCustNo());

		custCnslGuidMapper.updateCustTrnd(newDto);  /* 고객성향 */
	}

	private void updateTxtRecvFg(BCNUIP04DSSDDO09SEND vo) throws Exception{
		BtCustCnslGuidDTO newDto = new BtCustCnslGuidDTO();

		newDto.setTxtRecvFg(vo.getTxtRecvFg());
		newDto.setLoanNo(vo.getLoanNo());
		newDto.setLoanSeq(vo.getLoanSeq());
		newDto.setCustNo(vo.getCustNo());

		custCnslGuidMapper.updateTxtRecvFg(newDto); /* [영업]문자_수신_여부 */
	}


	private List<BCNUIP04DSSDDO09SEND> search9(String loanNo, String loanSeq, String custNo) throws Exception {

		List<BCNUIP04DSSDDO09SEND> returnList = new ArrayList<BCNUIP04DSSDDO09SEND>();
		BtCustCnslGuidDTO cond2 = new BtCustCnslGuidDTO();
		cond2.setLoanNo(loanNo);
		cond2.setLoanSeq(loanSeq);
		cond2.setCustNo(custNo);
		cond2.setGuidUrgeDivCd("01");

		List<BtCustCnslGuidDTO> rs = custCnslGuidMapper.search2(cond2);

		for (BtCustCnslGuidDTO sourceIO : rs) {
			BCNUIP04DSSDDO09SEND targetIO = new BCNUIP04DSSDDO09SEND();
			targetIO.setLoanNo(sourceIO.getLoanNo());
			targetIO.setLoanSeq(sourceIO.getLoanSeq());
			targetIO.setRegDt(sourceIO.getRegDt());
			targetIO.setRegTm(sourceIO.getRegTm());
			targetIO.setCustNo(sourceIO.getCustNo());
			targetIO.setGuidUrgeDivCd(sourceIO.getGuidUrgeDivCd());
			targetIO.setTelcGuidTpCd(sourceIO.getTelcGuidTpCd());
			targetIO.setDivsManNm(sourceIO.getDivsManNm());
			targetIO.setCnslObjManNm(sourceIO.getCnslObjManNm());
			targetIO.setCnslPlcDivCd(sourceIO.getCnslPlcDivCd());
			targetIO.setLoanRelCd(sourceIO.getLoanRelCd());
			targetIO.setDlyRsnCd(sourceIO.getDlyRsnCd());
			targetIO.setDlyRsnDetlCd(sourceIO.getDlyRsnDetlCd());
			targetIO.setPrmsDt(sourceIO.getPrmsDt());
			targetIO.setPrmsAmt(sourceIO.getPrmsAmt());
			targetIO.setTelcCntn(sourceIO.getTelcCntn());
			targetIO.setRlTelcMan(sourceIO.getRlTelcMan());
			targetIO.setPrmsDueMethCd(sourceIO.getPrmsDueMethCd());
			targetIO.setCntcPlcDivCd(sourceIO.getCntcPlcDivCd());
			targetIO.setCntcStatCd(sourceIO.getCntcStatCd());
			targetIO.setTelcDebtManNo(sourceIO.getTelcDebtManNo());
			targetIO.setInOutBoundDivCd(sourceIO.getInOutBoundDivCd());
			targetIO.setLngsDlyDdcnt(sourceIO.getLngsDlyDdcnt());
			targetIO.setPsgDdcnt(sourceIO.getPsgDdcnt());
			targetIO.setDlyAmt(sourceIO.getDlyAmt());
			targetIO.setDivsManEmpNo(sourceIO.getDivsManEmpNo());
			targetIO.setLoanWdrwAmt(sourceIO.getLoanWdrwAmt());
			targetIO.setPrtyCd(sourceIO.getPrtyCd());
			targetIO.setRcptDeptCd(sourceIO.getRcptDeptCd());
			targetIO.setIamtPrmsBankCd(sourceIO.getIamtPrmsBankCd());
			targetIO.setLoanRelNm(sourceIO.getLoanRelNm());
			targetIO.setCustTrndCd(sourceIO.getCustTrndCd());
			//targetIO.setTelcGuidTpNm(sourceIO.getTelcGuidTpNm());
			targetIO.setCnslPlcDivNm(sourceIO.getCnslPlcDivNm());
			//targetIO.setDlyDdcnt(sourceIO.getDlyDdcnt());
			//targetIO.setCustTpNm(sourceIO.getCustTpNm());
			//targetIO.setInOutBoundDivNm(sourceIO.getInOutBoundDivNm());
			targetIO.setTxtRecvFg(sourceIO.getTxtRecvFg());
			//targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo());
			//targetIO.setRnumber(sourceIO.getRnumber());
			targetIO.setDivsManNm2(sourceIO.getDivsManNm2());
			targetIO.setRegDt2(sourceIO.getRegDt2());
			targetIO.setRegTm2(sourceIO.getRegTm2());
			targetIO.setTelcCntn2(sourceIO.getTelcCntn2());
		}

		return returnList;
	}
}
