package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIM01Service;
import hanalife.b.cn.ui.vo.BCNUIM01DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIM01S01InVO;
import hanalife.b.cn.ui.vo.BCNUIM01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM01Controller.java Class
 * 클래스설명   : 연체리스트 관리 Controller
 * 작성일자     : 2023. 3. 9.
 * 작성자명     : 70326 / YouHyunSik / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][ 70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIM01Controller {

	@Resource(name = "BCNUIM01Service")
	private BCNUIM01Service BCNUIM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM01Controller.class);

	/**
	 * <p>메소드명      : BCNUIM01S01조회 / BCNUIM01S01.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): YouHyunSik
	 * <p>설명          : 연체리스트 조회해서 가져온다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIM01S01.do")
	public String BCNUIM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIM01Controller BCNUIM01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);
			LOGGER.info("##### BCNUIM01Controller sourceMap #####" + sourceMap);
			/** 연체리스트 조회 서비스 호출 입력값 대입 */
			BCNUIM01DSSMDOVO dsSMDOInVo = new BCNUIM01DSSMDOVO();

			dsSMDOInVo.setOrgCd((String) sourceMap.get("ORG_CD"));				    /** 관리부서 */
			dsSMDOInVo.setPrdtCd((String) sourceMap.get("PRDT_CD"));				/** 상품코드 */
			dsSMDOInVo.setLoanStatCd((String) sourceMap.get("LOAN_STAT_CD"));		/** 대출상태 */
			dsSMDOInVo.setEprtDtSt((String) sourceMap.get("EPRT_DT_ST"));			/** 만기시작일자 */
			dsSMDOInVo.setEprtDtEd((String) sourceMap.get("EPRT_DT_ED"));			/** 만기종료일자 */
			dsSMDOInVo.setCrdtStatCd((String) sourceMap.get("CRDT_STAT_CD"));		/** 신용상태 */
			dsSMDOInVo.setBndStatCd((String) sourceMap.get("BND_STAT_CD"));		    /** 채권상태 */
			dsSMDOInVo.setSecurityYn((String) sourceMap.get("SECURITY_YN"));		/** 담보여부 */
			dsSMDOInVo.setGoodCd((String) sourceMap.get("GOOD_CD"));				/** 자산건전성 */
			dsSMDOInVo.setLoanNo((String) sourceMap.get("LOAN_NO"));				/** 대출번호 */
			dsSMDOInVo.setLoanSeq((String) sourceMap.get("LOAN_SEQ"));	   		    /** 대출순번 */
			dsSMDOInVo.setThmmComgFrom((String) sourceMap.get("THMM_COMG_FROM"));	/** 도래회차시작 */
			dsSMDOInVo.setThmmComgTo((String) sourceMap.get("THMM_COMG_TO"));		/** 도래회차종료 */
			dsSMDOInVo.setCntSt((String) sourceMap.get("CNT_ST"));				    /** 연체회차시작 */
			dsSMDOInVo.setCntEd((String) sourceMap.get("CNT_ED"));				    /** 연체회차종료 */
			dsSMDOInVo.setDlyDdcntSt((String) sourceMap.get("DLY_DDCNT_ST"));		/** 연체일수시작 */
			dsSMDOInVo.setDlyDdcntEd((String) sourceMap.get("DLY_DDCNT_ED"));		/** 연체일수종료 */
			dsSMDOInVo.setKisanSt((String) sourceMap.get("KISAN_ST"));			    /** 결제일시작 */
			dsSMDOInVo.setKisanEd((String) sourceMap.get("KISAN_ED"));			    /** 결제일종료 */
			dsSMDOInVo.setContManNo((String) sourceMap.get("CONT_MAN_NO"));		    /** 고객번호 */
			dsSMDOInVo.setThmmUnUrge((String) sourceMap.get("THMM_UN_URGE"));		/** 당월미독촉 여부 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			BCNUIM01S01InVO InVO = new BCNUIM01S01InVO();
            InVO.setBCNUIM01DSSMDOVO(dsSMDOInVo);	/** 연체리스트 DS_SMDO 입력값 VO 객체 대입 */

            LOGGER.info("##### BCNUIM01Controller InVO #####" + InVO.getBCNUIM01DSSMDOVO().getThmmUnUrge());

            /** 연체리스트 업무 서비스 호출 수행 */
            BCNUIM01S01OutVO resultListVo = BCNUIM01.getBCNUIM01S01(InVO);

            /** 연체리스트 DataSet 결과값 설정 */
            XFrame5Util.setOutputData("DS_SDDO", resultListVo.getBCNUIM01DSSDDOVO(), model);

            LOGGER.info("##### BCNUIM01Controller BCNUIM01S01 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIM01Controller Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;
	}

}