package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIM04Service;
import hanalife.b.cn.ui.vo.BCNUIM04DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIM04S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM04Controller.java Class
 * 클래스설명   : SMS 발송내역 조회 (BCNUIM04) Controller
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIM04Controller {

	@Resource(name = "BCNUIM04Service")
	private BCNUIM04Service BCNUIM04;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM04Controller.class);

	/**
	 * <p>메소드명      : SMS 발송내역 조회조회 /BCNUIM04S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : SMS 발송내역 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIM04S01.do")
	public String BCNUIM04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIM04Controller BCNUIM04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> dsSmdoMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

			/** SMS 발송내역 조회내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIM04DSSMDOVO dsSmdoVo = new BCNUIM04DSSMDOVO();
			dsSmdoVo.setCustNo((String) dsSmdoMap.get("custNo"));
			dsSmdoVo.setDeptCd((String) dsSmdoMap.get("deptCd"));
			dsSmdoVo.setDlvrDeptCd((String) dsSmdoMap.get("dlvrDeptCd"));
			dsSmdoVo.setDlvrEmpNo((String) dsSmdoMap.get("dlvrEmpNo"));
			dsSmdoVo.setDlvrFromDt((String) dsSmdoMap.get("dlvrFromDt"));
			dsSmdoVo.setDlvrObjCd((String) dsSmdoMap.get("dlvrObjCd"));
			dsSmdoVo.setDlvrToDt((String) dsSmdoMap.get("dlvrToDt"));
			dsSmdoVo.setLoanNo((String) dsSmdoMap.get("loanNo"));
			dsSmdoVo.setLoanSeq((String) dsSmdoMap.get("loanSeq"));
			dsSmdoVo.setRecvTelNo((String) dsSmdoMap.get("recvTelNo"));
			dsSmdoVo.setSendStatDiv((String) dsSmdoMap.get("sendStatDiv"));

			/** SMS 발송내역 조회내역조회 업무 서비스 호출 수행 */
			BCNUIM04S01OutVO resultBCNUIM04S01 = BCNUIM04.getBCNUIM04S01(dsSmdoVo);

			XFrame5Util.setOutputData("DS_SDDO", resultBCNUIM04S01.getListBCNUIM04S0101VO(), model); /** 대출정보조회 */
			LOGGER.info("##### BCNUIM04Controller BCNUIM04S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIM04Controller BCNUIM04S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

//	/**
//	 * <p>메소드명      : SMS 발송내역 조회등록 /BCNUIM04I01.do </p>
//	 * <p>작성일자      : 2023. 2. 27.
//	 * <p>작성자(author): 70317
//	 * <p>설명          : SMS 발송내역 조회등록 한다.</p>
//	 * <p>예외처리      : Exception</p>
//	 */
//	@RequestMapping("/BCNUIM04I01.do")
//	public String BCNUIM04I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
//
//		LOGGER.info("##### BCNUIM04Controller BCNUIM04I01 Start #####");
//
//		try {
//			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
//			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
//
//			/** SMS 발송내역 조회내역조회 업무 서비스 호출 입력값 대입 */
//			BCNUIM04S01InVO targetVo = new BCNUIM04S01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */
//
//			/** SMS 발송내역 조회내역조회 업무 서비스 호출 수행 */
//			BCNUIM04S01OutVO resultBCNUIM04I01 = BCNUIM04.registerBCNUIM04I01(targetVo);
//
//			XFrame5Util.setOutputData("DS_SD01", resultBCNUIM04I01.getBCNUIM04I0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resultBCNUIM04I01.getBCNUIM04I0102VO(), model); /** 수납목록조회 */
//
//			LOGGER.info("##### BCNUIM04Controller BCNUIM04I01 Normal End #####");
//		} catch (Exception e) {
//			LOGGER.error("Error >>> " + e.getMessage());
//			// 오류 메시지 정보 설정
//			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
//			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
//
//			LOGGER.info("##### BCNUIM04Controller BCNUIM04I01 Exception End #####");
//		}
//
//		return XFrame5View.XFRAME5_VIEW;
//	}
//
//	/**
//	 * <p>메소드명      : SMS 발송내역 조회수정 /BCNUIM04U01.do </p>
//	 * <p>작성일자      : 2023. 2. 27.
//	 * <p>작성자(author): 70317
//	 * <p>설명          : SMS 발송내역 조회수정 한다.</p>
//	 * <p>예외처리      : Exception</p>
//	 */
//	@RequestMapping("/BCNUIM04U01.do")
//	public String BCNUIM04U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
//
//		LOGGER.info("##### BCNUIM04Controller BCNUIM04U01 Start #####");
//
//		try {
//			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
//			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
//
//			/** SMS 발송내역 조회내역조회 업무 서비스 호출 입력값 대입 */
//			BCNUIM04U01InVO targetVo = new BCNUIM04U01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */
//
//			/** SMS 발송내역 조회내역조회 업무 서비스 호출 수행 */
//			BCNUIM04S01OutVO resultBCNUIM04U01 = BCNUIM04.modifyBCNUIM04U01(targetVo);
//
//			XFrame5Util.setOutputData("DS_SD01", resultBCNUIM04U01.getBCNUIM04U0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resultBCNUIM04U01.getBCNUIM04U0102VO(), model); /** 수납목록조회 */
//
//			LOGGER.info("##### BCNUIM04Controller BCNUIM04U01 Normal End #####");
//		} catch (Exception e) {
//			LOGGER.error("Error >>> " + e.getMessage());
//			// 오류 메시지 정보 설정
//			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
//			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
//
//			LOGGER.info("##### BCNUIM04Controller BCNUIM04U01 Exception End #####");
//		}
//
//		return XFrame5View.XFRAME5_VIEW;
//	}
//
//	/**
//	 * <p>메소드명      : SMS 발송내역 조회삭제 /BCNUIM04D01.do </p>
//	 * <p>작성일자      : 2023. 2. 27.
//	 * <p>작성자(author): 70317
//	 * <p>설명          : SMS 발송내역 조회삭제 한다.</p>
//	 * <p>예외처리      : Exception</p>
//	 */
//	@RequestMapping("/BCNUIM04D01.do")
//	public String BCNUIM04D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
//
//		LOGGER.info("##### BCNUIM04Controller BCNUIM04D01 Start #####");
//
//		try {
//			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
//			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
//
//			/** SMS 발송내역 조회내역조회 업무 서비스 호출 입력값 대입 */
//			BCNUIM04D01InVO targetVo = new BCNUIM04D01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */
//
//			/** SMS 발송내역 조회내역조회 업무 서비스 호출 수행 */
//			BCNUIM04S01OutVO resultBCNUIM04D01 = BCNUIM04.removeBCNUIM04D01(targetVo);
//
//			XFrame5Util.setOutputData("DS_SD01", resultBCNUIM04D01.getBCNUIM04D0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resultBCNUIM04D01.getBCNUIM04D0102VO(), model); /** 수납목록조회 */
//
//			LOGGER.info("##### BCNUIM04Controller BCNUIM04D01 Normal End #####");
//		} catch (Exception e) {
//			LOGGER.error("Error >>> " + e.getMessage());
//			// 오류 메시지 정보 설정
//			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
//			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
//
//			LOGGER.info("##### BCNUIM04Controller BCNUIM04D01 Exception End #####");
//		}
//
//		return XFrame5View.XFRAME5_VIEW;
//	}

}
