package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIM05Service;
import hanalife.b.cn.ui.vo.BCNUIM05DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIM05S01InVO;
import hanalife.b.cn.ui.vo.BCNUIM05S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIM05Controller.java Class
 * 클래스설명   : BCNUIM05Controller Controller
 * 작성일자     : 2023. 3. 17.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 17.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIM05Controller {

    @Resource(name = "BCNUIM05Service")
    private BCNUIM05Service bcnuiM05Service;

    private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIM05Controller.class);

    /**
     *<pre>
     * 메소드명      : 입금약속자명세 /BCNUIM05S01.do
     * 작성일자      : 2023. 3. 17.
     * 작성자(author): 70331
     * 설명          : 입금약속자명세조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BCNUIM05S01.do")
    public String BCNUIM05S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BCNUIM05S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BCNUIM05DSSMDOVO inVo           = new BCNUIM05DSSMDOVO();
            BCNUIM05S01InVO  bcnui05S01InVO = new BCNUIM05S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setMngDeptCd   ((String) sourceMap.get("mngDeptCd")      ); // 관리_부서_코드
            inVo.setDivsManEmpNo((String) sourceMap.get("divsManEmpNo")   ); // 담당자_ID
            inVo.setDivsManNm   ((String) sourceMap.get("divsManNm")      ); // 담당자_명
            inVo.setCnslObjManNm((String) sourceMap.get("cnslObjManNm")   );
            inVo.setPrmsFromDt  ((String) sourceMap.get("prmsFromDt")     );
            inVo.setPrmsToDt    ((String) sourceMap.get("prmsToDt")       );


            /**************************************************
             * □ service로 보낼 Vo Set
             **************************************************/
            bcnui05S01InVO.setBCNUIM05DSSMDOVO(inVo);


            /**************************************************
             * ■ Call 입금약속자명세 조회
             **************************************************/
            BCNUIM05S01OutVO outVo = bcnuiM05Service.getBCNUIM05S01(bcnui05S01InVO);


            /**************************************************
             * □ 화면으로 Return 처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO", outVo.getBCNUIM05DSSDDOVOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.debug("##### todo0Controller todo0S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
