package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIP01Service;
import hanalife.b.cn.ui.vo.BCNUIP01DSSDDO01SENDVO;
import hanalife.b.cn.ui.vo.BCNUIP01DSSMDOVO;
import hanalife.b.cn.ui.vo.BCNUIP01S01InVO;
import hanalife.b.cn.ui.vo.BCNUIP01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIP01Controller.java Class
 * 클래스설명   : 고개정보상태 (BCNUIP01) Controller
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIP01Controller {

	@Resource(name = "BCNUIP01Service")
	private BCNUIP01Service BCNUIP01;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIP01Controller.class);

	/**
	 * <p>메소드명      : 고개정보상태조회 /BCNUIP01S01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70320
	 * <p>설명          : 고개정보상태조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP01S01.do")
	public String BCNUIP01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP01Controller BCNUIP01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);
			/** 고개정보상태내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP01S01InVO targetVo = new BCNUIP01S01InVO();
			BCNUIP01DSSMDOVO paramVo = new BCNUIP01DSSMDOVO();
			paramVo.setCustNo((String) sourceMap.get("custNo")); /** 고객번호 */
			targetVo.setBCNUIP01DSSMDOVO(paramVo);
			/** 고개정보상태내역조회 업무 서비스 호출 수행 */
			BCNUIP01S01OutVO resultBCNUIP01S01 = BCNUIP01.getBCNUIP01S01(targetVo);

			XFrame5Util.setOutputData("DS_CUST_STAT_INFO", resultBCNUIP01S01.getListBCNUIP01DSSDDO01SENDVO(), model); /** 대출정보조회 */

			LOGGER.info("##### BCNUIP01Controller BCNUIP01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP01Controller BCNUIP01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 고개정보상태등록 /BCNUIP01I01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70320
	 * <p>설명          : 고개정보상태등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP01I01.do")
	public String BCNUIP01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP01Controller BCNUIP01I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO01_SEND", request, response, model);

			/** 고개정보상태내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP01S01InVO inVo = new BCNUIP01S01InVO();
			BCNUIP01DSSDDO01SENDVO targetVo = new BCNUIP01DSSDDO01SENDVO();
			targetVo.setCustNo((String)sourceMap.get("custNo"));
			targetVo.setForeclosRightFg((String)sourceMap.get("foreclosRightFg"));
			targetVo.setCustBnkruptFg((String)sourceMap.get("custBnkruptFg"));
			targetVo.setDeadFg((String)sourceMap.get("deadFg"));
			targetVo.setFraudFg((String)sourceMap.get("fraudFg"));
			targetVo.setBnkruptFg((String)sourceMap.get("bnkruptFg"));
			targetVo.setClsBizFg((String)sourceMap.get("clsBizFg"));
			targetVo.setUserNo((String)sourceMap.get("logInEmpNo"));
			inVo.setBCNUIP01DSSDDO01SENDVO(targetVo);

			/** 고개정보상태내역조회 업무 서비스 호출 수행 */
			BCNUIP01S01OutVO resultBCNUIP01I01 = BCNUIP01.registerBCNUIP01I01(inVo);

			LOGGER.info("##### BCNUIP01Controller BCNUIP01I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP01Controller BCNUIP01I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 고개정보상태수정 /BCNUIP01U01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70320
	 * <p>설명          : 고개정보상태수정 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP01U01.do")
	public String BCNUIP01U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP01Controller BCNUIP01U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO01_SEND", request, response, model);

			/** 고개정보상태내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP01S01InVO inVo = new BCNUIP01S01InVO();
			BCNUIP01DSSDDO01SENDVO targetVo = new BCNUIP01DSSDDO01SENDVO();
			targetVo.setCustNo((String)sourceMap.get("custNo"));
			targetVo.setForeclosRightFg((String)sourceMap.get("foreclosRightFg"));
			targetVo.setCustBnkruptFg((String)sourceMap.get("custBnkruptFg"));
			targetVo.setDeadFg((String)sourceMap.get("deadFg"));
			targetVo.setFraudFg((String)sourceMap.get("fraudFg"));
			targetVo.setBnkruptFg((String)sourceMap.get("bnkruptFg"));
			targetVo.setClsBizFg((String)sourceMap.get("clsBizFg"));
			targetVo.setUserNo((String)sourceMap.get("logInEmpNo"));
			inVo.setBCNUIP01DSSDDO01SENDVO(targetVo);

			/** 고개정보상태내역조회 업무 서비스 호출 수행 */
			BCNUIP01S01OutVO resultBCNUIP01I01 = BCNUIP01.modifyBCNUIP01U01(inVo);

			LOGGER.info("##### BCNUIP01Controller BCNUIP01I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP01Controller BCNUIP01U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}
}