package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIP02Service;
import hanalife.b.cn.ui.vo.BCNUIP02DSSDDO01VO;
import hanalife.b.cn.ui.vo.BCNUIP02DSSDDO03VO;
import hanalife.b.cn.ui.vo.BCNUIP02DSSMDO01VO;
import hanalife.b.cn.ui.vo.BCNUIP02DSSMDO02VO;
import hanalife.b.cn.ui.vo.BCNUIP02InVO;
import hanalife.b.cn.ui.vo.BCNUIP02OutVO;
import hanalife.c.cm.sp.vo.sendSmsVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIP02Controller.java Class
 * 클래스설명   : SMS 메세지 (BCNUIP02) Controller
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIP02Controller {

	@Resource(name = "BCNUIP02Service")
	private BCNUIP02Service BCNUIP02;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIP02Controller.class);

	/**
	 * <p>메소드명      : SMS 메세지조회 /BCNUIP02S01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70320
	 * <p>설명          : SMS 메세지조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP02S01.do")
	public String BCNUIP02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP02Controller BCNUIP02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);
			/** SMS 메세지내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP02InVO targetVo = new BCNUIP02InVO();
			BCNUIP02DSSMDO01VO paramVo = new BCNUIP02DSSMDO01VO();

			BeanUtil.mapToBean(sourceMap, paramVo);
			targetVo.setBCNUIP02DSSMDO01(paramVo);
			/** SMS 메세지내역조회 업무 서비스 호출 수행 */
			BCNUIP02OutVO resultBCNUIP02 = BCNUIP02.getBCNUIP02S01(targetVo);

			XFrame5Util.setOutputData("DS_SDDO02", resultBCNUIP02.getListBCNUIP02DSSDDO02(), model); /**  */
			XFrame5Util.setOutputData("DS_SDDO03", resultBCNUIP02.getListBCNUIP02DSSDDO03(), model); /**  */

			LOGGER.info("##### BCNUIP02Controller BCNUIP02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP02Controller BCNUIP02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SMS 메세지조회 /BCNUIP02S02.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70320
	 * <p>설명          : SMS 메세지조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP02S02.do")
	public String BCNUIP02S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP02Controller BCNUIP02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO02", request, response, model);
			/** SMS 메세지내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP02InVO targetVo = new BCNUIP02InVO();
			BCNUIP02DSSMDO02VO paramVo = new BCNUIP02DSSMDO02VO();

			BeanUtil.mapToBean(sourceMap, paramVo);
			targetVo.setBCNUIP02DSSMDO02(paramVo);
			/** SMS 메세지내역조회 업무 서비스 호출 수행 */
			BCNUIP02OutVO resultBCNUIP02 = BCNUIP02.getBCNUIP02S02(targetVo);

			XFrame5Util.setOutputData("DS_SDDO04", resultBCNUIP02.getListBCNUIP02DSSDDO04(), model); /**  */

			LOGGER.info("##### BCNUIP02Controller BCNUIP02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP02Controller BCNUIP02S02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SMS 메세지를 전송,등록 /BCNUIP02I01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70320
	 * <p>설명          : SMS 메세지를 전송,등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP02I01.do")
	public String BCNUIP02I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP02Controller BCNUIP02I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);
			BCNUIP02DSSMDO01VO smdo01 = new BCNUIP02DSSMDO01VO();
			BeanUtil.mapToBean(sourceMap, smdo01);

			sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO01_SEND", request, response, model);
			BCNUIP02DSSDDO01VO sddo01 = new BCNUIP02DSSDDO01VO();
			BeanUtil.mapToBean(sourceMap, sddo01);

			sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO03_SEND", request, response, model);
			BCNUIP02DSSDDO03VO sddo03 = new BCNUIP02DSSDDO03VO();
			BeanUtil.mapToBean(sourceMap, sddo03);

			/** SMS 메세지내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP02InVO inVo = new BCNUIP02InVO();
			inVo.setBCNUIP02DSSDDO01(sddo01);
			inVo.setBCNUIP02DSSDDO03(sddo03);
			inVo.setBCNUIP02DSSMDO01(smdo01);

			/** SMS 메세지내역조회 업무 서비스 호출 수행 */
			BCNUIP02OutVO resultBCNUIP02I01 = BCNUIP02.registerBCNUIP02I01(inVo);
			sendSmsVO sendSmsVO = resultBCNUIP02I01.getSendSmsVO();

			if(!"0000".equals(sendSmsVO.getVfvRtnCtt())) {
				throw new Exception();
			}
			LOGGER.info("##### BCNUIP02Controller BCNUIP02I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, "SMS 전송이 실패했습니다.");

			LOGGER.info("##### BCNUIP02Controller BCNUIP02I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}
}