package hanalife.b.cn.ui.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.cn.ui.service.BCNUIP04Service;
import hanalife.b.cn.ui.vo.BCNUIP04DSSDDO09SEARCH;
import hanalife.b.cn.ui.vo.BCNUIP04DSSDDO09SEND;
import hanalife.b.cn.ui.vo.BCNUIP04InVO;
import hanalife.b.cn.ui.vo.BCNUIP04OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BCNUIP04Controller.java Class
 * 클래스설명   : 상담내역 (BCNUIP04) Controller
 * 작성일자     : 2023. 3. 28.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 28.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/b/cn/ui")
@Controller
public class BCNUIP04Controller {

	@Resource(name = "BCNUIP04Service")
	private BCNUIP04Service BCNUIP04;

	private static final Logger LOGGER = LoggerFactory.getLogger(BCNUIP04Controller.class);

	/**
	 * <p>메소드명      : 상담내역 /BCNUIP04S01.do </p>
	 * <p>작성일자      : 2023. 3. 28.
	 * <p>작성자(author): 70320
	 * <p>설명          : 상담내역 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP04S01.do")
	public String BCNUIP04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP04Controller BCNUIP04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);
			/** 상담내역내역조회 업무 서비스 호출 입력값 대입 */
			BCNUIP04InVO inVo = new BCNUIP04InVO();
			BCNUIP04DSSDDO09SEARCH targetVo = new BCNUIP04DSSDDO09SEARCH();
			BeanUtil.mapToBean(sourceMap, targetVo);
			inVo.setBCNUIP04DSSDDO09SEARCH(targetVo);

			/** 상담내역내역조회 업무 서비스 호출 수행 */
			BCNUIP04OutVO resultBCNUIP04S01 = BCNUIP04.getBCNUIP04S01(inVo);

			XFrame5Util.setOutputData("DS_SDDO09", resultBCNUIP04S01.getListBCNUIP04DSSDDO09SEND() , model); /** 대출정보조회 */

			LOGGER.info("##### BCNUIP04Controller BCNUIP04S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP04Controller BCNUIP04S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 상담내역등록 /BCNUIP04I01.do </p>
	 * <p>작성일자      : 2023. 3. 28.
	 * <p>작성자(author): 70320
	 * <p>설명          : 상담내역등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BCNUIP04I01.do")
	public String BCNUIP04I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BCNUIP04Controller BCNUIP04I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO09_SEND", request, response, model);

			/** 상담내역내역 등록 업무 서비스 호출 입력값 대입 */
			BCNUIP04InVO inVo = new BCNUIP04InVO();
			BCNUIP04DSSDDO09SEND targetVo = new BCNUIP04DSSDDO09SEND();
			BeanUtil.mapToBean(sourceMap, targetVo);
			inVo.setBCNUIP04DSSDDO09SEND(targetVo);

			/** 상담내역내역 등록 업무 서비스 호출 수행 */
			BCNUIP04OutVO resultBCNUIP04I01 = BCNUIP04.registerBCNUIP04I01(inVo);

			LOGGER.info("##### BCNUIP04Controller BCNUIP04I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### BCNUIP04Controller BCNUIP04I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}
}