package hanalife.b.dl.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.dl.dl.mapper.DlyReptMapper;
import hanalife.b.dl.dl.mapper.dto.DlyReptDSSDDI01DTO;
import hanalife.b.dl.dl.mapper.dto.DlyReptDSSDDO01DTO;
import hanalife.b.dl.dl.mapper.dto.DlyReptDSSDDO02DTO;
import hanalife.b.dl.dl.mapper.dto.DlyReptDSSDDO03DTO;
import hanalife.b.dl.dl.mapper.dto.DlyReptDSSDDO04DTO;
import hanalife.b.dl.dl.service.BDLDLM01Service;
import hanalife.b.dl.dl.vo.BDLDLM01DSSDDO01VO;
import hanalife.b.dl.dl.vo.BDLDLM01DSSDDO02VO;
import hanalife.b.dl.dl.vo.BDLDLM01DSSDDO03VO;
import hanalife.b.dl.dl.vo.BDLDLM01DSSDDO04VO;
import hanalife.b.dl.dl.vo.BDLDLM01S01InVO;
import hanalife.b.dl.dl.vo.BDLDLM01S01OutVO;
import hanalife.c.co.util.DateUtil;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BDLDLM01ServiceImpl.java Class
 * 클래스설명   : 연체현황조회 (BDLDLM01) Service Implements
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBDLDLM01S01 : 연체현황조회목록조회
 *              registerBDLDLM01I01 : 연체현황조회등록
 *              modifyBDLDLM01U01 : 연체현황조회수정
 *              removeBDLDLM01U01 : 연체현황조회삭제
 * </pre>
 */
@Service("BDLDLM01Service")
public class BDLDLM01ServiceImpl implements BDLDLM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BDLDLM01ServiceImpl.class);

    @Autowired
    private DlyReptMapper dlyReptMapper;

    private String sysDt   ;
    private String stndMm  ;
    private String bfmm    ;
    private String bfmmEnd ;

    /**
     * <pre>
     * 메소드명 : getBDLDLM01S01 : 연체현황목록조회(부서별)
     * 작성일자 : 2023. 3. 6.
     * 작성자(author): 70317 / younghwe.kim
     * 설명 : 연체현황조회목록을 조회 한다.
     * 메소드인수 : BDLDLM01S01InVo
     * 메소드리턴값 : BDLDLM01S01OutVo
     * 예외처리 : Exception
     * </pre>
     */
    @Override
    public BDLDLM01S01OutVO getBDLDLM01S01(BDLDLM01S01InVO inVo) throws Exception {

        /** 연체현황목록조회 서비스 결과값 객체 생성 */
        BDLDLM01S01OutVO resultVo = new BDLDLM01S01OutVO();

        /** 연체현황목록조회 조회 조건 입력값 객체 생성 및 대입 수행 */
        DlyReptDSSDDI01DTO i01Dto = new DlyReptDSSDDI01DTO();

        // 전역변수 Set
        stndMm  = inVo.getBDLDLM01DSSMDOVO().getStndDt().substring(0, 6);
        bfmm    = DateUtil.addMonth(inVo.getBDLDLM01DSSMDOVO().getStndDt(), -1).substring(0, 6);
        bfmmEnd = DateUtil.lastDayOfMonth(bfmm+"01");
        sysDt   = DateUtil.getServerDate(4); // 년월일

        i01Dto.setSrchOpt(inVo.getBDLDLM01DSSMDOVO().getSrchOpt()); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
        i01Dto.setStndDt(inVo.getBDLDLM01DSSMDOVO().getStndDt()); /** 기준일 */
        i01Dto.setMngDeptCd(inVo.getBDLDLM01DSSMDOVO().getMngDeptCd()); /** 관리부서 */
        i01Dto.setSetlDdFr(inVo.getBDLDLM01DSSMDOVO().getSetlDdFr()); /** 결제일(시작) */
        i01Dto.setSetlDdTo(inVo.getBDLDLM01DSSMDOVO().getSetlDdTo()); /** 결제일(종료) */
        i01Dto.setBndDivsEmpNoFg(inVo.getBDLDLM01DSSMDOVO().getBndDivsEmpNoFg()); /** 담당자구분 */
        i01Dto.setDivsEmpNo(inVo.getBDLDLM01DSSMDOVO().getDivsEmpNo()); /** 담당자번호 */
        i01Dto.setDlyTcntFr(inVo.getBDLDLM01DSSMDOVO().getDlyTcntFr()); /** 연체회차(시작) */
        i01Dto.setDlyTcntTo(inVo.getBDLDLM01DSSMDOVO().getDlyTcntTo()); /** 연체회자(종료) */
        i01Dto.setPrdtLrgeClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtLrgeClasCd()); /** 상품대분류 */
        i01Dto.setThmmComgTimsFr(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsFr()); /** 도래회차(시작) */
        i01Dto.setThmmComgTimsTo(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsTo()); /** 도래회차(종료) */
        i01Dto.setLoanNo(inVo.getBDLDLM01DSSMDOVO().getLoanNo()); /** 대출번호 */
        i01Dto.setLoanSeq(inVo.getBDLDLM01DSSMDOVO().getLoanSeq()); /** 대출순번 */
        i01Dto.setDlyDdCntFr(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntFr()); /** 연체일수(시작) */
        i01Dto.setDlyDdCntTo(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntTo()); /** 연체일수(종료) */
        i01Dto.setPrdtSmClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtSmClasCd()); /** 상품소분류 */
        i01Dto.setPrdtCd(inVo.getBDLDLM01DSSMDOVO().getPrdtCd()); /** 상품코드 */
        i01Dto.setChkMmstrBfmm(inVo.getBDLDLM01DSSMDOVO().getChkMmstrBfmm()); /** 월초(전월말)여부 */
        i01Dto.setNewReflFg(inVo.getBDLDLM01DSSMDOVO().getNewReflFg()); /** 대출확정여부 */
        i01Dto.setLoanPamtRamtFr(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtFr()); /** 대출상환원금(시작) */
        i01Dto.setLoanPamtRamtTo(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtTo()); /** 대출상환원금(종료) */
        i01Dto.setIvltClosExpt(inVo.getBDLDLM01DSSMDOVO().getIvltClosExpt()); /** 강제해지여부 */
        i01Dto.setBfmmEnd(bfmmEnd);
        i01Dto.setSysDt  (sysDt);
        i01Dto.setStndMm (stndMm);
        /** 연체현황목록조회(부서별) 조회 쿼리 Mapper 호출 수행 */
        List<DlyReptDSSDDO01DTO> resultDTO = dlyReptMapper.searchDeptList(i01Dto);

        /** 연체현황목록조회(부서별) 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BDLDLM01DSSDDO01VO> resultList = new ArrayList<BDLDLM01DSSDDO01VO>();
        for (DlyReptDSSDDO01DTO sourceIO : resultDTO) {
            /** 연체현황목록조회(부서별) VO에 조회된 Mapper DTO 값을 대입 */
            BDLDLM01DSSDDO01VO targetIO = new BDLDLM01DSSDDO01VO();
            targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /** 관리부서코드 */
            targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서명 */
            targetIO.setThddDlyCnt(sourceIO.getThddDlyCnt()); /** 당일연체건수 */
            targetIO.setThddDlyPamt(sourceIO.getThddDlyPamt()); /** 당일연체원금잔액 */
            targetIO.setThddDlyAmt(sourceIO.getThddDlyAmt()); /** 당일연체원리금 */
            targetIO.setThddDfee(sourceIO.getThddDfee()); /** 당일연체료 */
            targetIO.setDlySum(sourceIO.getDlySum()); /** 연체합계금액 */
            targetIO.setThddBndCnt(sourceIO.getThddBndCnt()); /** 당일건수 */
            targetIO.setThddLoanPamtRamt(sourceIO.getThddLoanPamtRamt()); /** 당일대출원금잔액 */
            targetIO.setThddBndRamt(sourceIO.getThddBndRamt()); /** 당일원금잔액 */
            targetIO.setThddAmtRat1(sourceIO.getThddAmtRat1()); /** 당일연체율+1 */
            targetIO.setThddAmtRat2(sourceIO.getThddAmtRat2()); /** 당일연체율+30 */
            targetIO.setThddAmtRat3(sourceIO.getThddAmtRat3()); /** 당일연체율+90 */
            targetIO.setThddDlyPamt1(sourceIO.getThddDlyPamt1()); /** 당일연체금액+1 */
            targetIO.setThddDlyPamt30(sourceIO.getThddDlyPamt30()); /** 당일연체금액+30 */
            targetIO.setThddDlyPamt90(sourceIO.getThddDlyPamt90()); /** 당일연체금액+90 */
            targetIO.setPamtRamt(sourceIO.getPamtRamt()); /** 대출원금잔액 */
            targetIO.setThddCntRat(sourceIO.getThddCntRat()); /** 당일연체건수 */
            /** 연체현황목록조회(부서별) List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 연체현황목록조회(부서별) 화면 출력 결과값 대입 */
        resultVo.setListBDLDLM01DSSDDO01VO(resultList);

        return resultVo;
    }

    /**
     * <pre>
     * 메소드명 : getBDLDLM01S02 : 연체현황목록조회(상품별)
     * 작성일자 : 2023. 3. 6.
     * 작성자(author): 70317 / younghwe.kim
     * 설명 : 연체현황조회목록을 조회 한다.
     * 메소드인수 : BDLDLM01S01InVo
     * 메소드리턴값 : BDLDLM01S01OutVo
     * 예외처리 : Exception
     * </pre>
     */
    @Override
    public BDLDLM01S01OutVO getBDLDLM01S02(BDLDLM01S01InVO inVo) throws Exception {

        /** 연체현황목록조회 서비스 결과값 객체 생성 */
        BDLDLM01S01OutVO resultVo = new BDLDLM01S01OutVO();

        /** 연체현황목록조회 조회 조건 입력값 객체 생성 및 대입 수행 */
        DlyReptDSSDDI01DTO i01Dto = new DlyReptDSSDDI01DTO();

        // 전역변수 Set
        stndMm  = inVo.getBDLDLM01DSSMDOVO().getStndDt().substring(0, 6);
        bfmm    = DateUtil.addMonth(inVo.getBDLDLM01DSSMDOVO().getStndDt(), -1).substring(0, 6);
        bfmmEnd = DateUtil.lastDayOfMonth(bfmm+"01");
        sysDt   = DateUtil.getServerDate(4); // 년월일

        i01Dto.setSrchOpt(inVo.getBDLDLM01DSSMDOVO().getSrchOpt()); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
        i01Dto.setStndDt(inVo.getBDLDLM01DSSMDOVO().getStndDt()); /** 기준일 */
        i01Dto.setMngDeptCd(inVo.getBDLDLM01DSSMDOVO().getMngDeptCd()); /** 관리부서 */
        i01Dto.setSetlDdFr(inVo.getBDLDLM01DSSMDOVO().getSetlDdFr()); /** 결제일(시작) */
        i01Dto.setSetlDdTo(inVo.getBDLDLM01DSSMDOVO().getSetlDdTo()); /** 결제일(종료) */
        i01Dto.setBndDivsEmpNoFg(inVo.getBDLDLM01DSSMDOVO().getBndDivsEmpNoFg()); /** 담당자구분 */
        i01Dto.setDivsEmpNo(inVo.getBDLDLM01DSSMDOVO().getDivsEmpNo()); /** 담당자번호 */
        i01Dto.setDlyTcntFr(inVo.getBDLDLM01DSSMDOVO().getDlyTcntFr()); /** 연체회차(시작) */
        i01Dto.setDlyTcntTo(inVo.getBDLDLM01DSSMDOVO().getDlyTcntTo()); /** 연체회자(종료) */
        i01Dto.setPrdtLrgeClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtLrgeClasCd()); /** 상품대분류 */
        i01Dto.setThmmComgTimsFr(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsFr()); /** 도래회차(시작) */
        i01Dto.setThmmComgTimsTo(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsTo()); /** 도래회차(종료) */
        i01Dto.setLoanNo(inVo.getBDLDLM01DSSMDOVO().getLoanNo()); /** 대출번호 */
        i01Dto.setLoanSeq(inVo.getBDLDLM01DSSMDOVO().getLoanSeq()); /** 대출순번 */
        i01Dto.setDlyDdCntFr(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntFr()); /** 연체일수(시작) */
        i01Dto.setDlyDdCntTo(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntTo()); /** 연체일수(종료) */
        i01Dto.setPrdtSmClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtSmClasCd()); /** 상품소분류 */
        i01Dto.setPrdtCd(inVo.getBDLDLM01DSSMDOVO().getPrdtCd()); /** 상품코드 */
        i01Dto.setChkMmstrBfmm(inVo.getBDLDLM01DSSMDOVO().getChkMmstrBfmm()); /** 월초(전월말)여부 */
        i01Dto.setNewReflFg(inVo.getBDLDLM01DSSMDOVO().getNewReflFg()); /** 대출확정여부 */
        i01Dto.setLoanPamtRamtFr(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtFr()); /** 대출상환원금(시작) */
        i01Dto.setLoanPamtRamtTo(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtTo()); /** 대출상환원금(종료) */
        i01Dto.setIvltClosExpt(inVo.getBDLDLM01DSSMDOVO().getIvltClosExpt()); /** 강제해지여부 */
        i01Dto.setBfmmEnd(bfmmEnd);
        i01Dto.setSysDt  (sysDt);


        /** 연체현황목록조회(상품별) 조회 쿼리 Mapper 호출 수행 */
        List<DlyReptDSSDDO02DTO> resultDTO = dlyReptMapper.searchPrdtList(i01Dto);

        /** 연체현황목록조회(상품별) 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BDLDLM01DSSDDO02VO> resultList = new ArrayList<BDLDLM01DSSDDO02VO>();
        for (DlyReptDSSDDO02DTO sourceIO : resultDTO) {
            /** 연체현황목록조회(상품별) VO에 조회된 Mapper DTO 값을 대입 */
            BDLDLM01DSSDDO02VO targetIO = new BDLDLM01DSSDDO02VO();
            targetIO.setPrdtLrgeMidClasCd(sourceIO.getPrdtLrgeMidClasCd()); /** 상품분류코드 */
            targetIO.setPrdtLrgeMidClasNm(sourceIO.getPrdtLrgeMidClasNm()); /** 상품분류코드명 */
            targetIO.setThddDlyCnt(sourceIO.getThddDlyCnt()); /** 당일연체건수 */
            targetIO.setThddDlyPamt(sourceIO.getThddDlyPamt()); /** 당일연체원금잔액 */
            targetIO.setThddDlyAmt(sourceIO.getThddDlyAmt()); /** 당일연체원리금 */
            targetIO.setThddDfee(sourceIO.getThddDfee()); /** 당일연체료 */
            targetIO.setDlySum(sourceIO.getDlySum()); /** 연체합계금액 */
            targetIO.setThddBndCnt(sourceIO.getThddBndCnt()); /** 당일건수 */
            targetIO.setThddLoanPamtRamt(sourceIO.getThddLoanPamtRamt()); /** 당일대출원금잔액 */
            targetIO.setThddBndRamt(sourceIO.getThddBndRamt()); /** 당일원금잔액 */
            targetIO.setThddAmtRat1(sourceIO.getThddAmtRat1()); /** 당일연체율+1 */
            targetIO.setThddAmtRat2(sourceIO.getThddAmtRat2()); /** 당일연체율+30 */
            targetIO.setThddAmtRat3(sourceIO.getThddAmtRat3()); /** 당일연체율+90 */
            targetIO.setThddCntRat(sourceIO.getThddCntRat()); /** 당일연체건수 */
            /** 연체현황목록조회(상품별) List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 연체현황목록조회(상품별) 화면 출력 결과값 대입 */
        resultVo.setListBDLDLM01DSSDDO02VO(resultList);

        return resultVo;

    }

    /**
     * <pre>
     * 메소드명 : getBDLDLM01S03 : 연체현황목록조회(담당자별)
     * 작성일자 : 2023. 3. 6.
     * 작성자(author): 70317 / younghwe.kim
     * 설명 : 연체현황조회목록을 조회 한다.
     * 메소드인수 : BDLDLM01S01InVo
     * 메소드리턴값 : BDLDLM01S01OutVo
     * 예외처리 : Exception
     * </pre>
     */
    @Override
    public BDLDLM01S01OutVO getBDLDLM01S03(BDLDLM01S01InVO inVo) throws Exception {

        /** 연체현황목록조회 서비스 결과값 객체 생성 */
        BDLDLM01S01OutVO resultVo = new BDLDLM01S01OutVO();

        /** 연체현황목록조회 조회 조건 입력값 객체 생성 및 대입 수행 */
        DlyReptDSSDDI01DTO i01Dto = new DlyReptDSSDDI01DTO();

        // 전역변수 Set
        stndMm  = inVo.getBDLDLM01DSSMDOVO().getStndDt().substring(0, 6);
        bfmm    = DateUtil.addMonth(inVo.getBDLDLM01DSSMDOVO().getStndDt(), -1).substring(0, 6);
        bfmmEnd = DateUtil.lastDayOfMonth(bfmm+"01");
        sysDt   = DateUtil.getServerDate(4); // 년월일

        i01Dto.setSrchOpt(inVo.getBDLDLM01DSSMDOVO().getSrchOpt()); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
        i01Dto.setStndDt(inVo.getBDLDLM01DSSMDOVO().getStndDt()); /** 기준일 */
        i01Dto.setMngDeptCd(inVo.getBDLDLM01DSSMDOVO().getMngDeptCd()); /** 관리부서 */
        i01Dto.setSetlDdFr(inVo.getBDLDLM01DSSMDOVO().getSetlDdFr()); /** 결제일(시작) */
        i01Dto.setSetlDdTo(inVo.getBDLDLM01DSSMDOVO().getSetlDdTo()); /** 결제일(종료) */
        i01Dto.setBndDivsEmpNoFg(inVo.getBDLDLM01DSSMDOVO().getBndDivsEmpNoFg()); /** 담당자구분 */
        i01Dto.setDivsEmpNo(inVo.getBDLDLM01DSSMDOVO().getDivsEmpNo()); /** 담당자번호 */
        i01Dto.setDlyTcntFr(inVo.getBDLDLM01DSSMDOVO().getDlyTcntFr()); /** 연체회차(시작) */
        i01Dto.setDlyTcntTo(inVo.getBDLDLM01DSSMDOVO().getDlyTcntTo()); /** 연체회자(종료) */
        i01Dto.setPrdtLrgeClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtLrgeClasCd()); /** 상품대분류 */
        i01Dto.setThmmComgTimsFr(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsFr()); /** 도래회차(시작) */
        i01Dto.setThmmComgTimsTo(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsTo()); /** 도래회차(종료) */
        i01Dto.setLoanNo(inVo.getBDLDLM01DSSMDOVO().getLoanNo()); /** 대출번호 */
        i01Dto.setLoanSeq(inVo.getBDLDLM01DSSMDOVO().getLoanSeq()); /** 대출순번 */
        i01Dto.setDlyDdCntFr(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntFr()); /** 연체일수(시작) */
        i01Dto.setDlyDdCntTo(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntTo()); /** 연체일수(종료) */
        i01Dto.setPrdtSmClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtSmClasCd()); /** 상품소분류 */
        i01Dto.setPrdtCd(inVo.getBDLDLM01DSSMDOVO().getPrdtCd()); /** 상품코드 */
        i01Dto.setChkMmstrBfmm(inVo.getBDLDLM01DSSMDOVO().getChkMmstrBfmm()); /** 월초(전월말)여부 */
        i01Dto.setNewReflFg(inVo.getBDLDLM01DSSMDOVO().getNewReflFg()); /** 대출확정여부 */
        i01Dto.setLoanPamtRamtFr(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtFr()); /** 대출상환원금(시작) */
        i01Dto.setLoanPamtRamtTo(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtTo()); /** 대출상환원금(종료) */
        i01Dto.setIvltClosExpt(inVo.getBDLDLM01DSSMDOVO().getIvltClosExpt()); /** 강제해지여부 */
        i01Dto.setBfmmEnd(bfmmEnd);
        i01Dto.setSysDt  (sysDt);

        /** 연체현황목록조회(담당자별) 조회 쿼리 Mapper 호출 수행 */
        List<DlyReptDSSDDO03DTO> resultDTO = dlyReptMapper.searchEmpList(i01Dto);

        /** 연체현황목록조회(담당자별) 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BDLDLM01DSSDDO03VO> resultList = new ArrayList<BDLDLM01DSSDDO03VO>();
        for (DlyReptDSSDDO03DTO sourceIO : resultDTO) {
            /** 연체현황목록조회(담당자별) VO에 조회된 Mapper DTO 값을 대입 */
            BDLDLM01DSSDDO03VO targetIO = new BDLDLM01DSSDDO03VO();
            targetIO.setDivsEmpNm(sourceIO.getDivsEmpNm()); /** 담당자명 */
            targetIO.setDivsEmpNo(sourceIO.getDivsEmpNo()); /** 담당자번호 */
            targetIO.setThddDlyCnt(sourceIO.getThddDlyCnt()); /** 당일연체건수 */
            targetIO.setThddDlyPamt(sourceIO.getThddDlyPamt()); /** 당일연체원금잔액 */
            targetIO.setThddDlyAmt(sourceIO.getThddDlyAmt()); /** 당일연체원리금 */
            targetIO.setThddDfee(sourceIO.getThddDfee()); /** 당일연체료 */
            targetIO.setDlySum(sourceIO.getDlySum()); /** 연체합계금액 */
            targetIO.setThddBndCnt(sourceIO.getThddBndCnt()); /** 당일건수 */
            targetIO.setThddLoanPamtRamt(sourceIO.getThddLoanPamtRamt()); /** 당일대출원금잔액 */
            targetIO.setThddBndRamt(sourceIO.getThddBndRamt()); /** 당일원금잔액 */
            targetIO.setThddAmtRat1(sourceIO.getThddAmtRat1()); /** 당일연체율+1 */
            targetIO.setThddAmtRat2(sourceIO.getThddAmtRat2()); /** 당일연체율+30 */
            targetIO.setThddAmtRat3(sourceIO.getThddAmtRat3()); /** 당일연체율+90 */
            targetIO.setThddCntRat(sourceIO.getThddCntRat()); /** 당일연체건수 */
            /** 연체현황목록조회(담당자별) List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 연체현황목록조회(담당자별) 화면 출력 결과값 대입 */
        resultVo.setListBDLDLM01DSSDDO03VO(resultList);

        return resultVo;

    }

    /**
     * <pre>
     * 메소드명 : getBDLDLM01S04 : 연체현황목록조회(명세)
     * 작성일자 : 2023. 3. 6.
     * 작성자(author): 70317 / younghwe.kim
     * 설명 : 연체현황목록조회(명세)을 조회 한다.
     * 메소드인수 : BDLDLM01S01InVo
     * 메소드리턴값 : BDLDLM01S01OutVo
     * 예외처리 : Exception
     * </pre>
     */
    @Override
    public BDLDLM01S01OutVO getBDLDLM01S04(BDLDLM01S01InVO inVo) throws Exception {

        /** 연체현황목록조회 서비스 결과값 객체 생성 */
        BDLDLM01S01OutVO resultVo = new BDLDLM01S01OutVO();

        /** 연체현황목록조회 조회 조건 입력값 객체 생성 및 대입 수행 */
        DlyReptDSSDDI01DTO i01Dto = new DlyReptDSSDDI01DTO();

        i01Dto.setSrchOpt(inVo.getBDLDLM01DSSMDOVO().getSrchOpt()); /** 조회구분코드(1:부서별검색, 2:상품별, 3:담당자별, 4:명세) */
        i01Dto.setStndDt(inVo.getBDLDLM01DSSMDOVO().getStndDt()); /** 기준일 */
        i01Dto.setMngDeptCd(inVo.getBDLDLM01DSSMDOVO().getMngDeptCd()); /** 관리부서 */
        i01Dto.setSetlDdFr(inVo.getBDLDLM01DSSMDOVO().getSetlDdFr()); /** 결제일(시작) */
        i01Dto.setSetlDdTo(inVo.getBDLDLM01DSSMDOVO().getSetlDdTo()); /** 결제일(종료) */
        i01Dto.setBndDivsEmpNoFg(inVo.getBDLDLM01DSSMDOVO().getBndDivsEmpNoFg()); /** 담당자구분 */
        i01Dto.setDivsEmpNo(inVo.getBDLDLM01DSSMDOVO().getDivsEmpNo()); /** 담당자번호 */
        i01Dto.setDlyTcntFr(inVo.getBDLDLM01DSSMDOVO().getDlyTcntFr()); /** 연체회차(시작) */
        i01Dto.setDlyTcntTo(inVo.getBDLDLM01DSSMDOVO().getDlyTcntTo()); /** 연체회자(종료) */
        i01Dto.setPrdtLrgeClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtLrgeClasCd()); /** 상품대분류 */
        i01Dto.setThmmComgTimsFr(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsFr()); /** 도래회차(시작) */
        i01Dto.setThmmComgTimsTo(inVo.getBDLDLM01DSSMDOVO().getThmmComgTimsTo()); /** 도래회차(종료) */
        i01Dto.setLoanNo(inVo.getBDLDLM01DSSMDOVO().getLoanNo()); /** 대출번호 */
        i01Dto.setLoanSeq(inVo.getBDLDLM01DSSMDOVO().getLoanSeq()); /** 대출순번 */
        i01Dto.setDlyDdCntFr(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntFr()); /** 연체일수(시작) */
        i01Dto.setDlyDdCntTo(inVo.getBDLDLM01DSSMDOVO().getDlyDdCntTo()); /** 연체일수(종료) */
        i01Dto.setPrdtSmClasCd(inVo.getBDLDLM01DSSMDOVO().getPrdtSmClasCd()); /** 상품소분류 */
        i01Dto.setPrdtCd(inVo.getBDLDLM01DSSMDOVO().getPrdtCd()); /** 상품코드 */
        i01Dto.setChkMmstrBfmm(inVo.getBDLDLM01DSSMDOVO().getChkMmstrBfmm()); /** 월초(전월말)여부 */
        i01Dto.setNewReflFg(inVo.getBDLDLM01DSSMDOVO().getNewReflFg()); /** 대출확정여부 */
        i01Dto.setLoanPamtRamtFr(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtFr()); /** 대출상환원금(시작) */
        i01Dto.setLoanPamtRamtTo(inVo.getBDLDLM01DSSMDOVO().getLoanPamtRamtTo()); /** 대출상환원금(종료) */
        i01Dto.setIvltClosExpt(inVo.getBDLDLM01DSSMDOVO().getIvltClosExpt()); /** 강제해지여부 */

        /** 연체현황목록조회(명세) 조회 쿼리 Mapper 호출 수행 */
        List<DlyReptDSSDDO04DTO> resultDTO = dlyReptMapper.searchSpecList(i01Dto);

        /** 연체현황목록조회(명세) 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BDLDLM01DSSDDO04VO> resultList = new ArrayList<BDLDLM01DSSDDO04VO>();
        for (DlyReptDSSDDO04DTO sourceIO : resultDTO) {
            /** 연체현황목록조회(명세) VO에 조회된 Mapper DTO 값을 대입 */
            BDLDLM01DSSDDO04VO targetIO = new BDLDLM01DSSDDO04VO();
            targetIO.setLoanNo(sourceIO.getLoanNo()); /** 대출번호 */
            targetIO.setLoanSeq(sourceIO.getLoanSeq()); /** 대출순번 */
            targetIO.setCustNm(sourceIO.getCustNm()); /** 상담인성명 */
            targetIO.setCustNo(sourceIO.getCustNo()); /** 고객번호 */
            targetIO.setSetlDd(sourceIO.getSetlDd()); /** 결제일 */
            targetIO.setBndStatNm(sourceIO.getBndStatNm()); /** 채권상태명 */
            targetIO.setDlyTcnt(sourceIO.getDlyTcnt()); /** 연체회차 */
            targetIO.setDlyPamt(sourceIO.getDlyPamt()); /** 연체원금 */
            targetIO.setDlyInt(sourceIO.getDlyInt()); /** 연체이자 */
            targetIO.setDlyAmt(sourceIO.getDlyAmt()); /** 연체금액 */
            targetIO.setLoanPamtRamt(sourceIO.getLoanPamtRamt()); /** 대출원금잔액 */
            targetIO.setLoanIntRamt(sourceIO.getLoanIntRamt()); /** 대출이자금액 */
            targetIO.setBndRamt(sourceIO.getBndRamt()); /** 채권잔액 */
            targetIO.setLoanStatNm(sourceIO.getLoanStatNm()); /** 대출상태명 */
            targetIO.setRmbrFrmlNm(sourceIO.getRmbrFrmlNm()); /**  */
            targetIO.setLeglActsStatNm(sourceIO.getLeglActsStatNm()); /**  */
            targetIO.setMrtgSmClasNm(sourceIO.getMrtgSmClasNm()); /**  */
            targetIO.setLnDivsEmpNm(sourceIO.getLnDivsEmpNm()); /** 여신담당자명 */
            targetIO.setLnDivsEmpNo(sourceIO.getLnDivsEmpNo()); /** 여신담담자번호 */
            targetIO.setBndDivsEmpNm(sourceIO.getBndDivsEmpNm()); /** 채권담당자명 */
            targetIO.setBndDivsEmpNo(sourceIO.getBndDivsEmpNo()); /** 채권담당자번호 */
            targetIO.setMakrNm(sourceIO.getMakrNm()); /**  */
            targetIO.setCprtComNm(sourceIO.getCprtComNm()); /** 제휴사명 */
            targetIO.setCprtBranNm(sourceIO.getCprtBranNm()); /** 제휴지점명 */
            targetIO.setSaleEmpNm(sourceIO.getSaleEmpNm()); /** 제휴사원명 */
            targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서명 */
            targetIO.setLoanPamt(sourceIO.getLoanPamt()); /** 대출원금 */
            targetIO.setLoanInt(sourceIO.getLoanInt()); /** 대출이자 */
            targetIO.setLoanDt(sourceIO.getLoanDt()); /** 대출일자 */
            targetIO.setLoanTerm(sourceIO.getLoanTerm()); /** 대출기간 */
            targetIO.setDfee(sourceIO.getDfee()); /** 연체료 */
            targetIO.setEprtDt(sourceIO.getEprtDt()); /** 만기일자 */
            targetIO.setDlyDdcnt(sourceIO.getDlyDdcnt()); /** 연체일수 */
            targetIO.setPrdtClasNm(sourceIO.getPrdtClasNm()); /** 상품분류코드명 */
            targetIO.setGodsNm(sourceIO.getGodsNm()); /**  */
            targetIO.setCustAddr(sourceIO.getCustAddr()); /** 고객주소 */
            targetIO.setCustTpNm(sourceIO.getCustTpNm()); /** 고객구분코드명 */
            targetIO.setDocKeepNo(sourceIO.getDocKeepNo()); /** 서류보관번호 */
            targetIO.setLeglCountRamt(sourceIO.getLeglCountRamt()); /** 법비용 */
            targetIO.setBadDebtDeprDt(sourceIO.getBadDebtDeprDt()); /** 대손상각일자 */
            targetIO.setBadDebtRcptStatCd(sourceIO.getBadDebtRcptStatCd()); /** 대손수납상태코드 */
            targetIO.setBadDebtRcptStatNm(sourceIO.getBadDebtRcptStatNm()); /** 대손수납상태코드 */
            targetIO.setBadDebtAcctDt(sourceIO.getBadDebtAcctDt()); /** 대손최종회수일자 */
            targetIO.setBadDebtSetlDt(sourceIO.getBadDebtSetlDt()); /** 대손최종결제일자 */
            targetIO.setWdrwTpCd(sourceIO.getWdrwTpCd()); /** 최종수납방법코드 */
            targetIO.setWdrwTpNm(sourceIO.getWdrwTpNm()); /** 최종수납방법코드명 */
            targetIO.setPrdtNm(sourceIO.getPrdtNm()); /** 상품명 */
            targetIO.setUnrcvRamt(sourceIO.getUnrcvRamt()); /** 인지대 */
            targetIO.setSumDlyAmt(sourceIO.getSumDlyAmt()); /** 총연체금액 */
            /** 연체현황목록조회(명세) List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
        }

        /** 연체현황목록조회(명세) 화면 출력 결과값 대입 */
        resultVo.setListBDLDLM01DSSDDO04VO(resultList);

        return resultVo;

    }

}