package hanalife.b.dl.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.dl.dl.mapper.DlyTimsReptReadMapper;
import hanalife.b.dl.dl.mapper.dto.DlyTimsReptReadDSSDDO01DTO;
import hanalife.b.dl.dl.mapper.dto.DlyTimsReptReadDSSDDO02DTO;
import hanalife.b.dl.dl.mapper.dto.DlyTimsReptReadDSSDDO03DTO;
import hanalife.b.dl.dl.mapper.dto.DlyTimsReptReadDSSDDO04DTO;
import hanalife.b.dl.dl.mapper.dto.DlyTimsReptReadDSSMDODTO;
import hanalife.b.dl.dl.service.BDLDLM03Service;
import hanalife.b.dl.dl.vo.BDLDLM03DSSDDO01VO;
import hanalife.b.dl.dl.vo.BDLDLM03DSSDDO02VO;
import hanalife.b.dl.dl.vo.BDLDLM03DSSDDO03VO;
import hanalife.b.dl.dl.vo.BDLDLM03DSSDDO04VO;
import hanalife.b.dl.dl.vo.BDLDLM03S01InVO;
import hanalife.b.dl.dl.vo.BDLDLM03S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BDLDLM03ServiceImpl.java Class
 * 클래스설명   : BDLDLM03ServiceImpl Service Implements
 * 작성일자     : 2023. 3. 17.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 17.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : geBDLDLM03S01 : 연체회차별현황 목록 조회
 * </pre>
 */
@Service("BDLDLM03Service")
public class BDLDLM03ServiceImpl implements BDLDLM03Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BDLDLM03ServiceImpl.class);

    @Autowired
    private DlyTimsReptReadMapper dlyTimsReptReadMapper;

    /** ASIS와 동일하게 조회구분 상수값 정의 */
    private static final int FIND_DEPT = 0;  // 부서별 검색
    private static final int FIND_PRDT = 1;  // 상품별 검색
    private static final int FIND_EMP  = 2;  // 담당자별 검색
    private static final int FIND_SPEC = 3;  // 명세 검색

    /**
     *<pre>
     * 메소드명      : getBDLDLM03S01 : 연체회차별현황 조회
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 연체회차별현황을 조회 한다.
     * 메소드인수    : BDLDLM03S01InVO
     * 메소드리턴값  : BDLDLM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BDLDLM03S01OutVO getBDLDLM03S01(BDLDLM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceImpl} getBDLDLM03S01 Start..}");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BDLDLM03S01OutVO                resultVo                  = new BDLDLM03S01OutVO();
        DlyTimsReptReadDSSMDODTO        dlyTimsReptReadDSSMDODto  = new DlyTimsReptReadDSSMDODTO();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        int srchOpt = Integer.parseInt(inVo.getBDLDLM03DSSMDOVO().getSrchOpt());
        dlyTimsReptReadDSSMDODto.setSrchOpt       (inVo.getBDLDLM03DSSMDOVO().getSrchOpt       ())      ;
        dlyTimsReptReadDSSMDODto.setStndDt        (inVo.getBDLDLM03DSSMDOVO().getStndDt        ())      ; // 기준일
        dlyTimsReptReadDSSMDODto.setMngDeptCd     (inVo.getBDLDLM03DSSMDOVO().getMngDeptCd     ())      ; // 관리부서
        dlyTimsReptReadDSSMDODto.setAsetSondTp    (inVo.getBDLDLM03DSSMDOVO().getAsetSondTp    ())      ; // 자산건전성
        dlyTimsReptReadDSSMDODto.setBndDivsEmpNoFg(inVo.getBDLDLM03DSSMDOVO().getBndDivsEmpNoFg())      ; // 담당자구분(채권/여신)
        dlyTimsReptReadDSSMDODto.setDivsEmpNo     (inVo.getBDLDLM03DSSMDOVO().getDivsEmpNo     ())      ; // 담당자
        dlyTimsReptReadDSSMDODto.setPrdtLrgeClasCd(inVo.getBDLDLM03DSSMDOVO().getPrdtLrgeClasCd())      ; // 상품대분류
        dlyTimsReptReadDSSMDODto.setSetlDdFr      (inVo.getBDLDLM03DSSMDOVO().getSetlDdFr      ())      ; // 결제일
        dlyTimsReptReadDSSMDODto.setSetlDdTo      (inVo.getBDLDLM03DSSMDOVO().getSetlDdTo      ())      ;
        dlyTimsReptReadDSSMDODto.setDlyTcntFr     (inVo.getBDLDLM03DSSMDOVO().getDlyTcntFr     ())      ; // 연체회차
        dlyTimsReptReadDSSMDODto.setDlyTcntTo     (inVo.getBDLDLM03DSSMDOVO().getDlyTcntTo     ())      ;
        dlyTimsReptReadDSSMDODto.setLoanNo        (inVo.getBDLDLM03DSSMDOVO().getLoanNo        ())      ; // 대출번호
        dlyTimsReptReadDSSMDODto.setLoanSeq       (inVo.getBDLDLM03DSSMDOVO().getLoanSeq       ())      ; // 대출순번
        dlyTimsReptReadDSSMDODto.setPrdtSmClasCd  (inVo.getBDLDLM03DSSMDOVO().getPrdtSmClasCd  ())      ; // 상품소분류
        dlyTimsReptReadDSSMDODto.setReptCd        (inVo.getBDLDLM03DSSMDOVO().getReptCd        ())      ; // 물품구분
        dlyTimsReptReadDSSMDODto.setThmmComgTimsFr(inVo.getBDLDLM03DSSMDOVO().getThmmComgTimsFr())      ; // 도래회차
        dlyTimsReptReadDSSMDODto.setThmmComgTimsTo(inVo.getBDLDLM03DSSMDOVO().getThmmComgTimsTo())      ;


        /**************************************************
         * ■ Call 구분값으로 분기처리 ( 조회 )
         **************************************************/
        // 화면에서 구분값을 가져온다.
        switch ( srchOpt ) {
        case FIND_DEPT : // 부서별 목록 조회
            resultVo = this._searchDeptList(dlyTimsReptReadDSSMDODto);
            break;

        case FIND_PRDT : // 상품별 목록 조회
            resultVo = this._searchPrdtList(dlyTimsReptReadDSSMDODto);
            break;

        case FIND_EMP :  // 담당자별 목록 조회
            resultVo = this._searchEmpList(dlyTimsReptReadDSSMDODto);
            break;

        case FIND_SPEC : // 명세 목록 조회
            resultVo = this._searchSpecList(dlyTimsReptReadDSSMDODto);
            break;

        default:
            throw new IllegalStateException("검색옵션이 유효하지 않습니다. : [" + srchOpt + "]");
        }

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : _searchDeptList
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 부서별 목록을 조회 한다.
     * 메소드인수    : DlyTimsReptReadDSSMDODTO
     * 메소드리턴값  : BDLDLM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    private BDLDLM03S01OutVO _searchDeptList(DlyTimsReptReadDSSMDODTO dto) throws Exception {

        /**************************************************
         * □ 초기선언
         **************************************************/
        List<BDLDLM03DSSDDO01VO> listVo     = new ArrayList<BDLDLM03DSSDDO01VO>();
        BDLDLM03S01OutVO         resultVo   = new BDLDLM03S01OutVO();


        /**************************************************
         * ■ Call 부서별 목록 조회
         **************************************************/
        List<DlyTimsReptReadDSSDDO01DTO> resultDeptList = dlyTimsReptReadMapper.searchDeptList(dto);


        /**************************************************
         * □ 부서별 목록 LOOP처리
         **************************************************/
        for(DlyTimsReptReadDSSDDO01DTO dlyTrIO : resultDeptList) {
            BDLDLM03DSSDDO01VO bdldlM03DSSDDO01Vo = new BDLDLM03DSSDDO01VO();

            bdldlM03DSSDDO01Vo.setMngDeptCd         (dlyTrIO.getMngDeptCd         ()) ; // 관리_부서_코드
            bdldlM03DSSDDO01Vo.setMngDeptNm         (dlyTrIO.getMngDeptNm         ()) ; // 관리_부서_명
            bdldlM03DSSDDO01Vo.setTcnt1DlyCnt       (dlyTrIO.getTcnt1DlyCnt       ()) ;
            bdldlM03DSSDDO01Vo.setTcnt1DlyAmt       (dlyTrIO.getTcnt1DlyAmt       ()) ;
            bdldlM03DSSDDO01Vo.setTcnt1DlyBndRamt   (dlyTrIO.getTcnt1DlyBndRamt   ()) ;
            bdldlM03DSSDDO01Vo.setSrchSctnDlyCnt    (dlyTrIO.getSrchSctnDlyCnt    ()) ;
            bdldlM03DSSDDO01Vo.setSrchSctnDlyAmt    (dlyTrIO.getSrchSctnDlyAmt    ()) ;
            bdldlM03DSSDDO01Vo.setSrchSctnDlyBndRamt(dlyTrIO.getSrchSctnDlyBndRamt()) ;
            bdldlM03DSSDDO01Vo.setOverSctnDlyCnt    (dlyTrIO.getOverSctnDlyCnt    ()) ;
            bdldlM03DSSDDO01Vo.setOverSctnDlyAmt    (dlyTrIO.getOverSctnDlyAmt    ()) ;
            bdldlM03DSSDDO01Vo.setOverSctnDlyBndRamt(dlyTrIO.getOverSctnDlyBndRamt()) ;
            bdldlM03DSSDDO01Vo.setTotDlyCnt         (dlyTrIO.getTotDlyCnt         ()) ;
            bdldlM03DSSDDO01Vo.setTotDlyAmt         (dlyTrIO.getTotDlyAmt         ()) ;
            bdldlM03DSSDDO01Vo.setTotDlyBndRamt     (dlyTrIO.getTotDlyBndRamt     ()) ;
            bdldlM03DSSDDO01Vo.setTotBndCnt         (dlyTrIO.getTotBndCnt         ()) ;
            bdldlM03DSSDDO01Vo.setTotBndRamt        (dlyTrIO.getTotBndRamt        ()) ;

            listVo.add(bdldlM03DSSDDO01Vo);

        }

        resultVo.setBDLDLM03DSSDDO01VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : _searchPrdtList
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 상품별 목록을 조회 한다.
     * 메소드인수    : DlyTimsReptReadDSSMDODTO
     * 메소드리턴값  : BDLDLM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    private BDLDLM03S01OutVO _searchPrdtList(DlyTimsReptReadDSSMDODTO dto) throws Exception {

        /**************************************************
         * □ 초기선언
         **************************************************/
        List<BDLDLM03DSSDDO02VO> listVo     = new ArrayList<BDLDLM03DSSDDO02VO>();
        BDLDLM03S01OutVO         resultVo   = new BDLDLM03S01OutVO();


        /**************************************************
         * ■ Call 상품별 목록 조회
         **************************************************/
        List<DlyTimsReptReadDSSDDO02DTO> resultPrdtList = dlyTimsReptReadMapper.searchPrdtList(dto);


        /**************************************************
         * □ 상품별 목록 LOOP처리
         **************************************************/
        for(DlyTimsReptReadDSSDDO02DTO dlyTr2IO : resultPrdtList) {
            BDLDLM03DSSDDO02VO bdldlM03DSSDDO02Vo = new BDLDLM03DSSDDO02VO();

            bdldlM03DSSDDO02Vo.setPrdtLrgeMidClasCd (dlyTr2IO.getPrdtLrgeMidClasCd ()) ; // 상품_대분류_코드
            bdldlM03DSSDDO02Vo.setPrdtLrgeMidClasNm (dlyTr2IO.getPrdtLrgeMidClasNm ()) ; // 상품_대분류_명
            bdldlM03DSSDDO02Vo.setPrdtSortOrd       (dlyTr2IO.getPrdtSortOrd       ()) ;
            bdldlM03DSSDDO02Vo.setTcnt1DlyCnt       (dlyTr2IO.getTcnt1DlyCnt       ()) ;
            bdldlM03DSSDDO02Vo.setTcnt1DlyAmt       (dlyTr2IO.getTcnt1DlyAmt       ()) ;
            bdldlM03DSSDDO02Vo.setTcnt1DlyBndRamt   (dlyTr2IO.getTcnt1DlyBndRamt   ()) ;
            bdldlM03DSSDDO02Vo.setSrchSctnDlyCnt    (dlyTr2IO.getSrchSctnDlyCnt    ()) ;
            bdldlM03DSSDDO02Vo.setSrchSctnDlyAmt    (dlyTr2IO.getSrchSctnDlyAmt    ()) ;
            bdldlM03DSSDDO02Vo.setSrchSctnDlyBndRamt(dlyTr2IO.getSrchSctnDlyBndRamt()) ;
            bdldlM03DSSDDO02Vo.setOverSctnDlyCnt    (dlyTr2IO.getOverSctnDlyCnt    ()) ;
            bdldlM03DSSDDO02Vo.setOverSctnDlyAmt    (dlyTr2IO.getOverSctnDlyAmt    ()) ;
            bdldlM03DSSDDO02Vo.setOverSctnDlyBndRamt(dlyTr2IO.getOverSctnDlyBndRamt()) ;
            bdldlM03DSSDDO02Vo.setTotDlyCnt         (dlyTr2IO.getTotDlyCnt         ()) ;
            bdldlM03DSSDDO02Vo.setTotDlyAmt         (dlyTr2IO.getTotDlyAmt         ()) ;
            bdldlM03DSSDDO02Vo.setTotDlyBndRamt     (dlyTr2IO.getTotDlyBndRamt     ()) ;
            bdldlM03DSSDDO02Vo.setTotBndCnt         (dlyTr2IO.getTotBndCnt         ()) ;
            bdldlM03DSSDDO02Vo.setTotBndRamt        (dlyTr2IO.getTotBndRamt        ()) ;

            listVo.add(bdldlM03DSSDDO02Vo);

        }

        resultVo.setBDLDLM03DSSDDO02VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : _searchEmpList
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 담당자별 목록을 조회 한다.
     * 메소드인수    : DlyTimsReptReadDSSMDODTO
     * 메소드리턴값  : BDLDLM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    private BDLDLM03S01OutVO _searchEmpList(DlyTimsReptReadDSSMDODTO dto) throws Exception {

        /**************************************************
         * □ 초기선언
         **************************************************/
        List<BDLDLM03DSSDDO03VO> listVo     = new ArrayList<BDLDLM03DSSDDO03VO>();
        BDLDLM03S01OutVO         resultVo   = new BDLDLM03S01OutVO();


        /**************************************************
         * ■ Call 담당자별 목록 조회
         **************************************************/
        List<DlyTimsReptReadDSSDDO03DTO> resultEmpList = dlyTimsReptReadMapper.searchEmpList(dto);


        /**************************************************
         * □ 담당자별 목록 LOOP처리
         **************************************************/
        for(DlyTimsReptReadDSSDDO03DTO dlyTr3IO : resultEmpList) {
            BDLDLM03DSSDDO03VO bdldlM03DSSDDO03Vo = new BDLDLM03DSSDDO03VO();

            bdldlM03DSSDDO03Vo.setBndDivsEmpCd      (dlyTr3IO.getBndDivsEmpCd      ()) ;
            bdldlM03DSSDDO03Vo.setBndDivsEmpNm      (dlyTr3IO.getBndDivsEmpNm      ()) ;
            bdldlM03DSSDDO03Vo.setDivsEmpSortOdr    (dlyTr3IO.getDivsEmpSortOdr    ()) ;
            bdldlM03DSSDDO03Vo.setTcnt1DlyCnt       (dlyTr3IO.getTcnt1DlyCnt       ()) ;
            bdldlM03DSSDDO03Vo.setTcnt1DlyAmt       (dlyTr3IO.getTcnt1DlyAmt       ()) ;
            bdldlM03DSSDDO03Vo.setTcnt1DlyBndRamt   (dlyTr3IO.getTcnt1DlyBndRamt   ()) ;
            bdldlM03DSSDDO03Vo.setSrchSctnDlyCnt    (dlyTr3IO.getSrchSctnDlyCnt    ()) ;
            bdldlM03DSSDDO03Vo.setSrchSctnDlyAmt    (dlyTr3IO.getSrchSctnDlyAmt    ()) ;
            bdldlM03DSSDDO03Vo.setSrchSctnDlyBndRamt(dlyTr3IO.getSrchSctnDlyBndRamt()) ;
            bdldlM03DSSDDO03Vo.setOverSctnDlyCnt    (dlyTr3IO.getOverSctnDlyCnt    ()) ;
            bdldlM03DSSDDO03Vo.setOverSctnDlyAmt    (dlyTr3IO.getOverSctnDlyAmt    ()) ;
            bdldlM03DSSDDO03Vo.setOverSctnDlyBndRamt(dlyTr3IO.getOverSctnDlyBndRamt()) ;
            bdldlM03DSSDDO03Vo.setTotDlyCnt         (dlyTr3IO.getTotDlyCnt         ()) ;
            bdldlM03DSSDDO03Vo.setTotDlyAmt         (dlyTr3IO.getTotDlyAmt         ()) ;
            bdldlM03DSSDDO03Vo.setTotDlyBndRamt     (dlyTr3IO.getTotDlyBndRamt     ()) ;
            bdldlM03DSSDDO03Vo.setTotBndCnt         (dlyTr3IO.getTotBndCnt         ()) ;
            bdldlM03DSSDDO03Vo.setTotBndRamt        (dlyTr3IO.getTotBndRamt        ()) ;

            listVo.add(bdldlM03DSSDDO03Vo);

        }

        resultVo.setBDLDLM03DSSDDO03VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : _searchSpecList
     * 작성일자      : 2023. 3. 20.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 명세 목록을 조회 한다.
     * 메소드인수    : DlyTimsReptReadDSSMDODTO
     * 메소드리턴값  : BDLDLM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    private BDLDLM03S01OutVO _searchSpecList(DlyTimsReptReadDSSMDODTO dto) throws Exception {

        /**************************************************
         * □ 초기선언
         **************************************************/
        List<BDLDLM03DSSDDO04VO> listVo     = new ArrayList<BDLDLM03DSSDDO04VO>();
        BDLDLM03S01OutVO         resultVo   = new BDLDLM03S01OutVO();


        /**************************************************
         * ■ Call 명세 목록 조회
         **************************************************/
        List<DlyTimsReptReadDSSDDO04DTO> resultSpecList = dlyTimsReptReadMapper.searchSpecList(dto);


        /**************************************************
         * □ 명세 목록 LOOP처리
         **************************************************/
        for(DlyTimsReptReadDSSDDO04DTO dlyTr4IO : resultSpecList) {
            BDLDLM03DSSDDO04VO bdldlM03DSSDDO04Vo = new BDLDLM03DSSDDO04VO();

            bdldlM03DSSDDO04Vo.setMngDeptNm       (dlyTr4IO.getMngDeptNm       ()) ;  /* 관리부서명       */
            bdldlM03DSSDDO04Vo.setBndDivsEmpNm    (dlyTr4IO.getBndDivsEmpNm    ()) ;  /* 채권담당사원명   */
            bdldlM03DSSDDO04Vo.setBndDivsEmpNo    (dlyTr4IO.getBndDivsEmpNo    ()) ;  /* 채권담당사원번호 */
            bdldlM03DSSDDO04Vo.setLoanNo          (dlyTr4IO.getLoanNo          ()) ;  /* 대출번호         */
            bdldlM03DSSDDO04Vo.setLoanSeq         (dlyTr4IO.getLoanSeq         ()) ;  /* 대출순번         */
            bdldlM03DSSDDO04Vo.setCustNm          (dlyTr4IO.getCustNm          ()) ;  /* 고객명           */
            bdldlM03DSSDDO04Vo.setCustNo          (dlyTr4IO.getCustNo          ()) ;  /* 고객번호         */
            bdldlM03DSSDDO04Vo.setLoanDt          (dlyTr4IO.getLoanDt          ()) ;  /* 대출일자         */
            bdldlM03DSSDDO04Vo.setThmmComgTims    (dlyTr4IO.getThmmComgTims    ()) ;  /* 당월도래회차     */
            bdldlM03DSSDDO04Vo.setDlyDdcnt        (dlyTr4IO.getDlyDdcnt        ()) ;  /* 연체일수         */
            bdldlM03DSSDDO04Vo.setDlyTcnt         (dlyTr4IO.getDlyTcnt         ()) ;  /* 연체회차         */
            bdldlM03DSSDDO04Vo.setDlyAmt          (dlyTr4IO.getDlyAmt          ()) ;  /* 연체금액         */
            bdldlM03DSSDDO04Vo.setBndRamt         (dlyTr4IO.getBndRamt         ()) ;  /* 원금잔액         */
            bdldlM03DSSDDO04Vo.setLeglActnCostRamt(dlyTr4IO.getLeglActnCostRamt()) ;  /* 법적조치비용잔액 */
            bdldlM03DSSDDO04Vo.setDlyLeasEtc      (dlyTr4IO.getDlyLeasEtc      ()) ;  /* 연체리스기타     */
            bdldlM03DSSDDO04Vo.setLeasGuarAmt     (dlyTr4IO.getLeasGuarAmt     ()) ;  /* 리스보증금       */
            bdldlM03DSSDDO04Vo.setPrdtNm          (dlyTr4IO.getPrdtNm          ()) ;  /* 상품명           */
            bdldlM03DSSDDO04Vo.setGodsNm          (dlyTr4IO.getGodsNm          ()) ;  /* 물품명           */
            bdldlM03DSSDDO04Vo.setMrtgSetRto      (dlyTr4IO.getMrtgSetRto      ()) ;  /* 담보설정비율     */
            bdldlM03DSSDDO04Vo.setCrdtStatNm      (dlyTr4IO.getCrdtStatNm      ()) ;  /* 신용상태명       */
            bdldlM03DSSDDO04Vo.setLoanStatNm      (dlyTr4IO.getLoanStatNm      ()) ;  /* 대출상태명       */
            bdldlM03DSSDDO04Vo.setLeasStatNm      (dlyTr4IO.getLeasStatNm      ()) ;  /* 리스상태명       */
            bdldlM03DSSDDO04Vo.setEprtDt          (dlyTr4IO.getEprtDt          ()) ;  /* 만기일자         */
            bdldlM03DSSDDO04Vo.setLnDivsEmpNm     (dlyTr4IO.getLnDivsEmpNm     ()) ;  /* 여신담당사원명   */
            bdldlM03DSSDDO04Vo.setLnDivsEmpNo     (dlyTr4IO.getLnDivsEmpNo     ()) ;  /* 여신담당사원번호 */
            bdldlM03DSSDDO04Vo.setBndMngPlcNm     (dlyTr4IO.getBndMngPlcNm     ()) ;  /* 채권관리처명     */
            bdldlM03DSSDDO04Vo.setCustNoTran      (dlyTr4IO.getCustNoTran      ()) ;  /* 고객번호         */
            bdldlM03DSSDDO04Vo.setReptCd          (dlyTr4IO.getReptCd          ()) ;  /* 물품구분         */
            bdldlM03DSSDDO04Vo.setPrdtSmClasCd    (dlyTr4IO.getPrdtSmClasCd    ()) ;  /* 상품소           */
            bdldlM03DSSDDO04Vo.setLoanTerm        (dlyTr4IO.getLoanTerm        ()) ;  /* 대출기간         */
            bdldlM03DSSDDO04Vo.setSetlDd          (dlyTr4IO.getSetlDd          ()) ;  /* 결제일           */
            bdldlM03DSSDDO04Vo.setDlyPamt         (dlyTr4IO.getDlyPamt         ()) ;  /* 연체원금         */
            bdldlM03DSSDDO04Vo.setDlyInt          (dlyTr4IO.getDlyInt          ()) ;  /* 연체이자         */
            bdldlM03DSSDDO04Vo.setDfee            (dlyTr4IO.getDfee            ()) ;  /* 연체로           */
            bdldlM03DSSDDO04Vo.setUnrcvRamt       (dlyTr4IO.getUnrcvRamt       ()) ;  /* 인지대           */

            listVo.add(bdldlM03DSSDDO04Vo);

        }

        resultVo.setBDLDLM03DSSDDO04VOList(listVo);

        return resultVo;

    }

}

