package hanalife.b.lm.em.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.lm.em.mapper.LeglActnCostProcMapper;
import hanalife.b.lm.em.mapper.dto.BtLeglActnAdjDescSMDODTO;
import hanalife.b.lm.em.mapper.dto.LeglActnCostTotSDDODTO;
import hanalife.b.lm.em.mapper.dto.LeglActnCostTotSMDODTO;
import hanalife.b.lm.em.mapper.dto.LeglActnCostWdrwSDDODTO;
import hanalife.b.lm.em.mapper.dto.LeglActnCostWdrwSMDODTO;
import hanalife.b.lm.em.mapper.dto.SelectAdjCnclDescSDDODTO;
import hanalife.b.lm.em.mapper.dto.SelectAdjCnclDescSMDODTO;
import hanalife.b.lm.em.mapper.dto.SelectAdjInsDescSDDODTO;
import hanalife.b.lm.em.mapper.dto.SelectAdjInsDescSMDODTO;
import hanalife.b.lm.em.mapper.dto.StLoanBaseSDDODTO;
import hanalife.b.lm.em.mapper.dto.StLoanBaseSMDODTO;
import hanalife.b.lm.em.mapper.dto.UpdateLeglActnCostRamtSMDODTO;
import hanalife.b.lm.em.service.LeglActnCostProcService;
import hanalife.b.lm.em.vo.LeglActnCostInVO;
import hanalife.b.lm.em.vo.LeglActnCostObjVO;
import hanalife.b.lm.em.vo.LeglActnCostOutVO;
import hanalife.b.lm.em.vo.LeglActnCostRsltVO;

/**
 * <pre>
 * 클래스명    : LeglActnCostProcService.java Class
 * 클래스설명  : 법적조치비용정산 조회/처리 요청/응답 수행
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70281 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70281 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("LeglActnCostProcService")
public class LeglActnCostProcServiceImpl implements LeglActnCostProcService {

	private static final Logger LOGGER = LoggerFactory.getLogger(LeglActnCostProcServiceImpl.class);
	private boolean debugFlag = false;

    @Autowired
    private LeglActnCostProcMapper leglActnCostProcMapper;

	@SuppressWarnings("unchecked")
	@Override
	public LeglActnCostOutVO calcLeglActnCost(LeglActnCostInVO inVo) throws Exception {
		LeglActnCostOutVO resultVo = new LeglActnCostOutVO();

		if (!isValidVO(inVo)) {
			resultVo.setRsltCd("E01");
			resultVo.setRsltCntn("법적조치비용정산 처리 요청 객체가 NULL입니다!");
			if (debugFlag) {
				LOGGER.debug("[법적조치비용정산 처리 결과 정보]");
				LOGGER.debug(inVo.toString());
			}

			return resultVo;
		}

		if (debugFlag) {
			LOGGER.debug("[법적조치비용정산 처리 요청 정보]");
			LOGGER.debug(resultVo.toString());
		}

		List leglActnCostObjVOList = inVo.getLeglActnCostObjVOList();
		List leglActnCostRsltVOList = inVo.getLeglActnCostRsltVOList();
		LeglActnCostRsltVO leglActnCostRsltVO = null;

		int adjResult = 0;

		try {

			for (int i = 0, n = leglActnCostObjVOList.size(); i < n; i++)
			{
				LeglActnCostObjVO leglActnCostObjVO = (LeglActnCostObjVO) leglActnCostObjVOList.get(i);
				if (debugFlag) {
					LOGGER.debug("LOAN_NO = {" + leglActnCostObjVO.getLoanNo() + "}");
					LOGGER.debug("LOAN_SEQ = {" + leglActnCostObjVO.getLoanSeq() + "}");
				}

				/* ASIS 대손로직 제외 */

				/* BT_법적_조치_비용_집계 테이블 의 요청금액 조회 */
				LeglActnCostTotSMDODTO leglActnCostTotSMDODTO = new LeglActnCostTotSMDODTO();
				leglActnCostTotSMDODTO.setLoanNo(	leglActnCostObjVO.getLoanNo());
				leglActnCostTotSMDODTO.setLoanSeq(	leglActnCostObjVO.getLoanSeq());

				LeglActnCostTotSDDODTO leglActnCostTotSDDODTO = leglActnCostProcMapper.selectLeglActnCostTot(leglActnCostTotSMDODTO);

				long lawCostAdjAmt 	= 0; // 정산금액
				long lawCostRcptamt = 0; // 수납금액
				long lawCostRamt 	= 0; // 수납후잔액

				if( leglActnCostTotSDDODTO == null ) {
					throw new Exception("법적조치비용정산 취소중 에러가 발생했습니다!");
				}

				// 청구금액 확인( LAW_COST_ASK_AMT )
				if( leglActnCostTotSDDODTO.getLawCostAskAmt() == 0 ) {
					throw new Exception("법적조치 집계테이블의 요청금액(LAW_COST_ASK_AMT)이 0입니다.\n확인해주세요!!!");
				}

				long rcptAmt = leglActnCostObjVO.getRcptAmt(); // 수납금액
				long exmpAmt = leglActnCostObjVO.getExmpAmt(); // 면제금액

				//잔액판단 (BT_법적_조치_비용_집계 테이블 의 법비용잔액 >= 수납금액 + 면제금액)
				if( leglActnCostTotSDDODTO.getLawCostRamt() >= rcptAmt + exmpAmt ) {

					//정산금액 = 수납금액 + 면제금액
					lawCostAdjAmt = rcptAmt + exmpAmt;
					//수납금액 = 수납금액
					lawCostRcptamt = rcptAmt;
					//수납후잔액 = 0
					lawCostRamt = 0;
				} else {

					//정산금액 = 법비용잔액
					lawCostAdjAmt = leglActnCostTotSDDODTO.getLawCostRamt();
					//수납금액 = 법비용잔액 - 면제금액
					lawCostRcptamt = leglActnCostTotSDDODTO.getLawCostRamt()+ exmpAmt;
					//수납후잔액 = 법비용잔액 - 수납금액
					lawCostRamt = rcptAmt - lawCostRcptamt;
				}

				if (debugFlag) {
					LOGGER.debug("정산금액 = {" + lawCostAdjAmt + "}");
					LOGGER.debug("수납금액 = {" + lawCostRcptamt + "}");
					LOGGER.debug("수납후잔액 = {" + lawCostRamt + "}");
				}

				// 처리구분 : 2 (회수) 인 경우
				if (leglActnCostObjVO.getProcDivCd().equals("2"))
				{
					// 1.1 회수테이블에 회수내역을 넣어준다.
					//법비용잔액이 존재하면 회수내역 생성
					if( leglActnCostTotSDDODTO.getLawCostRamt() != 0 ) {
						this.insertActnCostWdrw(leglActnCostObjVO, lawCostRcptamt);
					}

					//LAW_COST_ADJ_AMT + 수납금액(청입) + 면제금액(청입)
					long newLawCostAdjAmt = leglActnCostTotSDDODTO.getLawCostAdjAmt() + lawCostAdjAmt;
					//빕비용잔액 LAW_COST_RAMT = 청구금액 - 정산금액
					long newLawCostRamt   = leglActnCostTotSDDODTO.getLawCostAskAmt() - newLawCostAdjAmt;

					// 1.2 법적조치비용 집계테이블을 수정한다.
					this.updateActnCostTot(leglActnCostObjVO, newLawCostAdjAmt, newLawCostRamt);

					// 1.3 대출기본 수정한다 .
					/* BT_법적_조치_비용_집계 테이블 의 요청금액 조회 */
					StLoanBaseSMDODTO stLoanBaseSMDODTO = new StLoanBaseSMDODTO();
					stLoanBaseSMDODTO.setLoanNo(	leglActnCostObjVO.getLoanNo());
					stLoanBaseSMDODTO.setLoanSeq(	leglActnCostObjVO.getLoanSeq());
					StLoanBaseSDDODTO stLoanBaseSDDODTO = leglActnCostProcMapper.selectLoanBase(stLoanBaseSMDODTO);

					this.updateLoanBase(leglActnCostObjVO, stLoanBaseSDDODTO, lawCostAdjAmt);

					// 법비용정산내역 테이블에 정산 (정산금액 = 수납금액 + 면제금액)
					adjResult = this.insertLeglActnAdjDesc(leglActnCostObjVO, "CONFIRM");

					if(adjResult < 0)
					{
						throw new Exception("법적조치비용정산내역 insert중  에러가 발생했습니다!");
					}

					// 1.4 다 처리한 후 호출한 메서드로 아래 내역을 리턴한다.
					//leglActnCostRsltVO.setRcptAdjAmt(lawCostRcptamt);		--> lawCostAdjAmt로 변경 (면제금액이 포함된 내역으로 보내준다.)
					leglActnCostRsltVO.setRcptAdjAmt(lawCostAdjAmt); 					// 수납_정산_금액
					leglActnCostRsltVO.setRcptRamt(lawCostRamt); 						// 수납_잔액
					leglActnCostRsltVO.setExmpAdjAmt(leglActnCostObjVO.getExmpAmt()); 	// 면제_정산_금액
					leglActnCostRsltVO.setExmpRamt(0); 									// 면제_잔액
					leglActnCostRsltVO.fixNull(); 										// null제거
					leglActnCostRsltVOList.add(leglActnCostRsltVO);

				} else { // 2. 취소인 경우

					try {

						// DBSCRDT.BT_LEGL_ACTN_COST_WDRW --> RCPT_AMT[0], EXMP_AMT[1]
						// 2018-08-01 법비용정산내역 테이블에 정산하는 로직 추가 (정산금액 = 수납금액 + 면제금액)
						adjResult = this.insertLeglActnAdjDesc(leglActnCostObjVO, "CANCEL");

						// 2.1 법적조치비용회수에서 수납금액, 면제금액을 가져온다.
						LeglActnCostWdrwSMDODTO leglActnCostWdrwSMDODTO = new LeglActnCostWdrwSMDODTO();
						leglActnCostWdrwSMDODTO.setLoanNo(leglActnCostObjVO.getLoanNo());
						leglActnCostWdrwSMDODTO.setLoanSeq(leglActnCostObjVO.getLoanSeq());
						leglActnCostWdrwSMDODTO.setOrgSetlNo(leglActnCostObjVO.getOrgSetlNo());

						LeglActnCostWdrwSDDODTO leglActnCostWdrwSDDODTO = leglActnCostProcMapper.selectLeglActnCostWdrw(leglActnCostWdrwSMDODTO);

						// 2.2 회수내역에 세팅된 값을 넣어준다.
						if(leglActnCostWdrwSDDODTO.getRcptAmt() + leglActnCostWdrwSDDODTO.getExmpAmt() > 0)
						{
							this.insertActnCostWdrwCancel(leglActnCostObjVO, leglActnCostWdrwSDDODTO.getRcptAmt(), leglActnCostWdrwSDDODTO.getExmpAmt());
						}

						long newLawCostAdjAmt = leglActnCostTotSDDODTO.getLawCostAdjAmt();
						long newLawCostRamt = leglActnCostTotSDDODTO.getLawCostRamt();
						newLawCostAdjAmt -= (leglActnCostWdrwSDDODTO.getRcptAmt() + leglActnCostWdrwSDDODTO.getExmpAmt());
						newLawCostRamt =  leglActnCostTotSDDODTO.getLawCostAskAmt() - newLawCostAdjAmt;

						leglActnCostTotSDDODTO.setLawCostAdjAmt(newLawCostAdjAmt);
						leglActnCostTotSDDODTO.setLawCostRamt(lawCostRamt);

						// 2.3 법적조치비용집계테이블에 LAW_COST_ASK_AMT,  LAW_COST_ADJ_AMT과  LAW_COST_RAMT를 세팅한다.
						this.updateActnCostTot(leglActnCostObjVO, newLawCostAdjAmt, newLawCostRamt);

						// 대출기본 수정
						StLoanBaseSMDODTO stLoanBaseSMDODTO = new StLoanBaseSMDODTO();
						stLoanBaseSMDODTO.setLoanNo(	leglActnCostObjVO.getLoanNo());
						stLoanBaseSMDODTO.setLoanSeq(	leglActnCostObjVO.getLoanSeq());
						StLoanBaseSDDODTO stLoanBaseSDDODTO = leglActnCostProcMapper.selectLoanBase(stLoanBaseSMDODTO);

						this.updateLoanBaseCancel(leglActnCostObjVO, stLoanBaseSDDODTO, leglActnCostWdrwSDDODTO, lawCostRcptamt);

						// 수납정산금액
						leglActnCostRsltVO.setRcptAdjAmt(leglActnCostWdrwSDDODTO.getRcptAmt() + leglActnCostWdrwSDDODTO.getExmpAmt()); 	// 수납_정산_금액 (면제금액도 포함시킨다 )
						leglActnCostRsltVO.setRcptRamt( leglActnCostTotSDDODTO.getLawCostRamt() ); 				// 수납_잔액
						leglActnCostRsltVO.setExmpAdjAmt(leglActnCostWdrwSDDODTO.getExmpAmt()); 				// 면제_정산_금액
						leglActnCostRsltVO.setExmpRamt(leglActnCostWdrwSDDODTO.getExmpAmt()); 				// 면제_잔액
						leglActnCostRsltVO.fixNull(); 							// null제거
						leglActnCostRsltVOList.add(leglActnCostRsltVO);

					} catch (Exception e) {
						e.printStackTrace();
						resultVo.setRsltCd("E02");
						resultVo.setRsltCntn("법적조치비용정산 취소!!!!! 중 에러가 발생했습니다!");

						if (debugFlag) {
							LOGGER.debug("[법적조치비용정산 처리 결과 정보]");
							LOGGER.debug(resultVo.toString());
						}

						//throw new Exception("법적조치비용정산 처리에서 에러가발생하였습니다"+ e.getMessage());
					}
				}

				if(adjResult < 0)
				{
					throw new Exception("법적조치비용정산 취소내역 insert중 에러가 발생했습니다!");
				}
			}

		} catch (Exception e) {
			e.printStackTrace();
			resultVo.setRsltCd("E02");
			resultVo.setRsltCntn("법적조치비용정산 처리 중 에러가 발생했습니다!");
			if (debugFlag) {
				LOGGER.debug("[법적조치비용정산 처리 결과 정보]");
				LOGGER.debug(resultVo.toString());
			}

			//return resultVo;
		}

		resultVo.setRsltCd("N01");
		resultVo.setRsltCntn("법적조치비용정산 처리를 정상적으로 수행했습니다!");

		return resultVo;
	}

	private boolean isValidVO(LeglActnCostInVO leglActnCostVO) {
		if (leglActnCostVO == null || leglActnCostVO.getLeglActnCostObjVOList() == null) {
			return false;
		}
		return true;
	}

	private int insertActnCostWdrw(LeglActnCostObjVO leglActnCostObjVO, long lawCostRcptamt) throws Exception {

		int result = -1;

		LeglActnCostWdrwSMDODTO leglActnCostWdrwSMDODTO = new LeglActnCostWdrwSMDODTO();
		leglActnCostWdrwSMDODTO.setLoanNo(			leglActnCostObjVO.getLoanNo() );
		leglActnCostWdrwSMDODTO.setLoanSeq(			leglActnCostObjVO.getLoanSeq() );
		leglActnCostWdrwSMDODTO.setSetlNo(			leglActnCostObjVO.getSetlNo() );
		leglActnCostWdrwSMDODTO.setOrgSetlNo(		leglActnCostObjVO.getOrgSetlNo() );
		leglActnCostWdrwSMDODTO.setCostWdrwFg(		leglActnCostObjVO.getProcDivCd().equals("2") ? "1" : "0" ); //
		leglActnCostWdrwSMDODTO.setAcctDt( 			leglActnCostObjVO.getAcctDt() );
		leglActnCostWdrwSMDODTO.setSetlDt( 			leglActnCostObjVO.getSetlDt() );
		leglActnCostWdrwSMDODTO.setRcptAmt(			lawCostRcptamt );
		leglActnCostWdrwSMDODTO.setExmpAmt(  		leglActnCostObjVO.getExmpAmt() );
		leglActnCostWdrwSMDODTO.setProcDeptCd(  	leglActnCostObjVO.getProcDeptCd() );
		leglActnCostWdrwSMDODTO.setFrstRegEmpNo(	leglActnCostObjVO.getProcEmpNo() );
		leglActnCostWdrwSMDODTO.setLastProcEmpNo(	leglActnCostObjVO.getProcEmpNo() );
		leglActnCostWdrwSMDODTO.setAdjRamt(  		0); //임시셋팅

		result = leglActnCostProcMapper.insertLeglActnCostWdrw(leglActnCostWdrwSMDODTO);

		return result;
	}

	private int updateActnCostTot(LeglActnCostObjVO leglActnCostObjVO, long newLawCostAdjAmt, long newLawCostRamt) throws Exception {
		int result = -1;

		LeglActnCostTotSMDODTO leglActnCostTotSMDODTO = new LeglActnCostTotSMDODTO();
		leglActnCostTotSMDODTO.setLawCostAdjAmt(newLawCostAdjAmt);
		leglActnCostTotSMDODTO.setLawCostRamt(newLawCostRamt);

		//정산인경우
		if( leglActnCostObjVO.getProcDivCd().equals("2") ) {
			leglActnCostTotSMDODTO.setLawCostExmpAmt(leglActnCostObjVO.getExmpAmt());
		} else {
			leglActnCostTotSMDODTO.setLawCostExmpAmt( leglActnCostObjVO.getExmpAmt()* -1 );
		}

		leglActnCostTotSMDODTO.setLastProcEmpNo(leglActnCostObjVO.getProcEmpNo());
		leglActnCostTotSMDODTO.setLoanNo(leglActnCostObjVO.getLoanNo());
		leglActnCostTotSMDODTO.setLoanSeq(leglActnCostObjVO.getLoanSeq());

		result = leglActnCostProcMapper.updateActnCostTot(leglActnCostTotSMDODTO);

		return result;
	}

	private int updateLoanBase(LeglActnCostObjVO leglActnCostObjVO, StLoanBaseSDDODTO stLoanBaseSDDODTO, long lawCostAdjAmt) throws Exception {
		int result = -1;
		StLoanBaseSMDODTO stLoanBaseSMDODTO = new StLoanBaseSMDODTO();

		stLoanBaseSMDODTO.setRmbrLeglActsCost( stLoanBaseSDDODTO.getRmbrLeglActsCost() + lawCostAdjAmt );
		stLoanBaseSMDODTO.setExmpLeglActsCost( stLoanBaseSDDODTO.getExmpLeglActsCost() + leglActnCostObjVO.getExmpAmt() );
		stLoanBaseSMDODTO.setLeglActsCostRamt( stLoanBaseSDDODTO.getLeglActsCostRamt() - lawCostAdjAmt );
		stLoanBaseSMDODTO.setLastProcEmpNo( leglActnCostObjVO.getProcEmpNo() );
		stLoanBaseSMDODTO.setLoanNo( leglActnCostObjVO.getLoanNo() );
		stLoanBaseSMDODTO.setLoanSeq( leglActnCostObjVO.getLoanSeq() );

		result = leglActnCostProcMapper.updateLoanBase(stLoanBaseSMDODTO);

		return result;
	}

	//법적조치 개별정산 로직
	private int insertLeglActnAdjDesc(LeglActnCostObjVO leglActnCostObjVO, String decFg) throws Exception {

		int result = -1;

		try
		{
			if("CONFIRM".equals(decFg))  // 개별정산 (신청금액(정산금액) = 수납금액 + 면제금액
			{
				SelectAdjInsDescSMDODTO selectAdjInsDescSMDODTO = new SelectAdjInsDescSMDODTO();
				selectAdjInsDescSMDODTO.setApplAmt( leglActnCostObjVO.getRcptAmt() + leglActnCostObjVO.getExmpAmt() );
				selectAdjInsDescSMDODTO.setLoanNo(  leglActnCostObjVO.getLoanNo() );
				selectAdjInsDescSMDODTO.setLoanSeq( leglActnCostObjVO.getLoanSeq() );

				List<SelectAdjInsDescSDDODTO> selectAdjInsDescSDDODTO = leglActnCostProcMapper.selectAdjInsDesc(selectAdjInsDescSMDODTO);

				String loan_no  	= "";
				String loan_seq 	= "";
				String cons_sh_no 	= "";
				int	snum 			= 0;
				long rcpt_amt		= 0;
				long adj_ramt		= 0;
				long adj_amt		= 0;

				LOGGER.info("cellus_test ;:::::: StrgetSetlNo :::::::"+leglActnCostObjVO.getSetlNo())  ;
				LOGGER.info("cellus_test ;:::::: StrgetOrgSetlNo :::::::"+leglActnCostObjVO.getOrgSetlNo())  ;

				LOGGER.info("cellus_test ;:::::: getSetlNo :::::::"+Integer.parseInt(leglActnCostObjVO.getSetlNo())  );
				LOGGER.info("cellus_test ;:::::: getOrgSetlNo :::::::"+Integer.parseInt(leglActnCostObjVO.getOrgSetlNo())  );



				for( SelectAdjInsDescSDDODTO outDTO :  selectAdjInsDescSDDODTO ) {

					loan_no  	= outDTO.getLoanNo();
					loan_seq 	= outDTO.getLoanSeq();
					cons_sh_no 	= outDTO.getConsShNo();
					snum 		= outDTO.getSnum();
					rcpt_amt	= outDTO.getRcptAmt();
					adj_ramt	= outDTO.getAdjRamt();
					adj_amt		= outDTO.getAdjAmt();

					BtLeglActnAdjDescSMDODTO btLeglActnAdjDescSMDODTO = new BtLeglActnAdjDescSMDODTO();
					btLeglActnAdjDescSMDODTO.setLoanNo(loan_no);
					btLeglActnAdjDescSMDODTO.setLoanSeq(loan_seq);
					btLeglActnAdjDescSMDODTO.setConsShNo(cons_sh_no);
					btLeglActnAdjDescSMDODTO.setSnum(snum);
					btLeglActnAdjDescSMDODTO.setSetlNo(Integer.parseInt(leglActnCostObjVO.getSetlNo()) );
					btLeglActnAdjDescSMDODTO.setOrgSetlNo(0);
					btLeglActnAdjDescSMDODTO.setCnclFg("0");
					btLeglActnAdjDescSMDODTO.setCnclDt("");
					btLeglActnAdjDescSMDODTO.setAcctDt(leglActnCostObjVO.getAcctDt());
					btLeglActnAdjDescSMDODTO.setSetlDt(leglActnCostObjVO.getSetlDt());
					btLeglActnAdjDescSMDODTO.setRcptAmt(rcpt_amt);
					btLeglActnAdjDescSMDODTO.setAdjRamt(adj_ramt);
					btLeglActnAdjDescSMDODTO.setFrstRegEmpNo(leglActnCostObjVO.getProcEmpNo());
					btLeglActnAdjDescSMDODTO.setLastRegEmpNo(leglActnCostObjVO.getProcEmpNo());

					leglActnCostProcMapper.insertLeglActnAdjDesc(btLeglActnAdjDescSMDODTO);

					UpdateLeglActnCostRamtSMDODTO updateLeglActnCostRamtSMDODTO = new UpdateLeglActnCostRamtSMDODTO();
					updateLeglActnCostRamtSMDODTO.setLeglActnCostRamt(adj_ramt);
					updateLeglActnCostRamtSMDODTO.setAdjAmt(adj_amt);
					updateLeglActnCostRamtSMDODTO.setLoanNo(loan_no);
					updateLeglActnCostRamtSMDODTO.setLoanSeq(loan_seq);
					updateLeglActnCostRamtSMDODTO.setConsShNo(cons_sh_no);
					updateLeglActnCostRamtSMDODTO.setSnum(snum);

					leglActnCostProcMapper.updateLeglActnCostRamt(updateLeglActnCostRamtSMDODTO);
				}
			} else if("CANCEL".equals(decFg)) { // 개별정산취소

				String loan_no = "";
				String loan_seq = "";
				String cons_sh_no = "";
				int	snum = 0;
				long rcpt_amt = 0;
				long legl_actn_cost_ramt = 0;
				long adj_amt = 0;

				SelectAdjCnclDescSMDODTO selectAdjCnclDescSMDODTO = new SelectAdjCnclDescSMDODTO();
				selectAdjCnclDescSMDODTO.setLoanNo( leglActnCostObjVO.getLoanNo() );
				selectAdjCnclDescSMDODTO.setLoanSeq( leglActnCostObjVO.getLoanSeq() );
				selectAdjCnclDescSMDODTO.setOrgSetlNo( leglActnCostObjVO.getOrgSetlNo() );

				List<SelectAdjCnclDescSDDODTO> selectAdjCnclDescSDDODTO = leglActnCostProcMapper.selectAdjCnclDesc(selectAdjCnclDescSMDODTO);

				for( SelectAdjCnclDescSDDODTO outDTO :  selectAdjCnclDescSDDODTO ) {
					loan_no  	= outDTO.getLoanNo();
					loan_seq 	= outDTO.getLoanSeq();
					cons_sh_no 	= outDTO.getConsShNo();
					snum 		= outDTO.getSnum();
					rcpt_amt	= outDTO.getRcptAmt();
					legl_actn_cost_ramt	= outDTO.getLeglActnCostRamt();
					adj_amt		= outDTO.getAdjAmt();

					// bt_legl_adj_desc에 정산잔액을 insert 한다.
					BtLeglActnAdjDescSMDODTO btLeglActnAdjDescSMDODTO = new BtLeglActnAdjDescSMDODTO();
					btLeglActnAdjDescSMDODTO.setLoanNo(loan_no);
					btLeglActnAdjDescSMDODTO.setLoanSeq(loan_seq);
					btLeglActnAdjDescSMDODTO.setConsShNo(cons_sh_no);
					btLeglActnAdjDescSMDODTO.setSnum(snum);
					btLeglActnAdjDescSMDODTO.setSetlNo(Integer.parseInt(leglActnCostObjVO.getSetlNo()) );
					btLeglActnAdjDescSMDODTO.setOrgSetlNo(Integer.parseInt(leglActnCostObjVO.getOrgSetlNo()));
					btLeglActnAdjDescSMDODTO.setCnclFg("1");
					btLeglActnAdjDescSMDODTO.setCnclDt(leglActnCostObjVO.getAcctDt());
					btLeglActnAdjDescSMDODTO.setAcctDt(leglActnCostObjVO.getAcctDt());
					btLeglActnAdjDescSMDODTO.setSetlDt(leglActnCostObjVO.getSetlDt());
					btLeglActnAdjDescSMDODTO.setRcptAmt(rcpt_amt);
					btLeglActnAdjDescSMDODTO.setAdjRamt(legl_actn_cost_ramt);
					btLeglActnAdjDescSMDODTO.setFrstRegEmpNo(leglActnCostObjVO.getProcEmpNo());
					btLeglActnAdjDescSMDODTO.setLastRegEmpNo(leglActnCostObjVO.getProcEmpNo());

					leglActnCostProcMapper.insertLeglActnAdjDesc(btLeglActnAdjDescSMDODTO);

					UpdateLeglActnCostRamtSMDODTO updateLeglActnCostRamtSMDODTO = new UpdateLeglActnCostRamtSMDODTO();
					updateLeglActnCostRamtSMDODTO.setLeglActnCostRamt(legl_actn_cost_ramt);
					updateLeglActnCostRamtSMDODTO.setAdjAmt(adj_amt);
					updateLeglActnCostRamtSMDODTO.setLoanNo(loan_no);
					updateLeglActnCostRamtSMDODTO.setLoanSeq(loan_seq);
					updateLeglActnCostRamtSMDODTO.setConsShNo(cons_sh_no);
					updateLeglActnCostRamtSMDODTO.setSnum(snum);

					leglActnCostProcMapper.updateLeglActnCostRamt(updateLeglActnCostRamtSMDODTO);
				}
			}
		}catch (Exception e) {
			e.printStackTrace();
			throw new Exception("법적조치 개별정산 처리에서 에러가발생하였습니다"+ e.getMessage());
		}
		return result;
	}

	private int insertActnCostWdrwCancel(LeglActnCostObjVO leglActnCostObjVO, long rcptAmt, long exmpAmt ) throws Exception {

		int result = -1;

		LeglActnCostWdrwSMDODTO leglActnCostWdrwSMDODTO = new LeglActnCostWdrwSMDODTO();
		leglActnCostWdrwSMDODTO.setLoanNo(			leglActnCostObjVO.getLoanNo() );
		leglActnCostWdrwSMDODTO.setLoanSeq(			leglActnCostObjVO.getLoanSeq() );
		leglActnCostWdrwSMDODTO.setSetlNo(			leglActnCostObjVO.getSetlNo() );
		leglActnCostWdrwSMDODTO.setOrgSetlNo(		leglActnCostObjVO.getOrgSetlNo() );
		leglActnCostWdrwSMDODTO.setCostWdrwFg(		leglActnCostObjVO.getProcDivCd().equals("2") ? "1" : "0" ); //
		leglActnCostWdrwSMDODTO.setAcctDt( 			leglActnCostObjVO.getAcctDt() );
		leglActnCostWdrwSMDODTO.setSetlDt( 			leglActnCostObjVO.getSetlDt() );
		leglActnCostWdrwSMDODTO.setRcptAmt(			rcptAmt );
		leglActnCostWdrwSMDODTO.setExmpAmt(  		exmpAmt );
		leglActnCostWdrwSMDODTO.setProcDeptCd(  	leglActnCostObjVO.getProcDeptCd() );
		leglActnCostWdrwSMDODTO.setFrstRegEmpNo(	leglActnCostObjVO.getProcEmpNo() );
		leglActnCostWdrwSMDODTO.setLastProcEmpNo(	leglActnCostObjVO.getProcEmpNo() );
		leglActnCostWdrwSMDODTO.setAdjRamt(  		0); //임시셋팅

		result = leglActnCostProcMapper.insertLeglActnCostWdrw(leglActnCostWdrwSMDODTO);

		return result;
	}

	// 취소 대출기본 수정
	private int updateLoanBaseCancel(LeglActnCostObjVO leglActnCostObjVO, StLoanBaseSDDODTO stLoanBaseSDDODTO, LeglActnCostWdrwSDDODTO leglActnCostWdrwSDDODTO, long lawCostRcptamt)
			throws Exception {
		int result = -1;
		StLoanBaseSMDODTO stLoanBaseSMDODTO = new StLoanBaseSMDODTO();

		stLoanBaseSMDODTO.setRmbrLeglActsCost( stLoanBaseSDDODTO.getRmbrLeglActsCost() - ( leglActnCostWdrwSDDODTO.getRcptAmt() + leglActnCostWdrwSDDODTO.getExmpAmt() ) );
		stLoanBaseSMDODTO.setExmpLeglActsCost( stLoanBaseSDDODTO.getExmpLeglActsCost() - leglActnCostWdrwSDDODTO.getExmpAmt() );
		stLoanBaseSMDODTO.setLeglActsCostRamt( stLoanBaseSDDODTO.getLeglActsCostRamt() + ( leglActnCostWdrwSDDODTO.getRcptAmt() + leglActnCostWdrwSDDODTO.getExmpAmt() ) );
		stLoanBaseSMDODTO.setLastProcEmpNo( leglActnCostObjVO.getProcEmpNo() );
		stLoanBaseSMDODTO.setLoanNo( leglActnCostObjVO.getLoanNo() );
		stLoanBaseSMDODTO.setLoanSeq( leglActnCostObjVO.getLoanSeq() );

		result = leglActnCostProcMapper.updateLoanBase(stLoanBaseSMDODTO);

		return result;
	}

}
