package hanalife.b.lm.lm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.lm.lm.mapper.LeglActnConsAprvMapper;
import hanalife.b.lm.lm.mapper.dto.LeglActnConsAprvDSSDDO01DTO;
import hanalife.b.lm.lm.mapper.dto.LeglActnConsAprvDSSMDODTO;
import hanalife.b.lm.lm.service.BLMLMM01Service;
import hanalife.b.lm.lm.vo.BLMLMM01DSSDDO01VO;
import hanalife.b.lm.lm.vo.BLMLMM01S01InVO;
import hanalife.b.lm.lm.vo.BLMLMM01S01OutVO;
import hanalife.c.co.mapper.BtLeglActnBaseMapper;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: BLMLMM01ServiceImpl.java Class
 * 클래스설명	: 법조치품의승인내역조회 (BLMLMM01) Service Implements
 * 작성일자	: 2023. 3. 7.
 * 작성자명	: 70305 / bhansuk.ko / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBLMLMM01S01 : 법조치품의승인내역조회
 * </pre>
 */
@Service("BLMLMM01Service")
public class BLMLMM01ServiceImpl implements BLMLMM01Service {


	private static final Logger LOGGER = LoggerFactory.getLogger(BLMLMM01ServiceImpl.class);

	@Autowired
	private LeglActnConsAprvMapper leglActnConsAprvMapper;
	@Autowired
	private BtLeglActnBaseMapper btLeglActnBaseMapper;

	/**
	 * <p>메소드명			: getBLMLMM01S01 : 법조치품의승인내역조회</p>
	 * <p>작성일자			: 2023. 3. 7.
	 * <p>작성자(author)	: 70305 / kbs
	 * <p>설명			: 법조치품의승인내역을 조회 한다.</p>
	 * <p>메소드인수		: BLMLMM01S01InVo </p>
	 * <p>메소드리턴값		: BLMLMM01S01OutVo</p>
	 * <p>예외처리			: Exception</p>
	 */
	@Override
	public BLMLMM01S01OutVO getBLMLMM01S01(BLMLMM01S01InVO inVo) throws Exception {

		LOGGER.debug("{JYP} getBLMLMM01S01 Start..");

		/** 법조치품의승인내역 서비스 결과값 객체 생성 */
	    BLMLMM01S01OutVO resultVo = new BLMLMM01S01OutVO();

	    /** 법조치품의승인내역 조회 조건 입력값 객체 생성 및 대입 수행 */
	    LeglActnConsAprvDSSMDODTO i01Dto = new LeglActnConsAprvDSSMDODTO();

	    i01Dto.setConsFromDt(inVo.getBLMLMM01DSSMDOVO().getConsFromDt());	/** 품의시작일자 */
        i01Dto.setConsToDt(inVo.getBLMLMM01DSSMDOVO().getConsToDt());       /** 품의종료일자 */
        i01Dto.setDeptCd(inVo.getBLMLMM01DSSMDOVO().getDeptCd());           /** 관리부서코드 */
        i01Dto.setTpCd(inVo.getBLMLMM01DSSMDOVO().getTpCd());               /** 조회구분코드 */
        i01Dto.setReadCntn(inVo.getBLMLMM01DSSMDOVO().getReadCntn());       /** 조회구분내용 */

        LOGGER.info("##### inVO = " + i01Dto.getTpCd() );

        /** 법조치품의승인내역 조회 쿼리 Mapper 호출 수행 */
        List<LeglActnConsAprvDSSDDO01DTO> resultDTO = leglActnConsAprvMapper.searchLeglActnConsAprvList(i01Dto);

        /** 법조치품의승인내역조회 화면 출력을 위한 결과값 List VO 객체 생성 */
        List<BLMLMM01DSSDDO01VO> resultList = new ArrayList<BLMLMM01DSSDDO01VO>();
        for (LeglActnConsAprvDSSDDO01DTO sourceIO : resultDTO) {

        	/** 법조치품의승인내역조회 VO에 조회된 Mapper DTO 값을 대입 */
        	BLMLMM01DSSDDO01VO targetIO = new BLMLMM01DSSDDO01VO();

        	targetIO.setLoanNo(sourceIO.getLoanNo());				/** 대출번호 */
        	targetIO.setLoanSeq(sourceIO.getLoanSeq()); 			/** 대출SEQ */
        	targetIO.setCustNm(sourceIO.getCustNm());				/** 고객명 */
        	targetIO.setCustNo(sourceIO.getCustNo());				/** 고객번호 */
        	targetIO.setConsDt(sourceIO.getConsDt());				/** 품의일자 */
        	targetIO.setConsShNo(sourceIO.getConsShNo());			/** 품의번호 */
        	targetIO.setActnTpNm(sourceIO.getActnTpNm());			/** 조치유형 */
        	targetIO.setAskAmt(sourceIO.getAskAmt());				/** 청구금액 */
        	targetIO.setDepsAmt(sourceIO.getDepsAmt());				/** 공탁금액 */
        	targetIO.setEtcCost(sourceIO.getEtcCost());				/** 조치금액 */
        	targetIO.setConsStatNm(sourceIO.getConsStatNm());		/** 승인상태 */
        	targetIO.setMngDeptNm(sourceIO.getMngDeptNm());			/** 관리부서명 */
        	targetIO.setLnDivsEmpNm(sourceIO.getLnDivsEmpNm());		/** 담당자 */

            /** 법조치품의승인내역조회 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
		}

        /** 법조치품의승인내역조회 화면 출력 결과값 대입 */
        resultVo.setListBLMLMM01DSSDDO01VO(resultList);

        return resultVo;
	}

}
