package hanalife.b.lm.lm.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.lm.lm.service.BLMLMM05Service;
import hanalife.b.lm.lm.vo.BLMLMM05DSSMDOVO;
import hanalife.b.lm.lm.vo.BLMLMM05S01InVO;
import hanalife.b.lm.lm.vo.BLMLMM05S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 클래스명    : BLMLMM05Controller
 * 클래스설명  : 법조치진행현황조회 (BLMLMM05) Controller
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023.03.09
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.02.24][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 법조치진행현황조회 : /BLNLNM05S01.do
 * </pre>
 */
@RequestMapping("/b/lm/lm")
@Controller
public class BLMLMM05Controller {

	@Resource(name = "BLMLMM05Service")
    private BLMLMM05Service BLMLMM05;

	private static final Logger LOGGER = LoggerFactory.getLogger(BLMLMM05Controller.class);

    /**
	 * <p>메소드명      : 법조치진행현황조회 /BLNLNM05S01.do </p>
	 * <p>작성일자      : 2023. 3. 09.
	 * <p>작성자(author): 70281
	 * <p>설명          : 법조치진행 내역을 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/BLMLMM05S01.do")
	public String BLMLMM05S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### BLMLMM05Controller selectLeglActsFnshSpec Start #####");

	    try {

			/* XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> dataSetMap = XFrame5DataSetUtil.getXFrameDataSet("DS_STLOANBASE_SMDO", request, response, model);

			LOGGER.info("############################### List Before");

	        /* 법조치진행현황조회 업무 서비스 호출 입력값 대입 */
			BLMLMM05DSSMDOVO smdoVo = new BLMLMM05DSSMDOVO();

			LOGGER.debug("대출번호 : " + dataSetMap.get("loanNo"));
			smdoVo.setDeptCd((String) 			dataSetMap.get("deptCd"));			/* 관리부서코드 */
			smdoVo.setActnTpCd((String)   		dataSetMap.get("actnTpCd"));		/* 조치유형코드 */
			smdoVo.setEmpNo((String)     		dataSetMap.get("empNo"));			/* 채권담당자번호 */
			smdoVo.setCaseNoUnRegFg((String)	dataSetMap.get("caseNoUnRegFg"));	/* 사건번호미등록건유무 */
			smdoVo.setTpCd((String)       		dataSetMap.get("tpCd"));			/* 날짜유형코드 */
			smdoVo.setFromDt((String)   		dataSetMap.get("fromDt"));			/* 시작일자 */
			smdoVo.setToDt((String)   			dataSetMap.get("toDt"));			/* 종료일자 */
			smdoVo.setLoanNo((String)   		dataSetMap.get("loanNo"));			/* 대출번호 */
			smdoVo.setLoanSeq((String)   		dataSetMap.get("loanSeq"));			/* 대출번호순번 */
			smdoVo.setRsltDlyTimsStrt((String)	dataSetMap.get("rsltDlyTimsStrt"));	/* 시작연체회차 */
			smdoVo.setRsltDlyTimsEnd((String)   dataSetMap.get("rsltDlyTimsEnd"));	/* 종료연체회차 */
			smdoVo.setLoanStatCdFg((String)   	dataSetMap.get("loanStatCdFg"));	/* 대출진행여부 */
			smdoVo.setActnStatCd((String)   	dataSetMap.get("actnStatCd"));		/* 조치상태코드 */
			smdoVo.setRelCaseNo((String)   		dataSetMap.get("relCaseNo"));		/* 사건번호 */
			smdoVo.setCustNo((String)			dataSetMap.get("custNo"));			/* 고객번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            BLMLMM05S01InVO inVO = new BLMLMM05S01InVO();
            inVO.setBLMLMM05DSSMDOVO(smdoVo);    /** 법조치진행현황조회 DS_SMDO 입력값 VO 객체 대입 */

            LOGGER.info("##### inVO = " + inVO.toString() );
            LOGGER.debug("날짜유형코드 : " + smdoVo.getTpCd());
            LOGGER.debug("시작날짜 : " + smdoVo.getFromDt());
            LOGGER.debug("종료날짜 : " + smdoVo.getToDt());
            BLMLMM05S01OutVO outVo = null;
            /** 법조치진행현황조회 업무 서비스 호출 수행 */
            outVo = BLMLMM05.getBLMLMM05S01(inVO);

            if(outVo != null) {
            	XFrame5Util.setOutputData("DS_STLOANBASE_SDDO", outVo.getBLMLMM05DSSDDO01VO(), model); /** 법조치진행현황 */
            }


            LOGGER.info("##### BLMLMM05Controller BLMLMM05S01 Normal End #####");
        }
        catch (Exception e) {
        	LOGGER.error("Error >>> "+e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

        	LOGGER.info("##### BLMLMM05Controller BLMLMM05S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}
