package hanalife.b.vi.wd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.vi.wd.mapper.IntvMngMapper;
import hanalife.b.vi.wd.mapper.dto.IntvMngDSSDDO01DTO;
import hanalife.b.vi.wd.mapper.dto.IntvMngDSSDDO02DTO;
import hanalife.b.vi.wd.mapper.dto.IntvMngDSSDDO03DTO;
import hanalife.b.vi.wd.mapper.dto.IntvMngDSSMDO01DTO;
import hanalife.b.vi.wd.mapper.dto.IntvMngDSSMDO02DTO;
import hanalife.b.vi.wd.mapper.dto.IntvMngDSSMDO03DTO;
import hanalife.b.vi.wd.service.BVIWDM01Service;
import hanalife.b.vi.wd.vo.BVIWDM01DSSDDO01VO;
import hanalife.b.vi.wd.vo.BVIWDM01DSSDDO02VO;
import hanalife.b.vi.wd.vo.BVIWDM01DSSDDO03VO;
import hanalife.b.vi.wd.vo.BVIWDM01S01InVO;
import hanalife.b.vi.wd.vo.BVIWDM01S01OutVO;
import hanalife.b.vi.wd.vo.BVIWDM01S02InVO;
import hanalife.b.vi.wd.vo.BVIWDM01S02OutVO;
import hanalife.b.vi.wd.vo.BVIWDM01S03InVO;
import hanalife.b.vi.wd.vo.BVIWDM01S03OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDM01ServiceImpl.java Class
 * 클래스설명   : BVIWDM01ServiceImpl Service Implements
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBVIWDM01S01 : 면담대상자리스트조회
 *              getBVIWDM01S02 : 면담내용  리스트조회
 *              getBVIWDM01S03 : 면담            조회
 *
 * </pre>
 */
@Service("BVIWDM01Service")
public class BVIWDM01ServiceImpl implements BVIWDM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDM01ServiceImpl.class);

    /** 면담관리 mapper */
    @Autowired
    private IntvMngMapper intvMngMapper;

    /**
     *<pre>
     * 메소드명      : getBVIWDM01S01 : 면담대상자리스트조회
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 면담대상자리스트를 조회 한다.
     * 메소드인수    : BVIWDM01S01InVO
     * 메소드리턴값  : BVIWDM01S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM01S01OutVO getBVIWDM01S01(BVIWDM01S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM01S01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM01S01OutVO            resultVo                = new BVIWDM01S01OutVO();
        IntvMngDSSMDO01DTO          intvMngDSSMDO01Dto      = new IntvMngDSSMDO01DTO();
        List<BVIWDM01DSSDDO01VO>    listVo                  = new ArrayList<BVIWDM01DSSDDO01VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        intvMngDSSMDO01Dto.setLoanNo          (inVo.getBVIWDM01DSSMDO01VO().getLoanNo()             ); // 대출_번호
        intvMngDSSMDO01Dto.setLoanSeq         (inVo.getBVIWDM01DSSMDO01VO().getLoanSeq()            ); // 대출_순번
        intvMngDSSMDO01Dto.setIntvObjManResiNo(inVo.getBVIWDM01DSSMDO01VO().getIntvObjManResiNo()   ); // 고객_번호


        /**************************************************
         * ■ Call 면담관리 리스트 조회
         **************************************************/
        List<IntvMngDSSDDO01DTO> resultDto = intvMngMapper.search(intvMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(IntvMngDSSDDO01DTO intvMngIO : resultDto) {
            BVIWDM01DSSDDO01VO bviwdM01DSSDDO01Vo = new BVIWDM01DSSDDO01VO();

            bviwdM01DSSDDO01Vo.setLoanRelNm  (intvMngIO.getLoanRelNm ())  ;
            bviwdM01DSSDDO01Vo.setCustNm     (intvMngIO.getCustNm    ())  ;
            bviwdM01DSSDDO01Vo.setCustNo     (intvMngIO.getCustNo    ())  ;
            bviwdM01DSSDDO01Vo.setLoanCnt    (intvMngIO.getLoanCnt   ())  ;
            bviwdM01DSSDDO01Vo.setQuarCnt    (intvMngIO.getQuarCnt   ())  ;
            bviwdM01DSSDDO01Vo.setStrmDly1   (intvMngIO.getStrmDly1  ())  ;
            bviwdM01DSSDDO01Vo.setStrmDly2   (intvMngIO.getStrmDly2  ())  ;
            bviwdM01DSSDDO01Vo.setBadSt      (intvMngIO.getBadSt     ())  ;
            bviwdM01DSSDDO01Vo.setBadCnt     (intvMngIO.getBadCnt    ())  ;
            bviwdM01DSSDDO01Vo.setBadAmt     (intvMngIO.getBadAmt    ())  ;
            bviwdM01DSSDDO01Vo.setRlPlc      (intvMngIO.getRlPlc     ())  ;
            bviwdM01DSSDDO01Vo.setVsitDt     (intvMngIO.getVsitDt    ())  ;
            bviwdM01DSSDDO01Vo.setVsitObj    (intvMngIO.getVsitObj   ())  ;
            bviwdM01DSSDDO01Vo.setVsitRslt   (intvMngIO.getVsitRslt  ())  ;
            bviwdM01DSSDDO01Vo.setVsitTcnt   (intvMngIO.getVsitTcnt  ())  ;
            bviwdM01DSSDDO01Vo.setLoanNo     (intvMngIO.getLoanNo    ())  ;
            bviwdM01DSSDDO01Vo.setLoanSeq    (intvMngIO.getLoanSeq   ())  ;
            bviwdM01DSSDDO01Vo.setCustNoTran (intvMngIO.getCustNoTran())  ;

            listVo.add(bviwdM01DSSDDO01Vo);

        }

        resultVo.setBVIWDM01DSSDDO01VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM01S02 : 면담내용리스트조회
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 면담내용리스트를 조회 한다.
     * 메소드인수    : BVIWDM01S02InVO
     * 메소드리턴값  : BVIWDM01S02OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM01S02OutVO getBVIWDM01S02(BVIWDM01S02InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM01S02 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM01S02OutVO            resultVo                = new BVIWDM01S02OutVO();
        IntvMngDSSMDO02DTO          intvMngDSSMDO02Dto      = new IntvMngDSSMDO02DTO();
        List<BVIWDM01DSSDDO02VO>    listVo                  = new ArrayList<BVIWDM01DSSDDO02VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        intvMngDSSMDO02Dto.setLoanNo          (inVo.getBVIWDM01DSSMDO02VO().getLoanNo()             ); // 대출_번호
        intvMngDSSMDO02Dto.setLoanSeq         (inVo.getBVIWDM01DSSMDO02VO().getLoanSeq()            ); // 대출_순번
        intvMngDSSMDO02Dto.setIntvObjManResiNo(inVo.getBVIWDM01DSSMDO02VO().getIntvObjManResiNo()   ); // 고객_번호


        /**************************************************
         * ■ Call 면담내용 리스트 조회
         **************************************************/
        // ASIS의 DAO Method --> searchIntv
        List<IntvMngDSSDDO02DTO> resultDto = intvMngMapper.searchIntvCntn(intvMngDSSMDO02Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(IntvMngDSSDDO02DTO intvIO : resultDto) {
            BVIWDM01DSSDDO02VO bviwdM01DSSDDO02Vo = new BVIWDM01DSSDDO02VO();

            bviwdM01DSSDDO02Vo.setLoanNo           (intvIO.getLoanNo           ())    ; // 대출_번호
            bviwdM01DSSDDO02Vo.setLoanSeq          (intvIO.getLoanSeq          ())    ; // 대출_순번
            bviwdM01DSSDDO02Vo.setIntvObjManResiNo (intvIO.getIntvObjManResiNo ())    ;
            bviwdM01DSSDDO02Vo.setIntvObjManNm     (intvIO.getIntvObjManNm     ())    ;
            bviwdM01DSSDDO02Vo.setIntvPlanDt       (intvIO.getIntvPlanDt       ())    ;
            bviwdM01DSSDDO02Vo.setSnum             (intvIO.getSnum             ())    ;
            bviwdM01DSSDDO02Vo.setConsShNo         (intvIO.getConsShNo         ())    ;
            bviwdM01DSSDDO02Vo.setContManResiNo    (intvIO.getContManResiNo    ())    ;
            bviwdM01DSSDDO02Vo.setIntvPlcCd        (intvIO.getIntvPlcCd        ())    ;
            bviwdM01DSSDDO02Vo.setIntvPlcNm        (intvIO.getIntvPlcNm        ())    ;
            bviwdM01DSSDDO02Vo.setZipCd            (intvIO.getZipCd            ())    ;
            bviwdM01DSSDDO02Vo.setAddrCi           (intvIO.getAddrCi           ())    ;
            bviwdM01DSSDDO02Vo.setAddrGu           (intvIO.getAddrGu           ())    ;
            bviwdM01DSSDDO02Vo.setAddrDong         (intvIO.getAddrDong         ())    ;
            bviwdM01DSSDDO02Vo.setAddrSpec         (intvIO.getAddrSpec         ())    ;
            bviwdM01DSSDDO02Vo.setIntvPlanAprvFg   (intvIO.getIntvPlanAprvFg   ())    ;
            bviwdM01DSSDDO02Vo.setIntvSchdmanEmpNo (intvIO.getIntvSchdmanEmpNo ())    ;
            bviwdM01DSSDDO02Vo.setIntvSchdmanEmpNm (intvIO.getIntvSchdmanEmpNm ())    ;
            bviwdM01DSSDDO02Vo.setIntvObjCd        (intvIO.getIntvObjCd        ())    ;
            bviwdM01DSSDDO02Vo.setIntvObjNm        (intvIO.getIntvObjNm        ())    ;
            bviwdM01DSSDDO02Vo.setReqmanNm         (intvIO.getReqmanNm         ())    ;
            bviwdM01DSSDDO02Vo.setReqDt            (intvIO.getReqDt            ())    ;
            bviwdM01DSSDDO02Vo.setIntvCnfmCntn     (intvIO.getIntvCnfmCntn     ())    ;
            bviwdM01DSSDDO02Vo.setSnum2            (intvIO.getSnum2            ())    ;
            bviwdM01DSSDDO02Vo.setIntvManResiNo    (intvIO.getIntvManResiNo    ())    ;
            bviwdM01DSSDDO02Vo.setVsitDt           (intvIO.getVsitDt           ())    ; // 방문_일자
            bviwdM01DSSDDO02Vo.setIntvManNm        (intvIO.getIntvManNm        ())    ;

            listVo.add(bviwdM01DSSDDO02Vo);

        }

        resultVo.setBVIWDM01DSSDDO02VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM01S03 : 면담 조회
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 면담을(를) 조회 한다.
     * 메소드인수    : BVIWDM01S03InVO
     * 메소드리턴값  : BVIWDM01S03OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM01S03OutVO getBVIWDM01S03(BVIWDM01S03InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM01S03 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM01S03OutVO            resultVo                = new BVIWDM01S03OutVO();
        IntvMngDSSMDO03DTO          intvMngDSSMDO03Dto      = new IntvMngDSSMDO03DTO();
        List<BVIWDM01DSSDDO03VO>    listVo                  = new ArrayList<BVIWDM01DSSDDO03VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        intvMngDSSMDO03Dto.setLoanNo            (inVo.getBVIWDM01DSSMDO03VO().getLoanNo()               ); // 대출_번호
        intvMngDSSMDO03Dto.setLoanSeq           (inVo.getBVIWDM01DSSMDO03VO().getLoanSeq()              ); // 대출_순번
        intvMngDSSMDO03Dto.setIntvObjManResiNo  (inVo.getBVIWDM01DSSMDO03VO().getIntvObjManResiNo()     );
        intvMngDSSMDO03Dto.setVsitDt            (inVo.getBVIWDM01DSSMDO03VO().getVsitDt()               ); // 방문_일자
        intvMngDSSMDO03Dto.setSnum              (inVo.getBVIWDM01DSSMDO03VO().getSnum()                 ); // 일련_번호
        intvMngDSSMDO03Dto.setPlanSnum          (inVo.getBVIWDM01DSSMDO03VO().getPlanSnum()             );


        /**************************************************
         * ■ Call 면담 조회
         **************************************************/
        List<IntvMngDSSDDO03DTO> resultDto = intvMngMapper.searchIntv(intvMngDSSMDO03Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(IntvMngDSSDDO03DTO intvIO : resultDto) {
            BVIWDM01DSSDDO03VO bviwdM01DSSDDO03Vo = new BVIWDM01DSSDDO03VO();

            bviwdM01DSSDDO03Vo.setLoanNo          (intvIO.getLoanNo           ()) ; // 대출_번호
            bviwdM01DSSDDO03Vo.setLoanSeq         (intvIO.getLoanSeq          ()) ; // 대출_순번
            bviwdM01DSSDDO03Vo.setIntvManResiNo   (intvIO.getIntvManResiNo    ()) ; // 면담자_주민등록번호
            bviwdM01DSSDDO03Vo.setVsitDt          (intvIO.getVsitDt           ()) ; // 방문_일자
            bviwdM01DSSDDO03Vo.setSnum            (intvIO.getSnum             ()) ; // 일련번호
            bviwdM01DSSDDO03Vo.setIntvEmpNo       (intvIO.getIntvEmpNo        ()) ; // 방문_사원_번호
            bviwdM01DSSDDO03Vo.setIntvManNm       (intvIO.getIntvManNm        ()) ; // 면담자_명
            bviwdM01DSSDDO03Vo.setRelCd           (intvIO.getRelCd            ()) ; // 관계_코드
            bviwdM01DSSDDO03Vo.setReroomFg        (intvIO.getReroomFg         ()) ; // 면담_여부
            bviwdM01DSSDDO03Vo.setRsltSetlCd      (intvIO.getRsltSetlCd       ()) ; // 결과_결제_코드
            bviwdM01DSSDDO03Vo.setIntvObjManResiNo(intvIO.getIntvObjManResiNo ()) ; // 면담_대상자_주민등록번호
            bviwdM01DSSDDO03Vo.setIntvPlanDt      (intvIO.getIntvPlanDt       ()) ; // 면담_계획_일자
            bviwdM01DSSDDO03Vo.setPlanSnum        (intvIO.getPlanSnum         ()) ; // 계획_일련번호
            bviwdM01DSSDDO03Vo.setIntvObjCd       (intvIO.getIntvObjCd        ()) ; // 면담_목적_코드
            bviwdM01DSSDDO03Vo.setIntvRsltCd      (intvIO.getIntvRsltCd       ()) ; // 면담_결과_코드
            bviwdM01DSSDDO03Vo.setIntvPlcCd       (intvIO.getIntvPlcCd        ()) ; // 면담_장소_코드
            bviwdM01DSSDDO03Vo.setVsitAprvFg      (intvIO.getVsitAprvFg       ()) ; // 방문_승인_여부
            bviwdM01DSSDDO03Vo.setIntvCntn        (intvIO.getIntvCntn         ()) ; // 면담_내용
            bviwdM01DSSDDO03Vo.setHafPlan         (intvIO.getHafPlan          ()) ; // 향후_계획
            bviwdM01DSSDDO03Vo.setResiFg          (intvIO.getResiFg           ()) ; // 거주_여부
            bviwdM01DSSDDO03Vo.setWhrbAmbgTpCd    (intvIO.getWhrbAmbgTpCd     ()) ; // 행불_유형_코드
            bviwdM01DSSDDO03Vo.setBsnIndcCntn     (intvIO.getBsnIndcCntn      ()) ; // 업무_지시_내용
            bviwdM01DSSDDO03Vo.setPropExecPossFg  (intvIO.getPropExecPossFg   ()) ; // 동산_집행_가능_여부
            bviwdM01DSSDDO03Vo.setWdrwPossDoCd    (intvIO.getWdrwPossDoCd     ()) ; // 회수_가능_도_코드
            bviwdM01DSSDDO03Vo.setZipCd           (intvIO.getZipCd            ()) ; // 우편번호
            bviwdM01DSSDDO03Vo.setAddrCi          (intvIO.getAddrCi           ()) ; // 주소_시
            bviwdM01DSSDDO03Vo.setAddrGu          (intvIO.getAddrGu           ()) ; // 주소_구
            bviwdM01DSSDDO03Vo.setAddrDong        (intvIO.getAddrDong         ()) ; // 주소_동
            bviwdM01DSSDDO03Vo.setAddrSpec        (intvIO.getAddrSpec         ()) ; // 주소_상세
            bviwdM01DSSDDO03Vo.setMakeMan         (intvIO.getMakeMan          ()) ; // 작성자
            bviwdM01DSSDDO03Vo.setJstMan          (intvIO.getJstMan           ()) ; // 결재자
            bviwdM01DSSDDO03Vo.setIntvObjManNm    (intvIO.getIntvObjManNm     ()) ; //
            bviwdM01DSSDDO03Vo.setLoanRelNm       (intvIO.getLoanRelNm        ()) ; //

            listVo.add(bviwdM01DSSDDO03Vo);

        }

        resultVo.setBVIWDM01DSSDDO03VOList(listVo);

        return resultVo;

    }
}
