package hanalife.b.vi.wd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.vi.wd.mapper.IntvMngLdgrMapper;
import hanalife.b.vi.wd.mapper.dto.IntvMngLdgrDSSDDODTO;
import hanalife.b.vi.wd.mapper.dto.IntvMngLdgrDSSMDODTO;
import hanalife.b.vi.wd.service.BVIWDM02Service;
import hanalife.b.vi.wd.vo.BVIWDM02DSSDDOVO;
import hanalife.b.vi.wd.vo.BVIWDM02S01InVO;
import hanalife.b.vi.wd.vo.BVIWDM02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDM02ServiceImpl.java Class
 * 클래스설명   : BVIWDM02ServiceImpl Service Implements
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBVIWDM02S01 : 면담관리대장 리스트 조회
 * </pre>
 */
@Service("BVIWDM02Service")
public class BVIWDM02ServiceImpl implements BVIWDM02Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDM02ServiceImpl.class);

    /** 면담관리대장 mapper */
    @Autowired
    private IntvMngLdgrMapper intvMngLdgrMapper;

    /**
     *<pre>
     * 메소드명      : getBVIWDM02S01 : 면담관리대장 리스트 조회
     * 작성일자      : 2023. 3. 22.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 면담관리대장 리스트를 조회 한다.
     * 메소드인수    : BVIWDM02S01InVO
     * 메소드리턴값  : BVIWDM02S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM02S01OutVO getBVIWDM02S01(BVIWDM02S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM02S01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM02S01OutVO            resultVo                = new BVIWDM02S01OutVO();
        IntvMngLdgrDSSMDODTO        intvMngLdgrDSSMDODto    = new IntvMngLdgrDSSMDODTO();
        List<BVIWDM02DSSDDOVO>      listVo                  = new ArrayList<BVIWDM02DSSDDOVO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        intvMngLdgrDSSMDODto.setMngDeptCd   (inVo.getBVIWDM02DSSMDOVO().getMngDeptCd()      );
        intvMngLdgrDSSMDODto.setBndDivsEmpNo(inVo.getBVIWDM02DSSMDOVO().getBndDivsEmpNo()   );
        intvMngLdgrDSSMDODto.setIntvPlanSt  (inVo.getBVIWDM02DSSMDOVO().getIntvPlanSt()     );
        intvMngLdgrDSSMDODto.setIntvPlanEd  (inVo.getBVIWDM02DSSMDOVO().getIntvPlanEd()     );
        intvMngLdgrDSSMDODto.setIntvObjCd   (inVo.getBVIWDM02DSSMDOVO().getIntvObjCd()      );


        /**************************************************
         * ■ Call 면담관리대장 리스트 조회
         **************************************************/
        List<IntvMngLdgrDSSDDODTO> resultDto = intvMngLdgrMapper.searchIntvMngLdgr(intvMngLdgrDSSMDODto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(IntvMngLdgrDSSDDODTO intvMngLdgrIO : resultDto) {
            BVIWDM02DSSDDOVO bviwdM02DSSDDOVo = new BVIWDM02DSSDDOVO();

            bviwdM02DSSDDOVo.setBndDivsEmpNo    (intvMngLdgrIO.getBndDivsEmpNo    ()) ;
            bviwdM02DSSDDOVo.setLoanNo          (intvMngLdgrIO.getLoanNo          ()) ; // 대출_번호
            bviwdM02DSSDDOVo.setLoanSeq         (intvMngLdgrIO.getLoanSeq         ()) ; // 대출_순번
            bviwdM02DSSDDOVo.setContManNo       (intvMngLdgrIO.getContManNo       ()) ; // 고객_번호
            bviwdM02DSSDDOVo.setContManNm       (intvMngLdgrIO.getContManNm       ()) ; // 고객_명
            bviwdM02DSSDDOVo.setIntvObjManNm    (intvMngLdgrIO.getIntvObjManNm    ()) ;
            bviwdM02DSSDDOVo.setBndDivsEmpNm    (intvMngLdgrIO.getBndDivsEmpNm    ()) ; // 채권_담당자_명
            bviwdM02DSSDDOVo.setIntvPlanDt      (intvMngLdgrIO.getIntvPlanDt      ()) ;
            bviwdM02DSSDDOVo.setIntvObjNm       (intvMngLdgrIO.getIntvObjNm       ()) ;
            bviwdM02DSSDDOVo.setIntvSchdmanEmpNm(intvMngLdgrIO.getIntvSchdmanEmpNm()) ;
            bviwdM02DSSDDOVo.setAddress         (intvMngLdgrIO.getAddress         ()) ; // 주소
            bviwdM02DSSDDOVo.setVsitDt          (intvMngLdgrIO.getVsitDt          ()) ; // 방문_일자
            bviwdM02DSSDDOVo.setIntvManNm       (intvMngLdgrIO.getIntvManNm       ()) ;
            bviwdM02DSSDDOVo.setIntvRsltNm      (intvMngLdgrIO.getIntvRsltNm      ()) ;
            bviwdM02DSSDDOVo.setLoanRelNm       (intvMngLdgrIO.getLoanRelNm       ()) ; // 대출_관련인_명
            bviwdM02DSSDDOVo.setDlyTcnt         (intvMngLdgrIO.getDlyTcnt         ()) ;

            listVo.add(bviwdM02DSSDDOVo);

        }

        resultVo.setBVIWDM02DSSDDOVOList(listVo);

        return resultVo;

    }

}
