package hanalife.b.vi.wd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.vi.wd.mapper.PrptRschMngMapper;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO01DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO02DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO03DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO04DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO05DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO06DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO07DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSDDO08DTO;
import hanalife.b.vi.wd.mapper.dto.PrptRschMngDSSMDO01DTO;
import hanalife.b.vi.wd.service.BVIWDM03Service;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO01VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO02VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO03VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO04VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO05VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO06VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO07VO;
import hanalife.b.vi.wd.vo.BVIWDM03DSSDDO08VO;
import hanalife.b.vi.wd.vo.BVIWDM03S01InVO;
import hanalife.b.vi.wd.vo.BVIWDM03S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDM03ServiceImpl.java Class
 * 클래스설명   : BVIWDM03ServiceImpl Service Implements
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBVIWDM03S01 : 대출내역정보 리스트 조회
 *              getBVIWDM03S02 : 재산정보            조회
 *              getBVIWDM03S03 : 총건수       리스트 조회
 *              getBVIWDM03S04 : 부동산 TAB   리스트 조회
 *              getBVIWDM03S05 : 자동차 TAB   리스트 조회
 *              getBVIWDM03S06 : 채권         리스트 조회
 *              getBVIWDM03S07 : 동산         리스트 조회
 *              getBVIWDM03S08 : 관련인       리스트 조회
 * </pre>
 */
@Service("BVIWDM03Service")
public class BVIWDM03ServiceImpl implements BVIWDM03Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDM03ServiceImpl.class);

    /** 재산조사등록 mapper */
    @Autowired
    private PrptRschMngMapper prptRschMngMapper;

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S01 : 대출내역정보 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 대출내역정보 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S01(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO01VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO01VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setLoanNo  (inVo.getBVIWDM03DSSMDO01VO().getLoanNo()    ); // 대출_번호
        prptRschMngDSSMDO01Dto.setLoanSeq (inVo.getBVIWDM03DSSMDO01VO().getLoanSeq()   ); // 대출_순번
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()    ); // 고객_번호


        /**************************************************
         * ■ Call 대출내역정보 리스트 조회
         **************************************************/
        List<PrptRschMngDSSDDO01DTO> resultDto = prptRschMngMapper.search(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO01DTO prptRschIO : resultDto) {
            BVIWDM03DSSDDO01VO bviwd03DSSDDO01VO = new BVIWDM03DSSDDO01VO();

            bviwd03DSSDDO01VO.setLoanNo           (prptRschIO.getLoanNo          ()); // 대출_번호
            bviwd03DSSDDO01VO.setLoanSeq          (prptRschIO.getLoanSeq         ()); // 대출_순번
            bviwd03DSSDDO01VO.setCustNo           (prptRschIO.getCustNo          ()); // 고객_번호
            bviwd03DSSDDO01VO.setCustNm           (prptRschIO.getCustNm          ()); // 고객_명
            bviwd03DSSDDO01VO.setLoanPamt         (prptRschIO.getLoanPamt        ()); // 대출_원금
            bviwd03DSSDDO01VO.setLoanTerm         (prptRschIO.getLoanTerm        ()); // 대출_기간
            bviwd03DSSDDO01VO.setLoanPamtAmt      (prptRschIO.getLoanPamtAmt     ());
            bviwd03DSSDDO01VO.setLoanPamtRamt     (prptRschIO.getLoanPamtRamt    ()); // 대출_원금_잔액
            bviwd03DSSDDO01VO.setMngDeptNm        (prptRschIO.getMngDeptNm       ());
            bviwd03DSSDDO01VO.setPrdtNm           (prptRschIO.getPrdtNm          ());
            bviwd03DSSDDO01VO.setBndStatNm        (prptRschIO.getBndStatNm       ());
            bviwd03DSSDDO01VO.setFrstDlyDt        (prptRschIO.getFrstDlyDt       ());
            bviwd03DSSDDO01VO.setDlyTcnt          (prptRschIO.getDlyTcnt         ());
            bviwd03DSSDDO01VO.setDlyAmt           (prptRschIO.getDlyAmt          ());
            bviwd03DSSDDO01VO.setLnDivsEmpNo      (prptRschIO.getLnDivsEmpNo     ());
            bviwd03DSSDDO01VO.setLeglActnCostRamt (prptRschIO.getLeglActnCostRamt());
            bviwd03DSSDDO01VO.setThmmComgTims     (prptRschIO.getThmmComgTims    ());
            bviwd03DSSDDO01VO.setLeasGuarAmt      (prptRschIO.getLeasGuarAmt     ());
            bviwd03DSSDDO01VO.setLeasStatCd       (prptRschIO.getLeasStatCd      ());
            bviwd03DSSDDO01VO.setBndMngPlcNm      (prptRschIO.getBndMngPlcNm     ());
            bviwd03DSSDDO01VO.setBndDivsEmpNm     (prptRschIO.getBndDivsEmpNm    ());
            bviwd03DSSDDO01VO.setMngPlcDivCd      (prptRschIO.getMngPlcDivCd     ()); // 관리처_구분_코드
            bviwd03DSSDDO01VO.setBndDivsEmpNo     (prptRschIO.getBndDivsEmpNo    ()); // 채권_담당자_사원번호

            listVo.add(bviwd03DSSDDO01VO);

        }

        resultVo.setBVIWDM03DSSDDO01VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S02 : 재산정보 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 재산정보를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S02(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S02 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO02VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO02VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setLoanNo  (inVo.getBVIWDM03DSSMDO01VO().getLoanNo()    ); // 대출_번호
        prptRschMngDSSMDO01Dto.setLoanSeq (inVo.getBVIWDM03DSSMDO01VO().getLoanSeq()   ); // 대출_순번
        // ASIS에서 사용을 안함..
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()    ); // 고객_번호


        /**************************************************
         * ■ Call 재산정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO02DTO> resultDto = prptRschMngMapper.searchQuarantors(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO02DTO quaranIO : resultDto) {
            BVIWDM03DSSDDO02VO bviwd03DSSDDO02VO = new BVIWDM03DSSDDO02VO();

            bviwd03DSSDDO02VO.setLoanRelNm    (quaranIO.getLoanRelNm ()); // 관계
            bviwd03DSSDDO02VO.setCustNm       (quaranIO.getCustNm    ()); // 고객_명
            bviwd03DSSDDO02VO.setCustNo       (quaranIO.getCustNo    ()); // 고객_번호
            bviwd03DSSDDO02VO.setEsttCnt      (quaranIO.getEsttCnt   ()); // 부동산_건수
            bviwd03DSSDDO02VO.setCarCnt       (quaranIO.getCarCnt    ()); // 자동차_건수
            bviwd03DSSDDO02VO.setBndCnt       (quaranIO.getBndCnt    ()); // 채권_건수
            bviwd03DSSDDO02VO.setPropCnt      (quaranIO.getPropCnt   ()); // 동산_건수
            bviwd03DSSDDO02VO.setTotCnt       (quaranIO.getTotCnt    ()); // 총_건수
            bviwd03DSSDDO02VO.setCustNoTran   (quaranIO.getCustNoTran()); // 고객_번호

            listVo.add(bviwd03DSSDDO02VO);

        }

        resultVo.setBVIWDM03DSSDDO02VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S03 : 총건수 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 총건수 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S03(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S03 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO03VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO03VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setLoanNo  (inVo.getBVIWDM03DSSMDO01VO().getLoanNo()    ); // 대출_번호
        prptRschMngDSSMDO01Dto.setLoanSeq (inVo.getBVIWDM03DSSMDO01VO().getLoanSeq()   ); // 대출_순번
        // ASIS에서 사용을 안함..
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()    ); // 고객_번호


        /**************************************************
         * ■ Call 총건수 리스트정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO03DTO> resultDto = prptRschMngMapper.searchSurvey(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO03DTO surveyIO : resultDto) {
            BVIWDM03DSSDDO03VO bviwd03DSSDDO03VO = new BVIWDM03DSSDDO03VO();

            bviwd03DSSDDO03VO.setEstt (surveyIO.getEstt()); // 부동산_건수
            bviwd03DSSDDO03VO.setCar  (surveyIO.getCar ()); // 자동차_건수
            bviwd03DSSDDO03VO.setBnd  (surveyIO.getBnd ()); // 채권_건수
            bviwd03DSSDDO03VO.setProp (surveyIO.getProp()); // 동산_건수
            bviwd03DSSDDO03VO.setTot  (surveyIO.getTot ()); // 총_건수

            listVo.add(bviwd03DSSDDO03VO);

        }

        resultVo.setBVIWDM03DSSDDO03VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S04 : 부동산 TAB 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 부동산 TAB 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S04(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S04 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO04VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO04VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()    ); // 고객_번호


        /**************************************************
         * ■ Call 총건수 리스트정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO04DTO> resultDto = prptRschMngMapper.searchEstt(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO04DTO esttIO : resultDto) {
            BVIWDM03DSSDDO04VO bviwd03DSSDDO04VO = new BVIWDM03DSSDDO04VO();

            bviwd03DSSDDO04VO.setCustNo            (esttIO.getCustNo            ()) ;  // 고객_번호
            bviwd03DSSDDO04VO.setSnum              (esttIO.getSnum              ()) ;  // 일련_번호
            bviwd03DSSDDO04VO.setLoanNo            (esttIO.getLoanNo            ()) ;  // 대출_번호
            bviwd03DSSDDO04VO.setLoanSeq           (esttIO.getLoanSeq           ()) ;  // 대출_순번
            bviwd03DSSDDO04VO.setConsShNo          (esttIO.getConsShNo          ()) ;  // 품의서_번호
            bviwd03DSSDDO04VO.setPrptKindCd        (esttIO.getPrptKindCd        ()) ;  // 재산_종류_코드
            bviwd03DSSDDO04VO.setMngDeptCd         (esttIO.getMngDeptCd         ()) ;  // 관리_부서_코드
            bviwd03DSSDDO04VO.setBndDivsManEmpNo   (esttIO.getBndDivsManEmpNo   ()) ;  // 채권_담당자_사원번호
            bviwd03DSSDDO04VO.setPreRankMrtgCnt    (esttIO.getPreRankMrtgCnt    ()) ;  // 선_순위_담보_건수
            bviwd03DSSDDO04VO.setPreRankProvSeizCnt(esttIO.getPreRankProvSeizCnt()) ;  // 선_순위_가압류_건수
            bviwd03DSSDDO04VO.setPreRankProvSeizAmt(esttIO.getPreRankProvSeizAmt()) ;  // 선_순위_가압류_금액
            bviwd03DSSDDO04VO.setPreRankMrtgAmt    (esttIO.getPreRankMrtgAmt    ()) ;  // 선_순위_담보_금액
            bviwd03DSSDDO04VO.setOthOwnManNm       (esttIO.getOthOwnManNm       ()) ;  // 타인_소유자_명
            bviwd03DSSDDO04VO.setOwnRigtCesnDt     (esttIO.getOwnRigtCesnDt     ()) ;  // 소유권_이전_일자
            bviwd03DSSDDO04VO.setArea              (esttIO.getArea              ()) ;  // 면적
            bviwd03DSSDDO04VO.setAmtRegDt          (esttIO.getAmtRegDt          ()) ;  // 가_등기_일자
            bviwd03DSSDDO04VO.setAmtRegRigtMan     (esttIO.getAmtRegRigtMan     ()) ;  // 가_등기_권자
            bviwd03DSSDDO04VO.setGodsPlcZipCd      (esttIO.getGodsPlcZipCd      ()) ;  // 물건_지_우편번호
            bviwd03DSSDDO04VO.setGodsPlcAddrCi     (esttIO.getGodsPlcAddrCi     ()) ;  // 물건_지_주소_시
            bviwd03DSSDDO04VO.setGodsPlcAddrGu     (esttIO.getGodsPlcAddrGu     ()) ;  // 물건_지_주소_구
            bviwd03DSSDDO04VO.setGodsPlcAddrDong   (esttIO.getGodsPlcAddrDong   ()) ;  // 물건_지_주소_동
            bviwd03DSSDDO04VO.setGodsPlcAddrSpec   (esttIO.getGodsPlcAddrSpec   ()) ;  // 물건_지_주소_상세
            bviwd03DSSDDO04VO.setJudgAmt           (esttIO.getJudgAmt           ()) ;  // 감정가
            bviwd03DSSDDO04VO.setCnvsVal           (esttIO.getCnvsVal           ()) ;  // 환가_가치
            bviwd03DSSDDO04VO.setAddrMoveiDt       (esttIO.getAddrMoveiDt       ()) ;  // 주소_전입_일자
            bviwd03DSSDDO04VO.setDivsManRschOpn    (esttIO.getDivsManRschOpn    ()) ;  // 담당자_조사_의견
            bviwd03DSSDDO04VO.setInstNormIzeFg     (esttIO.getInstNormIzeFg     ()) ;  // 할부_정상화_여부
            bviwd03DSSDDO04VO.setRschDt            (esttIO.getRschDt            ()) ;  // 조사_일자
            bviwd03DSSDDO04VO.setActnStatOccrDt    (esttIO.getActnStatOccrDt    ()) ;  // 조치_일자
            bviwd03DSSDDO04VO.setActnTpNm          (esttIO.getActnTpNm          ()) ;  // 조치_유형
            bviwd03DSSDDO04VO.setRschmanEmpNo      (esttIO.getRschmanEmpNo      ()) ;  // 조사자명
            bviwd03DSSDDO04VO.setPrptOwnCd         (esttIO.getPrptOwnCd         ()) ;  // 재산소유코드
            bviwd03DSSDDO04VO.setRschmanEmpNm      (esttIO.getRschmanEmpNm      ()) ;  // 조사자명
            bviwd03DSSDDO04VO.setBndDivsManEmpNm   (esttIO.getBndDivsManEmpNm   ()) ;  // 채권담당자명
            bviwd03DSSDDO04VO.setFrstRegDt         (esttIO.getFrstRegDt         ()) ;  // 최초등록일
            bviwd03DSSDDO04VO.setLastProcDt        (esttIO.getLastProcDt        ()) ;  // 최종수정일
            bviwd03DSSDDO04VO.setFrstRegEmpNo      (esttIO.getFrstRegEmpNo      ()) ;  // 최초등록자
            bviwd03DSSDDO04VO.setFrstRegEmpNm      (esttIO.getFrstRegEmpNm      ()) ;  // 최초등록자명
            bviwd03DSSDDO04VO.setLastProcEmpNo     (esttIO.getLastProcEmpNo     ()) ;  // 최종수정자
            bviwd03DSSDDO04VO.setLastProcEmpNm     (esttIO.getLastProcEmpNm     ()) ;  // 최종수정자명


            listVo.add(bviwd03DSSDDO04VO);

        }

        resultVo.setBVIWDM03DSSDDO04VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S05 : 자동차 TAB 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 자동차 TAB 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S05(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S05 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO05VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO05VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()    ); // 고객_번호


        /**************************************************
         * ■ Call 자동차 TAB 리스트정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO05DTO> resultDto = prptRschMngMapper.searchCar(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO05DTO carIO : resultDto) {
            BVIWDM03DSSDDO05VO bviwdM03DSSDDO05Vo = new BVIWDM03DSSDDO05VO();

            bviwdM03DSSDDO05Vo.setCustNo            (carIO.getCustNo            ())   ; // CUST_NO   고객번호
            bviwdM03DSSDDO05Vo.setSnum              (carIO.getSnum              ())   ; // SNUM   일련번호
            bviwdM03DSSDDO05Vo.setLoanNo            (carIO.getLoanNo            ())   ; // LOAN_NO   대출_번호
            bviwdM03DSSDDO05Vo.setLoanSeq           (carIO.getLoanSeq           ())   ; // LOAN_SEQ   대출_순번
            bviwdM03DSSDDO05Vo.setConsShNo          (carIO.getConsShNo          ())   ; // CONS_SH_NO   품의서_번호
            bviwdM03DSSDDO05Vo.setPrptKindCd        (carIO.getPrptKindCd        ())   ; // PRPT_KIND_CD   재산_종류_코드
            bviwdM03DSSDDO05Vo.setMngDeptCd         (carIO.getMngDeptCd         ())   ; // MNG_DEPT_CD   관리_부서_코드
            bviwdM03DSSDDO05Vo.setBndDivsManEmpNo   (carIO.getBndDivsManEmpNo   ())   ; // BND_DIVS_MAN_EMP_NO   채권_담당자_사원번호
            bviwdM03DSSDDO05Vo.setGodsKindCd        (carIO.getGodsKindCd        ())   ; // GODS_KIND_CD   물품_종류_코드
            bviwdM03DSSDDO05Vo.setCarsNo            (carIO.getCarsNo            ())   ; // CARS_NO   차량_번호
            bviwdM03DSSDDO05Vo.setCargrpNm          (carIO.getCargrpNm          ())   ; // CARGRP_NM   차종_명
            bviwdM03DSSDDO05Vo.setMdlYear           (carIO.getMdlYear           ())   ; // MDL_YEAR   년식
            bviwdM03DSSDDO05Vo.setMakeComCd         (carIO.getMakeComCd         ())   ; // MAKE_COM_CD   제조_회사_코드
            bviwdM03DSSDDO05Vo.setPreRankMrtgCnt    (carIO.getPreRankMrtgCnt    ())   ; // PRE_RANK_MRTG_CNT   선_순위_담보_수
            bviwdM03DSSDDO05Vo.setPreRankMrtgAmt    (carIO.getPreRankMrtgAmt    ())   ; // PRE_RANK_MRTG_AMT   선_순위_담보_금액
            bviwdM03DSSDDO05Vo.setPreRankProvSeizCnt(carIO.getPreRankProvSeizCnt())   ; // PRE_RANK_PROV_SEIZ_CNT   선_순위_가압류_건수
            bviwdM03DSSDDO05Vo.setPreRankProvSeizAmt(carIO.getPreRankProvSeizAmt())   ; // PRE_RANK_PROV_SEIZ_AMT   선_순위_가압류_금액
            bviwdM03DSSDDO05Vo.setCnvsVal           (carIO.getCnvsVal           ())   ; // CNVS_VAL   환가_가치
            bviwdM03DSSDDO05Vo.setDivsManRschOpn    (carIO.getDivsManRschOpn    ())   ; // DIVS_MAN_RSCH_OPN   담당자_조사_의견
            bviwdM03DSSDDO05Vo.setInstNormIzeFg     (carIO.getInstNormIzeFg     ())   ; // INST_NORM_IZE_FG   할부_정상화_여부
            bviwdM03DSSDDO05Vo.setRschDt            (carIO.getRschDt            ())   ; // RSCH_DT   조사_일자
            bviwdM03DSSDDO05Vo.setActnStatOccrDt    (carIO.getActnStatOccrDt    ())   ; // ACTN_STAT_OCCR_DT   조치_일자
            bviwdM03DSSDDO05Vo.setActnTpNm          (carIO.getActnTpNm          ())   ; // ACTN_TP_NM   조치_유형
            bviwdM03DSSDDO05Vo.setCargrpNmNm        (carIO.getCargrpNmNm        ())   ; // CARGRP_NM_NM   차종_명
            bviwdM03DSSDDO05Vo.setRschmanEmpNo      (carIO.getRschmanEmpNo      ())   ; // RSCH_MAN_NM   조사자명
            bviwdM03DSSDDO05Vo.setGodsCd            (carIO.getGodsCd            ())   ; // GODS_CD 물품_코드

            listVo.add(bviwdM03DSSDDO05Vo);

        }

        resultVo.setBVIWDM03DSSDDO05VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S06 : 채권 TAB 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 채권 TAB 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S06(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S06 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO06VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO06VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()    ); // 고객_번호


        /**************************************************
         * ■ Call 채권 TAB 리스트정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO06DTO> resultDto = prptRschMngMapper.searchBond(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO06DTO bondIO : resultDto) {
            BVIWDM03DSSDDO06VO bviwdM03DSSDDO06Vo = new BVIWDM03DSSDDO06VO();

            bviwdM03DSSDDO06Vo.setCustNo           (bondIO.getCustNo         ())    ; //CUST_NO   고객번호
            bviwdM03DSSDDO06Vo.setSnum             (bondIO.getSnum           ())    ; //SNUM   일련번호
            bviwdM03DSSDDO06Vo.setLoanNo           (bondIO.getLoanNo         ())    ; //LOAN_NO   대출_번호
            bviwdM03DSSDDO06Vo.setLoanSeq          (bondIO.getLoanSeq        ())    ; //LOAN_SEQ   대출_순번
            bviwdM03DSSDDO06Vo.setPrptKindCd       (bondIO.getPrptKindCd     ())    ; //PRPT_KIND_CD   재산_종류_코드
            bviwdM03DSSDDO06Vo.setConsShNo         (bondIO.getConsShNo       ())    ; //CONS_SH_NO   품의서_번호
            bviwdM03DSSDDO06Vo.setMngDeptCd        (bondIO.getMngDeptCd      ())    ; //MNG_DEPT_CD   관리_부서_코드
            bviwdM03DSSDDO06Vo.setBndDivsManEmpNo  (bondIO.getBndDivsManEmpNo())    ; //BND_DIVS_MAN_EMP_NO   채권_담당자_사원번호
            bviwdM03DSSDDO06Vo.setCnvsVal          (bondIO.getCnvsVal        ())    ; //CNVS_VAL   환가_가치
            bviwdM03DSSDDO06Vo.setTirdDebtMan      (bondIO.getTirdDebtMan    ())    ; //TIRD_DEBT_MAN   제3_채무자
            bviwdM03DSSDDO06Vo.setTirdDebtRepr     (bondIO.getTirdDebtRepr   ())    ; //TIRD_DEBT_REPR   제3_채무_대표자
            bviwdM03DSSDDO06Vo.setHireDt           (bondIO.getHireDt         ())    ; //HIRE_DT   입사_일자
            bviwdM03DSSDDO06Vo.setMmSalrAmt        (bondIO.getMmSalrAmt      ())    ; //MM_SALR_AMT   월_급여_금액
            bviwdM03DSSDDO06Vo.setWorkPlcZipCd     (bondIO.getWorkPlcZipCd   ())    ; //WORK_PLC_ZIP_CD   소유자_우편번호
            bviwdM03DSSDDO06Vo.setWorkPlcAddrCi    (bondIO.getWorkPlcAddrCi  ())    ; //WORK_PLC_ADDR_CI   소유자_주소_시
            bviwdM03DSSDDO06Vo.setWorkPlcAddrGu    (bondIO.getWorkPlcAddrGu  ())    ; //WORK_PLC_ADDR_GU   소유자_주소_구
            bviwdM03DSSDDO06Vo.setWorkPlcAddrDong  (bondIO.getWorkPlcAddrDong())    ; //WORK_PLC_ADDR_DONG   소유자_주소_동
            bviwdM03DSSDDO06Vo.setWorkPlcAddrSpec  (bondIO.getWorkPlcAddrSpec())    ; //WORK_PLC_ADDR_SPEC   소유자_주소_상세
            bviwdM03DSSDDO06Vo.setFincOrgCd        (bondIO.getFincOrgCd      ())    ; //FINC_ORG_CD   금융_기관_코드
            bviwdM03DSSDDO06Vo.setDepoKindCd       (bondIO.getDepoKindCd     ())    ; //DEPO_KIND_CD   예금_종류_코드
            bviwdM03DSSDDO06Vo.setDepoAmt          (bondIO.getDepoAmt        ())    ; //DEPO_AMT   예금_금액
            bviwdM03DSSDDO06Vo.setAcntNo           (bondIO.getAcntNo         ())    ; //ACNT_NO   계좌_번호
            bviwdM03DSSDDO06Vo.setDivsManRschOpn   (bondIO.getDivsManRschOpn ())    ; //DIVS_MAN_RSCH_OPN   담당자_조사_의견
            bviwdM03DSSDDO06Vo.setInstNormIzeFg    (bondIO.getInstNormIzeFg  ())    ; //INST_NORM_IZE_FG   할부_정상화_여부
            bviwdM03DSSDDO06Vo.setRschDt           (bondIO.getRschDt         ())    ; //RSCH_DT   조사_일자
            bviwdM03DSSDDO06Vo.setActnStatOccrDt   (bondIO.getActnStatOccrDt ())    ; //ACTN_STAT_OCCR_DT   조치_일자
            bviwdM03DSSDDO06Vo.setActnTpNm         (bondIO.getActnTpNm       ())    ; //ACTN_TP_NM   조치_유형
            bviwdM03DSSDDO06Vo.setRschmanEmpNo     (bondIO.getRschmanEmpNo   ())    ; //RSCH_MAN_NM   조사자명
            bviwdM03DSSDDO06Vo.setRschmanEmpNm     (bondIO.getRschmanEmpNm   ())    ; // 조사자명
            bviwdM03DSSDDO06Vo.setBndDivsManEmpNm  (bondIO.getBndDivsManEmpNm())    ; // 채권담당자명
            bviwdM03DSSDDO06Vo.setFrstRegDt        (bondIO.getFrstRegDt      ())    ; // 최초등록일
            bviwdM03DSSDDO06Vo.setLastProcDt       (bondIO.getLastProcDt     ())    ; // 최종수정일
            bviwdM03DSSDDO06Vo.setFrstRegEmpNo     (bondIO.getFrstRegEmpNo   ())    ; // 최초등록자
            bviwdM03DSSDDO06Vo.setFrstRegEmpNm     (bondIO.getFrstRegEmpNm   ())    ; // 최초등록자명
            bviwdM03DSSDDO06Vo.setLastProcEmpNo    (bondIO.getLastProcEmpNo  ())    ; // 최종수정자
            bviwdM03DSSDDO06Vo.setLastProcEmpNm    (bondIO.getLastProcEmpNm  ())    ; // 최종수정자명

            listVo.add(bviwdM03DSSDDO06Vo);

        }

        resultVo.setBVIWDM03DSSDDO06VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S07 : 동산 TAB 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 동산 TAB 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S07(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S07 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO07VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO07VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setLoanNo  (inVo.getBVIWDM03DSSMDO01VO().getLoanNo()     ); // 대출_번호
        prptRschMngDSSMDO01Dto.setLoanSeq (inVo.getBVIWDM03DSSMDO01VO().getLoanSeq()    ); // 대출_순번
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()     ); // 고객_번호


        /**************************************************
         * ■ Call 동산 TAB 리스트정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO07DTO> resultDto = prptRschMngMapper.searchProp(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO07DTO propIO : resultDto) {
            BVIWDM03DSSDDO07VO bviwdM03DSSDDO07Vo = new BVIWDM03DSSDDO07VO();

            bviwdM03DSSDDO07Vo.setCustNo          (propIO.getCustNo         ())     ; // CUST_NO   고객번호
            bviwdM03DSSDDO07Vo.setSnum            (propIO.getSnum           ())     ; // SNUM   일련번호
            bviwdM03DSSDDO07Vo.setLoanNo          (propIO.getLoanNo         ())     ; // LOAN_NO   대출_번호
            bviwdM03DSSDDO07Vo.setLoanSeq         (propIO.getLoanSeq        ())     ; // LOAN_SEQ   대출_순번
            bviwdM03DSSDDO07Vo.setPrptKindCd      (propIO.getPrptKindCd     ())     ; // PRPT_KIND_CD   재산_종류_코드
            bviwdM03DSSDDO07Vo.setConsShNo        (propIO.getConsShNo       ())     ; // CONS_SH_NO   품의서_번호
            bviwdM03DSSDDO07Vo.setMngDeptCd       (propIO.getMngDeptCd      ())     ; // MNG_DEPT_CD   관리_부서_코드
            bviwdM03DSSDDO07Vo.setBndDivsManEmpNo (propIO.getBndDivsManEmpNo())     ; // BND_DIVS_MAN_EMP_NO   채권_담당자_사원번호
            bviwdM03DSSDDO07Vo.setQty             (propIO.getQty            ())     ; // QTY   수량
            bviwdM03DSSDDO07Vo.setJudgAmt         (propIO.getJudgAmt        ())     ; // JUDG_AMT   감정가
            bviwdM03DSSDDO07Vo.setCnvsVal         (propIO.getCnvsVal        ())     ; // CNVS_VAL   환가_가치
            bviwdM03DSSDDO07Vo.setOwnManNm        (propIO.getOwnManNm       ())     ; // OWN_MAN_NM   소유자_명
            bviwdM03DSSDDO07Vo.setOwnManZipCd     (propIO.getOwnManZipCd    ())     ; // OWN_MAN_ZIP_CD   소유자_우편번호
            bviwdM03DSSDDO07Vo.setOwnManAddrCi    (propIO.getOwnManAddrCi   ())     ; // OWN_MAN_ADDR_CI   소유자_주소_시
            bviwdM03DSSDDO07Vo.setOwnManAddrGu    (propIO.getOwnManAddrGu   ())     ; // OWN_MAN_ADDR_GU   소유자_주소_구
            bviwdM03DSSDDO07Vo.setOwnManAddrDong  (propIO.getOwnManAddrDong ())     ; // OWN_MAN_ADDR_DONG   소유자_주소_동
            bviwdM03DSSDDO07Vo.setOwnManAddrSpec  (propIO.getOwnManAddrSpec ())     ; // OWN_MAN_ADDR_SPEC   소유자_주소_상세
            bviwdM03DSSDDO07Vo.setDivsManRschOpn  (propIO.getDivsManRschOpn ())     ; // DIVS_MAN_RSCH_OPN   담당자_조사_의견
            bviwdM03DSSDDO07Vo.setInstNormIzeFg   (propIO.getInstNormIzeFg  ())     ; // INST_NORM_IZE_FG   할부_정상화_여부
            bviwdM03DSSDDO07Vo.setRschDt          (propIO.getRschDt         ())     ; // RSCH_DT   조사_일자
            bviwdM03DSSDDO07Vo.setActnStatOccrDt  (propIO.getActnStatOccrDt ())     ; // ACTN_STAT_OCCR_DT   조치_일자
            bviwdM03DSSDDO07Vo.setActnTpNm        (propIO.getActnTpNm       ())     ; // ACTN_TP_NM   조치_유형
            bviwdM03DSSDDO07Vo.setRschmanEmpNo    (propIO.getRschmanEmpNo   ())     ; // RSCH_MAN_NM   조사자명
            bviwdM03DSSDDO07Vo.setPrptOwnCd       (propIO.getPrptOwnCd      ())     ; // prptOwnCd     재산소유코드
            bviwdM03DSSDDO07Vo.setRschmanEmpNm    (propIO.getRschmanEmpNm   ())     ; // 조사자명
            bviwdM03DSSDDO07Vo.setBndDivsManEmpNm (propIO.getBndDivsManEmpNm())     ; // 채권담당자명
            bviwdM03DSSDDO07Vo.setFrstRegDt       (propIO.getFrstRegDt      ())     ; // 최초등록일
            bviwdM03DSSDDO07Vo.setLastProcDt      (propIO.getLastProcDt     ())     ; // 최종수정일
            bviwdM03DSSDDO07Vo.setFrstRegEmpNo    (propIO.getFrstRegEmpNo   ())     ; // 최초등록자
            bviwdM03DSSDDO07Vo.setFrstRegEmpNm    (propIO.getFrstRegEmpNm   ())     ; // 최초등록자명
            bviwdM03DSSDDO07Vo.setLastProcEmpNo   (propIO.getLastProcEmpNo  ())     ; // 최종수정자
            bviwdM03DSSDDO07Vo.setLastProcEmpNm   (propIO.getLastProcEmpNm  ())     ; // 최종수정자명

            listVo.add(bviwdM03DSSDDO07Vo);

        }

        resultVo.setBVIWDM03DSSDDO07VOList(listVo);

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : getBVIWDM03S08 : 관련인 TAB 리스트 조회
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70331 / P.S.Y
     * 설명          : 관련인 TAB 리스트를 조회 한다.
     * 메소드인수    : BVIWDM03S01InVO
     * 메소드리턴값  : BVIWDM03S01OutVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public BVIWDM03S01OutVO getBVIWDM03S08(BVIWDM03S01InVO inVo) throws Exception {

        LOGGER.debug("{PSY-serviceimpl} getBVIWDM03S08 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
        BVIWDM03S01OutVO            resultVo                = new BVIWDM03S01OutVO();
        PrptRschMngDSSMDO01DTO      prptRschMngDSSMDO01Dto  = new PrptRschMngDSSMDO01DTO();
        List<BVIWDM03DSSDDO08VO>    listVo                  = new ArrayList<BVIWDM03DSSDDO08VO>();


        /**************************************************
         * □ Input Data Set
         **************************************************/
        prptRschMngDSSMDO01Dto.setLoanNo  (inVo.getBVIWDM03DSSMDO01VO().getLoanNo()     ); // 대출_번호
        prptRschMngDSSMDO01Dto.setLoanSeq (inVo.getBVIWDM03DSSMDO01VO().getLoanSeq()    ); // 대출_순번
        prptRschMngDSSMDO01Dto.setCustNo  (inVo.getBVIWDM03DSSMDO01VO().getCustNo()     ); // 고객_번호


        /**************************************************
         * ■ Call 동산 TAB 리스트정보 조회
         **************************************************/
        List<PrptRschMngDSSDDO08DTO> resultDto = prptRschMngMapper.searchLoanRelMan(prptRschMngDSSMDO01Dto);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(PrptRschMngDSSDDO08DTO loanRelManIO : resultDto) {
            BVIWDM03DSSDDO08VO bviwdM03DSSDDO08Vo = new BVIWDM03DSSDDO08VO();

            bviwdM03DSSDDO08Vo.setLoanNo            (loanRelManIO.getLoanNo            ()) ; // 대출_번호
            bviwdM03DSSDDO08Vo.setLoanSeq           (loanRelManIO.getLoanSeq           ()) ; // 대출_순번
            bviwdM03DSSDDO08Vo.setCustNo            (loanRelManIO.getCustNo            ()) ; // 고객_번호
            bviwdM03DSSDDO08Vo.setLoanRelCd         (loanRelManIO.getLoanRelCd         ()) ; // 대출_관계_코드
            bviwdM03DSSDDO08Vo.setMainContManRelCd  (loanRelManIO.getMainContManRelCd  ()) ; // 주계약자_관계_코드
            bviwdM03DSSDDO08Vo.setDdlrFg            (loanRelManIO.getDdlrFg            ()) ; // 직영_여부
            bviwdM03DSSDDO08Vo.setTakeInFg          (loanRelManIO.getTakeInFg          ()) ; // 지입_여부
            bviwdM03DSSDDO08Vo.setRelMtr            (loanRelManIO.getRelMtr            ()) ; // 관계_사항
            bviwdM03DSSDDO08Vo.setMainContManFg     (loanRelManIO.getMainContManFg     ()) ; // 주계약자_여부
            bviwdM03DSSDDO08Vo.setRlDueManFg        (loanRelManIO.getRlDueManFg        ()) ; // 실납입자_여부
            bviwdM03DSSDDO08Vo.setAskPlcDivCd       (loanRelManIO.getAskPlcDivCd       ()) ; // 청구지_구분코드
            bviwdM03DSSDDO08Vo.setEmalAskFg         (loanRelManIO.getEmalAskFg         ()) ; // 전자메일_청구_여부
            bviwdM03DSSDDO08Vo.setCntcPlcDivCd      (loanRelManIO.getCntcPlcDivCd      ()) ; // 연락처_구분코드
            bviwdM03DSSDDO08Vo.setDlvrRsrvFg        (loanRelManIO.getDlvrRsrvFg        ()) ; // 발송_보류_여부
            bviwdM03DSSDDO08Vo.setContActlCnfmFg    (loanRelManIO.getContActlCnfmFg    ()) ; // 약정_사실_확인_여부
            bviwdM03DSSDDO08Vo.setContActlCnfmMethCd(loanRelManIO.getContActlCnfmMethCd()) ; // 약정_사실_확인_방법_코드
            bviwdM03DSSDDO08Vo.setContActlTelcDt    (loanRelManIO.getContActlTelcDt    ()) ; // 약정_사실_통화1_일자
            bviwdM03DSSDDO08Vo.setContActlTelcTm    (loanRelManIO.getContActlTelcTm    ()) ; // 약정_사실_통화1_시각
            bviwdM03DSSDDO08Vo.setContActlTelcDesc  (loanRelManIO.getContActlTelcDesc  ()) ; // 약정_사실_통화1_내역
            bviwdM03DSSDDO08Vo.setContProcEmpNo     (loanRelManIO.getContProcEmpNo     ()) ; // 약정_처리_사원번호
            bviwdM03DSSDDO08Vo.setLoanRelNm         (loanRelManIO.getLoanRelNm         ()) ; //
            bviwdM03DSSDDO08Vo.setCustNm            (loanRelManIO.getCustNm            ()) ; // 고객_명
            bviwdM03DSSDDO08Vo.setCrdtStatNm        (loanRelManIO.getCrdtStatNm        ()) ; //
            bviwdM03DSSDDO08Vo.setPrptCnt           (loanRelManIO.getPrptCnt           ()) ; //
            bviwdM03DSSDDO08Vo.setLoanRelFg         (loanRelManIO.getLoanRelFg         ()) ; //
            bviwdM03DSSDDO08Vo.setCustNoTran        (loanRelManIO.getCustNoTran        ()) ; //

            listVo.add(bviwdM03DSSDDO08Vo);

        }

        resultVo.setBVIWDM03DSSDDO08VOList(listVo);

        return resultVo;

    }

}
