package hanalife.b.vi.wd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.vi.wd.mapper.IntvPlanMapper;
import hanalife.b.vi.wd.mapper.UrgeGuidMngMapper;
import hanalife.b.vi.wd.mapper.dto.IntvPlanDSSDDO15DTO;
import hanalife.b.vi.wd.mapper.dto.UrgeGuidMngDSSDDO06DTO;
import hanalife.b.vi.wd.mapper.dto.UrgeGuidMngDSSMDODTO;
import hanalife.b.vi.wd.service.BVIWDP01Service;
import hanalife.b.vi.wd.vo.BVIWDP01DSSDDO06VO;
import hanalife.b.vi.wd.vo.BVIWDP01S01InVO;
import hanalife.b.vi.wd.vo.BVIWDP01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDP01ServiceImpl.java Class
 * 클래스설명   : BVIWDP01ServiceImpl Service Implements
 * 작성일자     : 2023. 4. 10.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 10.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBVIWDP01S01 : 주소 조회
 *         registerBVIWDP01I01 : 방문 내역 등록
 * </pre>
 */
@Service("BVIWDP01Service")
public class BVIWDP01ServiceImpl implements BVIWDP01Service{

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDP01ServiceImpl.class);

    /** 주소조회 mapper */
    @Autowired
    UrgeGuidMngMapper urgeGuidMngMapper;

    /** 방문내역등록 mapper */
    @Autowired
    IntvPlanMapper intvPlanMapper;

	/**
	* <pre>
	* 메소드명      : getBVIWDP01S01
	* 작성일자      : 2023. 4. 10.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 주소 조회
	* 메소드인수1   : BVIWDP01S01InVO
	* 메소드리턴값  : BVIWDP01S01OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BVIWDP01S01OutVO getBVIWDP01S01(BVIWDP01S01InVO inVo) throws Exception {

		 LOGGER.debug("getBVIWDP01S01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
		BVIWDP01S01OutVO resultVo = new BVIWDP01S01OutVO();
		UrgeGuidMngDSSMDODTO urgeGuidMngDSSMDODTO = new UrgeGuidMngDSSMDODTO();
        List<BVIWDP01DSSDDO06VO> listVo = new ArrayList<BVIWDP01DSSDDO06VO>();

        /**************************************************
         * □ Input Data Set
         **************************************************/
        urgeGuidMngDSSMDODTO.setCustNo(inVo.getBVIWDP01DSSMDO01VO().getCustNo()); // 고객번호

        /**************************************************
         * ■ Call 주소 리스트 조회
         **************************************************/
        List<UrgeGuidMngDSSDDO06DTO> resultDto = urgeGuidMngMapper.searchAddress(urgeGuidMngDSSMDODTO);


        /**************************************************
         * □ 결과값 LOOP처리
         **************************************************/
        for(UrgeGuidMngDSSDDO06DTO targetIO : resultDto) {
        	BVIWDP01DSSDDO06VO sourceIO = new BVIWDP01DSSDDO06VO();
        	sourceIO.setCdDescNo(targetIO.getCdDescNo());
        	sourceIO.setZipCd(targetIO.getZipCd());
        	sourceIO.setAddrCi(targetIO.getAddrCi());
        	sourceIO.setAddrGu(targetIO.getAddrGu());
        	sourceIO.setAddrDong(targetIO.getAddrDong());
        	sourceIO.setAddrSpec(targetIO.getAddrSpec());

            listVo.add(sourceIO);
        }

        resultVo.setBVIWDP01DSSDDO06VO(listVo);

		return resultVo;
	}

	/**
	* <pre>
	* 메소드명      : registerBVIWDP01I01
	* 작성일자      : 2023. 4. 10.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 방문 내역 등록
	* 메소드인수1   : BVIWDP01S01InVO
	* 메소드리턴값  : BVIWDP01S01OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BVIWDP01S01OutVO registerBVIWDP01I01(BVIWDP01S01InVO inVo) throws Exception {
		LOGGER.debug("registerBVIWDP01I01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
		BVIWDP01S01OutVO resultVo = new BVIWDP01S01OutVO();
		IntvPlanDSSDDO15DTO intvPlanDSSDDO15DTO = new IntvPlanDSSDDO15DTO();

        /**************************************************
         * □ Input Data Set
         **************************************************/
		intvPlanDSSDDO15DTO.setLoanNo(inVo.getBVIWDP01DSSDDO15VO().getLoanNo());
		intvPlanDSSDDO15DTO.setLoanSeq(inVo.getBVIWDP01DSSDDO15VO().getLoanSeq());
		intvPlanDSSDDO15DTO.setIntvObjManResiNo(inVo.getBVIWDP01DSSDDO15VO().getIntvObjManResiNo());
		intvPlanDSSDDO15DTO.setIntvPlanDt(inVo.getBVIWDP01DSSDDO15VO().getIntvPlanDt());
		intvPlanDSSDDO15DTO.setConsShNo(inVo.getBVIWDP01DSSDDO15VO().getConsShNo());
		intvPlanDSSDDO15DTO.setContManResiNo(inVo.getBVIWDP01DSSDDO15VO().getContManResiNo());
		intvPlanDSSDDO15DTO.setIntvPlcCd(inVo.getBVIWDP01DSSDDO15VO().getIntvPlcCd());
		intvPlanDSSDDO15DTO.setZipCd(inVo.getBVIWDP01DSSDDO15VO().getZipCd());
		intvPlanDSSDDO15DTO.setAddrCi(inVo.getBVIWDP01DSSDDO15VO().getAddrCi());
		intvPlanDSSDDO15DTO.setAddrGu(inVo.getBVIWDP01DSSDDO15VO().getAddrGu());
		intvPlanDSSDDO15DTO.setAddrDong(inVo.getBVIWDP01DSSDDO15VO().getAddrDong());
		intvPlanDSSDDO15DTO.setAddrSpec(inVo.getBVIWDP01DSSDDO15VO().getAddrSpec());
		intvPlanDSSDDO15DTO.setIntvPlanAprvFg(inVo.getBVIWDP01DSSDDO15VO().getIntvPlanAprvFg());
		intvPlanDSSDDO15DTO.setIntvSchdmanEmpNo(inVo.getBVIWDP01DSSDDO15VO().getIntvSchdmanEmpNo());
		intvPlanDSSDDO15DTO.setIntvObjCd(inVo.getBVIWDP01DSSDDO15VO().getIntvObjCd());
		intvPlanDSSDDO15DTO.setReqmanNm(inVo.getBVIWDP01DSSDDO15VO().getReqmanNm());
		intvPlanDSSDDO15DTO.setReqDt(inVo.getBVIWDP01DSSDDO15VO().getReqDt());
		intvPlanDSSDDO15DTO.setIntvCnfmCntn(inVo.getBVIWDP01DSSDDO15VO().getIntvCnfmCntn());
		intvPlanDSSDDO15DTO.setFrstRegEmpNo(inVo.getBVIWDP01DSSDDO15VO().getLogInEmpNo());

        /**************************************************
         * ■ Call 방문내역 등록
         **************************************************/
		intvPlanMapper.insertIntv(intvPlanDSSDDO15DTO);

		return resultVo;
	}



}
