package hanalife.b.vi.wd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.vi.wd.mapper.CustMngMapper;
import hanalife.b.vi.wd.service.BVIWDP02Service;
import hanalife.b.vi.wd.vo.BVIWDP02DSCUSTINFOREGSD02VO;
import hanalife.b.vi.wd.vo.BVIWDP02S01InVO;
import hanalife.b.vi.wd.vo.BVIWDP02S01OutVO;
import hanalife.c.co.mapper.dto.StCustAddrDTO;
import hanalife.c.co.mapper.dto.StCustBaseDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDP02ServiceImpl.java Class
 * 클래스설명   : BVIWDP02ServiceImpl Service Implements
 * 작성일자     : 2023. 4. 10.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 10.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getBVIWDP02S01 : 주소 조회
 * </pre>
 */
@Service("BVIWDP02Service")
public class BVIWDP02ServiceImpl implements BVIWDP02Service{

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDP02ServiceImpl.class);

    /** 주소조회 mapper */
    @Autowired
    CustMngMapper custMngMapper;

	/**
	* <pre>
	* 메소드명      : getBVIWDP02S01
	* 작성일자      : 2023. 4. 10.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 고객 주소 조회
	* 메소드인수1   : BVIWDP02S01InVO
	* 메소드리턴값  : BVIWDP02S01OutVO
	* 예외처리      : Exception
	* </pre>
	*/
	@Override
	public BVIWDP02S01OutVO getBVIWDP02S01(BVIWDP02S01InVO inVo) throws Exception {

		 LOGGER.debug("getBVIWDP02S01 Start..");

        /**************************************************
         * □ 초기선언
         **************************************************/
		BVIWDP02S01OutVO resultVo = new BVIWDP02S01OutVO();
		StCustBaseDTO stCustBaseDTO = new StCustBaseDTO();
        List<BVIWDP02DSCUSTINFOREGSD02VO> listVo = new ArrayList<BVIWDP02DSCUSTINFOREGSD02VO>();

        /**************************************************
         * □ Input Data Set
         **************************************************/
        stCustBaseDTO.setCustNo(inVo.getBVIWDP02DSCUSTINFOREGSMVO().getCustNo()); // 고객번호

        /**************************************************
         * ■ Call 고객정보 유형 조회함.
         **************************************************/
        List<StCustBaseDTO> custDto = custMngMapper.searchCustCheck(stCustBaseDTO);

        // 고객번호 검증
        if(custDto == null || custDto.size() == 0){
        	throw new Exception("ESS9999^해당되는 고객번호가 존재하지 않습니다. 신규 등록 하시기 바랍니다.");
        } else {

        	StCustAddrDTO stCustAddrDTO = new StCustAddrDTO();
        	stCustAddrDTO.setCustNo(inVo.getBVIWDP02DSCUSTINFOREGSMVO().getCustNo()); // 고객번호

        	List<StCustAddrDTO> resultDto = custMngMapper.searchCustAddr(stCustAddrDTO);

        	/**************************************************
             * □ 결과값 LOOP처리
             **************************************************/
            for(StCustAddrDTO targetIO : resultDto) {
            	BVIWDP02DSCUSTINFOREGSD02VO sourceIO = new BVIWDP02DSCUSTINFOREGSD02VO();
            	sourceIO.setAddrDivCd(targetIO.getAddrDivCd());
            	sourceIO.setAddrDivNm(targetIO.getAddrDivNm());
            	sourceIO.setZipCd(targetIO.getZipCd());
            	//sourceIO.setAddrCi(targetIO.getAddrCi());
            	//sourceIO.setAddrGu(targetIO.getAddrGu());
            	//sourceIO.setAddrDong(targetIO.getAddrDong());
            	sourceIO.setAddrSpec(targetIO.getAddrSpec());

                listVo.add(sourceIO);
            }

            resultVo.setBVIWDP02DSCUSTINFOREGSD02VO(listVo);
        }

		return resultVo;
	}
}
