package hanalife.b.vi.wd.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.vi.wd.service.BVIWDM03Service;
import hanalife.b.vi.wd.vo.BVIWDM03DSSMDO01VO;
import hanalife.b.vi.wd.vo.BVIWDM03S01InVO;
import hanalife.b.vi.wd.vo.BVIWDM03S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDM03Controller.java Class
 * 클래스설명   : BVIWDM03Controller Controller
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70331 / P.S.Y / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70331 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/vi/wd")
@Controller
public class BVIWDM03Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDM03Controller.class);

    @Autowired
    private BVIWDM03Service bviwd03Service;

    /**
     *<pre>
     * 메소드명      : 대출내역정보 리스트 조회 / BVIWDM03S01.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 대출내역정보 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S01.do")
    public String BVIWDM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDM03S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo       ((String) sourceMap.get("loanNo"  )); // 대출_번호
            inVo.setLoanSeq      ((String) sourceMap.get("loanSeq" )); // 대출_순번
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 대출내역정보 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S01(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO01", resultVo.getBVIWDM03DSSDDO01VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 재산정보 조회 / BVIWDM03S02.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 재산정보를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S02.do")
    public String BVIWDM03S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDM03S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO ();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo       ((String) sourceMap.get("loanNo"  )); // 대출_번호
            inVo.setLoanSeq      ((String) sourceMap.get("loanSeq" )); // 대출_순번
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 재산정보 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S02(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO02", resultVo.getBVIWDM03DSSDDO02VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 총건수 리스트 조회 / BVIWDM03S03.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 총건수 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S03.do")
    public String BVIWDM03S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY-controller} BVIWDM03S03 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo       ((String) sourceMap.get("loanNo"  )); // 대출_번호
            inVo.setLoanSeq      ((String) sourceMap.get("loanSeq" )); // 대출_순번
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 총건수 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S03(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO03", resultVo.getBVIWDM03DSSDDO03VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 부동산 TAB 리스트 조회 / BVIWDM03S04.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 부동산 TAB 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S04.do")
    public String BVIWDM03S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY-controller} BVIWDM03S04 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 부동산 TAB 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S04(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO04", resultVo.getBVIWDM03DSSDDO04VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 자동차 TAB 리스트 조회 / BVIWDM03S05.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 자동차 TAB 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S05.do")
    public String BVIWDM03S05(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY-controller} BVIWDM03S05 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 자동차 TAB 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S05(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO05", resultVo.getBVIWDM03DSSDDO05VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 채권 TAB 리스트 조회 / BVIWDM03S06.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 채권 TAB 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S06.do")
    public String BVIWDM03S06(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY-controller} BVIWDM03S06 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 자동차 TAB 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S06(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO06", resultVo.getBVIWDM03DSSDDO06VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 동산 TAB 리스트 조회 / BVIWDM03S07.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 동산 TAB 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S07.do")
    public String BVIWDM03S07(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY-controller} BVIWDM03S07 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setCustNo       ((String) sourceMap.get("custNo"  )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 동산 TAB 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S07(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO07", resultVo.getBVIWDM03DSSDDO07VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 관련인 TAB 리스트 조회 / BVIWDM03S08.do
     * 작성일자      : 2023. 3. 21.
     * 작성자(author): 70317
     * 설명          : 관련인 TAB 리스트를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDM03S08.do")
    public String BVIWDM03S08(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY-controller} BVIWDM03S08 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDM03DSSMDO01VO  inVo            = new BVIWDM03DSSMDO01VO();
            BVIWDM03S01InVO     bviwd03S01InVO  = new BVIWDM03S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);


            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setLoanNo       ((String) sourceMap.get("loanNo"   )); // 대출_번호
            inVo.setLoanSeq      ((String) sourceMap.get("loanSeq"  )); // 대출_순번
            // ASIS에선 SQL호출시 아규먼트로 사용안함..
            inVo.setCustNo       ((String) sourceMap.get("custNo"   )); // 고객_번호


            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            bviwd03S01InVO.setBVIWDM03DSSMDO01VO(inVo);


            /**************************************************
             * ■ Call 관련인 TAB 리스트 조회
             **************************************************/
            BVIWDM03S01OutVO resultVo = bviwd03Service.getBVIWDM03S08(bviwd03S01InVO);


            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO08", resultVo.getBVIWDM03DSSDDO08VOList(), model);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}