package hanalife.b.vi.wd.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.vi.wd.service.BVIWDP01Service;
import hanalife.b.vi.wd.vo.BVIWDP01DSSDDO15VO;
import hanalife.b.vi.wd.vo.BVIWDP01DSSMDO01VO;
import hanalife.b.vi.wd.vo.BVIWDP01S01InVO;
import hanalife.b.vi.wd.vo.BVIWDP01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDP01Controller.java Class
 * 클래스설명   : BVIWDP01Controller Controller
 * 작성일자     : 2023. 4. 10.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 10.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/vi/wd")
@Controller
public class BVIWDP01Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDP01Controller.class);

    @Autowired
    private BVIWDP01Service bviwdp01Service;

    /**
     *<pre>
     * 메소드명      : 주소조회 / BVIWDP01S01.do
     * 작성일자      : 2023. 4. 10.
     * 작성자(author): 70320
     * 설명          : 주소를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDP01S01.do")
    public String BVIWDP01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("BVIWDP01S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
        	BVIWDP01DSSMDO01VO inVo = new BVIWDP01DSSMDO01VO();
            BVIWDP01S01InVO BVIWDP01S01InVo = new BVIWDP01S01InVO ();

            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO01", request, response, model);

            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setCustNo((String) sourceMap.get("custNo")); // 고객번호

            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            BVIWDP01S01InVo.setBVIWDP01DSSMDO01VO(inVo);

            /**************************************************
             * ■ Call 주소조회
             **************************************************/
            BVIWDP01S01OutVO resultVo = bviwdp01Service.getBVIWDP01S01(BVIWDP01S01InVo);

            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_SDDO06", resultVo.getBVIWDP01DSSDDO06VO(), model);
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     *<pre>
     * 메소드명      : 방문내역 등록
     * 작성일자      : 2023. 4. 10.
     * 작성자(author): 70320
     * 설명          : 방문내역을 등록한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDP01I01.do")
    public String BVIWDP01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("{PSY} BVIWDP01S02 Start..");

        try {
            /**************************************************
             * □ 초기선언
             **************************************************/
            BVIWDP01DSSDDO15VO inVo = new BVIWDP01DSSDDO15VO();
            BVIWDP01S01InVO BVIWDP01S01InVo = new BVIWDP01S01InVO();


            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SDDO15", request, response, model);

            /**************************************************
             * □ Input Data Set
             **************************************************/
            BeanUtil.mapToBean(sourceMap, inVo);

            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            BVIWDP01S01InVo.setBVIWDP01DSSDDO15VO(inVo);

            /**************************************************
             * ■ Call 방문 내역 등록
             **************************************************/
            bviwdp01Service.registerBVIWDP01I01(BVIWDP01S01InVo);

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}
