package hanalife.b.vi.wd.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.b.vi.wd.service.BVIWDP02Service;
import hanalife.b.vi.wd.vo.BVIWDP02DSCUSTINFOREGSMVO;
import hanalife.b.vi.wd.vo.BVIWDP02S01InVO;
import hanalife.b.vi.wd.vo.BVIWDP02S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : BVIWDP02Controller.java Class
 * 클래스설명   : BVIWDP02Controller Controller
 * 작성일자     : 2023. 4. 10.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 10.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 *
 * </pre>
 */
@RequestMapping("/b/vi/wd")
@Controller
public class BVIWDP02Controller {

    private static final Logger LOGGER = LoggerFactory.getLogger(BVIWDP02Controller.class);

    @Autowired
    private BVIWDP02Service bviwdP02Service;

    /**
     *<pre>
     * 메소드명      : 주소조회 / BVIWDP02S01.do
     * 작성일자      : 2023. 4. 10.
     * 작성자(author): 70320
     * 설명          : 주소를 조회 한다.
     * 예외처리      : Exception
     *</pre>
     */
    @RequestMapping("/BVIWDP02S01.do")
    public String BVIWDP02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.debug("BVIWDP02S01 Start..");

        try {

            /**************************************************
             * □ 초기선언
             **************************************************/
        	BVIWDP02DSCUSTINFOREGSMVO inVo = new BVIWDP02DSCUSTINFOREGSMVO();
            BVIWDP02S01InVO BVIWDP02S01InVo = new BVIWDP02S01InVO ();

            /**************************************************
             * □ 조회조건 추출
             **************************************************/
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CUST_INFO_REG_SM", request, response, model);

            /**************************************************
             * □ Input Data Set
             **************************************************/
            inVo.setCustNo((String) sourceMap.get("custNo")); // 고객번호

            /**************************************************
             * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             **************************************************/
            BVIWDP02S01InVo.setBVIWDP02DSCUSTINFOREGSMVO(inVo);

            /**************************************************
             * ■ Call 주소조회
             **************************************************/
            BVIWDP02S01OutVO resultVo = bviwdP02Service.getBVIWDP02S01(BVIWDP02S01InVo);

            /**************************************************
             * □ 화면으로 Return처리
             **************************************************/
            XFrame5Util.setOutputData("DS_CUST_INFO_REG_SD02", resultVo.getBVIWDP02DSCUSTINFOREGSD02VO(), model);
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE  , "-100"           );
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage()   );
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}
