package hanalife.batch;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.FileAppender;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;
import org.apache.log4j.PropertyConfigurator;

import hanalife.batch.util.PropertyLoader;

/**
 * <pre>
 * 클래스명    : BatchLogger
 * 클래스설명 : BatchLogger의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class BatchLogger
{
	private static String SEP = System.getProperty("file.separator");
	public static Logger batchLogger = Logger.getLogger(BatchLogger.class.getName());

	/**
	 * <p>Logger 설정추가 (파일)
	 * @param logger 사용자입력 Logger
	 * @param level 로그레벨  ex) debug, info, warn, error, fatal
	 * @param logPath 로그홈경로 ex) ${BATCH_HOME}/log
	 * @param filename ex) RATAD0101
	 * @param pattern 로그 출력헤더 ex) %d{yyyy-MM-dd HH:mm:ss}, %5p [%t] (%F:%L) : %m%n
	 * @param append 로그파일 엎어쓰기(false), 뒤에 내용추가하기 (true)
	 * @param logFileNm ex) RATAD0101_2018-08-01.log
	 */
	public static void addFileAppender(Logger logger,
					String level,
					String logPath,
					String filename,
					String pattern,
					boolean append,
					String logFileNm) {

		//임의로 root로거를 셋팅한다.
		if(logger == null){
			batchLogger.error("입력 Logger에 Null값이 입력되었습니다.");
		}

		//로그레벨,패턴,로그경로,로그파일명,추가여부로 로깅한다.
		addFileAppender(level,
						pattern,
						logPath,
						logFileNm,
						append);
	}

	/**
	 * <p>Logger 설정추가 (파일)
	 * @param logger 사용자입력 Logger
	 * @param level 로그레벨  ex) debug, info, warn, error, fatal
	 * @param loghome ex) ${BATCH_HOME}/log
	 * @param filename ex) RATAD0101 or com.dobscap.r.at.ad.bat.RATAD0101
	 * @param pattern 로그 출력헤더 ex) %d{yyyy-MM-dd HH:mm:ss}, %5p [%t] (%F:%L) : %m%n
	 * @param append 로그파일 엎어쓰기(false), 뒤에 내용추가하기 (true)
	 */
	public static void addFileAppender(Logger logger,
					String level,
					String loghome,
					String filename,
					String pattern,
					boolean append ) {

		SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMdd");

		String prgmNo = filename;
		if( StringUtils.indexOf(filename, '.') >= 0) {
			prgmNo = filename.substring(filename.lastIndexOf(".")+1);
		}

		String logFileNm = prgmNo + "_" + formatter.format(new java.util.Date())+".log";

		addFileAppender(logger,
						level,
						loghome,
						prgmNo,
						pattern,
						append,
						logFileNm);
	}

	/**
	 * <p>Logger 설정추가 (파일)
	 * @param logger 사용자입력 Logger
	 * @param configFile 설정 properties ex) ${BATCH_HOME}/config/batch.config
	 * @param batchHm 배치홈,  full 디렉토리
	 * @param pack ex) rat
	 * @param prgmNo ex) RATAD0101
	 */
	public static void addFileAppender(Logger logger,
					String configFile,
					String batchHm,
					String pack,
					String prgmNo) {

		if( logger == null){
			batchLogger.error("입력 Logger에 Null값이 입력되었습니다.");
		}

		PropertyLoader pl = new PropertyLoader(configFile);
		PropertyConfigurator.configure( configFile );
		boolean appendFg = pl.getBoolean("log.append", true);

//		System.out.print(" PropertyLoader batchHm = " + batchHm);  //C:\batch\Batch_home
//		System.out.print(" configFile = " + configFile);           //C:\batch\Batch_home\config\batch.config
//		System.out.print(" appendFg = " + appendFg);
		addFileAppender( configFile, batchHm, pack, prgmNo, "", appendFg);
	}

	/**
	 * <p>Logger 설정추가 (파일)
	 * @param configFile ex) ${BATCH_HOME}/config/batch.config
	 * @param batchHm 배치홈 full 디렉토리
	 * @param prgmPack ex) rat
	 * @param prgmNo ex) RATAD0101
	 * @param inLogDt 로그파일은 디폴트로 현재일자 yyyyMMdd이다.
	 *                만약에 배치입력일자를 로그파일명에 붙이고자 할때 입력한다.
	 *                이때 현재일자를 파일명에 붙이는것은 무시된다.
	 *  ex) 현재일자가 2018-08-01 일때
	 *      inLogDt가 입력안되었을때 RATAD0101_2018-08-01.log
	 *      inLogDt가 2018-08-01로 입력되면 RATAD0101_2018-08-01.log
	 * @param appendFg 로그파일 엎어쓰기(false), 뒤에 내용추가하기 (true)
	 */
	public static void addFileAppender(
					String configFile,
					String batchHm,
					String prgmPack,
					String prgmNo,
					String inLogDt,
					boolean appendFg){


		// batchLogger.info("configFile  >> " + configFile);

		PropertyLoader pl = new PropertyLoader(configFile);  //batch.config 파일 읽기
		PropertyConfigurator.configure( configFile );		 //batch.config 파일 읽기
		String logHome = pl.getString("log.home", batchHm + SEP + "log");  //ex ) {$BATCH_HOME}/log

		// batchLogger.info("logHome >> " + logHome);

//		System.out.println("############# batchHm =" + batchHm);
//		System.out.println("############# logHome =" + logHome);

		String level = pl.getString("log.level", "debug");
		String pattern = pl.getString("log.pattern", "%d{yyyy-MM-dd HH:mm:ss}, %5p [%t] (%F:%L) : %m%n");

		addFileAppender(level, pattern, logHome, prgmPack, prgmNo, inLogDt, appendFg );
	}


	/**
	 * <p>Logger 설정추가 (파일)
	 * @param level 로그레벨  ex) debug, info, warn, error, fatal
	 * @param pattern 로그 출력헤더 ex) %d{yyyy-MM-dd HH:mm:ss}, %5p [%t] (%F:%L) : %m%n
	 * @param logHome ex) ${BATCH_HOME}/log
	 * @param prgmPack ex) rat
	 * @param prgmNo ex) RATAD0101
	 * @param inLogDt 로그파일은 디폴트로 현재일자 yyyyMMdd이다.
	 *                만약에 배치입력일자를 로그파일명에 붙이고자 할때 입력한다.
	 *                이때 현재일자를 파일명에 붙이는것은 무시된다.
	 *  ex) 현재일자가 2018-08-01 일때
	 *      inLogDt가 입력안되었을때 RATAD0101_2018-08-01.log
	 *      inLogDt가 2018-08-01로 입력되면 RATAD0101_2018-08-01.log
	 * @param append 로그파일 엎어쓰기(false), 뒤에 내용추가하기 (true)
	 */
	public static void addFileAppender(
					String level,
					String pattern,
					String logHome,
					String prgmPack,
					String prgmNo,
					String inLogDt,
					boolean append ){

		addFileAppender(level,
						pattern,
						getLogPath( logHome, prgmPack, prgmNo ),
						getLogFileNm(inLogDt, prgmNo),
						append
						);
	}

	/**
	 * <p>Logger 설정추가 (파일)
	 * @param level 로그레벨  ex) debug, info, warn, error, fatal
	 * @param pattern 로그 출력헤더 ex) %d{yyyy-MM-dd HH:mm:ss}, %5p [%t] (%F:%L) : %m%n
	 * @param logPath 로그경로 ex) ${LOG_HOME}/rat/RATAD0101
	 * @param logFileNm 로그파일명 ex) RATAD0101_2018-08-01.log
	 * @param append 로그파일 엎어쓰기(false), 뒤에 내용추가하기 (true)
	 */
	public static void addFileAppender(
					String level,
					String pattern,
					String logPath,
					String logFileNm,
					boolean append){
		try{


			// System.out.print("######## BatchLogger.java logPath ###########" + logPath);
			mkDir(logPath);	//로그폴더가 없으면 만든다.

			if(!append){
				backup(logPath + SEP+ logFileNm, logPath + SEP+ logFileNm + "." + Long.toString(System.currentTimeMillis()) );
			}

			Logger log = Logger.getRootLogger();

			// log.info("###################### batch root loger >> " + log);

			FileAppender appender  = new FileAppender(new PatternLayout(pattern), logPath + SEP+ logFileNm , append);
			appender.setEncoding("EUC-KR");
			log.addAppender(appender);
			log.setAdditivity(true);
			log.setLevel(getLevel(level));

//			log.info("LOG 파일 : " + logPath + SEP+ logFileNm);
//			log.info("LOG 레벨 : " + level);
//			log.info("LOG 기존파일 추가여부 : " + append);

		}catch(Exception e){
			e.printStackTrace();
		}
	}

	private static String getLogPath(String logHome, String prgmPack, String prgmNo){
		StringBuffer logPathBuff = new StringBuffer(1024);
		logPathBuff.append(logHome);
		if( !StringUtils.isEmpty(logHome) && !StringUtils.isEmpty(prgmPack)){
			logPathBuff.append(SEP);
			logPathBuff.append(prgmPack);
		}
		if(!StringUtils.isEmpty(prgmNo) &&  logPathBuff.length() > 0 ){
			logPathBuff.append(SEP);
			logPathBuff.append(prgmNo);
		}

		return logPathBuff.toString();
	}

	private static String getLogFileNm(String inLogDt, String prgmNo) {
		StringBuffer logFileNm = new StringBuffer(1024);
		logFileNm.append( prgmNo );
		logFileNm.append( "_" );
		if( StringUtils.isNotEmpty(inLogDt) ){
			logFileNm.append( inLogDt );
		}else{
			SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMdd");
			logFileNm.append( formatter.format(new java.util.Date()) );
		}
		logFileNm.append(".log");

		return logFileNm.toString();
	}

	private static Level getLevel(String level){
		if(level.equals("debug"))
		{
			return Level.DEBUG;
		}
		else if(level.equals("info"))
		{
			return Level.INFO;
		}
		else if(level.equals("warn"))
		{
			return Level.WARN;
		}
		else if(level.equals("error"))
		{
			return Level.ERROR;
		}
		else if(level.equals("fatal"))
		{
			return Level.FATAL;
		}else{
			return Level.DEBUG;
		}
	}

	private static boolean isExist( String fileNm ) throws BatchException{
		try{
			File file = new File(fileNm);
			if( file.exists()){
				return true;
			}else{
				return false;
			}
		}catch(Exception e){
			throw new BatchException("입력한 파일오픈중 에러발생[" + fileNm + "]");
		}
	}

	private static void mkDir( String dirPath ) throws BatchException, IOException{
		if( !isExist(dirPath)){
			FileUtils.forceMkdir(new File(dirPath));
		}
	}

	private static boolean backup( String src, String dest ) throws IOException, BatchException{

		if(isExist(src)){
			File srcFile = new File(src);
			File destFile = new File(dest);

			batchLogger.info("로그파일을 백업합니다.[백업파일 : " + dest + "]");

			//재생성시 기존 파일 내용은 덮어써진다. 따라서 백업파일을 만들어놓는다.
			FileUtils.copyFile(srcFile,destFile);
			return true;
		}
		return false;
	}

}
