package hanalife.batch;

import java.io.File;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.List;

/**
 * <pre>
 * 클래스명    : CommonBatch
 * 클래스설명 : CommonBatch의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public abstract class CommonBatch
{
    protected Connection con;
    protected String xmlFile;
    protected String dataHome;
    protected ConnMng conMng;

    /**
     * 배치 실행 메소드
     * @throws java.lang.Exception
     */
    public abstract void execute() throws Exception;


    /**
     * <p>전문 layout을 정의한 xml파일을 셋팅( 경로 + 파일명)</p>
     * @param xmlFile - 전문 layout xml file
     */
    public void setXmlFile(String xmlFile)
    {
        this.xmlFile = xmlFile;
    }

    /**
     * <p>전문 layout을 정의한 xml파일을 얻는다.( 경로 + 파일명)</p>
     * @return
     */
    public String getXmlFile()
    {
        return this.xmlFile;
    }

    /**
     * <p>전문 데이터가 있는 file의 home디렉토리를 셋팅한다. </p>
     * @param datahome - ex) /usr/batch/datahome/
     */
    public void setDataHome(String datahome)
    {
        this.dataHome = datahome;
    }

    /**
     * <p>DB Connect manager setting </p>
     * @param conMng
     */
    public void setConnectionManager(ConnMng conMng)
    {
        this.conMng = conMng;
    }

    /**
     * <p> MS 단위로 입력된 start, end의 사이값을 분-초-MS으로 리턴한다. </p>
     * @param start - 시작시간 (MS)
     * @param end - 종료시간 (MS)
     * @return
     */
    public String intervalTime(long start,long end)
    {
        long inteval = end-start;
        long minute = (inteval/1000/60);
        long second = ((inteval/1000)%60);
        long msec   = (inteval%1000);
        return minute+" M "+second+" S "+msec+" MS";
    }

    /**
     * <p>파일 경로안에 있는 파일들의 이름을 ArrayList로 반환한다.</p>
     * @param filePath - 파일경로, ex) /usr/batch/filehome
     * @return
     */
    public List getFileNames(String filePath)
    {
        File[] fileList = new File(filePath).listFiles();
        int fLength = fileList.length;
        List fileNames = new ArrayList();

        for(int i=0;i<fLength;i++)
        {
            if(fileList[i].isFile())
            {
                fileNames.add(fileList[i].getName());
            }
        }
        return fileNames;
    }



}
