package hanalife.batch;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.configuration.Configuration;
import org.apache.commons.configuration.ConfigurationException;
import org.apache.commons.configuration.PropertiesConfiguration;
import org.apache.commons.dbutils.DbUtils;
import org.apache.log4j.Logger;

/**
 * <pre>
 * 클래스명    : ConnMng
 * 클래스설명 : ConnMng의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class ConnMng {

	private Logger logger = Logger.getLogger(ConnMng.class.getName());

    private String driver = null;
    private String dbname = null;
    private String dbuser = null;
    private String dbpwd = null;
    private String urlprefix = null;


    /* [20221007][유창용][고객정보 삭제 영역 커넥션 정보 추가] 시작 */
    private String driverDele = null;
    private String dbnameDele = null;
    private String dbuserDele = null;
    private String dbpwdDele = null;
    private String urlprefixDele = null;
    /* [20221007][유창용][고객정보 삭제 영역 커넥션 정보 추가] 종료 */

    private String dzConnectionUrl = null;
    private String dzDbName = null;
    private String dzUserName = null;
    private String dzPassword = null;

    private List<Connection> connections = new ArrayList<>();
    private Connection conAutoCommit = null;

    public ConnMng(String config){
        loadConfig(config);
    }

    public ConnMng(String dbname, String dbuser, String dbpwd){
		try {
			Configuration config = new PropertiesConfiguration("app.properties");
	        this.urlprefix = config.getString("db.urlprefix");
	        this.driver = config.getString("db.driverclassname");
		} catch (ConfigurationException e) {
			e.printStackTrace();
		}
        init(dbname, dbuser, dbpwd);
    }

    public void loadConfig(String file){
		try {
			Configuration config = new PropertiesConfiguration(file);
	        this.driver = config.getString("db.driverclassname");
	        this.urlprefix = config.getString("db.urlprefix");
	        this.dbname = config.getString("db.dbname");
	        this.dbuser = config.getString("db.username");
	        this.dbpwd = config.getString("db.password");
	        /* [20221007][유창용][고객정보 삭제 영역 커넥션 정보 추가] 시작 */
	        this.driverDele 	= config.getString("db.dele.driverclassname");
	        this.urlprefixDele 	= config.getString("db.dele.urlprefix");
	        this.dbnameDele 	= config.getString("db.dele.dbname");
	        this.dbuserDele 	= config.getString("db.dele.username");
	        this.dbpwdDele	 	= config.getString("db.dele.password");
	        /* [20221007][유창용][고객정보 삭제 영역 커넥션 정보 추가] 종료 */

            this.dzConnectionUrl = config.getString("dz.db.connecturl");
            this.dzDbName = config.getString("dz.db.dbname");
            this.dzUserName = config.getString("dz.db.username");
            this.dzPassword = config.getString("dz.db.password");

		} catch (ConfigurationException e) {
			e.printStackTrace();
		} catch ( Exception ex){
			ex.printStackTrace();
		}
    }

    public void init(String dbname, String dbuser, String dbpwd){
        setDBName(dbname);
        setDBUser(dbuser);
        setDBPwd(dbpwd);
    }

    public Connection getConnection() throws BatchException{
        Connection connection = null;
        try {

            Class.forName(driver);

            connection = DriverManager.getConnection( urlprefix, dbuser, dbpwd);
            connection.setAutoCommit(false);

            connections.add(connection);

            return connection;
        }catch (ClassNotFoundException e) {
            logger.error("드라이버가 없습니다. : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }catch (SQLException e) {
        	logger.error("드라이버를 로드할 수 없습니다. : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }catch(Exception e){
            logger.error("connection 생성 에러 : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }
    }

    /* [20221007][유창용][고객정보 삭제 영역 커넥션 정보 추가] 시작 */
    /**
     * 고객정보 삭제 영역 Connection 가져오기.
     * @return
     * @throws BatchException
     */
    public Connection getConnectionDele() throws BatchException{
        Connection connection = null;
        try {

            Class.forName(driverDele);

            connection = DriverManager.getConnection( urlprefixDele, dbuserDele, dbpwdDele);
            connection.setAutoCommit(false);

            connections.add(connection);

            return connection;
        }catch (ClassNotFoundException e) {
            logger.error("드라이버가 없습니다. : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }catch (SQLException e) {
        	logger.error("드라이버를 로드할 수 없습니다. : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }catch(Exception e){
            logger.error("connection 생성 에러 : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }
    }

    /* [20221007][유창용][고객정보 삭제 영역 커넥션 정보 추가] 종료 */

    public Connection getDzConnection() {
        try {
            String connectionTemplate = "jdbc:sqlserver://%s;databaseName=%s;user=%s;password=%s";
            String connectionUrl = String.format(connectionTemplate, this.dzConnectionUrl, this.dzDbName,
                    this.dzUserName, this.dzPassword);

            Connection connection = DriverManager.getConnection(connectionUrl);
            connection.setAutoCommit(false);
            connections.add(connection);
            return connection;
        } catch (SQLException e) {
            throw new DbsBatchException("DZ 데이터베이스 연결오류(" + e.getMessage() + ")", e);
        }
    }

    public Connection getConnectionAutoCommit(){
        try {
//        	logger.info("driver : " + driver);
//        	logger.info("urlprefix : " + urlprefix);
//        	logger.info("dbuser : " + dbuser);
//        	logger.info("dbpwd : " + dbpwd);

            if( conAutoCommit == null ){
                Class.forName(driver);
                conAutoCommit = DriverManager.getConnection( urlprefix, dbuser, dbpwd);
                conAutoCommit.setAutoCommit(true);
            }

            return conAutoCommit;
        }catch (ClassNotFoundException e) {
            logger.error("드라이버가 없습니다. : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }catch (SQLException e) {
            logger.error("드라이버를 로드할 수 없습니다. : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }catch(Exception e){
            logger.error("connection 생성 에러 : " + e.getMessage());
            throw new DbsBatchException(e.getMessage(), e);
        }
    }

    public void releaseConnection(boolean isCommit){
        for( Connection con : connections  ){
            if( isCommit ){
                logger.warn("commit >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
                this.commit(con);
            } else {
                logger.warn("rollback >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
                this.rollback(con);
            }
        }

        if(conAutoCommit != null ){
            logger.warn("auto commit >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
            // Auto Commit 관리 안함..
//            this.commit(conAutoCommit);
        }
    }

    private void commit(Connection con){
        try{
            if( con != null ){
                con.commit();
            }
        }catch(Exception ignore){
            // 무시
            logger.warn("commit 오류 : " + ignore.getMessage(), ignore);
        }finally{
            DbUtils.closeQuietly(con);
        }
    }

    private void rollback(Connection con){
        try{
            if( con != null ){
                con.rollback();
            }
        }catch(Exception ignore){
            // 무시
            logger.warn("rollback 오류 : " + ignore.getMessage(), ignore);
        }finally{
            DbUtils.closeQuietly(con);
        }
    }

    public static void closeStatement(Statement stmt){
        try {
            if (stmt != null) {
                stmt.close();
                stmt = null;
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void closeResultSet(ResultSet rs){
        try {
            if (rs != null) {
                rs.close();
                rs = null;
            }
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void closeConnection(Connection con){
        try {
            if (con != null) {
                con.close();
                con = null;
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * <p> Connection의 commit을  할때 commit단위로 한다.</p>
     * <p> ex) cnt 99 일때 100건단위 commit이면 commit을 안한다.
     *         cnt 100 일때 100건단위 commit이면 commit을 한다. </p>
     * @param con - Connection
     * @param cnt - 배치처리된 갯수
     * @param cntOfCommit - commit단위, ex) 100건단위로 commmit
     * @throws SQLException
     */
    public static void userCommit(Connection con,int cnt, int cntOfCommit) throws SQLException{
        if(cnt % cntOfCommit == 0){
            userCommit(con);
        }
    }

    /**
     * <p> Connection의 commit을  할때 commit단위 (내부적인 정의로 10000건으로됨) 로 한다.</p>
     * @param con
     * @param cnt
     * @throws SQLException
     */
    public static void userCommit(Connection con, int cnt) throws SQLException{
        userCommit(con,cnt,10000);
    }

    /**
     * <p> Connection을 commit한다.  </p>
     * @param con
     * @throws SQLException
     */
    public static void userCommit(Connection con) throws SQLException{
        con.commit();
    }

    public static int countBat(int[] cnt){
        int length = cnt.length;
        int totCnt = 0;
        for(int i=0;i<length;i++){
            if(cnt[i] == -2 || cnt[i] == -3){
                totCnt++;
            }else if(cnt[i] >= 0){
                totCnt += cnt[i];
            }
        }
        return totCnt;
    }

    public void setDriverClassName(String driver){
        this.driver = driver;
    }

    public String getDriverClassName(){
        return this.driver;
    }

    public void setDBUser(String dbuser){
        this.dbuser = dbuser;
    }

    public String getDBUser(){
        return this.dbuser;
    }

    public void setDBPwd(String dbpwd){
        this.dbpwd = dbpwd;
    }

    public String getDBPwd(){
        return this.dbpwd;
    }

    public void setDBName(String dbname){
        this.dbname = dbname;
    }

    public String getDBName(){
        return this.dbname;
    }

    public void setUrlprefix(String urlprefix){
        this.urlprefix = urlprefix;
    }

    public String getUrlprefix(){
        return this.urlprefix;
    }

    public String getUrl(){
        return this.urlprefix;
    }

}
