package hanalife.batch.util.ftd;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;

import org.apache.log4j.Logger;

import hanalife.batch.BatchException;
import hanalife.batch.util.FileManager;

/**
 * <pre>
 * 클래스명    : FTDGenerator
 * 클래스설명 : file to db에 필요한 객체를 생성하여 리턴하는 Generator
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class FTDGenerator
	implements IFTDGenerator {
	private static Logger log = Logger.getLogger(FTDGenerator.class.getName());
	FTDParser parser;
	FileManager fm;
	FileInputStream in;
	BufferedReader buffRead;

	Map msgLayoutMap;
	String fileDesc;
	String deftClassNm;

	public FTDGenerator() {
		init();
	}

	/**
	 * <p>초기화</p>
	 */
	public void init() {
		this.parser = new FTDParser();
		this.fm = new FileManager();
		msgLayoutMap = new HashMap();
		fileDesc = "";
		deftClassNm = "";
	}

	/**
	 * 배치수행에 필요한 정보를 저장하고 있는 객체들의 집합을 리턴한다.
	 * @param fileNm 파일경로를 포함한 파일명
	 * @param xmlFileUrl 파싱할 xml 종류
	 * @return FTDMsgVOList 객체들의 집합
	 * @throws BatchException
	 */
	@Override
	public FTDMsgVOList getFTDList(String fileNm, String xmlFileUrl) throws
		BatchException {
		FTDMsgVOList ftdl = null;

		//전문을 파싱한다.
		fm.makeFileLayout(fileNm);

		//전문을 String으로 얻는다.
		String fileCntn = fm.getFileCntn();

		//xml을 파싱하여 메타정보를 저장한다.
		setXmlLayout(parser, xmlFileUrl);

		//객체생성
		ftdl = makeMsgVOList(fileCntn);
		ftdl.setFileDesc(this.fileDesc);

		return ftdl;
	}

	/**
	 * 필요한 객체를 생성하여 세팅해주는 메서드
	 * @param fileCntn 파일 내용
	 * @return FTDMsgVOList
	 * @throws FTDException 오류시 발생하는 Exception
	 */
	private FTDMsgVOList makeMsgVOList(String fileCntn) throws FTDException {
		FTDMsgVOList ftdl = new FTDMsgVOList();
		StringTokenizer st = null;
		FTDMsgLayout msgLayout = null;
		FTDMsgVO msgVO = null;
		int[] startPos = null;
		int[] bytes = null;
		List paramList = null;

		String msgRecord = "";
		String classNm = "";

		try {
			//전문을 엔터로 구분
			st = new StringTokenizer(fileCntn, "\n");

			//전문을 한라인씩 얻어와서 record type 에 맞게 전문 VO를 생성한다.
			while (st.hasMoreTokens()) {
				msgRecord = st.nextToken();
				msgLayout = getMsgLayoutWithXml(msgRecord);
				if (msgLayout == null) {
					throw new FTDException("전문 Formmat Layout이 없습니다.");
				}

				//개별 클래스가 없으면 디폴트 클래스로 생성한다.
				classNm = msgLayout.getClassNm();
/**
 * <pre>
 * 클래스명    : FTDGenerator
 * 클래스설명 : FTDGenerator의 설명
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
				if (classNm == null || "".equals(classNm)) {
					classNm = deftClassNm;
				}

				msgVO = (FTDMsgVO) getClass().getClassLoader().loadClass(
					classNm).newInstance();
				paramList = msgLayout.getParamList();

				startPos = new int[paramList.size()];
				bytes = new int[paramList.size()];

				//시작과 끝 바이트 수를 계산
				setCalcBytes(paramList, startPos, bytes);

				//각 업무별 프로그램에서 구현한 setting 매소드에 전달
				msgVO.setRecord(msgLayout.getRecDiv(), msgRecord, startPos,
								bytes);
				msgVO.setRecDiv(msgLayout.getRecDiv());
				ftdl.add(msgVO);
			}

		}
		catch (Exception e) {
			e.printStackTrace();
			throw new FTDException(e.getMessage());
		}

		return ftdl;
	}

	/**
	 * 객체의 각 변수들을 세팅시 필요한 시작과 끝 바이트 수를 계산해주는 메서드
	 * @param paramList
	 * @param startPos 시작 byte
	 * @param bytes 종료 byte
	 */
	private void setCalcBytes(List paramList, int[] startPos, int[] bytes) {
		int size = paramList.size();

		for (int i = 0; i < size; i++) {
			String[] temp = (String[]) paramList.get(i);

                  	if (i == 0) {
				startPos[i] = 0;
				bytes[i] = Integer.parseInt(temp[2]);
			}
			else {
				startPos[i] = bytes[i - 1];
				bytes[i] = startPos[i] + Integer.parseInt(temp[2]);
			}
		}
	}

	/**
	 * xml 파일의 정보를 파싱하여 세팅한다.
	 * @param parser xml 파싱 객체
	 * @param xmlFile 파싱할 xml 종류
	 * @throws FTDException 오류시 발생 Exception
	 */
	private void setXmlLayout(FTDParser parser, String xmlFile) throws
		FTDException {
		//xml 파일경로를 넘겨주어 record layout object를 얻는다.
		parser.setLayoutXml(xmlFile);
		parser.parse();
		msgLayoutMap = parser.getMsgMap();

		fileDesc = parser.getMsgDesc();
		deftClassNm = parser.getDeftClassNm();
	}

	/**
	 *
	 * 초기 파일을 로딩한다.
	 * @param String fileName --파일명
	 * @param String type -- xml struct
	 * @throws FTDException 오류시 발생 Exception
	 */
	public void loadFile(String fileNm, String xmlFile) throws FTDException {
		try {
			setXmlLayout(parser, xmlFile);
			this.in = new FileInputStream(fileNm);
			this.buffRead = new BufferedReader(new InputStreamReader(in));
		}
		catch (Exception e) {
			throw new FTDException(e.getMessage());
		}
	}

	/**
	 *
	 * 파일처리작업이 끝난후 파일을 닫는다.
	 * @throws FTDException 오류시 발생 Exception
	 */
	public void closeFile() throws FTDException {
		if (buffRead != null) {
			try {
				buffRead.close();
			}
			catch (Exception e) {
				throw new FTDException(e.getMessage());
			}
		}

		if (in != null) {
			try {
				in.close();
			}
			catch (Exception e) {
				throw new FTDException(e.getMessage());
			}
		}
	}

	/**
	 *
	 * 파일로딩후 한행씩 읽어 해당 객체로 구성한다.
	 * @param : String gubun --H : Header에 셋팅,B : Body에 셋팅, T : Tailer에 셋팅
	 * @throws FTDException 오류시 발생 Exception
	 */
	public FTDMsgVO getOneRowData(String gubun) throws FTDException {
		FTDMsgVO fo = null;
		byte[] buff = null;
		String fileCntn = null;
		List paramList = null;
		FTDMsgLayout layout = null;
		int[] startPos = null;
		int[] bytes = null;

		try {
			//record type으로 얻기
			layout = getMsgLayout(gubun);
			if (layout == null) {
				throw new FTDException("전문 Formmat Layout이 없습니다.");
			}

			fo = (FTDMsgVO) getClass().getClassLoader().loadClass(layout.
				getClassNm()).newInstance();

			paramList = layout.getParamList();
			fileCntn = buffRead.readLine();

			startPos = new int[paramList.size()];
			bytes = new int[paramList.size()];

			setCalcBytes(paramList, startPos, bytes);
			fo.setRecord(layout.getRecDiv(), fileCntn, startPos, bytes);
		}
		catch (Exception e) {
			throw new FTDException(e.getMessage());
		}

		fileCntn = null;

		return fo;
	}

	/**
	 * <p>전문 layout을 정의한 Obj를 리턴한다.</p>
	 * @param recTypeCd
	 * @return
	 */
	private FTDMsgLayout getMsgLayout(String recTypeCd) {
		try {
			return (FTDMsgLayout)this.msgLayoutMap.get(recTypeCd);
		}
		catch (Exception e) {
			return null;
		}
	}

    /**
     * <p>전문 layout을 정의한 Obj를 리턴한다.</p>
     * @param recTypeCd
     * @return
     */
	private FTDMsgLayout getMsgLayoutWithXml(String msgCntn) {
		Set set = null;
		Iterator i = null;
                String rr = "";
		try {
			set = this.msgLayoutMap.entrySet();
			i = set.iterator();
			while (i.hasNext()) {
				Map.Entry me = (Map.Entry) i.next();

				if (equalsBySize( (String) me.getKey(), msgCntn)) {
					return (FTDMsgLayout) me.getValue();
				}
                                else
                                {
                                    if (me.getKey() != null &&
                                        me.getKey().equals("@")) {
                                        return (FTDMsgLayout) me.getValue();
                                    }
                                }
			}
		}
		catch (Exception e) {
			e.printStackTrace();
		}
		return null;
	}

    /**
     * <p>left의 사이즈만큼 right의 String 비교</p>
     * @param left - 원비교 문자열 ( 사이즈 )
     * @param right - 비교대상 문자열
     * @return booelan - true/false 비교결과여부
     */
	private boolean equalsBySize(String left, String right) {
		int size = nts(left).length();

		if (size < 1) {
			return false;
		}

		if (size > right.length()) {
			return false;
		}

		return left.equals(right.substring(0, size));
	}

	/**
	 * nts
	 * null 문자열을 "" 문자열로, 이외는 trim()한 문자열로 리턴
	 * @param str String
	 * @return String
	 */
	private String nts(String str) {
		if (str == null) {
			return null;
		}
		return str.trim();
	}
}
