package hanalife.batch.util.ftd;

import hanalife.util.ReplaceChar;


/**
 * <pre>
 * 클래스명    : FTDMsgVO
 * 클래스설명 : 생성될 객체의 부모가 되는 추상클래스 VO
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public abstract class FTDMsgVO{
	String recDiv;

    public FTDMsgVO() {
    }

    /**
     * 데이터를 세팅한다.
     * @param fileCntn
     * @param startPos
     * @param bytes
     */
    abstract public void setRecord(String fTypeCd, String fileCntn, int[] startPos, int[] bytes);

    /**
     * <p>전문의 구분</p>
     * <p>예 : H : 헤더, B : 데이터, F : footer</p>
     */
    public String getRecDiv(){
    	return recDiv;
    }
    public void setRecDiv(String inRecDiv){
    	this.recDiv = inRecDiv;
    }

    /**
     * byte단위로 문자열을 파싱해준다.
     * @param str
     * @param startPos
     * @param byteSize
     * @return
     */
    protected String getByteString(String str, int startPos, int byteSize) {
        String retVal = getShortString(str, byteSize).substring(getShortString(str, startPos).length()).trim();

        return ReplaceChar.replaceChar(retVal);
    }

    /**
     * byte단위로 문자열을 파싱해준다. (trim하지 않음)
     * @param str
     * @param startPos
     * @param byteSize
     * @return
     */
    protected String getByteNoTrimString(String str, int startPos, int byteSize) {
        String retVal = getShortString(str, byteSize).substring( getShortString( str, startPos).length());

        return ReplaceChar.replaceChar(retVal);
    }

    /**
     * 문자열을 파싱한다.
     * @param str 전체문자열
     * @param startPos 파싱시작 byte
     * @param byteSize 파싱종료 byte
     * @return 파싱된 문자열
     */
    private String getShortString(String str, int byteSize) {
        int rSize = 0;
        int len = 0;

        if (str.getBytes().length > byteSize) {
            for (; rSize < str.length(); rSize++) {
                if (str.charAt(rSize) > 0x007F) {
                    len += 2;
                } else {
                    len++;
                }

                if (len > byteSize) {
                    break;
                }
            }

            str = str.substring(0, rSize);
        }

        return str;
    }

    @Override
	public String toString() {
        StringBuffer sBuffer = new StringBuffer();
        String fName = null;
        String uName = null;
        Class cls = this.getClass();
        String value = null;
        Object valObj = null;

        try {
            java.lang.reflect.Field[] f = cls.getDeclaredFields();

            sBuffer.append("\n\t[============ ");
            sBuffer.append(cls.getName());
            sBuffer.append(" ============\n");

	          int len = f.length;
	          for (int i = 0; i < len; i++)
	          {
	            fName = f[i].getName();
	            uName = fName.substring(0, 1).toUpperCase() +
	                fName.substring(1, fName.length());

	            java.lang.reflect.Method m = cls.getMethod("get" + uName, new Class[]{});
	            valObj = m.invoke(this, new Object[]{});

	            sBuffer.append("\t(");
	            sBuffer.append(i + 1);
	            sBuffer.append(")");
	            sBuffer.append(fName);
	            sBuffer.append(":");
	            sBuffer.append(valObj);
//	            sBuffer.append(value);
	            sBuffer.append("|");
	            if ((i + 1) % 5 == 0 && i != (len - 1))
	            {
	              sBuffer.append("\n");
	            }
	          }
	          sBuffer.append("\n]");
        } catch (Exception e) {
            e.printStackTrace();
        }

        return sBuffer.toString();
    }

    /**
     * <p>메소드명 : delNull</p>
     * <p>설명 : String 필드는 null 제거, numeric 필드는 '0'으로 초기화
     * </p>
     * <p>예외처리 : N/A </p>
     */
    public void delNull() {

        Class cls = this.getClass();
        String fName = null;
        String uName = null;
        Object[] tmpValArr = new Object[1];
        java.lang.reflect.Method method =null;

        java.lang.reflect.Field[] f = cls.getDeclaredFields();

        int len = f.length;
        for(int i = 0;i<len;i++)
        {

            if( f[i].getType() != String.class) {
                continue;
            }
            fName = f[i].getName();
            uName = fName.substring(0,1).toUpperCase()+fName.substring( 1, fName.length());
            try {
                tmpValArr[0] =(cls.getMethod("get"+uName, null)).invoke(this, new Object[]{});
                (cls.getMethod("set"+uName,new Class[]{String.class})).invoke(this, tmpValArr);
            }catch(Exception e) {
                e.printStackTrace();
                continue;
            }
        }
    }

    /**
     * <p>메소드명 :nts</p>
     * <p>설명 :null이 들어오면 ""로 변환</p>
     * <p>메소드인수1 :String args</p>
     * <p>메소드리턴값 :String args</p>
     * <p>예외처리 :FTDException 배치오류시 발생하는 Exception</p>
     */
    protected String nts(String args) {
        return (args == null) ? "" : args.trim();
    }

    /**
     * <p>메소드명 :ntz</p>
     * <p>설명 :null이 들어오면 "0"로 변환</p>
     * <p>메소드인수1 :String args</p>
     * <p>메소드리턴값 :String args</p>
     * <p>예외처리 :FTDException 배치오류시 발생하는 Exception</p>
     */
    protected String ntz(String args) {
        return (args == null) ? "0" : ("".equals(args.trim()) ? "0" : args);
    }
}
