package hanalife.c.bc.cc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.bc.cc.mapper.UserMngMapper;
import hanalife.c.bc.cc.mapper.dto.UserMngDSUSERCNTSDDTO;
import hanalife.c.bc.cc.mapper.dto.UserMngDSUSERMNGSDCDTO;
import hanalife.c.bc.cc.mapper.dto.UserMngDSUSERMNGSDDTO;
import hanalife.c.bc.cc.mapper.dto.UserMngDSUSERMNGSMDTO;
import hanalife.c.bc.cc.service.CBCCCM02Service;
import hanalife.c.bc.cc.vo.CBCCCM02DSUSERCNTSDVO;
import hanalife.c.bc.cc.vo.CBCCCM02DSUSERMNGSDCVO;
import hanalife.c.bc.cc.vo.CBCCCM02DSUSERMNGSDVO;
import hanalife.c.bc.cc.vo.CBCCCM02S01InVO;
import hanalife.c.bc.cc.vo.CBCCCM02S01OutVO;
import hanalife.c.bc.cc.vo.CBCCCM02U01InVO;
import hanalife.c.bc.cc.vo.CBCCCM02U01OutVO;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.CtUserMapper;
import hanalife.c.co.mapper.dto.CtUserDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCM02ServiceImpl.java Class
 * 클래스설명   : 사용자관리 (CBCCCM02) Service Implements
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCBCCCM02S01 : 사용자관리목록조회
 * 			 	getCBCCCM02S02 : 사용자관리건수조회
 * 			 	registerCBCCCM02I01 : 사용자관리등록
 * 			 	modifyCBCCCM02U01 : 사용자관리수정
 * 			 	deleteCBCCCM02U01 : 사용자관리삭제

 * </pre>
 */
@Service("CBCCCM02Service")
public class CBCCCM02ServiceImpl implements CBCCCM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCM02ServiceImpl.class);

    private MsgEnum msgEnum;

	@Autowired
	private UserMngMapper userMngMapper;

	@Autowired
	private CtUserMapper ctUserMapper;

	/**
	 * <p>메소드명      : getCBCCCM02S01 : 사용자관리</p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자관리 조회 한다.</p>
	 * <p>메소드인수    : CBCCCM02S01InVo </p>
	 * <p>메소드리턴값  : CBCCCM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCM02S01OutVO getCBCCCM02S01(CBCCCM02S01InVO inVo) throws Exception {

		CBCCCM02S01OutVO resultVo = new CBCCCM02S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		UserMngDSUSERMNGSMDTO inDto = new UserMngDSUSERMNGSMDTO();

		inDto.setUserNo(inVo.getCBCCCM02DSUSERMNGSMVO().getUserNo()); 		/** 사용자번호 */
		inDto.setUserDivCd(inVo.getCBCCCM02DSUSERMNGSMVO().getUserDivCd()); /** 사용자구분코드 */
		inDto.setUserNm(inVo.getCBCCCM02DSUSERMNGSMVO().getUserNm()); 		/** 사용자명 */
		inDto.setDeptCd(inVo.getCBCCCM02DSUSERMNGSMVO().getDeptCd());		/** 부서코드 */
		inDto.setDeptNm(inVo.getCBCCCM02DSUSERMNGSMVO().getDeptNm()); 		/** 부서명 */

		// 사용자관리 기본 목록 조회
		List<UserMngDSUSERMNGSDDTO> resultDTO = userMngMapper.joinUserMngSearch(inDto);	/** 사용자관리리스트*/

		List<CBCCCM02DSUSERMNGSDVO> resultList = new ArrayList<CBCCCM02DSUSERMNGSDVO>();

		for (UserMngDSUSERMNGSDDTO sourceIO : resultDTO) {
			CBCCCM02DSUSERMNGSDVO targetIO = new CBCCCM02DSUSERMNGSDVO();
			targetIO.setUserNo(sourceIO.getUserNo()); 					/** 사용자번호 */
			targetIO.setUserNm(sourceIO.getUserNm()); 					/** 사용자명 */
			targetIO.setPswd(sourceIO.getPswd()); 						/** 비밀번호 */
			//targetIO.setEmpNo(sourceIO.getEmpNo()); 					/** 사원번호 */
			targetIO.setDeptCd(sourceIO.getDeptCd()); 					/** 부서코드 */
			targetIO.setUseFg(sourceIO.getUseFg()); 					/** 사용여부 */
			targetIO.setUserDivCd(sourceIO.getUserDivCd()); 			/** 사용자구분코드 */
			targetIO.setEmalAddr(sourceIO.getEmalAddr()); 				/** 이메일주소 */
			targetIO.setRcntPswdChngDt(sourceIO.getRcntPswdChngDt()); 	/** 최근비밀번호변경일 */
			targetIO.setUseEndDt(sourceIO.getUseEndDt()); 				/** 사용종료일 */
			targetIO.setPosiCd(sourceIO.getPosiCd()); 					/** 직위코드 */
			//targetIO.setkSystemId(sourceIO.getkSystemId()); 			/** KSYSTEM아이디 */
			targetIO.setIpAddr(sourceIO.getIpAddr()); 					/** IP주소 */
			targetIO.setPswdErrCnt(sourceIO.getPswdErrCnt()); 			/** 패스워드오류건수 */
			targetIO.setBfPswd(sourceIO.getBfPswd()); 					/** 전패스워드 */
			targetIO.setBf2Pswd(sourceIO.getBf2Pswd()); 				/** 전전패스워드 */
			targetIO.setRetiCd(sourceIO.getRetiCd()); 					/** 퇴직코드 */

			resultList.add(targetIO);
		}

		// 사용자관리 건수 조회
		List<UserMngDSUSERCNTSDDTO> resultCntDTO = userMngMapper.selectUserCnt();	/** 사용자관리건수조회 */

		List<CBCCCM02DSUSERCNTSDVO> resultCntList = new ArrayList<CBCCCM02DSUSERCNTSDVO>();

		for (UserMngDSUSERCNTSDDTO sourceIO : resultCntDTO) {
			CBCCCM02DSUSERCNTSDVO targetIO = new CBCCCM02DSUSERCNTSDVO();
			targetIO.setTotCnt(sourceIO.getTotCnt()); 				/** 전체건수 */
			targetIO.setInqCnt(String.valueOf(resultDTO.size())); 	/** 조회건수 */
			targetIO.setUseY(sourceIO.getUseY()); 					/** 사용건수 */
			targetIO.setUseN(sourceIO.getUseN()); 					/** 잠김건수 */

			resultCntList.add(targetIO);
		}

		resultVo.setCBCCCM02DSUSERMNGSDVO(resultList);		/** 사용자관리리스트 */
		resultVo.setCBCCCM02DSUSERCNTSDVO(resultCntList);	/** 사용자관리건수리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : getCBCCCM02S02 : 사용자관리건수조회</p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자관리건수 조회 한다.</p>
	 * <p>메소드인수    : CBCCCM02S01InVo </p>
	 * <p>메소드리턴값  : CBCCCM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public int getCBCCCM02S02(CBCCCM02DSUSERMNGSDCVO inVo) throws Exception {

		List<UserMngDSUSERCNTSDDTO> resultList = new ArrayList<UserMngDSUSERCNTSDDTO>();
		int resultCnt = 0;

		UserMngDSUSERMNGSDCDTO inDto = new UserMngDSUSERMNGSDCDTO();
		inDto.setUserNo(inVo.getUserNo()); /** 사용자번호 */

		// 사용자관리 사용자 건수 조회
		resultList = userMngMapper.searchCnt(inDto);	/** 사용자건수리스트*/

		for (UserMngDSUSERCNTSDDTO sourceIO : resultList) {
			resultCnt = Integer.parseInt(sourceIO.getInqCnt()); /** 조회건수 */
		}

		return resultCnt;
	}

	/**
	 * <p>메소드명      : registerCBCCCM02I01 : 사용자관리등록</p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자관리 등록 한다.</p>
	 * <p>메소드인수    : CBCCCM02U01InVo </p>
	 * <p>메소드리턴값  : CBCCCM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCM02U01OutVO registerCBCCCM02U01(CBCCCM02U01InVO inVo) throws Exception {

		CBCCCM02U01OutVO resultVo = new CBCCCM02U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		CtUserDTO inDto = new CtUserDTO();

		int insResult = 0;

		inDto.setUserNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getUserNo()); 					/** 사용자번호 */
		inDto.setUserNm(inVo.getCBCCCM02DSUSERMNGSDCVO().getUserNm()); 					/** 사용자명 */
		inDto.setPswd(inVo.getCBCCCM02DSUSERMNGSDCVO().getPswd());						/** 비밀번호(DB에서 암호화) */
		//inDto.setEmpNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getEmpNo()); 					/** 사원번호 */
		inDto.setDeptCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getDeptCd()); 					/** 부서코드 */
		inDto.setUseFg(inVo.getCBCCCM02DSUSERMNGSDCVO().getUseFg()); 					/** 사용여부 */
		inDto.setUserDivCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getUserDivCd());			/** 사용자구분코드 */
		inDto.setEmalAddr(inVo.getCBCCCM02DSUSERMNGSDCVO().getEmalAddr()); 				/** 이메일주소 */
		inDto.setRcntPswdChngDt(inVo.getCBCCCM02DSUSERMNGSDCVO().getRcntPswdChngDt()); 	/** 최근비밀번호변경일 */
		inDto.setUseEndDt(inVo.getCBCCCM02DSUSERMNGSDCVO().getUseEndDt()); 				/** 사용종료일 */
		inDto.setPosiCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getPosiCd()); 					/** 직위코드 */
		//inDto.setkSystemId(inVo.getCBCCCM02DSUSERMNGSDCVO().getkSystemId()); 			/** KSYSTEM아이디 */
		inDto.setIpAddr(inVo.getCBCCCM02DSUSERMNGSDCVO().getIpAddr()); 					/** IP주소 */
		inDto.setPswdErrCnt(inVo.getCBCCCM02DSUSERMNGSDCVO().getPswdErrCnt()); 			/** 패스워드오류건수 */
		inDto.setBfPswd(inVo.getCBCCCM02DSUSERMNGSDCVO().getBfPswd()); 					/** 전패스워드 */
		inDto.setBf2Pswd(inVo.getCBCCCM02DSUSERMNGSDCVO().getBf2Pswd()); 				/** 전전패스워드 */
		inDto.setRetiCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getRetiCd()); 					/** 퇴직코드 */
		inDto.setFrstRegEmpNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getLogInEmpNo()); 		/** 최초등록사원번호 */
		inDto.setLastProcEmpNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getLogInEmpNo()); 		/** 마지막수정사원번호 */

		insResult = ctUserMapper.insert(inDto);

		if(insResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;

	}

	/**
	 * <p>메소드명      : modifyCBCCCM02U01 : 사용자관리수정</p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자관리 수정 한다.</p>
	 * <p>메소드인수    : CBCCCM02U01InVo </p>
	 * <p>메소드리턴값  : CBCCCM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCM02U01OutVO modifyCBCCCM02U01(CBCCCM02U01InVO inVo) throws Exception {

		CBCCCM02U01OutVO resultVo = new CBCCCM02U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		CtUserDTO inDto = new CtUserDTO();

		int updResult = 0;

		inDto.setUserNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getUserNo()); 					/** 사용자번호 */
		inDto.setUserNm(inVo.getCBCCCM02DSUSERMNGSDCVO().getUserNm()); 					/** 사용자명 */
		inDto.setPswd(inVo.getCBCCCM02DSUSERMNGSDCVO().getPswd());						/** 비밀번호 */
		//inDto.setEmpNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getEmpNo()); 					/** 사원번호 */
		inDto.setDeptCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getDeptCd()); 					/** 부서코드 */
		inDto.setUseFg(inVo.getCBCCCM02DSUSERMNGSDCVO().getUseFg()); 					/** 사용여부 */
		inDto.setUserDivCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getUserDivCd());			/** 사용자구분코드 */
		inDto.setEmalAddr(inVo.getCBCCCM02DSUSERMNGSDCVO().getEmalAddr()); 				/** 이메일주소 */
		inDto.setRcntPswdChngDt(inVo.getCBCCCM02DSUSERMNGSDCVO().getRcntPswdChngDt()); 	/** 최근비밀번호변경일 */
		inDto.setUseEndDt(inVo.getCBCCCM02DSUSERMNGSDCVO().getUseEndDt()); 				/** 사용종료일 */
		inDto.setPosiCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getPosiCd()); 					/** 직위코드 */
		//inDto.setkSystemId(inVo.getCBCCCM02DSUSERMNGSDCVO().getkSystemId()); 			/** KSYSTEM아이디 */
		inDto.setIpAddr(inVo.getCBCCCM02DSUSERMNGSDCVO().getIpAddr()); 					/** IP주소 */
		inDto.setPswdErrCnt(inVo.getCBCCCM02DSUSERMNGSDCVO().getPswdErrCnt()); 			/** 패스워드오류건수 */
		inDto.setBfPswd(inVo.getCBCCCM02DSUSERMNGSDCVO().getBfPswd()); 					/** 전패스워드 */
		inDto.setBf2Pswd(inVo.getCBCCCM02DSUSERMNGSDCVO().getBf2Pswd()); 				/** 전전패스워드 */
		inDto.setRetiCd(inVo.getCBCCCM02DSUSERMNGSDCVO().getRetiCd()); 					/** 퇴직코드 */
		inDto.setLastProcEmpNo(inVo.getCBCCCM02DSUSERMNGSDCVO().getLogInEmpNo()); 		/** 마지막수정사원번호 */

		updResult = ctUserMapper.update(inDto);	/** 사용자관리수정리스트*/

		if(updResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : deleteCBCCCM02U01 : 사용자관리삭제</p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자관리 삭제 한다.</p>
	 * <p>메소드인수    : CBCCCM02U01InVo </p>
	 * <p>메소드리턴값  : CBCCCM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCM02U01OutVO deleteCBCCCM02U01(CBCCCM02U01InVO inVo) throws Exception {

		CBCCCM02U01OutVO resultVo = new CBCCCM02U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		CtUserDTO inDto = new CtUserDTO();

		int delResult = 0;

		inDto.setUserNo(inVo.getCBCCCM02DSUSERMNGSDDVO().getUserNo()); /** 사용자번호 */

		delResult = ctUserMapper.remove(inDto);	/** 사용자관리삭제리스트*/

		if(delResult <= 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

}