package hanalife.c.bc.cc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.bc.cc.mapper.LoanIntgMapper;
import hanalife.c.bc.cc.mapper.dto.LoanIntgDSSRCHSDDTO;
import hanalife.c.bc.cc.mapper.dto.LoanIntgDSSRCHSMDTO;
import hanalife.c.bc.cc.service.CBCCCP01Service;
import hanalife.c.bc.cc.vo.CBCCCP01DSSRCHSDVO;
import hanalife.c.bc.cc.vo.CBCCCP01S01InVO;
import hanalife.c.bc.cc.vo.CBCCCP01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP01ServiceImpl.java Class
 * 클래스설명   : 대출통합검색 (CBCCCP01) Service Implements
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCBCCCP01S01 : 대출통합검색목록조회

 * </pre>
 */
@Service("CBCCCP01Service")
public class CBCCCP01ServiceImpl implements CBCCCP01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP01ServiceImpl.class);

	@Autowired
	private LoanIntgMapper loanIntgMapper;

	/**
	 * <p>메소드명      : getCBCCCP01S01 : 대출통합검색</p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 대출통합검색 한다.</p>
	 * <p>메소드인수    : CBCCCP01S01InVo </p>
	 * <p>메소드리턴값  : CBCCCP01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCP01S01OutVO getCBCCCP01S01(CBCCCP01S01InVO inVo) throws Exception {

		CBCCCP01S01OutVO resultVo = new CBCCCP01S01OutVO();

		LoanIntgDSSRCHSMDTO inDto = new LoanIntgDSSRCHSMDTO();

		String custNo = inVo.getCBCCCP01DSSRCHSMVO().getCustNo();	/** 고객번호 */
		String custNm = inVo.getCBCCCP01DSSRCHSMVO().getCustNm();	/** 고객명 */
		String rlDueCustNo = inVo.getCBCCCP01DSSRCHSMVO().getRlDueCustNo();	/** 실납입자고객번호 */
		String rlDueCustNm = inVo.getCBCCCP01DSSRCHSMVO().getRlDueCustNm();	/** 실납입자고객명 */
		String cprtComNo = inVo.getCBCCCP01DSSRCHSMVO().getCprtComNo();	/** 제휴사번호 */
		String cprtComNm = inVo.getCBCCCP01DSSRCHSMVO().getCprtComNm();	/** 제휴사명 */
		String cprtBranCd = inVo.getCBCCCP01DSSRCHSMVO().getCprtBranCd();	/** 제휴부서코드 */
		String cprtBranNm = inVo.getCBCCCP01DSSRCHSMVO().getCprtBranNm();	/** 제휴부서명 */
		String cprtOrgDeptCd = inVo.getCBCCCP01DSSRCHSMVO().getCprtOrgDeptCd();	/** 제휴부서코드 */

		// 제휴사 유무
		// AS-IS 제휴사번호, 제휴사명, 제휴부서명, 제휴원부서코드로 제휴사 유무 판별
		Boolean cprtYn = (cprtComNo != "" && !"".equals(cprtComNo)) || (cprtComNm != "" && !"".equals(cprtComNm)) || (cprtBranNm != "" && !"".equals(cprtBranNm)) || (cprtOrgDeptCd != "" && !"".equals(cprtOrgDeptCd));

		inDto.setCustNo(custNo); /** 고객번호 */
		inDto.setCustNm(custNm); /** 고객명 */
		inDto.setLoanNo(inVo.getCBCCCP01DSSRCHSMVO().getLoanNo()); /** 대출번호 */
		inDto.setLoanSeq(inVo.getCBCCCP01DSSRCHSMVO().getLoanSeq()); /** 대출순번 */
		inDto.setMngNo(inVo.getCBCCCP01DSSRCHSMVO().getMngNo()); /** 관리번호 */
		inDto.setCprtComNo(cprtComNo); /** 제휴사번호 */
		inDto.setCprtComNm(cprtComNm); /** 제휴사명 */
		inDto.setCprtBranCd(cprtBranCd); /** 제휴부서코드 */
		inDto.setCprtBranNm(cprtBranNm); /** 제휴부서명 */
		inDto.setCprtOrgDeptCd(cprtOrgDeptCd); /** 제휴부서코드 */
		inDto.setMngDeptCd(inVo.getCBCCCP01DSSRCHSMVO().getMngDeptCd()); /** 관리부서코드 */
		inDto.setLoanNormIzeFg(inVo.getCBCCCP01DSSRCHSMVO().getLoanNormIzeFg()); /** 대출최종여부 */
		inDto.setLoanStatCd(inVo.getCBCCCP01DSSRCHSMVO().getLoanStatCd()); /** 대출상태코드 */
		inDto.setFromLoanDt(inVo.getCBCCCP01DSSRCHSMVO().getFromLoanDt()); /** 대출일자시작 */
		inDto.setToLoanDt(inVo.getCBCCCP01DSSRCHSMVO().getToLoanDt()); /** 대출일자종료 */
		inDto.setHpNo(inVo.getCBCCCP01DSSRCHSMVO().getHpNo()); /** 핸드폰번호 */
		inDto.setCarsNo(inVo.getCBCCCP01DSSRCHSMVO().getCarsNo()); /** 차량번호 */
		inDto.setCaseNo(inVo.getCBCCCP01DSSRCHSMVO().getCaseNo()); /** 사건번호 */
		inDto.setRlDueCustNo(rlDueCustNo); /** 실납입자고객번호 */
		inDto.setRlDueCustNm(rlDueCustNm); /** 실납입자고객명 */
		inDto.setCnslNo(inVo.getCBCCCP01DSSRCHSMVO().getCnslNo()); /** 상담번호 */

		List<LoanIntgDSSRCHSDDTO> resultDTO = null;

		/** 대출고객이 있을 때 */
		if( (custNo != "" && !"".equals(custNo)) || (custNm != "" && !"".equals(custNm)) ) {
			if( cprtYn == true ) {
				resultDTO = loanIntgMapper.searchLoanIntgSrch_ST_LOAN_INTG_SEARCH03(inDto);	/** 대출통합검색(대출고객이 있고 제휴사/제휴점 있을때) */
			}else {
				resultDTO = loanIntgMapper.searchLoanIntgSrch_ST_LOAN_INTG_SEARCH01(inDto);	/** 대출통합검색(대출고객이 있고 제휴사/제휴점 없을때) */
			}
		/** 실납입자 고객이 있을 때 */
		}else if( (rlDueCustNo != "" && !"".equals(rlDueCustNo)) || (rlDueCustNm != "" && !"".equals(rlDueCustNm)) ) {
			//고객번호 및 고객명에 실납입자 정보 세팅
			inDto.setCustNo(rlDueCustNo); /** 고객번호 */
			inDto.setCustNm(rlDueCustNm); /** 고객명 */

			if( cprtYn == true ) {
				resultDTO = loanIntgMapper.searchLoanIntgSrch_ST_LOAN_INTG_SEARCH07(inDto);	/** 대출통합검색(실납입 고객이 있고 제휴사/제휴점 있을때) */
			}else {
				resultDTO = loanIntgMapper.searchLoanIntgSrch_ST_LOAN_INTG_SEARCH06(inDto);	/** 대출통합검색(실납입 고객이 있고 제휴사/제휴점 없을때) */
			}
		/** 고객정보가 없을 때 */
		}else {
			if( cprtYn == true ) {
				resultDTO = loanIntgMapper.searchLoanIntgSrch_ST_LOAN_INTG_SEARCH04(inDto);	/** 대출통합검색(대출고객이 없고 제휴사/제휴점 있을때) */
			}else {
				resultDTO = loanIntgMapper.searchLoanIntgSrch_ST_LOAN_INTG_SEARCH02(inDto);	/** 대출통합검색(대출고객이 없고 제휴사/제휴점 없을때) */
			}
		}

		List<CBCCCP01DSSRCHSDVO> resultList = new ArrayList<CBCCCP01DSSRCHSDVO>();

		for (LoanIntgDSSRCHSDDTO sourceIO : resultDTO) {
			CBCCCP01DSSRCHSDVO targetIO = new CBCCCP01DSSRCHSDVO();
			targetIO.setLoanNo(sourceIO.getLoanNo()); /** 대출번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /** 대출순번 */
			targetIO.setCustNo(sourceIO.getCustNo()); /** 고객번호 */
			targetIO.setCustNm(sourceIO.getCustNm()); /** 고객명 */
			targetIO.setLoanRelCd(sourceIO.getLoanRelCd()); /** 대출관계코드 */
			targetIO.setLoanStatCd(sourceIO.getLoanStatCd()); /** 대출상태코드 */
			targetIO.setLoanDt(sourceIO.getLoanDt()); /** 대출일 */
			targetIO.setLoanTerm(sourceIO.getLoanTerm()); /** 대출기간 */
			targetIO.setLoanPamt(sourceIO.getLoanPamt()); /** 대출원금 */
			targetIO.setCprtComNo(sourceIO.getCprtComNo()); /** 제휴사번호 */
			targetIO.setCprtComNm(sourceIO.getCprtComNm()); /** 제휴사명 */
			targetIO.setCprtBranCd(sourceIO.getCprtBranCd()); /** 제휴점코드 */
			targetIO.setCprtBranNm(sourceIO.getCprtBranNm()); /** 제휴점명 */
			targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /** 관리부서코드 */
			targetIO.setDeptNm(sourceIO.getDeptNm()); /** 관리부서 */
			targetIO.setLnDivsEmpNo(sourceIO.getLnDivsEmpNo()); /** 담당자사번 */
			targetIO.setUserNm(sourceIO.getUserNm()); /** 담당자명 */
			targetIO.setLoanPamtRamt(sourceIO.getLoanPamtRamt()); /** 대출잔액 */
			targetIO.setPrdtNm(sourceIO.getPrdtNm()); /** 대출상품 */
			targetIO.setGodsNm(sourceIO.getGodsNm()); /** 대출물품 */
			targetIO.setMngNo(sourceIO.getMngNo()); /** 관리번호 */
			targetIO.setDeliDt(sourceIO.getDeliDt()); /** 출고일자 */
			targetIO.setBndStatCd(sourceIO.getBndStatCd()); /** 채권상태코드 */
			targetIO.setCprtOrgDeptCd(sourceIO.getCprtOrgDeptCd()); /** 제휴사코드 */
			targetIO.setContManNo(sourceIO.getContManNo()); /** 고객번호 */
			targetIO.setContManNm(sourceIO.getContManNm()); /** 계약자명 */
			targetIO.setApplDt(sourceIO.getApplDt()); /** 승인일자 */
			targetIO.setHpNo(sourceIO.getHpNo()); /** 핸드폰번호 */
			targetIO.setCarsNo(sourceIO.getCarsNo()); /** 차량번호 */
			targetIO.setDocKeepPlcNo(sourceIO.getDocKeepPlcNo()); /** 서류보관처번호 */
			targetIO.setSetlDd(sourceIO.getSetlDd()); /** 결제일 */
			targetIO.setCaseNo(sourceIO.getCaseNo()); /** 사건번호 */
			targetIO.setCustResiNo(sourceIO.getCustResiNo()); /** 주민번호 */
			targetIO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd()); /** 상품중분류코드 */
			targetIO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd()); /** 상품대분류코드 */

			resultList.add(targetIO);
		}

		resultVo.setCBCCCP01DSSRCHSDVO(resultList);	/** 대출통합검색리스트 */

		return resultVo;
	}

}
