package hanalife.c.bc.cc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.bc.cc.mapper.CustSrchMapper;
import hanalife.c.bc.cc.mapper.dto.CustSrchMapperDSCUSTINFOSRCHSDDTO;
import hanalife.c.bc.cc.mapper.dto.CustSrchMapperDSCUSTINFOSRCHSMDTO;
import hanalife.c.bc.cc.service.CBCCCP02Service;
import hanalife.c.bc.cc.vo.CBCCCP02S01DSCUSTINFOSRCHSDVO;
import hanalife.c.bc.cc.vo.CBCCCP02S01InVO;
import hanalife.c.bc.cc.vo.CBCCCP02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP02ServiceImpl.java Class
 * 클래스설명   : 고객검색 (CBCCCP02) Service Implements
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCBCCCP02S01 : 고객검색목록조회
 *              registerCBCCCP02I01 : 고객검색등록
 *              modifyCBCCCP02U01 : 고객검색수정
 *              removeCBCCCP02U01 : 고객검색삭제
 * </pre>
 */
@Service("CBCCCP02Service")
public class CBCCCP02ServiceImpl implements CBCCCP02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP02ServiceImpl.class);

	@Autowired
	private CustSrchMapper custSrchMapper;

	/**
	 * <p>메소드명      : getCBCCCP02S01 : 고객검색목록조회</p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70321 / KimMinSeok
	 * <p>설명          : 고객검색목록을 조회 한다.</p>
	 * <p>메소드인수    : CBCCCP02S01InVo </p>
	 * <p>메소드리턴값  : CBCCCP02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CBCCCP02S01OutVO getCBCCCP02S01(CBCCCP02S01InVO inVo) throws Exception {

		CBCCCP02S01OutVO resultVo = new CBCCCP02S01OutVO();

		CustSrchMapperDSCUSTINFOSRCHSMDTO targetDto = new CustSrchMapperDSCUSTINFOSRCHSMDTO();

		targetDto.setCustNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCustNo()); /** 고객번호 */
		targetDto.setCustNm(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCustNm()); /** 고객명 */
		targetDto.setCorpRegNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCorpRegNo()); /** 법인번호 */
		targetDto.setBizManNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getBizManNo()); /** 사업자번호 */
		targetDto.setSearchCnt(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getSearchCnt()); /** 조회건수 */
		targetDto.setOprYn(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getOprYn()); /** 개인조회여부 */
		targetDto.setCellHpNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCellHpNo()); /** 핸드폰번호 */
		targetDto.setBirthDt(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getBirthDt()); /** 고객생년월일 */
		targetDto.setCustResiNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCustResiNo()); /** 고객인식번호 */
		targetDto.setTempCustFg(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getTempCustFg()); /** 임시고객여부 */
		targetDto.setLoanNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getLoanNo()); /** 대출번호 */
		targetDto.setCnslNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCnslNo()); /** 상담번호 */
		targetDto.setCarsNo(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getCarsNo()); /** 차량번호 */
		targetDto.setDstrYn(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getDstrYn()); /** 파기여부 */
		targetDto.setFrstDstrDt(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getFrstDstrDt()); /** 1차파기일자 */
		targetDto.setFrstDstrTm(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getFrstDstrTm()); /** 1차파기시각 */
		targetDto.setScndDstrDt(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getScndDstrDt()); /** 2차파기일자 */
		targetDto.setScndDstrTm(inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getScndDstrTm()); /** 2차파기시각 */

		//구분코드에 따라 다른 쿼리 동작
		String Gubun = inVo.getCBCCCP02S01DSCUSTINFOSRCHSMVO().getGubun(); /** 구분코드 */
		if(Gubun == null || "".equals(Gubun)) {
			Gubun = "99";
		}

		List<CustSrchMapperDSCUSTINFOSRCHSDDTO> resultDTO = new ArrayList<CustSrchMapperDSCUSTINFOSRCHSDDTO>();

		if( "99".equals(Gubun) ) {
			resultDTO = custSrchMapper.search21(targetDto);
		}
		else if( "98".equals(Gubun) ) {	//기간계 고객 정보 연동
//			AsocCustInfoGramCC acig = new AsocCustInfoGramCC();
//			acig.procReq(smdo, event, tx);
//
//			// 기간계 고객정보 연동 후 조회
//	        String[] condArr = convertSmdoToArray(smdo);

			resultDTO = custSrchMapper.search21(targetDto);
		}
		else {
			if( "1".equals(Gubun) ) {
				resultDTO = custSrchMapper.search10023(targetDto);
			}else if( "2".equals(Gubun) ) {
				resultDTO = custSrchMapper.search10024(targetDto);
			}else if( "3".equals(Gubun) ) {
				resultDTO = custSrchMapper.search10021(targetDto);
			}else if( "4".equals(Gubun) ) {
				resultDTO = custSrchMapper.search10022(targetDto);
			}else if( "5".equals(Gubun) ) {
				resultDTO = custSrchMapper.search10020(targetDto);
			}
		}

		List<CBCCCP02S01DSCUSTINFOSRCHSDVO> resultList = new ArrayList<CBCCCP02S01DSCUSTINFOSRCHSDVO>();

		for(CustSrchMapperDSCUSTINFOSRCHSDDTO sourceIO : resultDTO) {
			/** 상단의 고객 목록 VO에 조회된 Mapper DTO 값을 대입 */
			CBCCCP02S01DSCUSTINFOSRCHSDVO targetIO = new CBCCCP02S01DSCUSTINFOSRCHSDVO();

			targetIO.setCustTpNm(sourceIO.getCustTpNm()); /** 고객_구분 */
			targetIO.setCustNo(sourceIO.getCustNo()); /** 고객_번호 */
			targetIO.setCustNm(sourceIO.getCustNm()); /** 고객_명 */
			targetIO.setCustResiNo(sourceIO.getCustResiNo()); /** 주민_번호 */
			targetIO.setBirthDt(sourceIO.getBirthDt()); /** 고객_생년월일 */
			targetIO.setCellHpNo(sourceIO.getCellHpNo()); /** 핸드폰_번호 */
			targetIO.setHomeAddrCi(sourceIO.getHomeAddrCi()); /** 자택_주소_시 */
			targetIO.setHomeAddrGu(sourceIO.getHomeAddrGu()); /** 자택_주소_구 */
			targetIO.setHomeAddrDong(sourceIO.getHomeAddrDong()); /** 자택_주소_동 */
			targetIO.setReprCustNm(sourceIO.getReprCustNm()); /** 대표자_명 */
			targetIO.setReprCustNo(sourceIO.getReprCustNo()); /** 대표자_고객번호 */
			targetIO.setBizAddrCi(sourceIO.getBizAddrCi()); /** 사업장_주소_시 */
			targetIO.setBizAddrGu(sourceIO.getBizAddrGu()); /** 사업장_주소_구 */
			targetIO.setBizAddrDong(sourceIO.getBizAddrDong()); /** 사업장_주소_동 */
			targetIO.setCorpRegNo(sourceIO.getCorpRegNo()); /** 법인_번호 */
			targetIO.setDivsMannm(sourceIO.getDivsMannm()); /** 담당자_명 */
			targetIO.setDivsManHp(sourceIO.getDivsManHp()); /** 담당자_핸드폰_번호 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); /** 대출번호 */
			targetIO.setCnslNo(sourceIO.getCnslNo()); /** 상담번호 */
			targetIO.setCarsNo(sourceIO.getCarsNo()); /** 차량번호 */
			targetIO.setDstrYn(sourceIO.getDstrYn()); /** 파기여부 */
			targetIO.setFrstDstrDt(sourceIO.getFrstDstrDt()); /** 1차파기일자 */
			targetIO.setFrstDstrTm(sourceIO.getFrstDstrTm()); /** 1차파기시각 */
			targetIO.setScndDstrDt(sourceIO.getScndDstrDt()); /** 2차파기일자 */
			targetIO.setScndDstrTm(sourceIO.getScndDstrTm()); /** 2차파기시각 */

			/** 상단의 고객 목록 조회 결과 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
		}

		resultVo.setListCBCCCP02S01DSCUSTINFOSRCHSDVO(resultList);

		return resultVo;

	}

}
