package hanalife.c.bc.cc.web;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.cc.service.CBCCCM01Service;
import hanalife.c.bc.cc.vo.CBCCCM01DSCTCOMMCDDESCVO;
import hanalife.c.bc.cc.vo.CBCCCM01DSCTCOMMCDKINDVO;
import hanalife.c.bc.cc.vo.CBCCCM01DSSEARCHVO;
import hanalife.c.bc.cc.vo.CBCCCM01InVO;
import hanalife.c.bc.cc.vo.CBCCCM01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CBCCCM01Controller.java Class
 * 클래스설명	: 공통코드 관리 (CBCCCM01) Controller
 * 작성일자	: 2023.03.28.
 * 작성자명	: 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.03.28.][70280][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/bc/cc")
@Controller
public class CBCCCM01Controller {

	@Resource(name = "CBCCCM01Service")
	private CBCCCM01Service CBCCCM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCM01Controller.class);

    /**
     * <p>메소드명			: 공통코드관리내역 조회 /CBCCCM01S01.do </p>
     * <p>작성일자			: 2023.03.31.
     * <p>작성자(author)	: 70280
     * <p>설명			    : 공통코드관리내역을 조회한다.</p>
     * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCCCM01S01.do")
    public String CBCCCM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S01 추출 #####");

            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KIND_SEARCH", request, response, model);

            // 공통코드관리내역 조회 업무 서비스 호출 입력값 대입
            CBCCCM01DSSEARCHVO dsSEARCHVO = new CBCCCM01DSSEARCHVO();
            dsSEARCHVO.setCdKindNo      (sourceMap.get("cdKindNo").toString().trim());
            dsSEARCHVO.setCdKindNm      (sourceMap.get("cdKindNm").toString().trim().replaceAll("\\p{Z}", " ").replaceAll(" ", "%")); // 모든 공백 제거 -> % 치환 (LIKE 검색 위함)
            dsSEARCHVO.setCdDescShrtNm  (sourceMap.get("cdDescShrtNm").toString().trim().replaceAll("\\p{Z}", " ").replaceAll(" ", "%"));

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            CBCCCM01InVO InVO = new CBCCCM01InVO();

            // 공통코드관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setCBCCCM01DSSEARCHVO(dsSEARCHVO);

            // 공통코드관리내역 조회 업무 서비스 호출 수행
            CBCCCM01OutVO resultListVo = CBCCCM01.getCBCCCM01S01(InVO);

            // 공통코드관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_COMM_CD_KIND", resultListVo.getListCBCCCM01DSCTCOMMCDKINDVO(), model);

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S01  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S01 Exception End #####");
        }

        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명			: 공통코드관리내역 조회 /CBCCCM01S02.do </p>
     * <p>작성일자			: 2023.03.31.
     * <p>작성자(author)	: 70280
     * <p>설명			    : 공통코드관리내역을 조회한다.</p>
     * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCCCM01S02.do")
    public String CBCCCM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S02 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S02 추출 #####");

            LOGGER.info("1");

            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_DESC_SEARCH", request, response, model);

            // 공통코드관리내역 조회 업무 서비스 호출 입력값 대입
            CBCCCM01DSSEARCHVO dsSEARCHVO = new CBCCCM01DSSEARCHVO();
            dsSEARCHVO.setCdKindNo(((String) sourceMap.get("cdKindNo")).trim());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            CBCCCM01InVO InVO = new CBCCCM01InVO();

            // 공통코드관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setCBCCCM01DSSEARCHVO(dsSEARCHVO);

            // 공통코드관리내역 조회 업무 서비스 호출 수행
            CBCCCM01OutVO resultListVo = CBCCCM01.getCBCCCM01S02(InVO);

            // 공통코드관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_COMM_CD_DESC", resultListVo.getListCBCCCM01DSCTCOMMCDDESCVO(), model);

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S02  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S02 Exception End #####");
        }

        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S02 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명          : 공통코드관리내역 조회 /CBCCCM01S02.do </p>
     * <p>작성일자          : 2023.03.31.
     * <p>작성자(author)   : 70280
     * <p>설명                : 공통코드관리내역을 조회한다.</p>
     * <p>예외처리          : Exception</p>
     */
    @RequestMapping("/CBCCCM01S03.do")
    public String CBCCCM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S03 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S03 추출 #####");

            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KIND_SELECT", request, response, model);

            // 공통코드관리내역 조회 업무 서비스 호출 입력값 대입
            CBCCCM01DSSEARCHVO dsSEARCHVO = new CBCCCM01DSSEARCHVO();
            dsSEARCHVO.setCdKindNo(((String) sourceMap.get("cdKindNo")).trim());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            CBCCCM01InVO InVO = new CBCCCM01InVO();

            // 공통코드관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setCBCCCM01DSSEARCHVO(dsSEARCHVO);

            // 공통코드관리내역 조회 업무 서비스 호출 수행
            CBCCCM01OutVO resultListVo = CBCCCM01.getCBCCCM01S03(InVO);

            // 공통코드관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_KIND_SELECT_RESULT", resultListVo.getListCBCCCM01DSCTCOMMCDKINDVO(), model);

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S03  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01S03 Exception End #####");
        }

        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S03 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명			: 공통코드관리내역 등록 /CBCCCM01I01.do </p>
     * <p>작성일자			: 2023.03.31.
     * <p>작성자(author)	: 70280
     * <p>설명			    : 공통코드관리내역을 등록한다.</p>
     * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCCCM01I01.do")
    public String CBCCCM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 Start #####");

        String sOperation = "";

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 추출 #####");

            Map<String, Object> inMap = new HashMap<String, Object>();

            List<Map<String, Object>> sourceMapKind = XFrame5DataSetUtil.getXFrameDataSetList("DS_COMM_CD_KIND", request, response, model);         // CT_COMM_CD_KIND
            List<Map<String, Object>> sourceMapDesc = XFrame5DataSetUtil.getXFrameDataSetList("DS_COMM_CD_DESC", request, response, model);         // CT_COMM_CD_DESC (신규/업데이트용)
            List<Map<String, Object>> sourceMapDescD = XFrame5DataSetUtil.getXFrameDataSetList("DS_COMM_CD_DESC_D", request, response, model);      // CT_COMM_CD_DESC (삭제처리용)

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_KIND - INSERT #####");

            if (sourceMapKind.size() > 0)
            {
                for (int i = 0; i < sourceMapKind.size(); i++)
                {
                    inMap = sourceMapKind.get(i);

                    sOperation = inMap.get("XDATASET_RECORD_TYPE").toString();                                                     // Operation 종류

                    if ("I".equals(sOperation))
                    {
                        LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_KIND - INSERT ##### : " + sOperation);

                        CBCCCM01DSCTCOMMCDKINDVO inVoCtCommCdKind_I = new CBCCCM01DSCTCOMMCDKINDVO();

                        inVoCtCommCdKind_I.setCdKindNo      (inMap.get("cdKindNo").toString().trim()     );
                        inVoCtCommCdKind_I.setCdKindNm      (inMap.get("cdKindNm").toString().trim()     );
                        inVoCtCommCdKind_I.setBsnZoneCd     (inMap.get("bsnZoneCd").toString().trim()    );
                        inVoCtCommCdKind_I.setCdKindShrtNm  (inMap.get("cdKindShrtNm").toString().trim() );
                        inVoCtCommCdKind_I.setFrstRegEmpNo  (inMap.get("frstRegEmpNo").toString().trim() );
                        inVoCtCommCdKind_I.setLastProcEmpNo (inMap.get("lastProcEmpNo").toString().trim());

                        CBCCCM01InVO inVo = new CBCCCM01InVO();
                        inVo.setCBCCCM01DSCTCOMMCDKINDVO(inVoCtCommCdKind_I);

                        CBCCCM01OutVO outVo = CBCCCM01.insertCtCommCdKind(inVo);
                    }
                }
            }

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_DESC - DELETE #####");

            sOperation = "";
            if (sourceMapDescD.size() > 0)
            {
                for (int i = 0; i < sourceMapDescD.size(); i++)
                {
                    inMap = sourceMapDescD.get(i);

                    // Operation 종류
                    sOperation = inMap.get("XDATASET_RECORD_TYPE").toString();

                    if ("D".equals(sOperation))
                    {
                        LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_DESC_D - DELETE ##### : " + sOperation);

                        CBCCCM01DSCTCOMMCDDESCVO inVoCtCommCdDesc_D = new CBCCCM01DSCTCOMMCDDESCVO();
                        inVoCtCommCdDesc_D.setCdKindNo        (inMap.get("cdKindNo").toString().trim()       );
                        inVoCtCommCdDesc_D.setCdDescNo        (inMap.get("cdDescNo").toString().trim()       );
                        inVoCtCommCdDesc_D.setCdDescKorNm     (inMap.get("cdDescKorNm").toString().trim()    );
                        inVoCtCommCdDesc_D.setCdDescEngNm     (inMap.get("cdDescEngNm").toString().trim()    );
                        inVoCtCommCdDesc_D.setCdDescShrtNm    (inMap.get("cdDescShrtNm").toString().trim()   );
                        inVoCtCommCdDesc_D.setCdDescEtcNm     (inMap.get("cdDescEtcNm").toString().trim()    );
                        inVoCtCommCdDesc_D.setClas1           (inMap.get("clas1").toString().trim()          );
                        inVoCtCommCdDesc_D.setClas2           (inMap.get("clas2").toString().trim()          );
                        inVoCtCommCdDesc_D.setMarkOdr         (inMap.get("markOdr").toString().trim()        );
                        inVoCtCommCdDesc_D.setUseYn           (inMap.get("useYn").toString().trim()          );
                        inVoCtCommCdDesc_D.setFrstRegDt       (inMap.get("frstRegDt").toString().trim()      );
                        inVoCtCommCdDesc_D.setFrstRegTm       (inMap.get("frstRegTm").toString().trim()      );
                        inVoCtCommCdDesc_D.setFrstRegEmpNo    (inMap.get("frstRegEmpNo").toString().trim()   );
                        inVoCtCommCdDesc_D.setLastProcDt      (inMap.get("lastProcDt").toString().trim()     );
                        inVoCtCommCdDesc_D.setLastProcTm      (inMap.get("lastProcTm").toString().trim()     );
                        inVoCtCommCdDesc_D.setLastProcEmpNo   (inMap.get("lastProcEmpNo").toString().trim()  );

                        CBCCCM01InVO inVo = new CBCCCM01InVO();
                        inVo.setCBCCCM01DSCTCOMMCDDESCVO(inVoCtCommCdDesc_D);

                        CBCCCM01OutVO outVo = CBCCCM01.deleteCtCommCdDesc(inVo);
                    }
                }
            }

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_DESC - UPDATE #####");

            sOperation = "";
            if (sourceMapDesc.size() > 0)
            {
                for (int i = 0; i < sourceMapDesc.size(); i++)
                {
                    inMap = sourceMapDesc.get(i);

                    // Operation 종류
                    sOperation = inMap.get("XDATASET_RECORD_TYPE").toString();

                    if ("U".equals(sOperation))
                    {
                        LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_DESC - UPDATE ##### : " + sOperation);

                        CBCCCM01DSCTCOMMCDDESCVO inVoCtCommCdDesc_U = new CBCCCM01DSCTCOMMCDDESCVO();
                        inVoCtCommCdDesc_U.setCdKindNo        (inMap.get("cdKindNo").toString().trim()       );
                        inVoCtCommCdDesc_U.setCdDescNo        (inMap.get("cdDescNo").toString().trim()       );
                        inVoCtCommCdDesc_U.setCdDescKorNm     (inMap.get("cdDescKorNm").toString().trim()    );
                        inVoCtCommCdDesc_U.setCdDescEngNm     (inMap.get("cdDescEngNm").toString().trim()    );
                        inVoCtCommCdDesc_U.setCdDescShrtNm    (inMap.get("cdDescShrtNm").toString().trim()   );
                        inVoCtCommCdDesc_U.setCdDescEtcNm     (inMap.get("cdDescEtcNm").toString().trim()    );
                        inVoCtCommCdDesc_U.setClas1           (inMap.get("clas1").toString().trim()          );
                        inVoCtCommCdDesc_U.setClas2           (inMap.get("clas2").toString().trim()          );
                        inVoCtCommCdDesc_U.setMarkOdr         (inMap.get("markOdr").toString().trim()        );
                        inVoCtCommCdDesc_U.setUseYn           (inMap.get("useYn").toString().trim()          );
                        inVoCtCommCdDesc_U.setFrstRegDt       (inMap.get("frstRegDt").toString().trim()      );
                        inVoCtCommCdDesc_U.setFrstRegTm       (inMap.get("frstRegTm").toString().trim()      );
                        inVoCtCommCdDesc_U.setFrstRegEmpNo    (inMap.get("frstRegEmpNo").toString().trim()   );
                        inVoCtCommCdDesc_U.setLastProcDt      (inMap.get("lastProcDt").toString().trim()     );
                        inVoCtCommCdDesc_U.setLastProcTm      (inMap.get("lastProcTm").toString().trim()     );
                        inVoCtCommCdDesc_U.setLastProcEmpNo   (inMap.get("lastProcEmpNo").toString().trim()  );
                        inVoCtCommCdDesc_U.setpKeyCdKindNo    (inMap.get("pKeyCdKindNo").toString().trim()   );
                        inVoCtCommCdDesc_U.setpKeyCdDescNo    (inMap.get("pKeyCdDescNo").toString().trim()   );

                        LOGGER.info("XXX1: " + inVoCtCommCdDesc_U.getFrstRegEmpNo());
                        LOGGER.info("XXX2: " + inVoCtCommCdDesc_U.getLastProcEmpNo());

                        CBCCCM01InVO inVo = new CBCCCM01InVO();
                        inVo.setCBCCCM01DSCTCOMMCDDESCVO(inVoCtCommCdDesc_U);

                        CBCCCM01OutVO outVo = CBCCCM01.updateCtCommCdDesc(inVo);
                    }
                }
            }

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_DESC - INSERT #####");
            sOperation = "";
            if (sourceMapDesc.size() > 0)
            {
                for (int i = 0; i < sourceMapDesc.size(); i++)
                {
                    inMap = sourceMapDesc.get(i);

                    // Operation 종류
                    sOperation = sOperation = inMap.get("XDATASET_RECORD_TYPE").toString();

                    if ("I".equals(sOperation))
                    {
                        LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 CT_COMM_CD_DESC - INSERT ##### : " + sOperation);

                        CBCCCM01DSCTCOMMCDDESCVO inVoCtCommCdDesc_I = new CBCCCM01DSCTCOMMCDDESCVO();
                        inVoCtCommCdDesc_I.setCdKindNo        (inMap.get("cdKindNo").toString().trim()       );
                        inVoCtCommCdDesc_I.setCdDescNo        (inMap.get("cdDescNo").toString().trim()       );
                        inVoCtCommCdDesc_I.setCdDescKorNm     (inMap.get("cdDescKorNm").toString().trim()    );
                        inVoCtCommCdDesc_I.setCdDescEngNm     (inMap.get("cdDescEngNm").toString().trim()    );
                        inVoCtCommCdDesc_I.setCdDescShrtNm    (inMap.get("cdDescShrtNm").toString().trim()   );
                        inVoCtCommCdDesc_I.setCdDescEtcNm     (inMap.get("cdDescEtcNm").toString().trim()    );
                        inVoCtCommCdDesc_I.setClas1           (inMap.get("clas1").toString().trim()          );
                        inVoCtCommCdDesc_I.setClas2           (inMap.get("clas2").toString().trim()          );
                        inVoCtCommCdDesc_I.setMarkOdr         (inMap.get("markOdr").toString().trim()        );
                        inVoCtCommCdDesc_I.setUseYn           (inMap.get("useYn").toString().trim()          );
                        inVoCtCommCdDesc_I.setFrstRegDt       (inMap.get("frstRegDt").toString().trim()      );
                        inVoCtCommCdDesc_I.setFrstRegTm       (inMap.get("frstRegTm").toString().trim()      );
                        inVoCtCommCdDesc_I.setFrstRegEmpNo    (inMap.get("frstRegEmpNo").toString().trim()   );
                        inVoCtCommCdDesc_I.setLastProcDt      (inMap.get("lastProcDt").toString().trim()     );
                        inVoCtCommCdDesc_I.setLastProcTm      (inMap.get("lastProcTm").toString().trim()     );
                        inVoCtCommCdDesc_I.setLastProcEmpNo   (inMap.get("lastProcEmpNo").toString().trim()  );

                        CBCCCM01InVO inVo = new CBCCCM01InVO();
                        inVo.setCBCCCM01DSCTCOMMCDDESCVO(inVoCtCommCdDesc_I);

                        CBCCCM01OutVO outVo = CBCCCM01.insertCtCommCdDesc(inVo);
                    }
                }
            }

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01  Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### CBCCCM01 Controller CBCCCM01I01 Exception End #####");
        }

        LOGGER.info("##### CBCCCM01 Controller CBCCCM01S01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }
}