package hanalife.c.bc.cc.web;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.cc.service.CBCCCM02Service;
import hanalife.c.bc.cc.service.CBCCCP06Service;
import hanalife.c.bc.cc.vo.CBCCCM02DSUSERMNGSDCVO;
import hanalife.c.bc.cc.vo.CBCCCM02DSUSERMNGSDDVO;
import hanalife.c.bc.cc.vo.CBCCCM02DSUSERMNGSMVO;
import hanalife.c.bc.cc.vo.CBCCCM02S01InVO;
import hanalife.c.bc.cc.vo.CBCCCM02S01OutVO;
import hanalife.c.bc.cc.vo.CBCCCM02U01InVO;
import hanalife.c.bc.cc.vo.CBCCCM02U01OutVO;
import hanalife.c.bc.cc.vo.CBCCCP06DSPSWDVO;
import hanalife.c.bc.cc.vo.CBCCCP06U01InVO;
import hanalife.c.bc.cc.vo.CBCCCP06U01OutVO;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.vo.UserSessionVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCM02Controller.java Class
 *
 * 클래스설명   : 사용자관리 (CBCCCM02) Controller
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/bc/cc")
@Controller
public class CBCCCM02Controller {

	@Resource(name = "CBCCCM02Service")
	private CBCCCM02Service CBCCCM02;

	@Resource(name = "CBCCCP06Service")
	private CBCCCP06Service CBCCCP06;

	private Constants consts;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCM02Controller.class);

	/**
	 * <p>메소드명      : 사용자관리 /CBCCCM02S01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323
	 * <p>설명          : 사용자관리 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCM02S01.do")
	public String CBCCCM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCM02Controller CBCCCM02S01 Start #####");

		try {

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_USER_MNG_SM", request, response, model);

			/** 사용자관리내역조회 업무 서비스 호출 입력값 대입 */
			CBCCCM02S01InVO targetVo = new CBCCCM02S01InVO();
			CBCCCM02DSUSERMNGSMVO smVo = new CBCCCM02DSUSERMNGSMVO();

			smVo.setUserNo((String)sourceMap.get("userNo")); 		/** 사용자번호 */
			smVo.setUserDivCd((String)sourceMap.get("userDivCd"));  /** 사용자구분코드 */
			smVo.setUserNm((String)sourceMap.get("userNm")); 		/** 사용자명 */
			smVo.setDeptCd((String)sourceMap.get("deptCd")); 		/** 부서코드 */
			smVo.setDeptNm((String)sourceMap.get("deptNm")); 		/** 부서명 */

			targetVo.setCBCCCM02DSUSERMNGSMVO(smVo);

			/** 사용자관리내역조회 업무 서비스 호출 수행 */
			CBCCCM02S01OutVO resultCBCCCM02S01 = CBCCCM02.getCBCCCM02S01(targetVo);

			XFrame5Util.setOutputData("DS_USER_MNG_SD", resultCBCCCM02S01.getCBCCCM02DSUSERMNGSDVO(), model);	/** 사용자관리목록 */
			XFrame5Util.setOutputData("DS_USER_CNT_SD", resultCBCCCM02S01.getCBCCCM02DSUSERCNTSDVO(), model);	/** 사용자관리건수 */

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCBCCCM02S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCBCCCM02S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### CBCCCM02Controller CBCCCM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCCM02Controller CBCCCM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 사용자관리 입력, 수정, 삭제 /CBCCCM02U01.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323
	 * <p>설명          : 사용자관리 입력, 수정, 삭제 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCM02U01.do")
	public String CBCCCM02U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCM02Controller CBCCCM02U01 Start #####");

		try {
			/** 세션 정보 호출 */
			HttpSession session = request.getSession();
			UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

			/** 데이터셋 로그 출력 */
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			//parameter로 활용할 dataset 정보를 가져온다.
			List<Map<String,Object>> insList = XFrame5Util.getDataMapList(reqMap, "DS_USER_MNG_SD_C");
			List<Map<String,Object>> delList = XFrame5Util.getDataMapList(reqMap, "DS_USER_MNG_SD_D");

			CBCCCM02U01InVO targetVo = new CBCCCM02U01InVO();

			CBCCCM02DSUSERMNGSDCVO sdcVo = new CBCCCM02DSUSERMNGSDCVO();
			CBCCCM02DSUSERMNGSDDVO sddVo = new CBCCCM02DSUSERMNGSDDVO();

			int resultCnt = 0;	/** DB 내 유저 등록 여부 확인용 */

			// 등록, 수정
			if(insList != null) {

				for(int i=0; i < insList.size(); i++) {
					String operation = insList.get(i).get("operation").toString();						/** I:등록, U:수정, D:삭제 */

					sdcVo.setUserNo(insList.get(i).get("userNo").toString());							/** 사용자번호 */
					sdcVo.setUserNm(insList.get(i).get("userNm").toString());							/** 사용자명 */
					sdcVo.setPswd(insList.get(i).get("pswd").toString());								/** 비밀번호 */
					//sdcVo.setEmpNo(insList.get(i).get("empNo").toString());								/** 사원번호 */
					sdcVo.setDeptCd(insList.get(i).get("deptCd").toString());							/** 부서코드 */
					sdcVo.setUseFg(insList.get(i).get("useFg").toString());								/** 사용여부 */
					sdcVo.setUserDivCd(insList.get(i).get("userDivCd").toString());						/** 사용자구분코드 */
					sdcVo.setEmalAddr(insList.get(i).get("emalAddr").toString());						/** 이메일주소 */
					sdcVo.setRcntPswdChngDt(insList.get(i).get("rcntPswdChngDt").toString());			/** 최근비밀번호변경일 */
					sdcVo.setUseEndDt(insList.get(i).get("useEndDt").toString());						/** 사용종료일 */
					sdcVo.setPosiCd(insList.get(i).get("posiCd").toString());							/** 직위코드 */
					//sdcVo.setkSystemId(insList.get(i).get("kSystemId").toString());						/** KSYSTEM아이디 */
					sdcVo.setIpAddr(insList.get(i).get("ipAddr").toString());							/** IP주소 */

					/** 패스워드오류건수 디폴트 0 */
					long pswdErrCnt = 0;
					String strPswdErrCnt = insList.get(i).get("pswdErrCnt").toString();

					if(!"".equals(strPswdErrCnt)) {
						pswdErrCnt = Long.parseLong(strPswdErrCnt);
					}

					sdcVo.setPswdErrCnt(pswdErrCnt);													/** 패스워드오류건수 */
					sdcVo.setBfPswd(insList.get(i).get("bfPswd").toString());							/** 전패스워드 */
					sdcVo.setBf2Pswd(insList.get(i).get("bf2Pswd").toString());							/** 전전패스워드 */
					sdcVo.setRetiCd(insList.get(i).get("retiCd").toString());							/** 퇴직코드 */
					sdcVo.setLogInEmpNo(sessionVO.getUserNo());											/** 로그인사원번호 */

					resultCnt = CBCCCM02.getCBCCCM02S02(sdcVo);

					targetVo.setCBCCCM02DSUSERMNGSDCVO(sdcVo);

					// operation값에 따라 등록, 수정 분기
					if("I".equals(operation)) {
						if(resultCnt > 0) {
							CBCCCM02U01OutVO resultCBCCCM02U01 = CBCCCM02.modifyCBCCCM02U01(targetVo);
							model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCBCCCM02U01.getRsltCd());		/** 결과코드 */
							model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCBCCCM02U01.getRsltCntn());	/** 결과메세지 */

						}else {
							CBCCCM02U01OutVO resultCBCCCM02I01 = CBCCCM02.registerCBCCCM02U01(targetVo);
							model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCBCCCM02I01.getRsltCd());		/** 결과코드 */
							model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCBCCCM02I01.getRsltCntn());	/** 결과메세지 */
						}
					}else {
						CBCCCM02U01OutVO resultCBCCCM02U02 = CBCCCM02.modifyCBCCCM02U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCBCCCM02U02.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCBCCCM02U02.getRsltCntn());	/** 결과메세지 */
					}
				}

			}

			// 삭제
			if(delList != null) {

				for(int i=0; i < delList.size(); i++) {
					String operationD = delList.get(i).get("operation").toString();			/** I:등록, U:수정, D:삭제 */

					sddVo.setUserNo(delList.get(i).get("userNo").toString());	/** 사용자번호 */

					targetVo.setCBCCCM02DSUSERMNGSDDVO(sddVo);

					if("D".equals(operationD)) {
						CBCCCM02U01OutVO resultCBCCCM02D01 = CBCCCM02.deleteCBCCCM02U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCBCCCM02D01.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCBCCCM02D01.getRsltCntn());	/** 결과메세지 */
					}
				}
			}

			LOGGER.info("##### CBCCCM02Controller CBCCCM02U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCCM02Controller CBCCCM02U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 사용자관리 비밀번호 초기화 /CBCCCM02U02.do </p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70323
	 * <p>설명          : 사용자관리 비밀번호 초기화 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCM02U02.do")
	public String CBCCCM02D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCM02Controller CBCCCM02U02 Start #####");

		try {
			/** 세션 정보 호출 */
			HttpSession session = request.getSession();
			UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

			/** 데이터셋 로그 출력 */
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_PSWD", request, response, model);

			/** 사용자관리내역조회 업무 서비스 호출 입력값 대입 */
			CBCCCP06U01InVO targetVo = new CBCCCP06U01InVO();
			CBCCCP06DSPSWDVO smVo = new CBCCCP06DSPSWDVO();

			//BeanUtil.mapToBean(sourceMap, smVo);

			smVo.setUserNo((String)sourceMap.get("userNo"));  	/** 사용자번호 */
			smVo.setPswd((String)sourceMap.get("pswd"));  		/** 기존비밀번호 */
			smVo.setNewPswd(consts.PSWD);  						/** 신규비밀번호 */
			smVo.setkSysId((String)sourceMap.get("kSysId"));  	/** KSYS아이디 */
			smVo.setLogInEmpNo(sessionVO.getUserNo());  		/** 로그인사원번호 */

			targetVo.setCBCCCP06DSPSWDVO(smVo);

			/** 사용자관리내역조회 업무 서비스 호출 수행 */
			CBCCCP06U01OutVO resultCBCCCM02U02 = CBCCCP06.updateInitPswd(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCBCCCM02U02.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCBCCCM02U02.getRsltCntn());

			LOGGER.info("##### CBCCCM02Controller CBCCCM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCCM02Controller CBCCCM02U02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
