package hanalife.c.bc.cc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.cc.service.CBCCCP01Service;
import hanalife.c.bc.cc.vo.CBCCCP01DSSRCHSMVO;
import hanalife.c.bc.cc.vo.CBCCCP01S01InVO;
import hanalife.c.bc.cc.vo.CBCCCP01S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP01Controller.java Class
 *
 * 클래스설명   : 대출통합검색 (CBCCCP01) Controller
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/bc/cc")
@Controller
public class CBCCCP01Controller {

	@Resource(name = "CBCCCP01Service")
	private CBCCCP01Service CBCCCP01;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP01Controller.class);

	/**
	 * <p>메소드명      : 대출통합검색 /CBCCCP01S01.do </p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70323
	 * <p>설명          : 대출통합검색 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCP01S01.do")
	public String CBCCCP01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCP01Controller CBCCCP01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_LOAN_INTG_SRCH_SM", request, response, model);

			/** 대출통합검색내역조회 업무 서비스 호출 입력값 대입 */
			CBCCCP01S01InVO targetVo = new CBCCCP01S01InVO();
			CBCCCP01DSSRCHSMVO smVo = new CBCCCP01DSSRCHSMVO();

			smVo.setCustNo((String)sourceMap.get("custNo")); /** 고객번호 */
			smVo.setCustNm((String)sourceMap.get("custNm")); /** 고객번호 */
			smVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
			smVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */
			smVo.setMngNo((String)sourceMap.get("mngNo")); /** 관리번호 */
			smVo.setCprtComNo((String)sourceMap.get("cprtComNo")); /** 제휴사번호 */
			smVo.setCprtComNm((String)sourceMap.get("cprtComNm")); /** 제휴사명 */
			smVo.setCprtBranCd((String)sourceMap.get("cprtBranCd")); /** 제휴부서코드 */
			smVo.setCprtBranNm((String)sourceMap.get("cprtComNm")); /** 제휴부서명 */
			smVo.setMngDeptCd((String)sourceMap.get("mngDeptCd")); /** 관리부서코드 */
			smVo.setLoanNormIzeFg((String)sourceMap.get("loanNormIzeFg")); /** 대출최종여부 */
			smVo.setLoanStatCd((String)sourceMap.get("loanStatCd")); /** 대출상태코드 */
			smVo.setFromLoanDt((String)sourceMap.get("fromLoanDt")); /** 대출일자시작 */
			smVo.setToLoanDt((String)sourceMap.get("toLoanDt")); /** 대출일자종료 */
			smVo.setCprtOrgDeptCd((String)sourceMap.get("cprtOrgDeptCd")); /** 제휴부서코드 */
			smVo.setHpNo((String)sourceMap.get("hpNo")); /** 핸드폰번호 */
			smVo.setCarsNo((String)sourceMap.get("carsNo")); /** 차량번호 */
			smVo.setCaseNo((String)sourceMap.get("caseNo")); /** 사건번호 */
			smVo.setRlDueCustNo((String)sourceMap.get("rlDueCustNo")); /** 실납입자고객번호 */
			smVo.setRlDueCustNm((String)sourceMap.get("rlDueCustNm")); /** 실납입자고객명 */
			smVo.setCnslNo((String)sourceMap.get("cnslNo")); /** 상담번호 */

			targetVo.setCBCCCP01DSSRCHSMVO(smVo);

			/** 대출통합검색내역조회 업무 서비스 호출 수행 */
			CBCCCP01S01OutVO resultCBCCCP01S01 = CBCCCP01.getCBCCCP01S01(targetVo);

			XFrame5Util.setOutputData("DS_LOAN_INTG_SRCH_SD", resultCBCCCP01S01.getCBCCCP01DSSRCHSDVO(), model);

			LOGGER.info("##### CBCCCP01Controller CBCCCP01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCCP01Controller CBCCCP01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
