package hanalife.c.bc.cc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.cc.service.CBCCCP02Service;
import hanalife.c.bc.cc.vo.CBCCCP02S01DSCUSTINFOSRCHSMVO;
import hanalife.c.bc.cc.vo.CBCCCP02S01InVO;
import hanalife.c.bc.cc.vo.CBCCCP02S01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP02Controller.java Class
 * 클래스설명   : 고객검색 (CBCCCP02) Controller
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/bc/cc")
@Controller
public class CBCCCP02Controller {

	@Resource(name = "CBCCCP02Service")
	private CBCCCP02Service CBCCCP02;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP02Controller.class);

	/**
	 * <p>메소드명      : 고객검색조회 /CBCCCP02S01.do </p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70321
	 * <p>설명          : 고객정보를 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCP02S01.do")
	public String CBCCCP02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCP02Controller CBCCCP02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CUST_INFO_SRCH_SM", request, response, model);

			/** 고객정보조회 업무 서비스 호출 입력값 대입 */
			CBCCCP02S01DSCUSTINFOSRCHSMVO targetVo = new CBCCCP02S01DSCUSTINFOSRCHSMVO();

			targetVo.setCustNo((String)sourceMap.get("custNo")); /** 고객번호 */
			targetVo.setCustNm((String)sourceMap.get("custNm")); /** 고객명 */
			targetVo.setCorpRegNo((String)sourceMap.get("corpRegNo")); /** 법인번호 */
			targetVo.setBizManNo((String)sourceMap.get("bizManNo")); /** 사업자번호 */
			targetVo.setSearchCnt((String)sourceMap.get("searchCnt")); /** 조회건수 */
			targetVo.setOprYn((String)sourceMap.get("oprYn")); /** 개인조회여부 */
			targetVo.setCellHpNo((String)sourceMap.get("cellHpNo")); /** 핸드폰번호 */
			targetVo.setBirthDt((String)sourceMap.get("birthDt")); /** 고객생년월일 */
			targetVo.setCustResiNo((String)sourceMap.get("custResiNo")); /** 고객인식번호 */
			targetVo.setTempCustFg((String)sourceMap.get("tempCustFg")); /** 임시고객여부 */
			targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
			targetVo.setCnslNo((String)sourceMap.get("cnslNo")); /** 상담번호 */
			targetVo.setCarsNo((String)sourceMap.get("carsNo")); /** 차량번호 */
			targetVo.setDstrYn((String)sourceMap.get("dstrYn")); /** 파기여부 */
			targetVo.setFrstDstrDt((String)sourceMap.get("frstDstrDt")); /** 1차파기일자 */
			targetVo.setFrstDstrTm((String)sourceMap.get("frstDstrTm")); /** 1차파기시각 */
			targetVo.setScndDstrDt((String)sourceMap.get("scndDstrDt")); /** 2차파기일자 */
			targetVo.setScndDstrTm((String)sourceMap.get("scndDstrTm")); /** 2차파기시각 */
			targetVo.setGubun((String)sourceMap.get("gubun")); /** 구분코드 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			CBCCCP02S01InVO InVO = new CBCCCP02S01InVO();
            InVO.setCBCCCP02S01DSCUSTINFOSRCHSMVO(targetVo); /** 고객정보 DS_SMDO 입력값 VO 객체 대입 */

			/** 고객검색내역조회 업무 서비스 호출 수행 */
			CBCCCP02S01OutVO resultCBCCCP02S01 = CBCCCP02.getCBCCCP02S01(InVO);

			XFrame5Util.setOutputData("DS_CUST_INFO_SRCH_SD", resultCBCCCP02S01.getListCBCCCP02S01DSCUSTINFOSRCHSDVO(), model); /** 고객정보조회 */

			LOGGER.info("##### CBCCCP02Controller CBCCCP02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCCCP02Controller CBCCCP02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
