package hanalife.c.bc.cc.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.cc.service.CBCCCP06Service;
import hanalife.c.bc.cc.vo.CBCCCP06DSPSWDVO;
import hanalife.c.bc.cc.vo.CBCCCP06U01InVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CBCCCP06Controller.java Class
 * 클래스설명   : 비밀번호 변경 팝업 (CBCCCP06) Controller
 * 작성일자     : 2023. 3. 27.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/bc/cc")
@Controller
public class CBCCCP06Controller {

	@Resource(name = "CBCCCP06Service")
	private CBCCCP06Service CBCCCP06;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCCCP06Controller.class);

	/**
	 * <p>메소드명      : 비밀번호 변경 /CBCCCP06U01.do </p>
	 * <p>작성일자      : 2023. 3. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : 비밀번호를 변경한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CBCCCP06U01.do")
	public String CBCCCP06U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CBCCCP06Controller CBCCCP06U01 Start #####");

		try {

			/*************************************************
			 * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			 *************************************************/
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_PSWD", request, response, model);
			XFrame5DataSetUtil.printDataSetfromMap(XFrame5Util.xFrame5Map(request, response, model));

			/*************************************************
			 * ■ 비밀번호 변경 DataSet 항목값 VO객체 입력값 대입
			 *************************************************/
			CBCCCP06DSPSWDVO targetVo = new CBCCCP06DSPSWDVO();

			targetVo.setUserNo((String)sourceMap.get("userNo"));                   // 사용자번호
			targetVo.setPswd((String)sourceMap.get("pswd"));                       // 비밀번호
			targetVo.setNewPswd((String)sourceMap.get("newPswd"));                 // 변경비밀번호

			/*************************************************
			 * ■ VO객체에 DataSetVO 입력값 대입
			 *************************************************/
			CBCCCP06U01InVO InVO = new CBCCCP06U01InVO();
            InVO.setCBCCCP06DSPSWDVO(targetVo);

            /*************************************************
			 * ■ 비밀번호 변경 서비스 호출
			 *************************************************/
			CBCCCP06.updatePswd(InVO);

			/*************************************************
			 * ■ 비밀번호 변경 DataSet 결과값 설정
			 *************************************************/
//			XFrame5Util.setOutputData("DS_ZIP_CD_SD", resultCBCCCP06U01.getListCBCCCP06DSZIPCDSDVO(), model);
			LOGGER.info("##### CBCCCP06Controller CBCCCP06U01 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			String loginErrorCode = "{\"loginErrorCode\":\"-2000\"}";
			model.addAttribute(XFrame5View.XFRAME5_USER_HEADER, loginErrorCode);
			
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
			LOGGER.info("##### CBCCCP06Controller CBCCCP06U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;

	}

}
