package hanalife.c.bc.kb.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.bc.kb.service.CBCKBM01Service;
import hanalife.c.bc.kb.vo.CBCKBM01DSSRCHSMVO;
import hanalife.c.bc.kb.vo.CBCKBM01InVO;
import hanalife.c.bc.kb.vo.CBCKBM01OutVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CBCKBM01Controller.java Class
 * 클래스설명	: KB아파트시세등록 (CBCKBM01) Controller
 * 작성일자	: 2023.03.21.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.03.21.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	KB법정동_시도명 조회		: /CBCKBM01S01.do
 * 			KB법정동_시군구명 조회	: /CBCKBM01S02.do
 * 			KB법정동_읍면동명 조회	: /CBCKBM01S03.do
 * 			KB아파트정보 조회		: /CBCKBM01S04.do
 * 			KB평형정보 조회			: /CBCKBM01S05.do
 * 			KB시세 조회			: /CBCKBM01S06.do
 * </pre>
 */

@RequestMapping("/c/bc/kb")
@Controller
public class CBCKBM01Controller {

	@Resource(name = "CBCKBM01Service")
	private CBCKBM01Service CBCKBM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(CBCKBM01Controller.class);

	/**
	 * <p>메소드명			: KB법정동_시도명 조회 /CBCKBM01S01.do </p>
	 * <p>작성일자			: 2023.04.03.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB법정동_시도명 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
	@RequestMapping("/CBCKBM01S01.do")
	public String CBCKBM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### CBCBM01 Controller CBCKBM01S01 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S01 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_INFO_READ_SM", request, response, model);

			// 법정동_시도 조회 업무 서비스 호출 입력값 대입
			CBCKBM01DSSRCHSMVO dsSEARCHVO = new CBCKBM01DSSRCHSMVO();

            // 법정동_시도 조회 업무 서비스 호출 입력값 대입
			// 입력값 없음

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CBCKBM01InVO InVO = new CBCKBM01InVO();

			// 법정동_시도 내역조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCBCKBM01DSSRCHSMVO(dsSEARCHVO);

			// 법정동_시도 조회 업무 서비스 호출 수행
			CBCKBM01OutVO resultListVo = CBCKBM01.getCBCKBM01S01(InVO);

			// 법정동_시도 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD01", resultListVo.getListCBCKBM01DSKBLDONGCDSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S01 Exception End #####");

		}
		LOGGER.info("##### CBCKBM01 Controller CBCKBM01S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명			: KB법정동_시군구명 조회 /CBCKBM01S02.do </p>
	 * <p>작성일자			: 2023.04.04.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB법정동_시군구명 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCKBM01S02.do")
	public String CBCKBM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### CBCBM01 Controller CBCKBM01S02 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S02 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_INFO_READ_SM", request, response, model);

			// 법정동_시군구 조회 업무 서비스 호출 입력값 대입
			CBCKBM01DSSRCHSMVO dsSEARCHVO = new CBCKBM01DSSRCHSMVO();

			dsSEARCHVO.setProvNm((String)sourceMap.get("provNm"));	/** 시도_명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CBCKBM01InVO InVO = new CBCKBM01InVO();

			// 법정동_시군구 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCBCKBM01DSSRCHSMVO(dsSEARCHVO);

			// 법정동_시군구 조회 업무 서비스 호출 수행
			CBCKBM01OutVO resultListVo = CBCKBM01.getCBCKBM01S02(InVO);

			// 법정동_시군구 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD02", resultListVo.getListCBCKBM01DSKBLDONGCDSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S02 Exception End #####");

		}
		LOGGER.info("##### CBCKBM01 Controller CBCKBM01S02 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명			: KB법정동_읍면동명 조회 /CBCKBM01S03.do </p>
	 * <p>작성일자			: 2023.04.05.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB법정동_읍면동명 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCKBM01S03.do")
	public String CBCKBM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### CBCBM01 Controller CBCKBM01S03 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S03 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_INFO_READ_SM", request, response, model);

			// 법정동_읍면동 조회 업무 서비스 호출 입력값 대입
			CBCKBM01DSSRCHSMVO dsSEARCHVO = new CBCKBM01DSSRCHSMVO();

			dsSEARCHVO.setProvNm((String)    sourceMap.get("provNm")); 		/** 시도명 */
			dsSEARCHVO.setCigunguNm((String) sourceMap.get("cigunguNm"));	/** 시군구명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     : " + dsSEARCHVO.getProvNm());
			LOGGER.info("" + "dsSEARCHVO.getCigunguNm    : " + dsSEARCHVO.getCigunguNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CBCKBM01InVO InVO = new CBCKBM01InVO();

			// 법정동_읍면동 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCBCKBM01DSSRCHSMVO(dsSEARCHVO);

			// 법정동_읍면동 조회 업무 서비스 호출 수행
			CBCKBM01OutVO resultListVo = CBCKBM01.getCBCKBM01S03(InVO);

			// 법정동_읍면동 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_LDONG_CD_SD03", resultListVo.getListCBCKBM01DSKBLDONGCDSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S03 Exception End #####");

		}
		LOGGER.info("##### CBCKBM01 Controller CBCKBM01S03 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명			: KB아파트정보 조회 /CBCKBM01S04.do </p>
	 * <p>작성일자			: 2023.04.05.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트정보 조회 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCKBM01S04.do")
	public String CBCKBM01S04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### CBCBM01 Controller CBCKBM01S04 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S04 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_INFO_READ_SM", request, response, model);

			// 아파트정보 조회 업무 서비스 호출 입력값 대입
			CBCKBM01DSSRCHSMVO dsSEARCHVO = new CBCKBM01DSSRCHSMVO();

			dsSEARCHVO.setProvNm((String)		 sourceMap.get("provNm"));			/** 시도명 */
			dsSEARCHVO.setCigunguNm((String)	 sourceMap.get("cigunguNm"));		/** 시군구명 */
			dsSEARCHVO.setEubmyundongNm((String) sourceMap.get("eubmyundongNm"));	/** 읍면동명 */

			LOGGER.info("" + "dsSEARCHVO.getProvNm()     	 : " + dsSEARCHVO.getProvNm());
			LOGGER.info("" + "dsSEARCHVO.getCigunguNm    	 : " + dsSEARCHVO.getCigunguNm());
			LOGGER.info("" + "dsSEARCHVO.getEubmyundongNm    : " + dsSEARCHVO.getEubmyundongNm());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CBCKBM01InVO InVO = new CBCKBM01InVO();

			// 아파트정보 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCBCKBM01DSSRCHSMVO(dsSEARCHVO);

			// 아파트정보 조회 업무 서비스 호출 수행
			CBCKBM01OutVO resultListVo = CBCKBM01.getCBCKBM01S04(InVO);

			// 아파트정보 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_APT_INFO_SD", resultListVo.getListCBCKBM01DSKBAPTINFOSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S04 Exception End #####");

		}
		LOGGER.info("##### CBCKBM01 Controller CBCKBM01S04 End #####");

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명			: KB평형정보 조회 /CBCKBM01S05.do </p>
	 * <p>작성일자			: 2023.04.06.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB평형정보 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCKBM01S05.do")
	public String CBCKBM01S05(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
    	LOGGER.info("##### CBCKBM01 Controller CBCKBM01S05 Start #####");

    	try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S05 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_INFO_READ_SM", request, response, model);

			// 평정정보 조회 업무 서비스 호출 입력값 대입
			CBCKBM01DSSRCHSMVO dsSEARCHVO = new CBCKBM01DSSRCHSMVO();

			dsSEARCHVO.setEsttGodsCd((String) sourceMap.get("esttGodsCd"));	/** 부동산물건코드 */

			LOGGER.info("" + "dsSEARCHVO.getEsttGodsCd() : " + dsSEARCHVO.getEsttGodsCd());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CBCKBM01InVO InVO = new CBCKBM01InVO();

			// 평형정보 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCBCKBM01DSSRCHSMVO(dsSEARCHVO);

			// 평형정보 조회 업무 서비스 호출 수행
			CBCKBM01OutVO resultListVo = CBCKBM01.getCBCKBM01S05(InVO);

			// 평형정보 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_PNTP_INFO_SD", resultListVo.getListCBCKBM01DSKBPNTPINFOSDVO(), model);

    	}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S05 Exception End #####");

    	}
		LOGGER.info("##### CBCKBM01 Controller CBCKBM01S05 End #####");

		return XFrame5View.XFRAME5_VIEW;

    }

	/**
	 * <p>메소드명			: KB시세정보 조회 /CBCKBM01S06.do </p>
	 * <p>작성일자			: 2023.04.06.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB시세정보 내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/CBCKBM01S06.do")
	public String CBCKBM01S06(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
    	LOGGER.info("##### CBCKBM01 Controller CBCKBM01S06 Start #####");

    	try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S06 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_KB_APT_MKPR_INFO_READ_SM", request, response, model);

			// 평정정보 조회 업무 서비스 호출 입력값 대입
			CBCKBM01DSSRCHSMVO dsSEARCHVO = new CBCKBM01DSSRCHSMVO();

			dsSEARCHVO.setEsttGodsCd((String) sourceMap.get("esttGodsCd"));				/** 부동산물건코드 */
			dsSEARCHVO.setPntpSeq(Long.parseLong((String) sourceMap.get("pntpSeq")));	/** 평형seq */

			LOGGER.info("" + "dsSEARCHVO.getEsttGodsCd() : " + dsSEARCHVO.getEsttGodsCd());
			LOGGER.info("" + "dsSEARCHVO.getPntpSeq() 	 : " + dsSEARCHVO.getPntpSeq());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CBCKBM01InVO InVO = new CBCKBM01InVO();

			// 평형정보 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCBCKBM01DSSRCHSMVO(dsSEARCHVO);

			// 평형정보 조회 업무 서비스 호출 수행
			CBCKBM01OutVO resultListVo = CBCKBM01.getCBCKBM01S06(InVO);

			// 평형정보 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_KB_MKPR_INFO_SD", resultListVo.getListCBCKBM01DSKBMKPRINFOSDVO(), model);

    	}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CBCKBM01 Controller CBCKBM01S06 Exception End #####");

    	}
		LOGGER.info("##### CBCKBM01 Controller CBCKBM01S06 End #####");

		return XFrame5View.XFRAME5_VIEW;

    }

}
