package hanalife.c.co.iEnum;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : MsgEnum.java Class
 * 클래스설명   : 메시지코드 및 내용를(을) 위한 ENum;
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public enum MsgEnum implements IEnum{

    SUCCESS("0000", "성공", "정상 처리 되었습니다."),
    NOT_FOUND("0002", "데이터 없슴", "정보가 존재하지 않습니다."),
    ERR_SYSTEM("8888", "시스템 오류", "시스템 오류가 발생하였습니다. 관리자에게 문의하세요."),
    ISNULL_LOAN_NO("9000", "대출번호 미입력", "대출번호 입력 값이 존재하지 않습니다."),
    ISNULL_LOAN_SEQ("9001", "대출순번 미입력", "대출순번 입력 값이 존재하지 않습니다."),
    IS_EMPTY("9002", "항목 미입력", "입력 항목에 값이 존재하지 않습니다."),

    /** 가상계좌 */
    IMGACNT_LOAN_STAT("0003", "대출상태", "정상 진행중인 대출상태만 처리 가능합니다." ),
    IMGACNT_DESC_ZERO("0004", "가상계좌내역 대상이 없습니다.", "가상계좌내역 대상이 없습니다." ),
    IMGACNT_HIST_ZERO("0005", "가상계좌이력 대상이 없습니다.", "가상계좌이력 대상이 없습니다." ),
    IMGACNT_LOAN_BASE_ZERO("0006", "대출기본 건수가 없습니다.", "대출기본 건수가 없습니다." ),
    IMGACNT_BANK_ACNT_ZERO("0007", "해당은행의 가상계좌번호가 없습니다.", "해당은행의 가상계좌번호가 없습니다." ),
    IMGACNT_UNUSE_CD("0011", "미사용 계좌입니다.", "미사용 계좌입니다." ),
    IMGACNT_DISU_CD("0012", "폐기된 계좌입니다.", "폐기된 계좌입니다." ),

    /** 대출번호조회 및 체크 Util : SearchLoanSeqUtil */
    NOT_FOUND_LOAN("ESS9999", "데이터 없슴", "존재하지 않는 대출번호/순번입니다."),

    /** 면제품의 수납 조회 Util : readExmpConsCost */
    DATA_ZERO_READ_EXMP("E01", "요청 데이터 없슴", "면제품의내역 조회 요청 객체가 NULL입니다!"),
    ERR_SYSTEM_READ_EXMP("E02", "시스템 오류", "면제품의내역 조회 중 에러가 발생했습니다!"),
    SUCCESS_READ_EXMP("N01", "정상 조회", "면제품의내역 조회를 정상적으로 수행했습니다!"),
    NOT_FOUND_READ_EXMP("N02", "데이터 없슴", "수납 반영할 면제정보가 존재하지 않습니다."),
    TOO_MANY_READ_EXMP("N03", "데이터 다건 조회됨", "수납 반영할 면제정보가 1건 이상입니다."),

    /** 면제품의내역 수납 반영 Util : calcExmpConsCost */
    DATA_ZERO_CALC_EXMP("E01", "요청 데이터 없슴", "면제품의내역수납 반영 요청 객체가 NULL입니다!"),
    ERR_SYSTEM_CALC_EXMP("E02", "시스템 오류", "면제품의내역수납 반영 처리 중 에러가 발생했습니다!"),
    SUCCESS_CALC_EXMP("N01", "정상 조회", "법적조치비용정산 처리를 정상적으로 수행했습니다!"),
    NOT_FOUND_CALC_EXMP("N02", "데이터 없슴", "수납 반영할 면제정보가 존재하지 않습니다."),

    /** 제휴약정 한도잔액 수정 Util : cprtContMngMdul */
    CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다"),
    CPRT_CONT_ERR_SYSTEM("E002", "시스템 오류", "제휴약정 한도잔액 수정 처리 중 에러가 발생했습니다"),
    CPRT_CONT_ERR_SYSTEM_SEARCH_CPRT_LIM("E003", "시스템 오류", "제휴약정 한도잔액 조회 처리 중 에러가 발생했습니다"),
    CPRT_CONT_ERR_CHK_PRDT_CD_FAIL("E005", "시스템 오류", "대출상품 코드 조회 처리 실패하였습니다"),
    CPRT_CONT_ERR_SYSTEM_CHK_PRDT_CD("E004", "시스템 오류", "대출상품 코드 조회 중 에러가 발생했습니다"),
    CPRT_CONT_ERR_SYSTEM_UPDATE_CPRT_LIM("E005", "시스템 오류", "제휴약정 한도잔액 수정 처리 중 에러가 발생했습니다!"),

    CPRT_CONT_ERR_LIM_CHNG_FAIL("E011", "시스템 오류", "한도증감이력 등록 처리 실패하였습니다."),
    CPRT_CONT_ERR_UPDATE_FAIL("E021", "시스템 오류", "제휴약정 한도잔액 수정 처리 실패하였습니다."),
    CPRT_CONT_ERR_LOAN_APRV_DT_FAIL("E031", "시스템 오류", "대출 승인일 조회 처리 실패하였습니다."),
    CPRT_CONT_ERR_REG_LDGR_FAIL("E041", "시스템 오류", "대출 제휴점 조회 처리 실패하였습니다."),

    CPRT_CONT_ERR_CHECK_BIZ_DIV_CD("E051", "시스템 오류", "업무구분을 찾을 수 없습니다."),
    CPRT_CONT_ERR_CHECK_LOAN_NO("E052", "시스템 오류", "대출번호를 찾을 수 없습니다."),
    CPRT_CONT_ERR_CHECK_LOAN_SEQ("E053", "시스템 오류", "대출순번을 찾을 수 없습니다."),
    CPRT_CONT_ERR_CHECK_CPRT_COM_NO("E054", "시스템 오류", "제휴사번호를 찾을 수 없습니다."),
    CPRT_CONT_ERR_CHECK_CPRT_BRAN_CD("E055", "시스템 오류", "제휴점코드를 찾을 수 없습니다."),
    CPRT_CONT_ERR_CHECK_PRDT_CD("E056", "시스템 오류", "상품코드를 찾을 수 없습니다."),
    CPRT_CONT_ERR_CHECK_LOAN_PAMT("E057", "시스템 오류", "대출금액을 찾을 수 없습니다."),

    CPRT_CONT_ERR_MAX_SNUM_FAIL("E061", "시스템 오류", "한도증감이력 최대 한도 조회 처리 실패하였습니다."),

    /** 연체정보 생성 MSG*/
    DLY_CREATE_ERROR("D01", "입력정보 오류.", "실시간연체정보 생성중 오류 발생했습니다.입력값을 확인해주세요." ),
    DLY_CALC_ERROR("D02", "청구수납미수이자 계산 오류", "실시간연체정보 생성_청구수납미수이자 계산시 에러가 발생했습니다." ),

    /** 결제일변경 */
    DATE_CHECK_ERROR("C001", "입력정보 오류.", "날짜(시작일자,종료일자) 입력값을 확인 해 주세요."),
    SETL_DD_CHNG_CNCL_CHK_POSS_FG("C002", "취소가능여부체크", "취소 가능 한 내역이 없습니다."),
    SETL_DD_CHNG_CNCL_CHK_RCPT_SRCH("C003", "수납내역체크", "변경회차 이후에 수납내역이 존재합니다. 수납취소후 처리하시기 바랍니다.")

    /** 권리보험 전문 송수신 */
    , HI_CNCL_RE_SEND_ERROR ("H001", "재의뢰 전 취소 체크 오류"	, "재의뢰가 불가능 한 상태[의뢰취소] 입니다. 신규의뢰만 가능합니다.")
    , HI_BFASK_RE_SEND_ERROR("H002", "재의뢰 전 의뢰 체크 오류"	, "재의뢰가 불가능 한 상태[의뢰전] 입니다. 신규의뢰만 가능합니다.")
    , HI_ASK_SEND_SEND_ERROR("H003", "의뢰 전 의뢰 체크 오류"		, "신규의뢰가 불가능 한 상태[등기의뢰] 입니다. 재의뢰만 가능합니다.")
    , HI_ASK_SEND_CNCL_ERROR("H004", "의뢰 전 취소 체크 오류" 	, "이미 의뢰완료가 되었습니다. 의뢰취소 후 신규의뢰가 가능합니다.")
    , HI_CNCL_SEND_CHK_ERROR("H005", "의뢰취소 체크 오류" 		, "의뢰취소가 불가능 한 상태[의뢰전] 입니다.\n신규의뢰 후 의뢰취소가 가능합니다.")
    , HI_EXEC_ASK           ("H006", "실행재통보 오류"			, "실행재통보가 이미 완료 되었습니다.")
    , HI_RMBR_ASK           ("H007", "완제재통보 오류"			, "완제재통보가 이미 완료 되었습니다.")

    /** 전자등기 전문 송수신 */
    , FT_CNCL_RE_SEND_ERROR ("F001", "재의뢰 전 취소 체크 오류"	, "재의뢰가 불가능 한 상태[등기취소] 입니다. 신규의뢰만 가능합니다.")
    , FT_BFASK_RE_SEND_ERROR("F002", "재의뢰 전 의뢰 체크 오류"	, "재의뢰가 불가능 한 상태[의뢰전] 입니다. 신규의뢰만 가능합니다.")
    , FT_ASK_SEND_SEND_ERROR("F003", "의뢰 전 의뢰 체크 오류"		, "등기 신규의뢰가 불가능 한 상태[등기의뢰] 입니다. 재의뢰만 가능합니다.")
    , FT_ASK_SEND_CNCL_ERROR("F004", "의뢰 전 취소 체크 오류" 	, "이미 등기의뢰완료가 되었습니다. 등기취소 후 등기의뢰가 가능합니다.")
    , FT_ASK_SEND_CHK_ERROR ("F005", "의뢰 가능여부 체크 오류"	, "의뢰 가능한 상태가 아닙니다. \n피노텍에 확인 하시기 바랍니다.[등기부등본 수신여부확인]")
    , FT_RE_SEND_CHK_ERROR  ("F006", "재의뢰 가능여부 체크 오류"	, "재의뢰 가능한 상태가 아닙니다. \n피노텍에 확인 하시기 바랍니다.")

    /** 사용자 체크 */
    , NOT_FOUND_USER("ERR9999", "데이터 없음", "존재하지 않는 사용자입니다.")

    /** 전략수행 오류 */
    , CSS_SUCCESS("0", "전략 수행 성공", "전략이 정상 수행되었습니다.")
    , CSS_ERROR("9", "전략 수행 오류", "전략 수행중 오류가 발생했습니다.")

    /** 채널 응답 코드 */
    , CHANNEL_SUCCESS("000", "성공", "정상 처리되었습니다.")
    , CHANNEL_ERROR("999", "오류", "오류가 발생했습니다.")

    /** HOMS회신결과 등록 오류 */
    , HOMS_ERROR("HOMSERR01", "기등록 데이터", "이미 등록된 결과입니다.")

    /** 대출실행 시 등록 오류 */
    , INS_EXEC_ERROR     ("EXE001", "등록 오류"        	, "실행 시 등록 된 데이터가 없습니다.")
    , INS_EXEC_CHNL_ERROR("EXE002", "채널진행상태 수정 오류"	, "대출상담번호가 없습니다.")
    ;

    private final String errorCd;
    private final String errorCn;
    private final String description;


    /**
     * Constructor
     * @param pstrErrorCode
     * @param pstrErrorCn
     * @param pstrDescription
     */
    MsgEnum(String pstrErrorCode, String pstrErrorCn, String pstrDescription) {
        this.errorCd        = pstrErrorCode;
        this.errorCn        = pstrErrorCn;
        this.description    = pstrDescription;
    }

    /** 입력된 오류코드에 다른 오류메시지내용 및 Description 조회 */
    public static MsgEnum getEnum(String pstrErrorCode) {
        for ( MsgEnum item : MsgEnum.values() ) {
            if ( pstrErrorCode.equals(item.errorCd) ) {
                return item;
            }
        }
        return null;
    }

    @Override
    public String getErrorCd() {
        return errorCd;
    }

    @Override
    public String getErrorCn() {
        return errorCn;
    }

    @Override
    public String getDescription() {
        return description;
    }

}
