package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StExecCostDTO;
import hanalife.c.co.vo.CommCostVO;

/**
 * <pre>
 * 프로젝트명 	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명  	: CommBizMapper.java Class
 * 클래스설명	: 업무별 공통 유틸리티 Interface Mapper
 * 작성일자  	: 2023. 6. 13.
 * 작성자명  	: 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 6. 13.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>CommBizMapper
 */
@Mapper("CommCostMapper")
public interface CommCostMapper {

    /**
     * <pre>
     * 메소드명      	: selectCostInfo
     * 작성일자      	: 2023. 6. 13.
     * 작성자(author)	: 70319 / 가계대출 시스템 구축
     * 설명          	: 비용 등록여부 및 금액 조회
     * 메소드인수1   	: {StExecCostDTO} inDto(loanApplNo)
     * 메소드리턴값  	: {StExecCostDTO}
     * 예외처리      	: Exception
     * </pre>
     */
    public List<CommCostVO> selectCostInfo(CommCostVO inVO) throws Exception;

    /**
     * <pre>
     * 메소드명      	: selectCostInfoList
     * 작성일자      	: 2023. 6. 13.
     * 작성자(author)	: 70319 / 가계대출 시스템 구축
     * 설명          	: 비용 금액 조회
     * 메소드인수1   	: {StExecCostDTO} inDto(loanApplNo)
     * 메소드리턴값  	: {StExecCostDTO}
     * 예외처리      	: Exception
     * </pre>
     */
    public List<CommCostVO> selectCostInfoList(CommCostVO inVO) throws Exception;

    /**
     * <pre>
     * 메소드명      	: insertCostInfo
     * 작성일자      	: 2023. 6. 13.
     * 작성자(author)	: 70319 / 가계대출 시스템 구축
     * 설명          	: 비용 등록 처리
     * 메소드인수1   	: {CommCostVO} inDto(pstrLoanApplNo, pstrCostDiv, pstrProcDiv)
     * 메소드리턴값  	: void
     * 예외처리      	: Exception
     * </pre>
     */
    public int insertCostInfoList(CommCostVO insVo) throws Exception;

    /**
     * <pre>
     * 메소드명      	: updateCostInfo
     * 작성일자      	: 2023. 6. 13.
     * 작성자(author)	: 70319 / 가계대출 시스템 구축
     * 설명          	: 비용 등록 처리
     * 메소드인수1   	: {StExecCostDTO} inDto(loanApplNo)
     * 메소드리턴값  	: void
     * 예외처리      	: Exception
     * </pre>
     */
    public int updateCostInfo(StExecCostDTO inDto) throws Exception;

}
