package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.CtCommCdDescDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CtCommCdDescMapper.java Class
 * 클래스설명   : 공통코드 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("CtCommCdDescMapper")
public interface CtCommCdDescMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : 공통코드 조회
     * 메소드인수1   : {CtCommCdDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {CtCommCdDescDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public CtCommCdDescDTO select(CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : 공통코드 목록조회
     * 메소드인수1   : {CtCommCdDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<CtCommCdDescDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<CtCommCdDescDTO> selectList(CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : 공통코드 등록(신규)
     * 메소드인수1   : {CtCommCdDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : 공통코드 변경(수정)
     * 메소드인수1   : {CtCommCdDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : 공통코드 삭제(USE_YN) UPDATE
     * 메소드인수1   : {CtCommCdDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : 공통코드 제거(테이블에서 삭제)
     * 메소드인수1   : {CtCommCdDescDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchCommCd
     * 작성일자      : 2023. 3. 9.
     * 작성자(author): 70317 / younghwe.kim / 가계대출 시스템 구축
     * 설명          : 공통코드 조회 한다.
     * 메소드인수1   : CtCommCdDescDTO 입력
     * 메소드리턴값  : CtCommCdDescDTO 출력(단건)
     * 예외처리      : Exception
     * </pre>
     */
    public CtCommCdDescDTO searchCommCd (CtCommCdDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchCommCdList
     * 작성일자      : 2023. 3. 9.
     * 작성자(author): 70317 / younghwe.kim / 가계대출 시스템 구축
     * 설명          : 공통코드목록을 조회 한다.
     * 메소드인수1   : CtCommCdDescDTO 입력
     * 메소드리턴값  : List<CtCommCdDescDTO> 출력
     * 예외처리      : Exception
     * </pre>
     */
    public List<CtCommCdDescDTO> searchCommCdList (CtCommCdDescDTO inDto) throws Exception;

}
