package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.RtClsSubDescDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RtClsSubDescMapper.java Class
 * 클래스설명   : RT-마감보조내역(RT_CLS_SUB_DESC) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 24.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 24.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("RtClsSubDescMapper")
public interface RtClsSubDescMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : RT-마감보조내역(RT_CLS_SUB_DESC) 조회
     * 메소드인수1   : {RtClsSubDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {RtClsSubDescDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public RtClsSubDescDTO select(RtClsSubDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : RT-마감보조내역(RT_CLS_SUB_DESC) 목록조회
     * 메소드인수1   : {RtClsSubDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<RtClsSubDescDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<RtClsSubDescDTO> selectList(RtClsSubDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : RT-마감보조내역(RT_CLS_SUB_DESC) 등록(신규)
     * 메소드인수1   : {RtClsSubDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(RtClsSubDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : RT-마감보조내역(RT_CLS_SUB_DESC) 변경(수정)
     * 메소드인수1   : {RtClsSubDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(RtClsSubDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : RT-마감보조내역(RT_CLS_SUB_DESC) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {RtClsSubDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(RtClsSubDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : RT-마감보조내역(RT_CLS_SUB_DESC) 제거(테이블에서 삭제)
     * 메소드인수1   : {RtClsSubDescDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(RtClsSubDescDTO inDto) throws Exception;

}
