package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.RtRcptDescDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RtRcptDescMapper.java Class
 * 클래스설명   : RT-수납내역(RT_RCPT_DESC) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("RtRcptDescMapper")
public interface RtRcptDescMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : RT-수납내역(RT_RCPT_DESC) 조회
     * 메소드인수1   : {RtRcptDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {RtRcptDescDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public RtRcptDescDTO select(RtRcptDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : RT-수납내역(RT_RCPT_DESC) 목록조회
     * 메소드인수1   : {RtRcptDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<RtRcptDescDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<RtRcptDescDTO> selectList(RtRcptDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : RT-수납내역(RT_RCPT_DESC) 등록(신규)
     * 메소드인수1   : {RtRcptDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(RtRcptDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : RT-수납내역(RT_RCPT_DESC) 변경(수정)
     * 메소드인수1   : {RtRcptDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(RtRcptDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : RT-수납내역(RT_RCPT_DESC) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {RtRcptDescDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(RtRcptDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : RT-수납내역(RT_RCPT_DESC) 제거(테이블에서 삭제)
     * 메소드인수1   : {RtRcptDescDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(RtRcptDescDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchRcptDesc
     * 작성일자      : 2023. 3. 16.
     * 작성자(author): 70319 / 가계대출 시스템 구축
     * 설명          : 수납거래내역을 조회 한다.
     * 메소드인수1   : RtCyclDescDTO 입력
     * 메소드리턴값  : RtCyclDescDTO 출력
     * 예외처리      : Exception
     * </pre>
     */
    public List<RtRcptDescDTO> searchRcptDesc(RtRcptDescDTO inDto) throws Exception;

}
