package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.RtTrOrgHistDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RtTrOrgHistMapper.java Class
 * 클래스설명   : RT-거래기관이력(RT_TR_ORG_HIST) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 28.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 28.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("RtTrOrgHistMapper")
public interface RtTrOrgHistMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : RT-거래기관이력(RT_TR_ORG_HIST) 조회
     * 메소드인수1   : {RtTrOrgHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {RtTrOrgHistDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public RtTrOrgHistDTO select(RtTrOrgHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : RT-거래기관이력(RT_TR_ORG_HIST) 목록조회
     * 메소드인수1   : {RtTrOrgHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<RtTrOrgHistDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<RtTrOrgHistDTO> selectList(RtTrOrgHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : RT-거래기관이력(RT_TR_ORG_HIST) 등록(신규)
     * 메소드인수1   : {RtTrOrgHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(RtTrOrgHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : RT-거래기관이력(RT_TR_ORG_HIST) 변경(수정)
     * 메소드인수1   : {RtTrOrgHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(RtTrOrgHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : RT-거래기관이력(RT_TR_ORG_HIST) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {RtTrOrgHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(RtTrOrgHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : RT-거래기관이력(RT_TR_ORG_HIST) 제거(테이블에서 삭제)
     * 메소드인수1   : {RtTrOrgHistDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(RtTrOrgHistDTO inDto) throws Exception;

}
