package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StGodsBaseDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StGodsBaseMapper.java Class
 * 클래스설명   : ST-물품기본(ST_GODS_BASE) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StGodsBaseMapper")
public interface StGodsBaseMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-물품기본(ST_GODS_BASE) 조회
     * 메소드인수1   : {StGodsBaseDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StGodsBaseDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StGodsBaseDTO select(StGodsBaseDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-물품기본(ST_GODS_BASE) 목록조회
     * 메소드인수1   : {StGodsBaseDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StGodsBaseDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StGodsBaseDTO> selectList(StGodsBaseDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-물품기본(ST_GODS_BASE) 등록(신규)
     * 메소드인수1   : {StGodsBaseDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StGodsBaseDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-물품기본(ST_GODS_BASE) 변경(수정)
     * 메소드인수1   : {StGodsBaseDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StGodsBaseDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-물품기본(ST_GODS_BASE) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StGodsBaseDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StGodsBaseDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-물품기본(ST_GODS_BASE) 제거(테이블에서 삭제)
     * 메소드인수1   : {StGodsBaseDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StGodsBaseDTO inDto) throws Exception;

}
