package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StRmbrPlanHistDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StRmbrPlanHistMapper.java Class
 * 클래스설명   : ST-상환계획이력(ST_RMBR_PLAN_HIST) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StRmbrPlanHistMapper")
public interface StRmbrPlanHistMapper {

    /**
     * <pre>
     * 메소드명      : select
     * 설명          : ST-상환계획이력(ST_RMBR_PLAN_HIST) 조회
     * 메소드인수1   : {StRmbrPlanHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StRmbrPlanHistDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public StRmbrPlanHistDTO select(StRmbrPlanHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : ST-상환계획이력(ST_RMBR_PLAN_HIST) 목록조회
     * 메소드인수1   : {StRmbrPlanHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {List<StRmbrPlanHistDTO>}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StRmbrPlanHistDTO> selectList(StRmbrPlanHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : ST-상환계획이력(ST_RMBR_PLAN_HIST) 등록(신규)
     * 메소드인수1   : {StRmbrPlanHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StRmbrPlanHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : ST-상환계획이력(ST_RMBR_PLAN_HIST) 변경(수정)
     * 메소드인수1   : {StRmbrPlanHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StRmbrPlanHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : delete
     * 설명          : ST-상환계획이력(ST_RMBR_PLAN_HIST) 삭제(USE_YN) UPDATE
     * 메소드인수1   : {StRmbrPlanHistDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int delete(StRmbrPlanHistDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : ST-상환계획이력(ST_RMBR_PLAN_HIST) 제거(테이블에서 삭제)
     * 메소드인수1   : {StRmbrPlanHistDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StRmbrPlanHistDTO inDto) throws Exception;

}
