package hanalife.c.co.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StTitleInsuDTO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : StTitleInsuMapper.java Class
 * 클래스설명   : 권원보험관리원장(ST_TITLE_INSU) 조회(목록), 등록, 수정, 삭제, 제거 Interface Mapper
 * 작성일자     : 2023. 4. 13.
 * 작성자명     : 70319 / jeongseon.shin / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 13.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("StTitleInsuMapper")
public interface StTitleInsuMapper {

    /**
     * <pre>
     * 메소드명      : selectList
     * 설명          : 권원보험관리원장(ST_TITLE_INSU) 조회
     * 메소드인수1   : {StTitleInsuDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {StTitleInsuDTO}
     * 예외처리      : Exception
     * </pre>
     */
    public List<StTitleInsuDTO> selectList(StTitleInsuDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : insert
     * 설명          : 권원보험관리원장(ST_TITLE_INSU) 등록(신규)
     * 메소드인수1   : {StTitleInsuDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int insert(StTitleInsuDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : update
     * 설명          : 권원보험관리원장(ST_TITLE_INSU) 변경(수정)
     * 메소드인수1   : {StTitleInsuDTO} inDto(영업일자:yyyyMMdd)
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int update(StTitleInsuDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : remove
     * 설명          : 권원보험관리원장(ST_TITLE_INSU) 제거(테이블에서 삭제)
     * 메소드인수1   : {StTitleInsuDTO}
     * 메소드리턴값  : {int}
     * 예외처리      : Exception
     * </pre>
     */
    public int remove(StTitleInsuDTO inDto) throws Exception;

}
