package hanalife.c.sc.pg.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.sc.pg.mapper.dto.CnstMngDSSDDO01DTO;
import hanalife.c.sc.pg.mapper.dto.CnstMngDSSMDODTO;

/**
 * <pre>
 * 클래스명	: CnstMngMapper.java Class
 * 클래스설명	: CSCPGM05 Mapper
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 작성일자	: 2023. 3. 27.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * 변경이력	:
 * -----------------------------------------------------------------------------
 * [수정일자	   ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 8.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@Mapper("CnstMngMapper")
public interface CnstMngMapper {

    /**
     * <p>메소드명			: searchCnstMngList</p>
     * <p>설명			: 상수리스트관리내역을 조회한다.</p>
     * <p>메소드인수1		: 상수리스트관리내역 조회 CnstMngDSSMDODTO </p>
     * <p>메소드리턴값		: 상수리스트관리내역 조회 결과 CnstMngDSSDDO01DTO list</p>
     * <p>예외처리			: Exception</p>
     */
	public List<CnstMngDSSDDO01DTO> searchCnstMngList(CnstMngDSSMDODTO inDto) throws Exception;

    /**
     * <p>메소드명			: selectCnstMngCount</p>
     * <p>설명			: 상수리스트관리내역을 count 한다.</p>
     * <p>메소드인수1		: 상수리스트관리내역 조회 CnstMngDSSMDO01DTO </p>
     * <p>메소드리턴값		: String</p>
     * <p>예외처리			: Exception</p>
     */
    public String selectCnstMngCount(CnstMngDSSMDODTO inDto) throws Exception;


    /**
     * <p>메소드명			: insertCnstMng</p>
     * <p>설명			: 상수리스트관리를 등록 한다.</p>
     * <p>메소드인수1		: 상수리스트관리 등록 CnstMngDSSMDO01DTO </p>
     * <p>메소드리턴값		: void </p>
     * <p>예외처리			: Exception</p>
     */
    public void insertCnstMng(CnstMngDSSDDO01DTO inDto) throws Exception;

    /**
     * <p>메소드명			: updateCnstMng</p>
     * <p>설명			: 상수리스트관리를 수정 한다.</p>
     * <p>메소드인수1		: 상수리스트관리 수정 CnstMngDSSMDO01DTO </p>
     * <p>메소드리턴값		: void </p>
     * <p>예외처리			: Exception</p>
     */
    public void updateCnstMng(CnstMngDSSDDO01DTO inDto) throws Exception;

    /**
     * <p>메소드명			: deleteCnstMng</p>
     * <p>설명			: 상수리스트관리를 삭제 한다.</p>
     * <p>메소드인수1		: 상수리스트관리 삭제 CnstMngDSSMDO01DTO </p>
     * <p>메소드리턴값		: void </p>
     * <p>예외처리			: Exception</p>
     */
    public void deleteCnstMng(CnstMngDSSDDO01DTO inDto) throws Exception;

    /**
     * <p>메소드명			: searchCnstDesc</p>
     * <p>설명			: 상수리스트내역을 상세조회한다.</p>
     * <p>메소드인수1		: 상수리스트내역 상세조회 CnstMngDSSMDODTO </p>
     * <p>메소드리턴값		: 상수리스트내역 상세조회 결과 CnstMngDSSDDO01DTO list</p>
     * <p>예외처리			: Exception</p>
     */
	public List<CnstMngDSSDDO01DTO> searchCnstDesc(CnstMngDSSMDODTO inDto) throws Exception;

}