package hanalife.c.sc.pg.web;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.pg.service.CSCPGM05Service;
import hanalife.c.sc.pg.vo.CSCPGM05DSSDDO01VO;
import hanalife.c.sc.pg.vo.CSCPGM05DSSMDOVO;
import hanalife.c.sc.pg.vo.CSCPGM05I01InVO;
import hanalife.c.sc.pg.vo.CSCPGM05S01InVO;
import hanalife.c.sc.pg.vo.CSCPGM05S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: CSCPGM05Controller.java Class
 * 클래스설명	: 상수리스트 관리 (CSCPGM05) Controller
 * 작성일자	: 2023. 3. 27.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.03.27.][70305][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 상수리스트관리 조회 : /CSCPGM05S01.do
 * 서비스구성 : 상수리스트관리 저장 : /CSCPGM05I01.do
 * </pre>
 */

@RequestMapping("/c/sc/pg")
@Controller
public class CSCPGM05Controller {

	@Resource(name = "CSCPGM05Service")
	private CSCPGM05Service CSCPGM05;

	private static final Logger LOGGER = LoggerFactory.getLogger(CSCPGM05Controller.class);

	/**
	 * <p>메소드명			: 상수리스트관리내역 조회 /CSCPGM05S01.do </p>
	 * <p>작성일자			: 2023. 3. 27.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: 상수리스트관리내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
	@RequestMapping("/CSCPGM05S01.do")
	public String CSCPGM05S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCPGM05 Controller CSCPGM05S01 Start #####");

		try {

			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### CSCPGM05 Controller CSCPGM05S01 추출 #####");

			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SMDO", request, response, model);

			// 상수리스트관리내역 조회 업무 서비스 호출 입력값 대입
			CSCPGM05DSSMDOVO dsSMDOInVo = new CSCPGM05DSSMDOVO();

			dsSMDOInVo.setDutyZonCd((String) sourceMap.get("dutyZonCd")); 	/* 업무영역 */

			LOGGER.info("##### inVO = " + dsSMDOInVo.getDutyZonCd() );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			CSCPGM05S01InVO InVO = new CSCPGM05S01InVO();

			// 상수리스트관리 내역조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setCSCPGM05DSSMDOVO(dsSMDOInVo);

			// 상수리스트관리내역 조회 업무 서비스 호출 수행
			CSCPGM05S01OutVO resultListVo = CSCPGM05.getCSCPGM05S01(InVO);

			// 상수리스트관리내역 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_SDDO", resultListVo.getListCSCPGM05DSSDDO01VO(), model);

			LOGGER.info("##### CSCPGM05 Controller CSCPGM05S01  Normal End #####");

		}catch (Exception e) {

			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCPGM05 Controller CSCPGM05S01 Exception End #####");

		}

		LOGGER.info("##### CSCPGM05 Controller CSCPGM05S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

    /**
	 * <p>메소드명			: 상수리스트관리내역 저장(등록,수정,삭제) /CSCPGM05I01.do </p>
	 * <p>작성일자			: 2023.03.30.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: 상수리스트관리내역 저장(등록,수정,삭제)을 한다.</p>
	 * <p>예외처리			: Exception</p>
     */
	@RequestMapping("/CSCPGM05I01.do")
    public String CSCPGM05I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCPGM05Controller CSCPGM05I01 Start #####");

		try {

			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.

			List<Map<String, Object>> sourceMapC = XFrame5DataSetUtil.getXFrameDataSetList("DS_SDDO_C", request, response, model); // 수정 & 등록
			List<Map<String, Object>> sourceMapD = XFrame5DataSetUtil.getXFrameDataSetList("DS_SDDO_D", request, response, model);	// 삭제

			// ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			Map<String, Object> inMap = new HashMap<String, Object>();
			CSCPGM05I01InVO InVO = null;
			CSCPGM05DSSDDO01VO inSddoVo = null;

			// ■ 등록 전 조회를 위한 INVO
			CSCPGM05I01InVO srchVO = new CSCPGM05I01InVO();

            // ■ 등록, 수정 처리
			CSCPGM05S01OutVO resultCSCPGM05I01 = new CSCPGM05S01OutVO();
			String strOperation = "";

			if( sourceMapC.size() > 0 ) {
				for( int idx=0; idx<sourceMapC.size(); idx++ ) {
					inMap = sourceMapC.get(idx);
					strOperation = inMap.get("XDATASET_RECORD_TYPE").toString();    // operation 종류(I : 등록, U : 수정 D:삭제)

					if( !strOperation.trim().equals("") ) {
						// □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입[업무영역코드, 상수명, 상수값, 상수설명]
						inSddoVo = new CSCPGM05DSSDDO01VO();

						inSddoVo.setDutyZonCd     (inMap.get("dutyZonCd").toString());			/* 업무영역코드 */
						inSddoVo.setCnstNm        (inMap.get("cnstNm").toString());				/* 상수명 */
						inSddoVo.setCnstCntn      (inMap.get("cnstCntn").toString());			/* 상수값 */
						inSddoVo.setDescCntn      (inMap.get("descCntn").toString());			/* 상수설명 */
						inSddoVo.setFrstRegEmpNo  (inMap.get("frstRegEmpNo").toString());		/* 최초등록사원번호 */
						inSddoVo.setLastProcEmpNo (inMap.get("lastProcEmpNo").toString());		/* 최종변경사원변호 */

						LOGGER.info("상수리스트관리 컨트롤러" + "최초등록사원번호 = inSddoVo.getFrstRegEmpNo  : " + inSddoVo.getFrstRegEmpNo());
						LOGGER.info("상수리스트관리 컨트롤러" + "최종변경사원번호 = inSddoVo.getLastProcEmpNo : " + inSddoVo.getLastProcEmpNo());

						// □ 역할관리 저장 서비스 호출 입력값 대입
						InVO = new CSCPGM05I01InVO();
						InVO.setCSCPGM05DSSDDO01VO(inSddoVo);

						// □ 등록(저장,수정) 전 데이터 조회
						srchVO.setCSCPGM05DSSDDO01VO(inSddoVo);
						int iCount = CSCPGM05.getCSCPGM01S02(srchVO);

						if( strOperation.equals("I") ) {
//						if( iCount == 0) {

							// □ 상수리스트 저장 서비스 호출 수행
							resultCSCPGM05I01 = CSCPGM05.saveCSCPGM05I01(InVO);

						}
//						else if(strOperation.equals("I") && iCount != 0) {
//							LOGGER.info("##### 고반석 :: 신규등록 데이터 중복 #####");
//							return XFrame5View.XFRAME5_VIEW;
//						}
						else {
							// □ 상수리스트 수정 서비스 호출 수행
							resultCSCPGM05I01 = CSCPGM05.updCSCPGM05U01(InVO);

						}
					}
				}
			}

		    // ■  삭제
		    if( sourceMapD.size() > 0 ) {
		        inMap = new HashMap<String, Object>();
		        for( int idy=0; idy<sourceMapD.size(); idy++ ) {
		            inMap = sourceMapD.get(idy);

		            strOperation = inMap.get("XDATASET_RECORD_TYPE").toString();    // operation 종류

		            if( !strOperation.trim().equals("") ) {

		                // □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
		                inSddoVo = new CSCPGM05DSSDDO01VO();

		                inSddoVo.setDutyZonCd(inMap.get("dutyZonCd").toString());
		                inSddoVo.setCnstNm(inMap.get("cnstNm").toString());
		                inSddoVo.setCnstCntn(inMap.get("cnstCntn").toString());
		                inSddoVo.setDescCntn(inMap.get("descCntn").toString());

		                // □ 역할관리 저장 서비스 호출 입력값 대입
		                InVO =  new CSCPGM05I01InVO();
		                InVO.setCSCPGM05DSSDDO01VO(inSddoVo);

		                // □ 삭제 전 데이터 조회
		                srchVO.setCSCPGM05DSSDDO01VO(inSddoVo);
		                int iCount = CSCPGM05.getCSCPGM01S02(srchVO);

		                if( iCount == 1 ) {
		                    // □ 역할관리 삭제 서비스 호출 수행
		                	resultCSCPGM05I01 = CSCPGM05.delCSCPGM05D01(InVO);

		                }
		            }
		        }
		    }

			LOGGER.info("##### CSCPGM05Controller CSCPGM05I01 Normal End #####");
		}
		catch (Exception e) {

			LOGGER.error("Error >>> "+e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCPGM05Controller CSCPGM05I01 Exception End #####");
		}
		return XFrame5View.XFRAME5_VIEW;
	}

}

