package hanalife.c.sc.ro.service;

import hanalife.c.sc.ro.vo.CSCROM02S01InVO;
import hanalife.c.sc.ro.vo.CSCROM02S01OutVO;
import hanalife.c.sc.ro.vo.CSCROM02U01InVO;
import hanalife.c.sc.ro.vo.CSCROM02U01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CSCROM02Service.java Class
 * 클래스설명   : 사용자역할관리 (CSCROM02) Service Interface
 * 작성일자     : 2023. 4. 19.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 19.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCSCROM02S01 : 사용자역할관리목록조회
 * 			 	getCSCROM02S02 : 사용자역할관리건수조회
 * 			 	registerCSCROM02I01 : 사용자역할관리등록
 * 			 	modifyCSCROM02U01 : 사용자역할관리수정
 * 			 	deleteCSCROM02U01 : 사용자역할관리삭제
 * </pre>
 */

public interface CSCROM02Service {

	/**
	 * <p>메소드명      : getCSCROM02S01 : 사용자역할관리</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 조회한다.</p>
	 * <p>메소드인수    : CSCROM02S01InVo </p>
	 * <p>메소드리턴값  : CSCROM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public CSCROM02S01OutVO getCSCROM02S01(CSCROM02S01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : registerCSCROM02U01 : 사용자역할관리등록</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 등록한다.</p>
	 * <p>메소드인수    : CSCROM02U01InVo </p>
	 * <p>메소드리턴값  : CSCROM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 * @return
	 */
	public CSCROM02U01OutVO registerCSCROM02U01(CSCROM02U01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : modifyCSCROM02U01 : 사용자역할관리수정</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 수정한다.</p>
	 * <p>메소드인수    : CSCROM02U01InVo </p>
	 * <p>메소드리턴값  : CSCROM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 * @return
	 */
	public CSCROM02U01OutVO modifyCSCROM02U01(CSCROM02U01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : deleteCSCROM02U01 : 사용자역할관리삭제</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 삭제한다.</p>
	 * <p>메소드인수    : CSCROM02U01InVo </p>
	 * <p>메소드리턴값  : CSCROM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 * @return
	 */
	public CSCROM02U01OutVO deleteCSCROM02U01(CSCROM02U01InVO inVo) throws Exception;

}
