package hanalife.c.sc.ro.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.sc.ro.mapper.CtUserRoleMapper;
import hanalife.c.sc.ro.mapper.dto.ctUserRoleDSSDCDTO;
import hanalife.c.sc.ro.mapper.dto.ctUserRoleDSSDDDTO;
import hanalife.c.sc.ro.mapper.dto.ctUserRoleDSSDDTO;
import hanalife.c.sc.ro.mapper.dto.ctUserRoleDSSMDTO;
import hanalife.c.sc.ro.service.CSCROM02Service;
import hanalife.c.sc.ro.vo.CSCROM02DSSDVO;
import hanalife.c.sc.ro.vo.CSCROM02S01InVO;
import hanalife.c.sc.ro.vo.CSCROM02S01OutVO;
import hanalife.c.sc.ro.vo.CSCROM02U01InVO;
import hanalife.c.sc.ro.vo.CSCROM02U01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CSCROM02ServiceImpl.java Class
 * 클래스설명   : 사용자역할관리 (CSCROM02) Service Implements
 * 작성일자     : 2023. 4. 19.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 19.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getCSCROM02S01 : 사용자역할관리목록조회
 * 			 	registerCSCROM02I01 : 사용자역할관리등록
 * 			 	modifyCSCROM02U01 : 사용자역할관리수정
 * 			 	deleteCSCROM02U01 : 사용자역할관리삭제

 * </pre>
 */
@Service("CSCROM02Service")
public class CSCROM02ServiceImpl implements CSCROM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CSCROM02ServiceImpl.class);

    private MsgEnum msgEnum;

	@Autowired
	private CtUserRoleMapper ctUserRoleMapper;

	/**
	 * <p>메소드명      : getCSCROM02S01 : 사용자역할관리</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 조회 한다.</p>
	 * <p>메소드인수    : CSCROM02S01InVo </p>
	 * <p>메소드리턴값  : CSCROM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM02S01OutVO getCSCROM02S01(CSCROM02S01InVO inVo) throws Exception {

		CSCROM02S01OutVO resultVo = new CSCROM02S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctUserRoleDSSMDTO inDto = new ctUserRoleDSSMDTO();

		inDto.setUserNo(inVo.getCSCROM02DSSMVO().getUserNo()); 		/** 사용자번호 */

		// 사용자역할관리 기본 목록 조회
		List<ctUserRoleDSSDDTO> resultDTO = ctUserRoleMapper.searchUserRole(inDto);	/** 사용자역할관리리스트*/

		if(resultDTO.isEmpty()) {
			resultVo.setRsltCd(msgEnum.NOT_FOUND_USER.getErrorCd());
			resultVo.setRsltCntn(msgEnum.NOT_FOUND_USER.getDescription());
		}

		List<CSCROM02DSSDVO> resultList = new ArrayList<CSCROM02DSSDVO>();

		for (ctUserRoleDSSDDTO sourceIO : resultDTO) {
			CSCROM02DSSDVO targetIO = new CSCROM02DSSDVO();

			targetIO.setUserNo(sourceIO.getUserNo()); 			/** 사용자번호 */
			targetIO.setRoleNo(sourceIO.getRoleNo()); 			/** 역할번호 */
			targetIO.setRoleNm(sourceIO.getRoleNm()); 			/** 역할명 */
			targetIO.setRoleDesc(sourceIO.getRoleDesc()); 		/** 역할설명 */

			resultList.add(targetIO);
		}

		resultVo.setCSCROM02DSSDVO(resultList);		/** 사용자역할관리리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : registerCSCROM02U01 : 사용자역할관리등록</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 등록 한다.</p>
	 * <p>메소드인수    : CSCROM02U01InVo </p>
	 * <p>메소드리턴값  : CSCROM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM02U01OutVO registerCSCROM02U01(CSCROM02U01InVO inVo) throws Exception {

		CSCROM02U01OutVO resultVo = new CSCROM02U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctUserRoleDSSDCDTO inDto = new ctUserRoleDSSDCDTO();

		int insResult = 0;

		inDto.setUserNo(inVo.getCSCROM02DSSDCVO().getUserNo()); 			/** 사용자번호 */
		inDto.setRoleNo(inVo.getCSCROM02DSSDCVO().getRoleNo()); 			/** 역할번호 */
		inDto.setLogInEmpNo(inVo.getCSCROM02DSSDCVO().getLogInEmpNo()); 	/** 로그인사원번호 */

		insResult = ctUserRoleMapper.registerCtUserRole(inDto);

		if(insResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;

	}

	/**
	 * <p>메소드명      : modifyCSCROM02U01 : 사용자역할관리수정</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 수정 한다.</p>
	 * <p>메소드인수    : CSCROM02U01InVo </p>
	 * <p>메소드리턴값  : CSCROM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM02U01OutVO modifyCSCROM02U01(CSCROM02U01InVO inVo) throws Exception {

		CSCROM02U01OutVO resultVo = new CSCROM02U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctUserRoleDSSDCDTO inDto = new ctUserRoleDSSDCDTO();

		int updResult = 0;

		inDto.setUserNo(inVo.getCSCROM02DSSDCVO().getUserNo()); 			/** 사용자번호 */
		inDto.setRoleNo(inVo.getCSCROM02DSSDCVO().getRoleNo()); 			/** 역할번호 */
		inDto.setLogInEmpNo(inVo.getCSCROM02DSSDCVO().getLogInEmpNo()); 	/** 로그인사원번호 */

		updResult = ctUserRoleMapper.modifyCtUserRole(inDto);	/** 사용자역할관리수정리스트*/

		if(updResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : deleteCSCROM02U01 : 사용자역할관리삭제</p>
	 * <p>작성일자      : 2023. 4. 19.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 사용자역할관리 삭제 한다.</p>
	 * <p>메소드인수    : CSCROM02U01InVo </p>
	 * <p>메소드리턴값  : CSCROM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM02U01OutVO deleteCSCROM02U01(CSCROM02U01InVO inVo) throws Exception {

		CSCROM02U01OutVO resultVo = new CSCROM02U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctUserRoleDSSDDDTO inDto = new ctUserRoleDSSDDDTO();

		int delResult = 0;

		inDto.setUserNo(inVo.getCSCROM02DSSDDVO().getUserNo()); 			/** 사용자번호 */
		inDto.setRoleNo(inVo.getCSCROM02DSSDDVO().getRoleNo()); 			/** 역할번호 */

		delResult = ctUserRoleMapper.deleteCtUserRole(inDto);	/** 사용자역할관리삭제리스트*/

		if(delResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

}