package hanalife.c.sc.ro.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.sc.ro.mapper.CtPrgmRoleMapper;
import hanalife.c.sc.ro.mapper.dto.ctPrgmRoleDSSDCDTO;
import hanalife.c.sc.ro.mapper.dto.ctPrgmRoleDSSDDDTO;
import hanalife.c.sc.ro.mapper.dto.ctPrgmRoleDSSDPDTO;
import hanalife.c.sc.ro.mapper.dto.ctPrgmRoleDSSDPRDTO;
import hanalife.c.sc.ro.mapper.dto.ctPrgmRoleDSSMPDTO;
import hanalife.c.sc.ro.mapper.dto.ctPrgmRoleDSSMPRDTO;
import hanalife.c.sc.ro.service.CSCROM03Service;
import hanalife.c.sc.ro.vo.CSCROM03DSSDPRVO;
import hanalife.c.sc.ro.vo.CSCROM03DSSDPVO;
import hanalife.c.sc.ro.vo.CSCROM03S01InVO;
import hanalife.c.sc.ro.vo.CSCROM03S01OutVO;
import hanalife.c.sc.ro.vo.CSCROM03U01InVO;
import hanalife.c.sc.ro.vo.CSCROM03U01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CSCROM03ServiceImpl.java Class
 * 클래스설명   : 프로그램역할관리 (CSCROM03) Service Implements
 * 작성일자     : 2023. 5. 4.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 4.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getPrgmRoleCnt : 프로그램건수조회
 * 				getCSCROM03S01 : 프로그램조회
 * 				getCSCROM03S02 : 프로그램역할조회
 * 			 	registerCSCROM03I01 : 프로그램역할관리등록
 * 			 	modifyCSCROM03U01 : 프로그램역할관리수정
 * 			 	deleteCSCROM03U01 : 프로그램역할관리삭제

 * </pre>
 */
@Service("CSCROM03Service")
public class CSCROM03ServiceImpl implements CSCROM03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(CSCROM03ServiceImpl.class);

    private MsgEnum msgEnum;

	@Autowired
	private CtPrgmRoleMapper ctPrgmRoleMapper;

	/**
	 * <p>메소드명      : getPrgmRoleCnt : 프로그램건수조회</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램건수 조회한다.</p>
	 * <p>메소드인수    : CSCROM03S01InVo </p>
	 * <p>메소드리턴값  : CSCROM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public int getPrgmRoleCnt(CSCROM03U01InVO inVo) throws Exception {

		ctPrgmRoleDSSDCDTO inDto = new ctPrgmRoleDSSDCDTO();

		inDto.setRoleNo(inVo.getCSCROM03DSSDCVO().getRoleNo()); 		/** 역할번호 */
		inDto.setPrgmNo(inVo.getCSCROM03DSSDCVO().getPrgmNo()); 		/** 프로그램번호 */

		// 프로그램역할관리 건수 조회
		List<ctPrgmRoleDSSDCDTO> resultDTO = ctPrgmRoleMapper.selectPrgmCnt(inDto);	/** 프로그램리스트*/

		int resultCnt = 0;

		for (ctPrgmRoleDSSDCDTO sourceIO : resultDTO) {
			resultCnt = Integer.parseInt(sourceIO.getPrgmCnt()); 		/** 조회건수 */
		}

		return resultCnt;
	}

	/**
	 * <p>메소드명      : getCSCROM03S01 : 프로그램조회</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램 조회한다.</p>
	 * <p>메소드인수    : CSCROM03S01InVo </p>
	 * <p>메소드리턴값  : CSCROM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM03S01OutVO getCSCROM03S01(CSCROM03S01InVO inVo) throws Exception {

		CSCROM03S01OutVO resultVo = new CSCROM03S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctPrgmRoleDSSMPDTO inDto = new ctPrgmRoleDSSMPDTO();

		inDto.setBsnDivCd(inVo.getCSCROM03DSSMPVO().getBsnDivCd()); 		/** 업무구분 */

		// 프로그램역할관리 기본 목록 조회
		List<ctPrgmRoleDSSDPDTO> resultDTO = ctPrgmRoleMapper.searchPrgmList(inDto);	/** 프로그램리스트*/

		List<CSCROM03DSSDPVO> resultList = new ArrayList<CSCROM03DSSDPVO>();

		for (ctPrgmRoleDSSDPDTO sourceIO : resultDTO) {
			CSCROM03DSSDPVO targetIO = new CSCROM03DSSDPVO();

			targetIO.setPrgmNo(sourceIO.getPrgmNo()); 						/** 프로그램번호 */
			targetIO.setPrgmNm(sourceIO.getPrgmNm()); 						/** 프로그램명 */
			targetIO.setUpPrgmNo(sourceIO.getUpPrgmNo()); 					/** 상위프로그램번호 */
			targetIO.setMenuLevl(sourceIO.getMenuLevl()); 					/** 메뉴LV */

			resultList.add(targetIO);
		}

		resultVo.setCSCROM03DSSDPVO(resultList);		/** 프로그램리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : getCSCROM03S02 : 프로그램역할조회</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할 조회한다.</p>
	 * <p>메소드인수    : CSCROM03S01InVo </p>
	 * <p>메소드리턴값  : CSCROM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM03S01OutVO getCSCROM03S02(CSCROM03S01InVO inVo) throws Exception {

		CSCROM03S01OutVO resultVo = new CSCROM03S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctPrgmRoleDSSMPRDTO inDto = new ctPrgmRoleDSSMPRDTO();

		inDto.setRoleNo(inVo.getCSCROM03DSSMPRVO().getRoleNo()); 		/** 프로그램번호 */

		// 프로그램역할관리 기본 목록 조회
		List<ctPrgmRoleDSSDPRDTO> resultDTO = ctPrgmRoleMapper.searchPrgmRoleList(inDto);	/** 프로그램역할리스트*/

		List<CSCROM03DSSDPRVO> resultList = new ArrayList<CSCROM03DSSDPRVO>();

		for (ctPrgmRoleDSSDPRDTO sourceIO : resultDTO) {
			CSCROM03DSSDPRVO targetIO = new CSCROM03DSSDPRVO();

			targetIO.setRoleNo(sourceIO.getRoleNo()); 					/** 역할번호 */
			targetIO.setPrgmNo(sourceIO.getPrgmNo()); 					/** 프로그램번호 */
			targetIO.setPrgmNm(sourceIO.getPrgmNm()); 					/** 프로그램명 */
			targetIO.setMenuReadFg(sourceIO.getMenuReadFg()); 			/** 메뉴조회여부 */
			targetIO.setUseDgre(sourceIO.getUseDgre()); 				/** 사용등급 */
			targetIO.setBtnSelectUseFg(sourceIO.getBtnSelectUseFg()); 				/** 조회사용권한유무 */
			targetIO.setBtnInsertUseFg(sourceIO.getBtnInsertUseFg()); 				/** 추가사용권한유무 */
			targetIO.setBtnUpdateUseFg(sourceIO.getBtnUpdateUseFg()); 				/** 저장사용권한유무 */
			targetIO.setBtnDeleteUseFg(sourceIO.getBtnDeleteUseFg()); 				/** 삭제사용권한유무 */

			resultList.add(targetIO);
		}

		resultVo.setCSCROM03DSSDPRVO(resultList);		/** 프로그램역할리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : registerCSCROM03U01 : 프로그램역할관리등록</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할관리 등록 한다.</p>
	 * <p>메소드인수    : CSCROM03U01InVo </p>
	 * <p>메소드리턴값  : CSCROM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM03U01OutVO registerCSCROM03U01(CSCROM03U01InVO inVo) throws Exception {

		CSCROM03U01OutVO resultVo = new CSCROM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctPrgmRoleDSSDCDTO inDto = new ctPrgmRoleDSSDCDTO();

		int insResult = 0;

		inDto.setRoleNo(inVo.getCSCROM03DSSDCVO().getRoleNo()); 			/** 역할번호 */
		inDto.setPrgmNo(inVo.getCSCROM03DSSDCVO().getPrgmNo()); 			/** 프로그램번호 */
		inDto.setMenuReadFg(inVo.getCSCROM03DSSDCVO().getMenuReadFg()); 	/** 메뉴조회여부 */
		inDto.setUseDgre(inVo.getCSCROM03DSSDCVO().getUseDgre()); 			/** 사용등급 */
		inDto.setLogInEmpNo(inVo.getCSCROM03DSSDCVO().getLogInEmpNo()); 	/** 로그인사원번호 */
		
		inDto.setBtnSelectUseFg(inVo.getCSCROM03DSSDCVO().getBtnSelectUseFg()); 	/** 조회사용권한유무 */
		inDto.setBtnInsertUseFg(inVo.getCSCROM03DSSDCVO().getBtnInsertUseFg()); 	/** 추가사용권한유무 */
		inDto.setBtnUpdateUseFg(inVo.getCSCROM03DSSDCVO().getBtnUpdateUseFg()); 	/** 저장사용권한유무 */
		inDto.setBtnDeleteUseFg(inVo.getCSCROM03DSSDCVO().getBtnDeleteUseFg()); 	/** 삭제사용권한유무 */

		insResult = ctPrgmRoleMapper.registerCtPrgmRole(inDto);				/** 프로그램역할 등록 */

		if(insResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}else if(insResult > 0) {
			int insHistResult = 0;

			insHistResult = ctPrgmRoleMapper.registerCtPrgmRoleHist(inDto);		/** 프로그램역할이력등록 */

			if(insHistResult < 0) {
				resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
				resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
			}
		}

		return resultVo;

	}

	/**
	 * <p>메소드명      : modifyCSCROM03U01 : 프로그램역할관리수정</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할관리 수정 한다.</p>
	 * <p>메소드인수    : CSCROM03U01InVo </p>
	 * <p>메소드리턴값  : CSCROM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM03U01OutVO modifyCSCROM03U01(CSCROM03U01InVO inVo) throws Exception {

		CSCROM03U01OutVO resultVo = new CSCROM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctPrgmRoleDSSDCDTO inDto = new ctPrgmRoleDSSDCDTO();

		int updResult = 0;

		inDto.setRoleNo(inVo.getCSCROM03DSSDCVO().getRoleNo()); 			/** 역할번호 */
		inDto.setPrgmNo(inVo.getCSCROM03DSSDCVO().getPrgmNo()); 			/** 프로그램번호 */
		inDto.setMenuReadFg(inVo.getCSCROM03DSSDCVO().getMenuReadFg()); 	/** 메뉴조회여부 */
		inDto.setUseDgre(inVo.getCSCROM03DSSDCVO().getUseDgre()); 			/** 사용등급 */
		inDto.setLogInEmpNo(inVo.getCSCROM03DSSDCVO().getLogInEmpNo()); 	/** 로그인사원번호 */
		
		inDto.setBtnSelectUseFg(inVo.getCSCROM03DSSDCVO().getBtnSelectUseFg()); 	/** 조회사용권한유무 */
		inDto.setBtnInsertUseFg(inVo.getCSCROM03DSSDCVO().getBtnInsertUseFg()); 	/** 추가사용권한유무 */
		inDto.setBtnUpdateUseFg(inVo.getCSCROM03DSSDCVO().getBtnUpdateUseFg()); 	/** 저장사용권한유무 */
		inDto.setBtnDeleteUseFg(inVo.getCSCROM03DSSDCVO().getBtnDeleteUseFg()); 	/** 삭제사용권한유무 */

		updResult = ctPrgmRoleMapper.modifyCtPrgmRole(inDto);	/** 프로그램역할관리수정리스트*/

		if(updResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}else if(updResult > 0) {
			int updHistResult = 0;

			updHistResult = ctPrgmRoleMapper.registerCtPrgmRoleHist(inDto);		/** 프로그램역할이력등록 */

			if(updHistResult < 0) {
				resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
				resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
			}
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : deleteCSCROM03U01 : 프로그램역할관리삭제</p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 프로그램역할관리 삭제 한다.</p>
	 * <p>메소드인수    : CSCROM03U01InVo </p>
	 * <p>메소드리턴값  : CSCROM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public CSCROM03U01OutVO deleteCSCROM03U01(CSCROM03U01InVO inVo) throws Exception {

		CSCROM03U01OutVO resultVo = new CSCROM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ctPrgmRoleDSSDDDTO inDto = new ctPrgmRoleDSSDDDTO();
		ctPrgmRoleDSSDCDTO hisDto = new ctPrgmRoleDSSDCDTO();

		int delResult = 0;

		inDto.setRoleNo(inVo.getCSCROM03DSSDDVO().getRoleNo()); 			/** 역할번호 */
		inDto.setPrgmNo(inVo.getCSCROM03DSSDDVO().getPrgmNo()); 			/** 프로그램번호 */

		hisDto.setRoleNo(inVo.getCSCROM03DSSDDVO().getRoleNo()); 			/** 역할번호 */
		hisDto.setPrgmNo(inVo.getCSCROM03DSSDDVO().getPrgmNo()); 			/** 프로그램번호 */
		hisDto.setMenuReadFg(inVo.getCSCROM03DSSDDVO().getMenuReadFg()); 	/** 메뉴조회여부 */
		hisDto.setUseDgre(inVo.getCSCROM03DSSDDVO().getUseDgre()); 			/** 사용등급 */
		hisDto.setLogInEmpNo(inVo.getCSCROM03DSSDDVO().getLogInEmpNo()); 	/** 로그인사원번호 */

		delResult = ctPrgmRoleMapper.deleteCtPrgmRole(inDto);	/** 프로그램역할관리삭제리스트*/

		if(delResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}else if(delResult > 0) {
			int delHistResult = 0;

			delHistResult = ctPrgmRoleMapper.registerCtPrgmRoleHist(hisDto);		/** 프로그램역할이력등록 */

			if(delResult < 0) {
				resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
				resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
			}
		}

		return resultVo;
	}

}