package hanalife.c.sc.ro.web;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.ro.service.CCSROM01Service;
import hanalife.c.sc.ro.vo.CSCROM01DSSDDO01VO;
import hanalife.c.sc.ro.vo.CSCROM01DSSMVO;
import hanalife.c.sc.ro.vo.CSCROM01I01InVO;
import hanalife.c.sc.ro.vo.CSCROM01InVO;
import hanalife.c.sc.ro.vo.CSCROM01OutVO;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 클래스명    : CSCROM01Controller
 * 클래스설명  : 역할관리 (CSCROM01) Controller
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023.03.24
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.03.24][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 역할관리조회 : CSCROM01S01 /searchRoleList.do
 * 서비스구성 : 역할관리저장 : CSCROM01I01 /saveRoleList.do
 * </pre>
 */
@RequestMapping("c/sc/ro")
@Controller
public class CSCROM01Controller {

    @Resource(name = "CSCROM01Service")
    private CCSROM01Service CSCROM01;

    private static final Logger LOGGER = LoggerFactory.getLogger(CSCROM01Controller.class);

    /**
     * <p>메소드명      : 역할관리조회 /searchRoleList.do </p>
     * <p>작성일자      : 2023. 3. 24.
     * <p>작성자(author): 70319
     * <p>설명          : 역할관리 목록을 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/CCSROM01S01.do")
    public String CSCROM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### CSCROM01Controller CSCROM01S01 Start #####");

        try {
            /*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

            /*************************************************
             * ■ 역할관리조회 업무 서비스 호출 입력값 대입
             *************************************************/
            CSCROM01DSSMVO targetVo = new CSCROM01DSSMVO();

            /*************************************************
             * ■ ListVO에 DataSet 항목값을 대입[조회구분, 역할번호, 역할명]
             *************************************************/
            targetVo = (CSCROM01DSSMVO) BeanUtil.mapToBean(sourceMap, targetVo);

            /*************************************************
             * ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             *************************************************/
            CSCROM01InVO InVO = new CSCROM01InVO();
            InVO.setCSCROM01DSSMVO(targetVo);

            LOGGER.info("##### InVO = " + InVO.getCSCROM01DSSMVO().getRoleNo() + " > " + InVO.getCSCROM01DSSMVO().getRoleNm() + " > " + InVO.getCSCROM01DSSMVO().getCond());

            /*************************************************
             * ■ 역할관리조회 업무 서비스 호출 수행
             *************************************************/
            CSCROM01OutVO resultCSCROM01S01 = CSCROM01.getCCSROM01S01(InVO);

            /*************************************************
             * ■ 역할관리조회 DataSet 결과값 설정
             *************************************************/
            model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM01S01.getRsltCd());
            model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM01S01.getRsltCntn());

            XFrame5Util.setOutputData("DS_SDDO01", resultCSCROM01S01.getCSCROM01DSSDDO01VO(), model);

            LOGGER.info("##### CSCROM01Controller CSCROM01S01 Normal End #####");
        }
        catch (Exception e) {
            LOGGER.error("Error getMessage >>> " + e.getMessage());
            LOGGER.error("Error toString   >>> " + e.toString()  );
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### CSCROM01Controller CSCROM01S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 역할관리 저장(등록,수정,삭제) /saveRoleList.do </p>
     * <p>작성일자      : 2023. 2. 27.
     * <p>작성자(author): 70317
     * <p>설명          : 역할관리 저장(등록,수정,삭제)을 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/CCSROM01I01.do")
    public String CCSROM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### CSCROM01Controller CCSROM01I01 Start #####");

        try {
            /*************************************************
             * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
             *************************************************/
        	Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

        	XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

            List<Map<String, Object>> insList   = XFrame5Util.getDataMapList(reqMap, "DS_SDDO01_C");
            List<Map<String, Object>> delList   = XFrame5Util.getDataMapList(reqMap, "DS_SDDO01_D");

//            Map<String, Object>       sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

            /*************************************************
             * ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
             *************************************************/
            Map<String, Object> inMap = new HashMap<String, Object>();
            CSCROM01I01InVO    InVO              = new CSCROM01I01InVO();
            CSCROM01I01InVO    srchVO            = new CSCROM01I01InVO();
            CSCROM01DSSDDO01VO inSddoVo          = new CSCROM01DSSDDO01VO();
            CSCROM01OutVO      resultCSCROM01I01 = new CSCROM01OutVO();

            /*************************************************
             * ■ 등록, 수정 처리
             *************************************************/
            String strOperation = "";
            if( insList.size() > 0 ) {
                for( int idx=0; idx<insList.size(); idx++ ) {
                    inMap = insList.get(idx);
                    strOperation = inMap.get("XDATASET_RECORD_TYPE").toString();    // operation 종류

                    if( !strOperation.trim().equals("") ) {
                        /*************************************************
                         * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입[조회구분, 역할번호, 역할명]
                         *************************************************/
                        inSddoVo = new CSCROM01DSSDDO01VO();

                        inSddoVo.setRoleNo     (inMap.get("roleNo").toString()  );
                        inSddoVo.setRoleNm     (inMap.get("roleNm").toString()  );
                        inSddoVo.setRoleDesc   (inMap.get("roleDesc").toString());
                        inSddoVo.setLogInUserNo(inMap.get("logInUserNo").toString());			/** 로그인사용자번호 */
                        inSddoVo.setLogInEmpNo (inMap.get("logInEmpNo").toString());			/** 로그인사원번호 */

                        /*************************************************
                         * □ 역할관리 저장 서비스 호출 입력값 대입
                         *************************************************/
                        InVO =  new CSCROM01I01InVO();
                        InVO.setCSCROM01DSSDDO01VO(inSddoVo);

                        /*************************************************
                         *  □ 등록(저장,수정) 전 데이터 조회
                         *************************************************/
                        srchVO.setCSCROM01DSSDDO01VO(inSddoVo);
                        int iCount = CSCROM01.getCCSROM01S02(srchVO);

                        //if( strOperation.equals("I") ) {
                        if( iCount == 0 ) {
                            /*************************************************
                             * □ 역할관리 저장 서비스 호출 수행
                             *************************************************/
                            resultCSCROM01I01 = CSCROM01.saveCCSROM01I01(InVO);
                        } else {
                            /*************************************************
                             * □ 역할관리 수정 서비스 호출 수행
                             *************************************************/
                            resultCSCROM01I01 = CSCROM01.updCCSROM01U01(InVO);
                        }
                    }
                }
            }

            /*************************************************
             * ■  삭제
             *************************************************/
            if( delList.size() > 0 ) {
                inMap = new HashMap<String, Object>();
                for( int idy=0; idy<delList.size(); idy++ ) {
                    inMap = delList.get(idy);
                    strOperation = inMap.get("XDATASET_RECORD_TYPE").toString();    // operation 종류

                    if( !strOperation.trim().equals("") ) {
                        /*************************************************
                         * □ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
                         *************************************************/
                        inSddoVo = new CSCROM01DSSDDO01VO();

                        inSddoVo.setRoleNo  (inMap.get("roleNo").toString()  );
                        inSddoVo.setRoleNm  (inMap.get("roleNm").toString()  );
                        inSddoVo.setRoleDesc(inMap.get("roleDesc").toString());

                        /*************************************************
                         * □ 역할관리 저장 서비스 호출 입력값 대입
                         *************************************************/
                        InVO = new CSCROM01I01InVO();
                        InVO.setCSCROM01DSSDDO01VO(inSddoVo);

                        /*************************************************
                         * □ 삭제 전 데이터 조회
                         *************************************************/
                        srchVO.setCSCROM01DSSDDO01VO(inSddoVo);
                        //int iCount = CSCROM01.getCCSROM01S02(srchVO);

                        if( strOperation.equals("D") ) {
                            /*************************************************
                             * □ 역할관리 삭제 서비스 호출 수행
                             *************************************************/
                            resultCSCROM01I01 = CSCROM01.delCCSROM01D01(InVO);
                        }
                    }
                }
            }

            LOGGER.info("##### CSCROM01Controller CCSROM01I01 Normal End #####");
        }
        catch (Exception e) {
            LOGGER.error("Error >>> "+e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### CSCROM01Controller CSCROM01S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}