package hanalife.c.sc.ro.web;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.ro.service.CCSROM01Service;
import hanalife.c.sc.ro.service.CSCROM03Service;
import hanalife.c.sc.ro.vo.CSCROM01DSSMVO;
import hanalife.c.sc.ro.vo.CSCROM01InVO;
import hanalife.c.sc.ro.vo.CSCROM01OutVO;
import hanalife.c.sc.ro.vo.CSCROM03DSSDCVO;
import hanalife.c.sc.ro.vo.CSCROM03DSSDDVO;
import hanalife.c.sc.ro.vo.CSCROM03DSSMPRVO;
import hanalife.c.sc.ro.vo.CSCROM03DSSMPVO;
import hanalife.c.sc.ro.vo.CSCROM03S01InVO;
import hanalife.c.sc.ro.vo.CSCROM03S01OutVO;
import hanalife.c.sc.ro.vo.CSCROM03U01InVO;
import hanalife.c.sc.ro.vo.CSCROM03U01OutVO;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.framework.comm.vo.UserSessionVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CSCROM03Controller.java Class
 *
 * 클래스설명   : 프로그램역할관리 (CSCROM03) Controller
 * 작성일자     : 2023. 5. 4.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 4.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/c/sc/ro")
@Controller
public class CSCROM03Controller {

	@Resource(name = "CSCROM01Service")
	private CCSROM01Service CSCROM01;

	@Resource(name = "CSCROM03Service")
	private CSCROM03Service CSCROM03;

	private MsgEnum msgEnum;

	private static final Logger LOGGER = LoggerFactory.getLogger(CSCROM03Controller.class);

	/**
	 * <p>메소드명      : 프로그램조회 /CSCROM03S01.do </p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323
	 * <p>설명          : 프로그램 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CSCROM03S01.do")
	public String CSCROM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCROM03Controller CSCROM03S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM_P", request, response, model);

			/** 프로그램역할관리내역조회 업무 서비스 호출 입력값 대입 */
			CSCROM03S01InVO targetVo = new CSCROM03S01InVO();
			CSCROM03DSSMPVO smPVo = new CSCROM03DSSMPVO();

			BeanUtil.mapToBean(sourceMap, smPVo);	/** Map을 VO로 변환 */

			targetVo.setCSCROM03DSSMPVO(smPVo);

			/** 프로그램역할관리내역조회 업무 서비스 호출 수행 */
			CSCROM03S01OutVO resultCSCROM03S01 = CSCROM03.getCSCROM03S01(targetVo);

			XFrame5Util.setOutputData("DS_SD_P", resultCSCROM03S01.getCSCROM03DSSDPVO(), model);	/** 프로그램목록 */

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM03S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM03S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### CSCROM03Controller CSCROM03S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCROM03Controller CSCROM03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 프로그램역할조회 /CSCROM03S02.do </p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323
	 * <p>설명          : 프로그램역할 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CSCROM03S02.do")
	public String CSCROM03S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCROM03Controller CSCROM03S02 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM_PR", request, response, model);

			/** 프로그램역할관리내역조회 업무 서비스 호출 입력값 대입 */
			CSCROM03S01InVO targetVo = new CSCROM03S01InVO();
			CSCROM03DSSMPRVO smPrVo = new CSCROM03DSSMPRVO();

			BeanUtil.mapToBean(sourceMap, smPrVo);	/** Map을 VO로 변환 */

			targetVo.setCSCROM03DSSMPRVO(smPrVo);

			/** 프로그램역할관리내역조회 업무 서비스 호출 수행 */
			CSCROM03S01OutVO resultCSCROM03S02 = CSCROM03.getCSCROM03S02(targetVo);

			XFrame5Util.setOutputData("DS_SD_PR", resultCSCROM03S02.getCSCROM03DSSDPRVO(), model);	/** 역할관리목록 */

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM03S02.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM03S02.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### CSCROM03Controller CSCROM03S02 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCROM03Controller CSCROM03S02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 역할조회 /CSCROM03S03.do </p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323
	 * <p>설명          : 역할 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CSCROM03S03.do")
	public String CSCROM03S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCROM03Controller CSCROM03S03 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM_R", request, response, model);

			/** 프로그램역할관리내역조회 업무 서비스 호출 입력값 대입 */
			CSCROM01InVO targetVo = new CSCROM01InVO();
			CSCROM01DSSMVO smVo = new CSCROM01DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */

			targetVo.setCSCROM01DSSMVO(smVo);

			/** 프로그램역할관리내역조회 업무 서비스 호출 수행 */
			CSCROM01OutVO resultCSCROM01S01 = CSCROM01.getCCSROM01S01(targetVo);

			boolean result = resultCSCROM01S01.getCSCROM01DSSDDO01VO().isEmpty();

			if(result) {
				model.addAttribute(XFrame5View.XFRAME5_MSG_CODE,   "1111");								/** 결과코드 */
				model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, "조회된 역할이 없습니다.");			/** 결과메세지 */
			}else {
				XFrame5Util.setOutputData("DS_SD_R", resultCSCROM01S01.getCSCROM01DSSDDO01VO(), model);	/** 역할관리목록 */
				model.addAttribute(XFrame5View.XFRAME5_MSG_CODE,   resultCSCROM01S01.getRsltCd());		/** 결과코드 */
				model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM01S01.getRsltCntn());	/** 결과메세지 */
			}

			LOGGER.info("##### CSCROM03Controller CSCROM03S03 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCROM03Controller CSCROM03S03 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 프로그램역할관리 입력, 수정, 삭제 /CSCROM03U01.do </p>
	 * <p>작성일자      : 2023. 5. 4.
	 * <p>작성자(author): 70323
	 * <p>설명          : 프로그램역할관리 입력, 수정, 삭제 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/CSCROM03U01.do")
	public String CSCROM03U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### CSCROM03Controller CSCROM03U01 Start #####");

		try {
			/** 세션 정보 호출 */
			HttpSession session = request.getSession();
			UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

			/** 데이터셋 로그 출력 */
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			//parameter로 활용할 dataset 정보를 가져온다.
			List<Map<String,Object>> insList = XFrame5Util.getDataMapList(reqMap, "DS_SD_C");
			List<Map<String,Object>> delList = XFrame5Util.getDataMapList(reqMap, "DS_SD_D");

			CSCROM03U01InVO targetVo = new CSCROM03U01InVO();

			CSCROM03DSSDCVO sdcVo = new CSCROM03DSSDCVO();
			CSCROM03DSSDDVO sddVo = new CSCROM03DSSDDVO();

			int resultCnt = 0;	/** DB 내 프로그램 등록 여부 확인용 */

			// 등록, 수정
			if(insList != null && !insList.isEmpty()) {

				for(int i=0; i < insList.size(); i++) {
					String operation = insList.get(i).get("operation").toString();				/** I:등록, U:수정, D:삭제 */

					sdcVo.setRoleNo(insList.get(i).get("roleNo").toString());					/** 역할번호 */
					sdcVo.setPrgmNo(insList.get(i).get("prgmNo").toString());					/** 프로그램번호 */
					sdcVo.setMenuReadFg(insList.get(i).get("menuReadFg").toString());			/** 메뉴조회여부 */
					//sdcVo.setUseDgre(insList.get(i).get("useDgre").toString());				/** 사용등급 */
					sdcVo.setUseDgre("");														/** 사용등급 */
					sdcVo.setBtnSelectUseFg(insList.get(i).get("btnSelectUseFg").toString());	/** 조회사용권한유무 */
					sdcVo.setBtnInsertUseFg(insList.get(i).get("btnInsertUseFg").toString());	/** 추가사용권한유무 */
					sdcVo.setBtnUpdateUseFg(insList.get(i).get("btnUpdateUseFg").toString());	/** 저장사용권한유무 */
					sdcVo.setBtnDeleteUseFg(insList.get(i).get("btnDeleteUseFg").toString());	/** 삭제사용권한유무 */
					sdcVo.setLogInEmpNo(sessionVO.getUserNo());									/** 로그인사원번호 */

					targetVo.setCSCROM03DSSDCVO(sdcVo);

					resultCnt = CSCROM03.getPrgmRoleCnt(targetVo);								/** 프로그램 등록 여부 확인 */

					// operation값에 따라 등록, 수정 분기
					if("I".equals(operation)) {
						if(resultCnt > 0) {
							CSCROM03U01OutVO resultCSCROM03I01 = CSCROM03.modifyCSCROM03U01(targetVo);
							model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM03I01.getRsltCd());		/** 결과코드 */
							model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM03I01.getRsltCntn());	/** 결과메세지 */

						}else {
							CSCROM03U01OutVO resultCSCROM03I01 = CSCROM03.registerCSCROM03U01(targetVo);
							model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM03I01.getRsltCd());		/** 결과코드 */
							model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM03I01.getRsltCntn());	/** 결과메세지 */
						}
					}else {
						CSCROM03U01OutVO resultCSCROM03U02 = CSCROM03.modifyCSCROM03U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM03U02.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM03U02.getRsltCntn());	/** 결과메세지 */
					}
				}

			}

			// 삭제
			if(delList != null && !delList.isEmpty()) {

				for(int i=0; i < delList.size(); i++) {
					String operationD = delList.get(i).get("operation").toString();			/** I:등록, U:수정, D:삭제 */

					sddVo.setRoleNo(delList.get(i).get("roleNo").toString());					/** 역할번호 */
					sddVo.setPrgmNo(delList.get(i).get("prgmNo").toString());					/** 프로그램번호 */
					sddVo.setMenuReadFg(delList.get(i).get("menuReadFg").toString());			/** 메뉴조회여부 */
					//sddVo.setUseDgre(delList.get(i).get("useDgre").toString());				/** 사용등급 */
					sdcVo.setBtnSelectUseFg(insList.get(i).get("btnSelectUseFg").toString());	/** 조회사용권한유무 */
					sdcVo.setBtnInsertUseFg(insList.get(i).get("btnInsertUseFg").toString());	/** 추가사용권한유무 */
					sdcVo.setBtnUpdateUseFg(insList.get(i).get("btnUpdateUseFg").toString());	/** 저장사용권한유무 */
					sdcVo.setBtnDeleteUseFg(insList.get(i).get("btnDeleteUseFg").toString());	/** 삭제사용권한유무 */
					sddVo.setUseDgre("");														/** 사용등급 */
					sddVo.setLogInEmpNo(sessionVO.getUserNo());									/** 로그인사원번호 */

					targetVo.setCSCROM03DSSDDVO(sddVo);

					if("D".equals(operationD)) {
						CSCROM03U01OutVO resultCSCROM03D01 = CSCROM03.deleteCSCROM03U01(targetVo);
						model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultCSCROM03D01.getRsltCd());		/** 결과코드 */
						model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultCSCROM03D01.getRsltCntn());	/** 결과메세지 */
					}
				}
			}

			LOGGER.info("##### CSCROM03Controller CSCROM03U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### CSCROM03Controller CSCROM03U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
