package hanalife.framework.comm.spring;

import org.aspectj.lang.ProceedingJoinPoint;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.util.StopWatch;

public class LogAdvisor {

	private static final Logger LOGGER = LoggerFactory.getLogger(LogAdvisor.class);
	
	public Object doAround (ProceedingJoinPoint joinPoint) throws Throwable {
		Object returnObject = null;
		StopWatch stopWatch = new StopWatch();
		
		try {
			stopWatch.start();
			if (LOGGER.isDebugEnabled()) {
				String simpleName = joinPoint.getTarget().getClass().getSimpleName();
				StringBuffer logStringBuffer = new StringBuffer().append("(@) ")
																.append(simpleName.indexOf("ServiceImpl")>=0?"  ":"")
																.append(simpleName).append(".")
																.append(joinPoint.getSignature().getName()).append(" - started");
				printLog(joinPoint, logStringBuffer);
			}
			
			returnObject = joinPoint.proceed();
			
		} catch (Exception e) {
			//e.printStackTrace();
			throw e;
		} finally {
			stopWatch.stop();
			if (LOGGER.isDebugEnabled()) {
				String simpleName = joinPoint.getTarget().getClass().getSimpleName();
				StringBuffer logStringBuffer = new StringBuffer().append("(@) ")
																.append(simpleName.indexOf("ServiceImpl")>=0?"  ":"")
																.append(joinPoint.getTarget().getClass().getSimpleName()).append(".")
																.append(joinPoint.getSignature().getName()).append(" - finished")
																.append(" (execution time: ")
																.append(stopWatch.getTotalTimeMillis())
																.append(" ms)");
				printLog(joinPoint, logStringBuffer);
			}
		}
		
		return returnObject;
	}
	
	private void printLog(ProceedingJoinPoint joinPoint, StringBuffer logStringBuffer) {
		//String packageName = joinPoint.getTarget().getClass().getPackage().getName();
		//LOGGER.debug(packageName);
		
		LOGGER.debug(logStringBuffer.toString());//Normal
	}
}
