package hanalife.framework.comm.util;

import java.io.IOException;
import java.io.StringWriter;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.UUID;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;

import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;

/**
 * 공통 유틸 관련 개발자 : <a href="mailto:yhk1712@kico.co.kr">김윤환</a> 생성일자 : 2020. 07.
 * 29.
 */
public class CommUtil {
	private static final Logger LOGGER = LoggerFactory.getLogger(CommUtil.class);
	/**
	 * 19자리 유니크 글자 가져오기
	 *
	 * @return String
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 09. 15.
	 */
	public static String uniqName() {
		return DateUtil.toDateString(new Date(), "ddHHmmssSSS") + UUID.randomUUID().toString().substring(0, 3);
	}

	/**
	 * 22자리 유니크 글자 가져오기
	 *
	 * @return String
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 09. 29.
	 */
	public static String uniqExcelName() {
		return DateUtil.toDateString(new Date(), "ddHHmmssSSS") + UUID.randomUUID().toString().substring(0, 6);
	}

	/**
	 * 브라우저 구하기
	 *
	 * @return String
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 09. 15.
	 */
	public static String browser(String userAgent) {
		String strUserAgent = userAgent.toUpperCase();
		if (strUserAgent.indexOf("MSIE") > -1 || strUserAgent.indexOf("TRIDENT") > -1) {
			return "MSIE";
		} else if (strUserAgent.indexOf("CHROME") > -1) {
			return "Chrome";
		} else if (strUserAgent.indexOf("OPERA") > -1) {
			return "Opera";
		}
		return "Firefox";
	}

	/**
	 * 파일 다운로드시 파일명 인코딩
	 *
	 * @return String
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 09. 15.
	 */
	public static String getDisposition(String filename, String browser) throws UnsupportedEncodingException {
		String dispositionPrefix = "attachment;filename=";
		String encodedFilename = null;
		if (browser.equals("MSIE")) {
			encodedFilename = URLEncoder.encode(filename, "UTF-8").replaceAll("\\+", "%20");
		} else if (browser.equals("Firefox")) {
			encodedFilename = "\"" + new String(filename.getBytes("UTF-8"), "8859_1") + "\"";
		} else if (browser.equals("Opera")) {
			encodedFilename = "\"" + new String(filename.getBytes("UTF-8"), "8859_1") + "\"";
		} else if (browser.equals("Chrome")) {
			StringBuffer sb = new StringBuffer();
			for (int i = 0; i < filename.length(); i++) {
				char c = filename.charAt(i);
				if (c > '~') {
					sb.append(URLEncoder.encode("" + c, "UTF-8"));
				} else {
					sb.append(c);
				}
			}
			encodedFilename = sb.toString();
		}
		return dispositionPrefix + encodedFilename;
	}

	/**
	 * 클라이언트 접속 IP 가져오기
	 *
	 * @return String
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 09. 15.
	 */
	public static String getClientIP(HttpServletRequest request) {

		String ip = request.getHeader("X-Forwarded-For");

		if (ip == null) {
			ip = request.getHeader("Proxy-Client-IP");
		}
		if (ip == null) {
			ip = request.getHeader("WL-Proxy-Client-IP");
		}
		if (ip == null) {
			ip = request.getHeader("HTTP_CLIENT_IP");
		}
		if (ip == null) {
			ip = request.getHeader("HTTP_X_FORWARDED_FOR");
		}
		if (ip == null) {
			ip = request.getRemoteAddr();

		}

		return ip;
	}

	/**
	 * 웹 디렉터리 외 별도 디렉터리에 저장하여 사용자가 URL을 통해 접근하지 못하도록 하기위한 파일 필터.
	 *
	 * @return Boolean
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 10. 15.
	 */
	public static Boolean chkFileFilter(String strAtacFileNum){
		boolean fileChk = false;
		if(StringUtil.isEmpty(strAtacFileNum)
				|| strAtacFileNum.indexOf("..") > -1
				|| strAtacFileNum.indexOf("/") > -1
				|| strAtacFileNum.indexOf("\'") > -1
				|| strAtacFileNum.indexOf("%") > -1) {

			fileChk = true;
		}
		return fileChk;
	}

	/**
	 * 웹 디렉터리 외 별도 디렉터리에 저장하여 사용자가 URL을 통해 접근하지 못하도록 하기위한 파일 필터.
	 *
	 * @return Boolean
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 10. 15.
	 */
	public static Boolean chkFilePathFilter(String strAtacFileNum){
		boolean filePathChk = false;
		if(StringUtil.isEmpty(strAtacFileNum)
				|| strAtacFileNum.indexOf("../") > -1
				|| strAtacFileNum.indexOf("..\'") > -1
				|| strAtacFileNum.indexOf("%") > -1) {

			filePathChk = true;
		}
		return filePathChk;
	}

	/**
	 * 현재 작업 디렉토리 경로
	 * 윈도우일 경우에는 C: 또는 그외 경로
	 * @return String
	 * @author <a href="mailto:yhk1712@kico.co.kr">김윤환</a>
	 * @since 2020. 09. 29.
	 */
	public static String baseDriver(){
		String os = System.getProperty("os.name");
		if( os.toLowerCase().indexOf("windows")!=-1){
			return System.getProperty("user.dir").substring(0, 2);
		}
		return "";
	}

	public static String getPrintStackTrace(Exception e) {

		StringWriter errors = new StringWriter();
		//e.printStackTrace(new PrintWriter(errors));

		return errors.toString();

	}

	/**
	 * param 데이터들을 URLDecoder.decode 조치
	 *
	 * @param Map<String, Object>
	 *
	 */
	public static void paramUrlDecoder(Map<String, Object> param) throws Exception{

		try {
			Iterator<String> keys = param.keySet().iterator();
			while (keys.hasNext()) {
				String key = keys.next();
				param.put(key, URLDecoder.decode(String.valueOf(param.get(key)),"UTF-8"));
			}
		} catch (Exception e) {
			throw e;
		}
	}
	/**
	 * Client 정보 가져오기
	 *
	 * @param HttpServletRequest
	 *
	 */
	public static Map<String, Object> getClientInfo(HttpServletRequest request) throws Exception{
		Map<String, Object> mapReturn = new HashMap<String, Object>();

		String strAgent = request.getHeader("USER-AGENT").toString().toLowerCase();
		String strOsInfo = getClientOs(strAgent);
		String strBrowerInfo = browser(strAgent);
		String strIp = getClientIP(request);

		mapReturn.put("OS", strOsInfo);
		mapReturn.put("BROWER", strBrowerInfo);
		mapReturn.put("IP", strIp);

		return mapReturn;
	}
	/**
	 * Client OS 정보 가져오기
	 *
	 * @param String
	 *
	 */
	public static String getClientOs(String strAgent) throws Exception{
		String strOs  = "Other";

		if(strAgent.indexOf("windows 95") >= 0)				{	strOs = "Windows 95";			}
		else if(strAgent.indexOf("windows 98") >= 0)		{	strOs = "Windows 98";			}
		else if(strAgent.indexOf("windows nt 4.0") >= 0)	{	strOs = "Windows NT";			}
		else if(strAgent.indexOf("windows nt 5.0") >= 0)	{	strOs = "Windows 2000";			}
		else if(strAgent.indexOf("windows nt 5.1") >= 0)	{	strOs = "Windows XP";			}
		else if(strAgent.indexOf("windows nt 6.0") >= 0)	{	strOs = "Windows Vista";		}
		else if(strAgent.indexOf("windows nt 6.1") >= 0)	{	strOs = "Windows 7";			}
		else if(strAgent.indexOf("windows nt 6.2") >= 0)	{	strOs = "Windows 8";			}
		else if(strAgent.indexOf("windows nt 10.0") >= 0)	{	strOs = "Windows 10";			}
		else if(strAgent.indexOf("android") >= 0)			{	strOs = "Android";				}
		else if(strAgent.indexOf("iphone") >= 0)			{	strOs = "IPhone";				}
		else if(strAgent.indexOf("mac") >= 0)				{	strOs = "mac";					}
		else if(strAgent.indexOf("linux") >= 0)				{	strOs = "Linux";					}

		return strOs;
	}

    /**
     * printStackTrace 를 Log4j 로 출력해준다.
     *
     * @description :
     * @param e
     * @return
     */
    public static String printStackTraceForLog4j(Exception e) {
    	StringBuffer result = new StringBuffer();
    	StackTraceElement[] element = e.getStackTrace();
    	for (int i=0; i<element.length; i++) {
    		result.append("\r\n	[!] at ")
    				.append(element[i].getClassName())
    				.append(".")
    				.append(element[i].getMethodName())
    				.append(":")
    				.append(element[i].getLineNumber());
    	}

    	return result.toString();
    }

    /**
	 * 개행 코드가 들어간 문서를 표시할때 태그에 손상없이 보이기 위한 메서드
	 *
	 * @param strString
	 * @return HTML 태그를 치환한 문자열
	 */
	public static String checkHtmlView(String strString) {
		String strNew = "";

		StringBuffer strTxt = new StringBuffer("");

		char chrBuff;
		int len = strString.length();

		for (int i = 0; i < len; i++) {
			chrBuff = strString.charAt(i);

			switch (chrBuff) {

				case 10:
					strTxt.append("<br>");
					break;

				//break;
				default:
					strTxt.append(chrBuff);
			}
		}

		strNew = strTxt.toString();

		return strNew;
	}

    public static String byteToString(byte[] byteArr, int startIndex, int cutLenght, String charSet) {

    	charSet = charSet == null ? "UTF-8" : charSet;

    	byte[] newByte = new byte[cutLenght];

    	int count = 0;

    	for(int i = startIndex ; i < startIndex + cutLenght ; i++) {
    		newByte[count++] = byteArr[i];
    	}

    	try {
			return new String(newByte, charSet);
		} catch (UnsupportedEncodingException e) {
//			e.printStackTrace();
			LOGGER.debug(e.toString());

			return "";
		}
    }

    /**
	 * @description : 마스킹 처리
	 * @param value
	 * @param type
	 * @return
	 */
	public static String setMasking(String value, String type) {
    	String retValue = value;

    	// value에 '-'이 존재할 경우 제거
    	if(retValue.indexOf("-") > 0) {
    		retValue = retValue.replaceAll("-", "");
    	}

    	if(type == "01") {	//계좌번호 및 카드번호
    		String mask = "";
    		//마스킹할 자리수만큼 '*' 증가
    		for(int i=0; i<retValue.substring(5).length(); i++) {
    			mask += "*";
    		}

    		if(retValue.length() > 5) {
    			retValue = retValue.substring(0,5)+mask;
    		}

    	} else if(type == "02") {	//전화번호
    		if(retValue.length() == 11) {
    			retValue = retValue.substring(0,3)+"-"+retValue.substring(3, 7)+"-"+"****";
    		} else if(retValue.length() == 10) {
    			retValue = retValue.substring(0,3)+"-"+retValue.substring(3, 6)+"-"+"****";
    		} else if(retValue.length() == 4) {
    			retValue = "****";
    		}
    	} else if(type == "03") {		//이름
    		/*if(retValue.length() >= 3) {
    			retValue = retValue.substring(0, retValue.length()-2)+"*"+retValue.substring(retValue.length()-1);
    		} else if(retValue.length() == 2) {
    			retValue = retValue.substring(0,1)+"*";
    		}*/
    	} else if(type == "04") {	//주민번호
    		if(retValue.length() == 13) {
    			retValue = retValue.substring(0, 6)+"-"+retValue.substring(6, 7)+"******";
    		} else if(retValue.length() == 7) {
    			retValue = retValue.substring(0, 1)+"******";
    		}
    	} else if(type == "05") {	//이메일
    		String emailId = retValue.substring(0, retValue.indexOf("@"));	//이메일 아이디
    		String emailAddr = retValue.substring(retValue.indexOf("@"));	//이메일 도메인

    		if(emailId.length() > 3) {	//이메일 아이디가 4자리 이상인 경우
    			emailId = emailId.substring(0, emailId.length()-3) + "***";
    		} else if(emailId.length() == 2) {	//이메일 아이디가 2자리인 경우
    			emailId = "**";
    		} else if(emailId.length() == 1) {	//이메일 아이디가 1자리인 경우
    			emailId = "*";
    		} else {							//이메일 아이디가 3자리인 경우
    			emailId = "***";
    		}

    		retValue = emailId+emailAddr;
    	}

    	return retValue;
    }

	/**
	 * 크로스 사이트 스크립팅 방지
	 * @param str
	 * @return
	 */
	public static String removeXSS(String str) {
        str = str.replaceAll("\"","&gt;");
        str = str.replaceAll("&", "&amp;");
        str = str.replaceAll("<", "&lt;");
        str = str.replaceAll(">", "&gt;");
        str = str.replaceAll("%00", null);
        str = str.replaceAll("\"", "&#34;");
        str = str.replaceAll("\'", "&#39;");
        str = str.replaceAll("%", "&#37;");
        str = str.replaceAll("../", "");
        str = str.replaceAll("..\\\\", "");
        str = str.replaceAll("./", "");
        str = str.replaceAll("%2F", "");
        str = str.replaceAll("document", "");
        str = str.replaceAll("cookie", "");
        str = str.replaceAll("forms", "");

	    return str;
	}

	/**
	 * XXS 방지처리
	 * @param value
	 * @return
	 */
	public static String cleanXXS(final String value) {
		return StringUtils.replaceEach(value, new String[] { "&;", "<", ">", "'", "\"", "eval\\((.*)\\)", "[\\\"\\\'][\\s]*javascirpt:(.*)[\\\"\\\']", "script" }, new String[] { "&amp;", "&lt;",
				"&gt;", "&#039;", "&quot;", StringUtils.EMPTY, "\"\"", StringUtils.EMPTY });
	}

	/**
	 * XXS 방지처리 - String Array 를 받아서 XXS 방지 처리 후 String Array return
	 * @param arr
	 * @return
	 */
	public static String[] cleanXXSArr(final String[] arr) {
		for (int i = 0; i < arr.length; i++) {
			arr[i] = cleanXXS(arr[i]);
		}
		return arr;
	}

	/**
	 * Object를 클래스로 변환
	 * @param Object
	 * @param Class<T>
	 * @return <T>
	 */
	public static <T> T ObjectToClass(Object object, Class<T> className) {
		ObjectMapper objectMapper = new ObjectMapper().configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
		return objectMapper.convertValue(object, className);
	}
	
	/*
	 * 파일의 줄수 return
	 */
	public static long getFileLineCount(String filePath) {
		long lineCount =0;
		try {
			lineCount = Files.lines(Paths.get(filePath)).count();
		} catch (IOException e) {
			LOGGER.debug(e.toString());
		}
		return lineCount;
	}
}
