package hanalife.framework.comm.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;

import SCSL.SLBsUtil;
import SCSL.SLDsFile;
import hanalife.c.co.vo.FileInfoVO;
import hanalife.framework.comm.contants.Constants;
import hanalife.framework.comm.exception.HLFLException;
import hanalife.framework.comm.exception.factory.HLFLExceptionFactory;

/**
 *
 * 파일 설명
 * ex) 샘플 사용자 관리 구현
 * <pre>
 * 기능에 대한 구체적인 내용 기술
 * ex) 사용자 생성, 조회, 수정, 삭제
 * </pre>
 *
 * @author 70114
 * @since
 * @version 1.0
 */
public class FileUtil {

	private static final Logger LOGGER = LoggerFactory.getLogger(FileUtil.class);

	/**
	 * 파일정보
	 * @description : 업로드할 파일정보 조회
	 * @param file
	 * @param path 파일경로
	 * @param dtyTrryCd 업무영역코드
	 * @return
	 */
	public static FileInfoVO getFileInfo(MultipartFile file, String dtyTrryCd) {
		//TODO 정해지면 수정
		String path = PropertiesHandler.getInstance().getProperty("data.sfa.upload.file.path");
		FileInfoVO fileInfoVO = new FileInfoVO();

		String actFlPth; // 첨부파일경로
		String actFlNm; // 첨부파일명
		String orglFlNm; // 원본첨부파일명
		String actFlDv; // 첨부파일구분(확장자)
		long actFlVol; // 첨부파일크기

		String formattedValue = (new SimpleDateFormat("yyyyMMddHHmmssSSS", new Locale("ko", "KR"))).format(new Date());
		orglFlNm =  file.getOriginalFilename();
		actFlDv = orglFlNm.substring(orglFlNm.lastIndexOf(".")+1).toLowerCase();
		actFlNm = orglFlNm.substring(0, orglFlNm.lastIndexOf(".")) + "_" + formattedValue + "." + actFlDv;
		String flId = actFlNm.substring(0, actFlNm.lastIndexOf("."));
		actFlVol = file.getSize();
		actFlPth = path + dtyTrryCd + "/";

		fileInfoVO.setFlId(flId);
		fileInfoVO.setActFlPth(actFlPth);
		fileInfoVO.setActFlNm(actFlNm);
		fileInfoVO.setOrglFlNm(orglFlNm);
		fileInfoVO.setActFlDv(actFlDv);
		fileInfoVO.setActFlVol(actFlVol);

		return fileInfoVO;
	}

	/**
	 * 오즈 서식 파일정보
	 * @description : 업로드할 파일정보 조회
	 * @param file
	 * @param path 파일경로
	 * @param dtyTrryCd 업무영역코드
	 * @return
	 */
	public static FileInfoVO getFileInfoOZ(MultipartFile file, String dtyTrryCd) {
		//TODO 정해지면 수정
		String path = PropertiesHandler.getInstance().getProperty("data.sfa.upload.ad.oz.path");
		FileInfoVO fileInfoVO = new FileInfoVO();

		String actFlPth; // 첨부파일경로
		String actFlNm; // 첨부파일명
		String orglFlNm; // 원본첨부파일명
		String actFlDv; // 첨부파일구분(확장자)
		long actFlVol; // 첨부파일크기

		String formattedValue = (new SimpleDateFormat("yyyyMMddHHmmssSSS", new Locale("ko", "KR"))).format(new Date());
		orglFlNm =  file.getOriginalFilename();
		actFlDv = orglFlNm.substring(orglFlNm.lastIndexOf(".")+1).toLowerCase();
		actFlNm = orglFlNm.substring(0, orglFlNm.lastIndexOf(".")) + "_" + formattedValue + "." + actFlDv;
		String flId = actFlNm.substring(0, actFlNm.lastIndexOf("."));
		actFlVol = file.getSize();
		actFlPth = path + dtyTrryCd + "/";

		fileInfoVO.setFlId(flId);
		fileInfoVO.setActFlPth(actFlPth);
		fileInfoVO.setActFlNm(actFlNm);
		fileInfoVO.setOrglFlNm(orglFlNm);
		fileInfoVO.setActFlDv(actFlDv);
		fileInfoVO.setActFlVol(actFlVol);

		return fileInfoVO;
	}

	/**
	 * apk, ipa, 가이드 서식 파일정보
	 * @description : 업로드할 파일정보 조회
	 * @param file
	 * @param path 파일경로
	 * @return
	 */
	public static FileInfoVO getFileInfoAppVer(MultipartFile file) {
		//TODO 정해지면 수정
		String path = PropertiesHandler.getInstance().getProperty("data.sfa.upload.ad.app.path");
		FileInfoVO fileInfoVO = new FileInfoVO();

		String actFlPth; // 첨부파일경로
		String actFlNm; // 첨부파일명
		String orglFlNm; // 원본첨부파일명
		String actFlDv; // 첨부파일구분(확장자)
		long actFlVol; // 첨부파일크기

		orglFlNm =  file.getOriginalFilename();
		actFlDv = orglFlNm.substring(orglFlNm.lastIndexOf(".")+1).toLowerCase();
		actFlNm = orglFlNm;
		String flId = actFlNm.substring(0, actFlNm.lastIndexOf("."));
		actFlVol = file.getSize();
		actFlPth = path;

		fileInfoVO.setFlId(flId);
		fileInfoVO.setActFlPth(actFlPth);
		fileInfoVO.setActFlNm(actFlNm);
		fileInfoVO.setOrglFlNm(orglFlNm);
		fileInfoVO.setActFlDv(actFlDv);
		fileInfoVO.setActFlVol(actFlVol);

		return fileInfoVO;
	}

	/**
	 * 파일업로드
	 * @description : 지정된 경로로 파일업로드 수행
	 * @param file
	 * @param fileInfoVO
	 */
	public static void upload(MultipartFile file, FileInfoVO fileInfoVO) {
		try {
			String actFlNm = fileInfoVO.getActFlNm(); //서버에 저장할 파일명
			String uploadFolder = fileInfoVO.getActFlPth();

			//경로 생성
			if(!new File(uploadFolder).exists()) {
				File folder = new File(uploadFolder);
				folder.mkdirs();
				Runtime.getRuntime().exec("chmod 755 " + folder);
			}
			File saveFile = new File(uploadFolder + actFlNm);

			file.transferTo(saveFile);

			String SERVER = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
			LOGGER.debug("SERVER : " + SERVER);
			if(Constants.PROD.equals(SERVER) || Constants.UAT.equals(SERVER)|| Constants.DEV.equals(SERVER)) { //DRM해제
				String sourcePath = uploadFolder + actFlNm;
				String destPath = uploadFolder+ actFlNm.substring(0, actFlNm.lastIndexOf(".")) + "_dec." + actFlNm.substring(actFlNm.lastIndexOf(".")+1);

				String rslt = decnDrmFile(sourcePath, destPath);
				LOGGER.debug("sourcePath : " + sourcePath);
				LOGGER.debug("destPath : " + destPath);
				if(!StringUtils.equals("File is not Encrypted", rslt)){ //FIXME
					removeFile(fileInfoVO);
					renameByPath(destPath, fileInfoVO.getActFlNm());
					LOGGER.debug("변경함 :************************* ");
				}

				SFTPUtil.putSftp(uploadFolder+actFlNm , uploadFolder); //SFTP로 전송
			}
		}  catch (Exception e) {
			//e.printStackTrace();
			new HLFLException("파일 업로드시 오류가 발생하였습니다.");
		}
	}


	/**
	 * 파일명변경
	 * @description : 지정된 파일명으로 변경
	 * @param file
	 * @param fileInfoVO
	 */
	private static void renameByPath(String flNmPth, String rename) {

		File file = new File(flNmPth);
		if(file.exists()) {
			LOGGER.debug("파일존재");
			LOGGER.debug(flNmPth.substring(0, flNmPth.lastIndexOf('/')+1)+ rename);
			file.renameTo(new File(flNmPth.substring(0, flNmPth.lastIndexOf('/')+1)+ rename));
		}else {
			throw HLFLExceptionFactory.create("info.nodata.msg");
		}
	}


	/**
	 * 파일 다운로드
	 * @description : 지정된 경로에 해당하는 파일을 다운
	 * @param response
	 * @param fileInfoVO
	 */
	public static void download(HttpServletResponse response, FileInfoVO fileInfoVO) {
		FileInputStream fileInputStream = null;
		OutputStream out = null;
		try {

			String path = fileInfoVO.getActFlPth()+fileInfoVO.getActFlNm();
			String orglFlNm = fileInfoVO.getOrglFlNm();

			LOGGER.debug("download start!!!!");
			LOGGER.debug("path : " + path);
			LOGGER.debug("orglFlNm1 : " + orglFlNm);

			File file = new File(path);
			orglFlNm = URLEncoder.encode(orglFlNm,"UTF-8").replaceAll("\\+","%20"); //한글파일명 처리
			LOGGER.debug("orglFlNm2 : " + orglFlNm);

			String mimeType = "application/octet-stream";

			response.setContentType(mimeType);

			response.setHeader("Content-Disposition", "attachment;filename=" + orglFlNm);
			fileInputStream = new FileInputStream(path);
			out = response.getOutputStream();

			int read = 0;
			byte[] buffer = new byte[1024];
			while((read = fileInputStream.read(buffer)) != -1) {
				out.write(buffer, 0, read);
			}

		}catch(FileNotFoundException e) {
			throw HLFLExceptionFactory.create("info.nodata.msg");
		}catch(Exception e) {
			throw HLFLExceptionFactory.create("fail.common.msg");
		}finally {
			if(fileInputStream != null) {
				try {
					fileInputStream.close();
				} catch (IOException e) {
					throw HLFLExceptionFactory.create("fail.common.msg");
				}
			}
			if(out != null) {
				try {
					out.close();
				} catch (IOException e) {
					throw HLFLExceptionFactory.create("fail.common.msg");
				}
			}

		}
	}

	/**
	 * 파일삭제
	 * @description : 지정된 경로에 해당 파일을 삭제한다.
	 * @param fileInfoVO
	 */
	public static void removeFile(FileInfoVO fileInfoVO) {
		String path = fileInfoVO.getActFlPth()+fileInfoVO.getActFlNm();

		File file = new File(path);
		if(file.exists()) {
			file.delete();
		}else {
			//throw HLFLExceptionFactory.create("info.nodata.msg");
		}

		SFTPUtil.removeSftp(path); //Sftp 삭제

	}


	/**
	 * 파일삭제
	 * @description :
	 * @param flNmPth 파일명을 포함한 경로명
	 */
	public static void removeFileByPath(String flNmPth) {
		String path = flNmPth;

		File file = new File(path);
		if(file.exists()) {
			file.delete();
		}else {
			//throw HLFLExceptionFactory.create("info.nodata.msg");
		}

		SFTPUtil.removeSftp(path); //Sftp 삭제
	}

//	private String getConvertedFileName(MultipartFile file) {
//		String originalFilename = file.getOriginalFilename();
//		String fileNameExtension = originalFilename.substring(originalFilename.lastIndexOf(".")+1).toLowerCase();
//
//		SimpleDateFormat formatter_file = new SimpleDateFormat("yyyyMMddHHmmssSSS", new Locale("ko", "KR"));
//		String formattedValue_file = formatter_file.format(new Date());
//		String convertedFileName = "FILE-" + formattedValue_file + "-" ;
//
//		return convertedFileName;
//	}

	/**
	 *
	 * @description : DRM암호화
	 * @param orglFlNmPth 원본파일경로(파일명포함)
	 * @param tgtFlNmPth 대상파일경로(파일명포함)
	 * @return
	 */
	public static String encnDrmFile(String orglFlNmPth, String tgtFlNmPth) {
		//방화벽이 PROD,UAT에만 뚫려서 PROD,UAT에서만 실행 가능

		String result = null;

		//TODO 정해지면 수정
		String SERVER = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
		String ROOT = Constants.PROD.equals(SERVER)?"/sorc/sfa"
						:Constants.UAT.equals(SERVER)?"/sorc/sfa":"";

		SLDsFile slFile = new SCSL.SLDsFile();
		slFile.SettingPathForProperty("/app/softcamp/keymanager/lib/softcamp.properties");

		int retVal = slFile.DSAPIEncFileV2(
			"/app/softcamp/keymanager/keyfile/key.sc",// 키 파일 경로
			"JJ00002", //범주ID
		      "하나생명",// 범주이름
		      "하나로",// 시스템 이름
		      orglFlNmPth,
		      tgtFlNmPth,
			1);

		result = String.valueOf(retVal);
		return result;

	}

	/**
	 *
	 * @description : DRM복호화
	 * @param orglFlNmPth 원본파일경로(파일명포함)
	 * @param tgtFlNmPth 대상파일경로(파일명포함)
	 * @return
	 */
	public static String decnDrmFile(String orglFlNmPth, String tgtFlNmPth) {
		//방화벽이 PROD,UAT에만 뚫려서 PROD,UAT에서만 실행 가능

		String SERVER = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
		String ROOT = Constants.PROD.equals(SERVER)?"/sorc/sfa"
						:Constants.UAT.equals(SERVER)?"/sorc/sfa":"";

		String result = null;

		SLDsFile slFile = new SCSL.SLDsFile();
		SLBsUtil slUtil = new SCSL.SLBsUtil();

		slFile.SettingPathForProperty("/app/softcamp/keymanager/lib/softcamp.properties");
		int encrypted = slUtil.isEncryptFile(orglFlNmPth);
		if (encrypted == 1) {
			int retVal = slFile.CreateDecryptFile(
					        "/app/softcamp/keymanager/keyfile/key.sc", //키 파일 경로
					        "JJ00002", //범주ID
					        orglFlNmPth,
					        tgtFlNmPth
						);
			result = String.valueOf(retVal);
		} else {
			result = "File is not Encrypted";
		}
		LOGGER.debug("decnDrmFile result : " + result);
		return result;
	}

	/**
	 * 파일 다운로드
	 * @description : 지정된 경로에 해당하는 파일을 다운
	 * @param response
	 * @param fileInfoVO
	 */
	public static void zipDownload(HttpServletResponse response, List<FileInfoVO> fileInfoList, String fileName) {

		ZipOutputStream zipOutputStream = null;
		FileInputStream fileInputStream = null;

		response.setContentType("application/zip");
		response.setHeader("Content-Disposition", "attachment;filename=" + fileName + ".zip");

		try {
			zipOutputStream = new ZipOutputStream(response.getOutputStream());

			LOGGER.debug("zipDownload start!!!!");

			for (FileInfoVO fileInfoVO : fileInfoList) {



				String path = fileInfoVO.getActFlPth()+fileInfoVO.getActFlNm();
				String orglFlNm = fileInfoVO.getOrglFlNm();

				orglFlNm = URLEncoder.encode(orglFlNm,"UTF-8").replaceAll("\\+","%20"); //한글파일명 처리

				File file = new File(path);

				if(file.exists()) {
					//본래 파일명 유지, 경로제외 파일압축을 위해 new File로
			        ZipEntry zipEntry = new ZipEntry(orglFlNm);
			        zipOutputStream.putNextEntry(zipEntry);

					fileInputStream = new FileInputStream(path);
					LOGGER.debug("zipDownload each start!!!!");
					int read = 0;
					byte[] buffer = new byte[1024];
					while((read = fileInputStream.read(buffer)) != -1) {
						zipOutputStream.write(buffer, 0, read);
					}

					zipOutputStream.closeEntry();
					fileInputStream.close();
				} else {
					throw HLFLExceptionFactory.create("info.nodata.msg");
				}


			}

			zipOutputStream.close();

			LOGGER.debug("zipDownload end!!!!");

		}catch(Exception e) {
			throw HLFLExceptionFactory.create("fail.common.msg");
		}finally {
			if(fileInputStream != null) {
				try {
					fileInputStream.close();
				} catch (IOException e) {
					throw HLFLExceptionFactory.create("fail.common.msg");
				}
			}
			if(zipOutputStream != null) {
				try {
					zipOutputStream.close();
				} catch (IOException e) {
					throw HLFLExceptionFactory.create("fail.common.msg");
				}
			}

		}
	}
}
