package hanalife.framework.comm.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Vector;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.jcraft.jsch.Channel;
import com.jcraft.jsch.ChannelSftp;
import com.jcraft.jsch.JSch;
import com.jcraft.jsch.JSchException;
import com.jcraft.jsch.Session;
import com.jcraft.jsch.SftpException;

import hanalife.framework.comm.exception.HLFLException;
import hanalife.framework.comm.exception.factory.HLFLExceptionFactory;

/**
 * 
 * SFTP Util
 * 
 * @author 70114
 * @since  
 * @version 1.0
 */
public class SFTPClient {

	private static final Logger LOGGER = LoggerFactory.getLogger(SFTPClient.class);

    private Session session = null;
    private Channel channel = null;
    private ChannelSftp channelSftp = null;
	
	
	private void init(String userName, String host, int port, String password) {
        //접속 초기화
        
        JSch jSch = new JSch();
        try {
        session = jSch.getSession(userName, host, port);
        session.setPassword(password);

        // session 관련 설정정보를 위한 프로퍼티
        java.util.Properties config = new java.util.Properties();
        // 접속 시 hostkeychecking 여부 - 호스트 정보 검사하지 않는다.
        config.put("StrictHostKeyChecking", "no");
        session.setConfig(config);
        session.connect();

        //sftp로 접속
        channel = session.openChannel("sftp");
        channel.connect();
        } catch (JSchException e) {
            e.printStackTrace();
            throw new HLFLException("SFTP 초기화에러");
        }
        channelSftp = (ChannelSftp) channel;
	}
	
	public void putSftp(String localFilePath, String remotePath, String host, int port, String userName, String password) {
		LOGGER.debug("localFilePath : " + localFilePath);
		LOGGER.debug("remotePath : " + remotePath);
		LOGGER.debug("host : " + host);
		LOGGER.debug("port : " + port);
		LOGGER.debug("userName : " + userName);
		LOGGER.debug("password : " + password);
		
        //접속 초기화
		this.init(userName, host, port, password);
        //접속초기화END

		//디렉토리 생성
        this.mkdir(remotePath);
        
        LOGGER.debug("localFilePath : " + localFilePath);
        File uploadFile = new File(localFilePath); // 파일 객체 생성
        boolean isUploaded = false;
        FileInputStream fis = null;

        try {
            fis = new FileInputStream(uploadFile);
            channelSftp.cd(remotePath);
            channelSftp.put(fis, uploadFile.getName());
            
            // 업로드했는지 확인
            //if (exists(remotePath+"/"+uploadFile.getName())) {
            if (exists(remotePath+uploadFile.getName())) {
                isUploaded = true;
            }
        } catch (SftpException e) {
            e.printStackTrace();
            throw new HLFLException("putSftp SFTP 에러");
        } catch (FileNotFoundException e) {
            //e.printStackTrace();
            throw new HLFLException("putSftp FileNotFound 에러");
        } finally {
            try {
                fis.close();
                // 연결/자원 해제
                channelSftp.quit();
                session.disconnect();
            } catch (IOException e) {
            	throw HLFLExceptionFactory.create("fail.common.msg");
            }
        }
        LOGGER.debug("isUploaded : " + isUploaded);
	}
	
	public void removeSftp(String remoteFilePath, String host, int port, String userName, String password) {
        //접속 초기화
		this.init(userName, host, port, password);
        //접속초기화END
        
        //boolean isUpload = this.upload(remotePath, uploadFile); // 업로드
        boolean isUploaded = false;

        String remotePath = remoteFilePath.substring(0, remoteFilePath.lastIndexOf("/"));
        String fileName = remoteFilePath.substring(remoteFilePath.lastIndexOf("/")+1);
        try {
        	LOGGER.debug("remotePath : " + remotePath);
        	LOGGER.debug("fileName : " + fileName);
        	if (exists(remoteFilePath)) {
        		channelSftp.cd(remotePath);
            	channelSftp.rm(fileName);
            }
            
            // 업로드했는지 확인
            if (!exists(remoteFilePath)) {
            	LOGGER.debug("삭제됨");
            }
        } catch (SftpException e) {
            e.printStackTrace();
            throw new HLFLException("removeSftp SFTP 에러");
        } finally {
            // 연결/자원 해제
            channelSftp.quit();
            session.disconnect();
        }
        LOGGER.debug("isUploaded : " + isUploaded);
	}

	
	public void renameSftp(String filePath, String rename, String host, int port, String userName, String password) {
        //접속 초기화
		this.init(userName, host, port, password);
        //접속초기화END
        
        boolean isUploaded = false;

        String path = filePath.substring(0, filePath.lastIndexOf("/"));
        String fileName = filePath.substring(filePath.lastIndexOf("/")+1);
        try {
        	LOGGER.debug("path : " + path);
        	LOGGER.debug("fileName : " + fileName);
        	
            channelSftp.cd(path);
            channelSftp.rename(fileName, rename);
            
            // 변경했는지 확인
            if (exists(path+"/"+rename)) {
            	LOGGER.debug("변경됨");
            }
            
        } catch (SftpException e) {
            e.printStackTrace();
            throw new HLFLException("renameSftp SFTP 에러");
        } finally {
            // 연결/자원 해제
            channelSftp.quit();
            session.disconnect();
        }
        LOGGER.debug("isUploaded : " + isUploaded);
	}
	
    /**
     * 디렉토리 생성
     *
     * @param dir 이동할 주소
     * @param newDirName 생성할 디렉토리명
     */
    private void mkdir(String remotePath) {
    	LOGGER.debug("mkdir start!!!!!!");
    	LOGGER.debug("remotePath : " + remotePath);
    	String[] folders = remotePath.split("/");
    	LOGGER.debug("folders : " + folders);
    	String remoteTempPath = "";
    	
    	if (!exists(remotePath)) {
    		LOGGER.debug("notexists");
	    	for(String folder : folders) {
	    		LOGGER.debug("folder : " + folder);
	    		if(StringUtils.isNotBlank(folder)) {
	    			remoteTempPath += "/" + folder;
	    			LOGGER.debug("remoteTempPath : " + remoteTempPath);
	    			boolean flag = true;
	    			try {
	    				channelSftp.cd(remoteTempPath);
	    			}catch (SftpException e) {
	    				e.printStackTrace();
						flag = false;
					}
	    			LOGGER.info("change working directory : " + remoteTempPath + "-->" + (flag?"SUCCESS":"FAIL"));
	    			if(!flag) {
	    				try {
	    					channelSftp.mkdir(remoteTempPath);
	    					flag = true;
	    				}catch (SftpException e) { 
	    					e.printStackTrace();
	    					throw new HLFLException("mkdir 에러");
	    				}
	    				LOGGER.info("make directory : " + remoteTempPath + "-->" + (flag?"SUCCESS":"FAIL"));
	    			}
	    		}
	    	}
    	}
    	
    }
    
    /**
     * 디렉토리( or 파일) 존재 여부
     * @param path 디렉토리 (or 파일)
     * @return
     */
    private boolean exists(String path) {
        Vector res = null;
        try {
            res = channelSftp.ls(path);
        } catch (SftpException e) {
            if (e.id == ChannelSftp.SSH_FX_NO_SUCH_FILE) {
                return false;
            }
        }
        return res != null && !res.isEmpty();
    }
    
}
