package hanalife.framework.comm.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import hanalife.framework.comm.exception.HLFLException;
import hanalife.framework.comm.vo.UserSessionVO;

/**
 *
 * session Util
 * <pre>
 * session에 대한 attribute set, get 제공
 * </pre>
 *
 * @author 70114
 * @since  2022.07.07
 * @version 1.0
 */
public class SessionUtil {
	private static final Logger LOGGER = LoggerFactory.getLogger(SessionUtil.class);

	/**
	 *
	 * @description : attribute 값을 가져오기 위한 method
	 * @param name
	 * @return
	 * @throws Exception
	 */
	public static Object getAttribute(String name) throws HLFLException {
		return RequestContextHolder.getRequestAttributes().getAttribute(name, RequestAttributes.SCOPE_SESSION);
	}

	/**
	 *
	 * @description : attribute 등록(설정) method
	 * @param name
	 * @param object
	 * @return
	 * @throws Exception
	 */
	public static void setAttribute(String name, Object object) throws HLFLException {
		RequestContextHolder.getRequestAttributes().setAttribute(name, object, RequestAttributes.SCOPE_SESSION);
	}

	/**
	 *
	 * @description : 설정한 attribute 삭제
	 * @param name
	 * @throws Exception
	 */
	public static void removeAttribute(String name) throws HLFLException{
		RequestContextHolder.getRequestAttributes().removeAttribute(name, RequestAttributes.SCOPE_SESSION);
	}

	/**
	 *
	 * @description : Session 전체초기화
	 * @param name
	 * @throws Exception
	 */
	public static void invalidate() throws HLFLException{
		ServletRequestAttributes servletRequestAttributes =  (ServletRequestAttributes) RequestContextHolder.currentRequestAttributes();
		servletRequestAttributes.getRequest().getSession().invalidate();
	}

	/**
	 *
	 * @description : Session Id 조회
	 * @param name
	 * @throws Exception
	 */
	public static String getSessionId() throws HLFLException{
		ServletRequestAttributes servletRequestAttributes =  (ServletRequestAttributes) RequestContextHolder.currentRequestAttributes();
		return servletRequestAttributes.getRequest().getSession().getId();
	}

	/**
	 * 세션에서 로그인한 설계사 사번을 리턴
	 * @description :
	 * @return
	 */
	public static String getUserId() {
		String register = "";

		//TODO 정해지면 수정
//		if (SessionUtil.getAttribute("userSession") != null) {
//			UserSessionVO userSessionVO = (UserSessionVO)SessionUtil.getAttribute("userSession");
//			register = StringUtil.reqNvl(userSessionVO.getUsrId());
//		} else {
//			String serverMode = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
//			if ("LOCAL".equals(serverMode)) {
//				register = "0882760";
//			} else {
//				new HLFLException("로그인 세션 정보가 없습니다.");
//			}
//		}
		LOGGER.debug("SessionUtil.getUserId() 호출");

		return register;
	}
	/**
	 * 세션에서 로그인한 설계사 사번을 리턴
	 * @description :
	 * @return
	 */
	public static UserSessionVO getUserSession() throws HLFLException {

		UserSessionVO rtnUserSessionVO = null;
		// 세션의 유저 정보를 가져온다.
		if (SessionUtil.getAttribute("userSession") != null) {
			rtnUserSessionVO = (UserSessionVO)SessionUtil.getAttribute("userSession");
		} else {
			throw new HLFLException("NOTLOGIN","로그인 세션이 없습니다.");
		}

		return rtnUserSessionVO;
	}
}
