package hanalife.l.cm.cm.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.l.cm.cm.mapper.LtLeasIFRSLeaseDescMapper;
import hanalife.l.cm.cm.mapper.dto.LtLeasIFRSLeaseDescINDTO;
import hanalife.l.cm.cm.service.IFRSLeaseBaseService;
import hanalife.l.cm.cm.vo.RsltFVvalueVO;



/**
 * <pre>
 * 클래스　명 : RcptRfndServiceImpl
 * 클래스설명 : RcptRfndServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("IFRSLeaseBaseService")
public class IFRSLeaseBaseServiceImpl implements IFRSLeaseBaseService {

	private static final Logger log = LoggerFactory.getLogger(IFRSLeaseBaseServiceImpl.class);

	@Autowired
	private LtLeasIFRSLeaseDescMapper ltLeasIFRSLeaseDescMapper;

	@Override
	 /**
	   * <p>메소드명             : getNonDeprvalue</p>
	   * <p>설명                       : 중도해지 및 당일이후 실행 취소 할 때  미상각잔액액 을 구한다.</p>
	   * <p>메소드인수1  : LtLeasIFRSLeaseDescDO </p>
	   * <p>메소드인수2  : Connection conn Connection </p>
	   * <p>메소드리턴값   : RsltFVvalueVO - 결과를 담고 있는 DO</p>
	   */
	public RsltFVvalueVO getNonDeprvalue(LtLeasIFRSLeaseDescINDTO FVvalueParam) throws Exception {

		RsltFVvalueVO rsltDO = new RsltFVvalueVO();
		StLoanBaseDTO outDTO = new StLoanBaseDTO();
		StLoanBaseDTO inDTO = new StLoanBaseDTO();
		RsltFVvalueVO tmpDO = new RsltFVvalueVO();

		long tempFV = 0;

		// 시스템일자
		String yyyymmdd = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
		// 시스템시간
		String hhmmss = DateUtil.getServerDate(DateUtil.HHMMSS);

		try {

			inDTO.setLoanNo(FVvalueParam.getLoanNo()); // 대출_번호
			inDTO.setLoanSeq(FVvalueParam.getLoanSeq()); // 대출_순번

			outDTO = ltLeasIFRSLeaseDescMapper.selectStLoanData(inDTO);

			if (outDTO.getLoanDt() == null) {
				log.debug("대출번호[ " + FVvalueParam.getLoanNo() + " ]에 대한 대출정보가 존재하지 않습니다.");
				throw new Exception();
			}

			log.debug("Call 미상각금액 Fuction Input Value");
			log.debug("Date   :[" + yyyymmdd + "]");
			log.debug("LoanDt :[" + outDTO.getLoanDt() + "]");
			log.debug("LoanNo :[" + outDTO.getLoanNo() + "]");
			log.debug("LoanSeq :[" + outDTO.getLoanSeq() + "]");
			log.debug("=======================================");

			log.debug("====================================================");
			log.debug("미상각금액 금액 :[" + tempFV + "]");
			log.debug("====================================================");

			rsltDO.setCurrValDiscAmt(tempFV); // 미상각금액금

			tmpDO.setLoanNo(FVvalueParam.getLoanNo());
			tmpDO.setLoanSeq(FVvalueParam.getLoanSeq());
			tmpDO.setLoanDt(outDTO.getLoanDt());
			tmpDO.setEprtDt(outDTO.getEprtDt());
			//tmpDO.setAcctCd(outDTO.getAcctCd());
			tmpDO.setCurrValDiscAmt(tempFV);
			tmpDO.setRegDt(yyyymmdd);
			tmpDO.setRegTm(hhmmss);
			// [DOBSCAP]
			// rlst = dao.inserCurrValDisc(tmpDO, conn);

		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}

		return rsltDO;
	}
}
