package hanalife.r.at.ad.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.RtAcntDescDTO;
import hanalife.c.co.mapper.dto.RtAutoTranAcntApplDescDTO;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranAcntInDTO;
import hanalife.r.at.ad.mapper.dto.SearchAcntByLoanNoOutDTO;
import hanalife.r.at.ad.mapper.dto.SearchApplDescOutDTO;
import hanalife.r.at.ad.mapper.dto.SearchApplDescPropOutDTO;
import hanalife.r.at.ad.mapper.dto.SearchAutoTranTrOrgOutDTO;
import hanalife.r.at.ad.mapper.dto.SearchFileCntnInDTO;
import hanalife.r.at.ad.mapper.dto.SearchFileCntnOutDTO;
import hanalife.r.at.ad.mapper.dto.TrOrgCdOutDTO;
import hanalife.r.at.ad.vo.SearchClosObjOutDTO;

/**
 * <pre>
 * 클래스명	: AutoTranAcntProcMapper
 * 클래스설명  : 자동이체계좌관리
 * <p>내용   : 자동이체계좌에 대한 신규등록/수정/해지 처리를 한다.
 * 			  신청구분에 따라 자동이체계좌 신청/수정/해지를 처리, 신청구분(1:신규,2:수정,3:해지)</p>
 * 프로젝트명  : DOBSCAP
 * 작성일자	: 2023-03-21
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@Mapper("AutoTranAcntMapper")
public interface AutoTranAcntMapper {

	/**
	* <pre>
	* 메소드명     : searchAutoTranTrOrg
	* 설명        : 자동이체 거래기관 조회
	* 메소드인수값  : SearchAutoTranTrOrgOUTDTO
	* 메소드리턴값  : SearchAutoTranTrOrginDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public SearchAutoTranTrOrgOutDTO searchAutoTranTrOrg(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : isSend
	* 설명        : 전송여부 확인
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int isSend(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntStatIng
	* 설명        : 자동이체 신청내역 업데이트
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntStatIng(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateLoanAcntStatIng
	* 설명        : 대출 자동이체 계좌 상태 변경
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateLoanAcntStatIng(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : insertAcntApplDesc
	* 설명        : 자동이체 신청 내역 생성
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int insertAcntApplDesc(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntApplDescSendSnum
	* 설명        : 자동이체 신청 내역 순번 정렬
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntApplDescSendSnum(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : deleteAcntGramSrDesc
	* 설명        : 자동이체 전문전송내역 삭제
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int deleteAcntGramSrDesc(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : insertAcntGramSrDesc
	* 설명        : 자동이체 신청내역 전문 전송내역 생성
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int insertAcntGramSrDesc(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : searchApplDesc
	* 설명        : 자동이체 신청내역 조회
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : SearchApplDescOUTDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public List<SearchApplDescOutDTO> searchApplDesc(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : searchApplDescProp
	* 설명        : 자동이체 신청내역 조회(증빙)
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : SearchApplDescPropOutDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public List<SearchApplDescPropOutDTO> searchApplDescProp(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntDescCancel
	* 설명        : 자동이체 계좌 내역 취소
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntDescCancel(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateLoanBaseCancel
	* 설명        : 자동이체 대출원장 취소
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateLoanBaseCancel(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : deleteAcntGramSrDescCancel
	* 설명        : 자동이체 전문 전송내역 취소
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int deleteAcntGramSrDescCancel(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : deleteApplDescCancel
	* 설명        : 자동이체 신청내역 취소
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int deleteApplDescCancel(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : isAlreadyReceived
	* 설명        : 전송여부 확인
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int isAlreadyReceived(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntApplRslt
	* 설명        : 계좌처리 결과 업데이트
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntApplRslt(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : searchAcntByLoanNo
	* 설명        : 대출번호로 자동이체 내역을 조회
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : SearchAcntByLoanNoOutDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public SearchAcntByLoanNoOutDTO searchAcntByLoanNo(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : isAutoTranAskIng
	* 설명        : 자동이체 청구내역 여부
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int isAutoTranAskIng(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : isExistsAcnt
	* 설명        : 자동이체 계좌 존재 여부 조회
	* 메소드인수값  : StLoanBaseDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int isExistsAcnt(StLoanBaseDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : searchLastAcntDesc
	* 설명        : 최근 계좌정보
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : RtAcntDescDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public RtAcntDescDTO searchLastAcntDesc(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : searchLastAcntDescEqualBankAcnt
	* 설명        : 최근 계좌정보(은행신청)
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : RtAcntDescDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public RtAcntDescDTO searchLastAcntDescEqualBankAcnt(RtAcntDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : createAcntDesc
	* 설명        : 계좌내역 생성
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int createAcntDesc(RtAcntDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : createAutoTranAcntApplDesc
	* 설명        : 자동이체 계좌 신청내역 생성
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int createAutoTranAcntApplDesc(RtAutoTranAcntApplDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateLoanBase
	* 설명        : 대출 계좌정보 업데이트
	* 메소드인수값  : StLoanBaseDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateLoanBase(StLoanBaseDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntApplDescSuccess
	* 설명        : 자동이체 신청내역 결과 업데이트 (실패건 이외 성공처리)
	* 메소드인수값  : RtAutoTranAcntApplDescDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntApplDescSuccess(RtAutoTranAcntApplDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntDescSuccess
	* 설명        : 자동이체 내역 수신성공처리
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntDescSuccess(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateLoanAcntApplRsltSuccess
	* 설명        : 대출원장 자동이체 계좌 신청 결과 업데이트
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateLoanAcntApplRsltSuccess(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAutoTranAcntGramRslt
	* 설명        : 수신/송신처리 상태 업데이트
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAutoTranAcntGramRslt(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntDescBankRslt
	* 설명        : EB11 해지요청 계좌내역 변경
	* 메소드인수값  : RtAcntDescDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntDescBankRslt(RtAcntDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : updateAcntApplDescBankRslt
	* 설명        : EB11 신청내역 오류결과 업데이트
	* 메소드인수값  : RtAutoTranAcntApplDescDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int updateAcntApplDescBankRslt(RtAutoTranAcntApplDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : hasEb11Request
	* 설명        : 은행 계좌등록 요청이 있는지 확인
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : int
	* 예외처리     : Exception
	* </pre>
	*/
	public int hasEb11Request(RtAutoTranAcntApplDescDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : getTrOrgCd
	* 설명        : 거래기관코드 조회
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : TrOrgCdOutDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public List<TrOrgCdOutDTO> getTrOrgCd(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : getTrOrgCdEB12
	* 설명        : EB12 수신할 거래기관 조회
	* 메소드인수값  : AutoTranAcntInDTO
	* 메소드리턴값  : TrOrgCdOutDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public List<TrOrgCdOutDTO> getTrOrgCdEB12(AutoTranAcntInDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명     : searchFileCntn
	* 설명        : 파일을 조회해서 리턴
	* 메소드인수값  : SearchFileCntnInDTO
	* 메소드리턴값  : SearchFileCntnOutDTO
	* 예외처리     : Exception
	* </pre>
	*/
	public SearchFileCntnOutDTO searchFileCntn(SearchFileCntnInDTO inDTO) throws Exception;

   /**
    * <pre>
    * 메소드명     : searchClosObj
    * 설명        : 해지대상조회
    * 메소드인수값  : AutoTranAcntInDTO
    * 메소드리턴값  : SearchClosObjOutDTO
    * 예외처리     : Exception
    * </pre>
    */
    public List<SearchClosObjOutDTO> searchClosObj(AutoTranAcntInDTO inDTO) throws Exception;

}
