package hanalife.r.at.ad.mapper;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.r.at.ad.mapper.dto.AutoTranAcntProcDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranAcntProcOutDTO;

/**
 * <pre>
 * 클래스명	: AutoTranAcntProcMapper
 * 클래스설명  : 자동이체계좌관리
 * <p>내용   : 자동이체계좌에 대한 신규등록/수정/해지 처리를 한다.
 * 			  신청구분에 따라 자동이체계좌 신청/수정/해지를 처리, 신청구분(1:신규,2:수정,3:해지)</p>
 * 프로젝트명  : DOBSCAP
 * 작성일자	: 2023-03-21
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@Mapper("AutoTranAcntProcMapper")
public interface AutoTranAcntProcMapper {

	/**
     * <p>메소드명      : searchLoanBase</p>
     * <p>사용여부      : 사용
     * <p>설명         : [대출_기본] 검색 </p>
     * <p>메소드인수1   : AutoTranAcntProcDTO</p>
     * <p>메소드리턴값  : Map</p>
     * <p>예외처리      : Exception</p>
     */
	public AutoTranAcntProcOutDTO searchLoanBase(AutoTranAcntProcDTO inDto) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateAcntDescClosDt
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 기존계좌 해지처리
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateAcntDescClosDt(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateAcntDescCancel
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 신청정보 취소
	* 메소드인수1   :
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateAcntDescCancel(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateAcntAplyDt
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 계좌내역 수정
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateAcntAplyDt(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateAcntDesc
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 자동이체 계좌내역 DB에 udpat
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateAcntDesc(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : createAcntDesc
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : 자동이체 계좌내역 DB에 insert
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int createAcntDesc(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateLoanBaseNew
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : [대출_기본] DB update 신규처리시
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateLoanBaseNew(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateAutoTranAcntApplDesc
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : [대출_기본] DB update 신규처리시
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateAutoTranAcntApplDesc(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : chngDueMeth
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          :  납입방법 변경
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int chngDueMeth(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateLoanBaseClos
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : [대출_기본] DB update 해지처리시
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateLoanBaseClos(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateLoanRelMan
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : [대출_관계] DB update 발송방법 수정
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateLoanRelMan(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : insertLoanRlDueMan
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : [대출_관계] DB update 발송방법 수정
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int insertLoanRlDueMan(AutoTranAcntProcDTO inDTO) throws Exception;

	/**
	* <pre>
	* 메소드명      : updateLoanBaseUpdt
	* 작성일자      : 2023. 3. 24.
	* 작성자(author): 70320 jaeho.jang
	* 설명          : [대출_기본] DB update 수정처리시
	* 메소드인수1   :  AutoTranAcntProcDTO
	* 메소드리턴값  :  int
	* 예외처리      : Exception
	* </pre>
	*/
	public int updateLoanBaseUpdt(AutoTranAcntProcDTO inDTO) throws Exception;
}
