package hanalife.r.at.ad.service.impl;

import java.sql.SQLException;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.util.StringUtil;
import hanalife.r.at.ad.mapper.AutoTranAcntProcMapper;
import hanalife.r.at.ad.mapper.dto.AutoTranAcntProcDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranAcntProcOutDTO;
import hanalife.r.at.ad.service.AutoTranAcntProcService;
import hanalife.r.at.ad.vo.AutoTranAcntProcOutVO;
import hanalife.util.BizException;

@Service("AutoTranAcntProcService")
public class AutoTranAcntProcServiceImpl implements AutoTranAcntProcService {
	private static final Logger LOGGER = LoggerFactory.getLogger(AutoTranAcntProcServiceImpl.class);

	public final String PROC_COMM = "1";
	public final String PROC_INTN = "2";

	public final String DIV_NEW  = "1"; //신규요청
	public final String DIV_UPDT = "2"; //수정요청
	public final String DIV_CLOS = "3"; //해지요청

	public final String APPL_RSLT_RECV_METH_EMAL = "1";

	//시스템경로코드( R00069 )
	public final String SYS_PATH_SWIS = "01";		//DOBSCAP
	public final String SYS_PATH_HOMEPAGE = "02";	//홈페이지
	public final String SYS_PATH_TOT_REG = "03";		//일괄등록
	public final String SYS_PATH_SWIS_CT = "04";		//DOBSCAP_컨텍센터
	public final String SYS_PATH_CT = "05";			//컨텍센터

	public final String ACNT_APPL_RSN_COL = "01";	//창구징구
	public final String ACNT_APPL_RSN_UN_COL = "02";	//창구미징구
	public final String ACNT_APPL_RSN_FROM_BANK = "03";	//은행신청
	public final String ACNT_APPL_RSN_SWIS_CT = "04";	//DOBSCAP_컨텍센터
	public final String ACNT_APPL_RSN_CT = "05";			//컨텍센터
	public final String ACNT_APPL_RSN_HOMEPAGE = "06";	//홈페이지

	public Map errMap;
	public final String SUCCESS_CD = "0000"; //성공
	public final String CLOS_SKIP = "SKIP"; //해지처리 Skip
	public final String ERR_NOT_FOUND_ACNT = "0001";
	public final String ERR_INVALID_DUE_METH = "0002";
	public final String ERR_NOT_ATTACH = "0003";
	public final String ERR_SYSTEM = "8888";
	public final String ERR_LOAN_NOT_NORMAL = "0004";
	public final String MSG_NOT_FOUND_ACNT = "최종등록된 계좌가 아닙니다.";
	public final String MSG_INVALID_DUE_METH = "해지처리는 자동이체만 가능합니다.";
	public final String MSG_NOT_ATTACH = "계좌 반영 실패";
	public final String MSG_SYSTEM = "시스템 에러발생";
	public final String MSG_LOAN_NOT_NORMAL = "정상대출건이 아닙니다.";
	private final String BLANK = "";
	@Autowired
	private AutoTranAcntProcMapper autoTranAcntProcMapper;


	/**
	 * <p>메소드명		: proc</p>
	 * <p>설명			: 신청구분에 따라 자동이체계좌 신청/수정/해지를 처리</p>
	 * <p>메소드인수1	: AutoTranAcntProcCCDO</p>
	 * <p>메소드인수2	: ITransaction</p>
	 * <p>메소드리턴값	: List</p>
	 * <p>예외처리		: N/A</p>
	 * -----------------------------------------------------------------------
	 * ※ Connection의 commit, rollback은 이 함수에서 하지 않는다. Call하는 함수에서
	 * Connection의 생성, commit, rollback, resource free등을 해야함.
	 * -----------------------------------------------------------------------
	 * (String) 에러코드 (0)<br>
	 * 0000 : 정상 <br>
	 * 0000 이 아닐때 에러 <br>
	 * 에러코드 예) <br>
	 * 0001 : 최종등록된 계좌가 아닙니다. <br>
	 * 0002 : 해지처리는 자동이체만 가능합니다. <br>
	 * 0003 : 계좌 반영 실패 <br>
	 * 0004 : 정상대출건이 아닙니다. <br>
	 * 8888 : 시스템 에러발생 <br>
	 * ----------------------------- <br>
	 * (String) 에러메시지(1) <br>
	 * 에러코드에 해당하는 에러메시지 <br>
	 * ex) "해지처리는 자동이체만 가능합니다." --> 이때 에러코드 (0002) <br>
	 * </p>
	 * <p>예외처리 : </p>
	 */
	@Override
	public AutoTranAcntProcOutVO proc(AutoTranAcntProcDTO inVO) {
		AutoTranAcntProcOutVO result = null;
		if (inVO == null) {
			return makeResult(ERR_SYSTEM, "요청정보가 입력되지 않았습니다.");
		}

		//요청구분
		String applDiv = inVO.getAcntApplDiv();
		LOGGER.info("■ AutoTranAcntProcCC.proc : applDiv = "+applDiv);

		try {
			//시스템경로(신청경로)가 입력안되면 디폴트로 DOBSCAP로 입력한다.
			String sysPathCd = StringUtil.isNull(inVO.getSysPathCd())?"01":inVO.getSysPathCd();
			inVO.setSysPathCd(sysPathCd);

			if (DIV_NEW.equals(applDiv)) { //신규신청 : 1
				LOGGER.info("■ AutoTranAcntProcCC.proc : 신규신청 ");
				result = makeResult(procNew(inVO), "");
				LOGGER.info("■ AutoTranAcntProcCC.proc : result " + result);
			} else if (DIV_UPDT.equals(applDiv)) { //수정 : 2
				result = makeResult(procUpdt(inVO), "");

			} else if (DIV_CLOS.equals(applDiv)) { //해지 : 3
				result = makeResult(procClos(inVO), "");

			} else { //잘못된요청
				LOGGER.info("■ AutoTranAcntProcCC.proc : BAD REQUEST ");
				result = makeResult(ERR_SYSTEM, "요청정보가 잘못되었습니다. 입력요청구분 : " + applDiv);
			}
		} catch (Throwable e) {
			LOGGER.error(e.getMessage(), e);
			LOGGER.info("■ AutoTranAcntProcCC.proc : ERROR ");
			result = makeResult(ERR_SYSTEM, e.getMessage());
		}
		LOGGER.info("■ AutoTranAcntProcCC.proc : WHAT result " + result);
		return result;
	}

	/**
	 * <p>매소드명		: procNew</p>
	 * <p>설명			: 자동이체계좌내역을 등록, 대출계좌정보수정  </p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드리턴값	: 결과코드 ( 0000이 아니면 에러)</p>
	 * <p>예외처리		: Exception</p>
	 */
	private String procNew(AutoTranAcntProcDTO inVO) throws Exception {
		LOGGER.info("■ 자동이체계좌 신규처리 STRAT");

		//기존계좌를 해지하고 일련번호를 얻는다.
		String rsltCd = procClos(inVO);
		if (!SUCCESS_CD.equals(rsltCd)) {
			return rsltCd;
		}
		LOGGER.info("■ 자동이체계좌 일련번호 get");
		// 수정중인 처리 안함.
		// boolean isNew = closeForNew(inVO, tx);

		//계좌일련번호 1증가.
		inVO.setAcntSnum(inVO.getAcntSnum() + 1);
		LOGGER.info("■ 자동이체계좌 일련번호 +1");
		// 증빙파일 생성
		/* NOTE 증빙파일은 사용하지 않는다.
		long fileNo = createFiles(inVO, tx);
		inVO.setFileNo(fileNo);
		*/

		//계좌내역을 생성함.
		if (createAcntDesc(inVO) != 1) {
			return ERR_NOT_ATTACH;
		}
		LOGGER.info("■ 자동이체계좌 계좌내역 생성");
		//대출원장에 최종 계좌를 갱신함.
		if (updateLoanBaseNew(inVO) != 1) {
			return ERR_NOT_ATTACH;
		}
		LOGGER.info("■ 자동이체계좌 대출원장 업데이트");
		// 항상 자동이체만 사용함.
		//기존 납입방법이 자동이체가 아니면 ( 지로/창구수납등 -> 자동이체 라는 이력을 생성한다. )
//		if ( !inVO.getOrigDueMethCd().equals("02") ) {
//			//실납입자의 이력등록
//			String strSnum = GenerateKey.getNextNumber("S006", inVO.getLoanNo(), inVO.getLoanSeq(), inVO.getEmpNo(), tx);
//
//			if (insertLoanRlDueMan(inVO, "02", null, strSnum, tx) < 1) {
//				return ERR_NOT_ATTACH;
//			}
//		}

		//계좌발생코드가 은행인경우 업데이트침.
		updateAutoTranAcntApplDesc(inVO);
		LOGGER.info("■ 자동이체계좌 계좌발생코드가 은행인경우 업데이트");
		LOGGER.info("■ SUCCESS_CD : " + SUCCESS_CD);
		return SUCCESS_CD;
	}

	/**
	 * TODO 미사용
	 * 신규신청 요청 처리
	 *
	 * @deprecated 계좌등록후 계좌를 변경할때 수정으로 처리하지 않고 해지후 신규건으로 처리한다. 수정처리는 하지 않는다.
	 *
	 * @param inVO
	 * @param tx
	 * @return
	 * @throws Exception
	 */
	//private boolean closeForNew(AutoTranAcntProcDTO inVO) throws Exception {}

	/**
	 * 기존계좌 해지처리
	 * @param loanNo
	 * @param loanSeq
	 * @param acntSnum
	 * @param connection
	 * @return
	 */
	private int updateAcntDescClosDt(String loanNo, String loanSeq, int acntSnum) throws Exception {
		try {
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setAcntSnum(acntSnum);

			return autoTranAcntProcMapper.updateAcntDescClosDt(inDTO);
		} catch (SQLException e) {
			throw new BizException("[계좌내역 수정오류] - " + e.getMessage() + "-");
		}
	}

	/**
	 * 신청정보 취소
	 * @param loanNo
	 * @param loanSeq
	 * @param acntSnum
	 * @param connection
	 * @return
	 */
	private int updateAcntDescCancel(String loanNo, String loanSeq, int acntSnum) throws Exception {

		try {
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setAcntSnum(acntSnum);

			return autoTranAcntProcMapper.updateAcntDescCancel(inDTO);
		} catch (SQLException e) {
			throw new BizException("[계좌내역 수정오류] - " + e.getMessage() + "-");
		}
	}

	/**
	 * <p>매소드명		: procUpdt</p>
	 * <p>설명			: 자동이체 계좌 내역을 수정한다. 대출정보를 수정한다. ( 자동이체_적용_일자 )</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: 결과코드 ( 0000이 아니면 에러)</p>
	 * <p>예외처리		: Exception</p>
	 */
	private String procUpdt(AutoTranAcntProcDTO inVO) throws Exception {

		if (updateAcntAplyDt(inVO) < 1) {
			return ERR_NOT_ATTACH;
		}

		if (updateLoanBaseUpdt(inVO) < 1) {
			return ERR_NOT_ATTACH;
		}

		return SUCCESS_CD;
	}

	/**
	 * <p>매소드명		: procClos</p>
	 * <p>설명			: 자동이체계좌해지처리 </p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: 결과코드 ( 0000이 아니면 에러)</p>
	 * <p>예외처리		: Exception</p>
	 */
	private String procClos(AutoTranAcntProcDTO inVO) throws	Exception {
		LOGGER.info("■ 자동이체계좌 해지처리 STRAT (1.해지신청 / 2.변경일때 기존건 해지)");

		//해지가능여부 체크
		String errCd = chkAcntClos(inVO);
		if (CLOS_SKIP.equals(errCd)) {
			return SUCCESS_CD;
		}

		if (!SUCCESS_CD.equals(errCd)) {
			return errCd;
		}

		//계좌내역에 해지처리를 한다.
		if (updateAcntDesc(inVO) != 1) {
			return ERR_NOT_ATTACH;
		}

		//대출정보에 자동이체를 해지한다.
		String dueMeth = "03";	// 01:지로,03:창구수납 (지로는 안쓰므로 임의로 창구수납으로 변경)
		if (updateLoanBaseClos(inVO, dueMeth) != 1) {
			return ERR_NOT_ATTACH;
		}

		String applDiv = inVO.getAcntApplDiv();

		/* 계좌해지시 납입방법이 자동이체 -> 지로로 수정된다.
		 * 신규계좌 등록을 위해 기존 계좌해지시 지로로 변경되는것이 아니므로 이력을 등록하지 않는다.
		 */
		if (!DIV_NEW.equals(applDiv)) {
			//대출관계자 청구방법 수정 (지로는 무조건 0:우편발송임. 따라서 기존 청구방법이 우편이 아니면 우편발송으로 수정한다.)
			// 의미가 없음
//			String afAskMethCd = null;
//			if (!inVO.getAskMethCd().equals("0")) {
//				afAskMethCd = "0";
//				if (updateLoanRelMan(inVO, afAskMethCd, tx.getConnection()) != 1) {
//					throw new Exception("[계좌청구방법수정오류]대출관계자 변경실패");
//				}
//			}

			// 실납입자의 이력등록(청구방법, 납입방법 수정)
//			String strSnum = GenerateKey.getNextNumber("S006", inVO.getLoanNo(), inVO.getLoanSeq(), inVO.getEmpNo(), tx);
//			int iCnt = insertLoanRlDueMan(inVO, dueMeth, afAskMethCd, strSnum, tx);
//			if (iCnt!=1) {
//				throw new Exception("[계좌청구방법수정오류]대출관계자이력 등록실패");
//			}
		}

		//자동이체계좌신청내역 수정(은행신청은 받지 않는다.)
		updateAutoTranAcntApplDesc(inVO);

		LOGGER.info("자동이체계좌 해지처리 END");
		return SUCCESS_CD;
	}

	/**
	 * <p>매소드명		: chkAcntClos</p>
	 * <p>설명			: 해지가능여부 체크</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: 결과코드 ( 0000이 아니면 에러)</p>
	 * <p>예외처리		: Exception</p>
	 */
	private String chkAcntClos(AutoTranAcntProcDTO inVO) throws Exception {
		LOGGER.info("chkAcntClos in");
		String errCd = SUCCESS_CD;

		String acntDiv = inVO.getAcntApplDiv();
		AutoTranAcntProcOutDTO loan = searchLoanBase(inVO);
		if (loan == null) {
			return ERR_NOT_FOUND_ACNT; //최종 등록된 계좌가 아닙니다.
		}

		//대출정상(최종)여부 확인
		String loanNormFg = loan.getLoanLastFg(); //대출정상여부

		if (!"1".equals(loanNormFg)) {
			return ERR_LOAN_NOT_NORMAL;
		}

		int acntSnum = loan.getAcntSnum();	//대출원장에 존재하는 계좌순번
		int acntDescAcntSnum = loan.getAcntDescSnum();
		if (acntSnum != acntDescAcntSnum ) {
			throw new Exception("대출에 등록된 계좌와 정보가 일치하지 않습니다.(계좌일련번호 이상)");
		}
		String dueMethCd = loan.getDueMethCd(); //납입방법코드
		String askMethCd = loan.getAskMethCd();

		//기존 계좌내용 셋팅
		inVO.setAcntSnum(acntSnum);
		inVO.setRlDueManNo(loan.getRlDueManNo());
		inVO.setAskMethCd(askMethCd);
		inVO.setAcctUnitCd(loan.getAcctUnitCd());
		inVO.setOrigDueMethCd(dueMethCd);
		inVO.setTrOrgCd(loan.getTrOrgCd());

		LOGGER.debug("************ : " + inVO.getTrOrgCd());

		/*해지요청시 자동이체가 아니면 오류 신규요청에 의한 기존계좌 해지요청이면 오류아님 */
		// 항상 자동이체만 존재함.
//		if (!"02".equals(dueMethCd)) {
//			if (DIV_NEW.equals(acntDiv)) {
//				//신규신청시에는 자동이체납부가 아니어도 자동이체로 변경하기때문에 SKIP
//				return CLOS_SKIP;
//			}
//			return ERR_INVALID_DUE_METH; //자동이체만 가능.
//		}

		if (acntSnum == 0) {	//기존계좌가 없을때 해지는 SKIP

			if (DIV_CLOS.equals(acntDiv)) {	//해지요청시 계좌정보가 없으면 납입상태를 변경함.
				// 항상 자동이체로 유지시킴
				//등록된 계좌가 없을때 납입방법이 자동이체이면 창구수납(or지로)로 수정한다.
//				if (dueMethCd.equals("02") ) {
//					//납입방법 변경 (납입방법 창구수납으로 수정)
//					chngDueMeth(inVO, "03", tx);
//
//					//대출관계좌 수정의 청구방법 수정 (지로는 무조건 우편발송임. 따라서 기존 청구방법이 우편이 아니면 우편발송으로 수정한다.)
//					String afAskMethCd = null;
//					if (!inVO.getAskMethCd().equals("0")) {
//						afAskMethCd = "0";
//						if (updateLoanRelMan(inVO, afAskMethCd, tx.getConnection()) != 1) {
//							throw new Exception("[계좌청구방법수정오류]대출관계자 변경실패");
//						}
//					}
//
//					// 실납입자의 이력등록 (청구방법, 납입방법 수정)
//					String strSnum = GenerateKey.getNextNumber("S006", inVO.getLoanNo(), inVO.getLoanSeq(), inVO.getEmpNo(), tx);
//
//					if (insertLoanRlDueMan(inVO, "01", afAskMethCd, strSnum, tx) != 1) {
//						throw new Exception("[계좌청구방법수정오류]대출관계자이력 등록실패");
//					}
//				}
			}
			errCd = CLOS_SKIP;
		} else {
            // 강제 해지 처리
		    if( "1".equals( loan.getClosIvltFg())){
                errCd = SUCCESS_CD;
                inVO.setClosIvltFg("1");
            }
        }
		return errCd;
	}

	/**
	 * <p>매소드명		: searchLoanBase</p>
	 * <p>설명			: [대출_기본] 검색</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: Map</p>
	 * <p>예외처리		: Exception</p>
	 */
	private AutoTranAcntProcOutDTO searchLoanBase(AutoTranAcntProcDTO inVO) throws Exception {
		try {
			return autoTranAcntProcMapper.searchLoanBase(inVO);
		} catch (SQLException e) {
			throw new Exception("[대출정보 조회중 DB장애] - " + e.getMessage() + "-");
		}
	}

	/**
	 * <p>매소드명		: updateAcntAplyDt</p>
	 * <p>설명			: 계좌내역 수정 </p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: int</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateAcntAplyDt(AutoTranAcntProcDTO inVO) throws Exception {
		try{
			return autoTranAcntProcMapper.updateAcntAplyDt(inVO);
		}catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-적용일자수정에러] - " + se.getMessage());
		}
	}

	/**
	 * <p>매소드명		: updateAcntDesc</p>
	 * <p>설명			: 자동이체 계좌내역 DB에 udpate</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction</p>
	 * <p>매소드리턴값	: update건수</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateAcntDesc(AutoTranAcntProcDTO inVO) throws Exception {
		/*
			00 미등록		-> 33 해지
			01 계좌확인중		-> 신규등록(해지) 불가,  결과요청을 해야함.
			03 계좌확인성공	-> 33 해지
			04 계좌확인오류	-> 33 해지
			05 계좌강제등록	-> 33 해지
			11 신규신청		-> 33 해지
			12 신규신청중		-> 31 신규신청중, 신규등록되었는지 등록실패인지 모르므로 해지신청을 함.
			13 신규정상		-> 31 해지신청
			14 신규오류		-> 33 해지
			31 해지신청		-> 31 해지신청
			32 해지신청중		-> 32 해지신청중
			33 해지			-> 33 해지
			34 해지오류		-> 34 해지오류
		*/

		try {
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();

			inDTO.setAcntApplDivCd("3");
			inDTO.setAcntClosRsnCd(inVO.getAcntClosRsnCd());	//해지사유
			inDTO.setSysPathCd(inVO.getSysPathCd());		//신청경로
			inDTO.setEmpNo(inVO.getEmpNo());
			inDTO.setLoanNo(inVO.getLoanNo());
			inDTO.setLoanSeq(inVO.getLoanSeq());
			inDTO.setAcntSnum(new Integer(inVO.getAcntSnum()));

			return autoTranAcntProcMapper.updateAcntDesc(inDTO);
		} catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-해지정보갱신오류] - " + se.getMessage());
		}
	}

	/**
	 * <p>매소드명		: insertAcntDesc</p>
	 * <p>설명			: 자동이체 계좌내역 DB에 insert</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: Connection</p>
	 * <p>매소드리턴값	: insert 건수</p>
	 * <p>예외처리		: Exception</p>
	 */
	private int createAcntDesc(AutoTranAcntProcDTO inVO) throws Exception {

		int cnt = 0;

		try {
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setLoanNo(inVO.getLoanNo());					//대출번호
			inDTO.setLoanSeq(inVO.getLoanSeq());					//대출순번
			inDTO.setAcntSnum(new Integer(inVO.getAcntSnum()));	//계좌_일련번호
			inDTO.setBankCd(inVO.getBankCd());					//은행코드
			inDTO.setAcntNo(inVO.getAcntNo());					//계좌번호
			inDTO.setDepoOwnNo(inVO.getDepoOwnNo());				//예금주번호
			inDTO.setDepoOwnnm(inVO.getDepoOwnnm());				//예금주명
			inDTO.setDepoOwnRelCd(inVO.getDepoOwnRelCd());			//예금주_관계_코드
			inDTO.setAcntApplDiv(inVO.getAcntApplDiv());				//계좌_신청_구분코드
			inDTO.setAcntStatCd("11");								//계좌_상태_코드(11:신규)
			inDTO.setAcntOccrCd("1");								//계좌_발생_코드 (1:당사)
			inDTO.setClosDt(StringUtil.nvl(BLANK));					//해지_일자
			inDTO.setSendDt(StringUtil.nvl(BLANK));					//전송_일자
			inDTO.setAcntRsltCd(StringUtil.nvl(BLANK));					//계좌_결과_코드
			inDTO.setAcntErrCd(StringUtil.nvl(BLANK));					//계좌_오류_코드
			inDTO.setAcntAplyDt(inVO.getAcntAplyDt());				//계좌_적용_일자
			inDTO.setAcntApplRsnCd(inVO.getAcntApplRsnCd());			//계좌_신청_사유_코드
			inDTO.setAcntClosRsnCd(StringUtil.nvl(BLANK));					//계좌_해지_사유_코드
			inDTO.setAcctUnitCd(inVO.getAcctUnitCd());				//회계_단위_코드
			inDTO.setApplManTel1(inVO.getApplManTel1());				//신청_인_전화1
			inDTO.setApplManTel2(inVO.getApplManTel2());				//신청_인_전화2
			inDTO.setApplManTel3(inVO.getApplManTel3());				//신청_인_전화3
			inDTO.setEmpNo(inVO.getEmpNo());					//최초등록자사번
			inDTO.setEmpNo(inVO.getEmpNo());					//최종처리자
			inDTO.setSysPathCd(inVO.getSysPathCd());				//시스템경로코드
			inDTO.setApplManEmal(inVO.getApplManEmal());				//신청_이메일
			inDTO.setApplRsltRecvMethCd(inVO.getApplRsltRecvMethCd());		//신청결과수신방법코드
			inDTO.setTrOrgCd(inVO.getTrOrgCd());					//거래기관코드
			inDTO.setFileNo(inVO.getFileNo());					//파일번호

			cnt = autoTranAcntProcMapper.createAcntDesc(inDTO);
		} catch(SQLException se) {
			throw new BizException("[자동이체계좌처리-자동이체내역등록오류] - " + se.getMessage());
		}

		return cnt;
	}

	/**
	 * <p>매소드명		: updateLoanBaseNew</p>
	 * <p>설명			: [대출_기본] DB update 신규처리시</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: Connection</p>
	 * <p>매소드리턴값	: update건수 </p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateLoanBaseNew(AutoTranAcntProcDTO inVO) throws Exception {
		int cnt = 0;

		try {
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setAcntSnum(new Integer(inVO.getAcntSnum()));	//계좌_일련번호
			inDTO.setBankCd(inVO.getBankCd());			//은행코드
			inDTO.setAcntNo(inVO.getAcntNo());			//계좌번호
			inDTO.setDepoOwnNo(inVO.getDepoOwnNo());		//예금주번호
			inDTO.setDepoOwnnm(inVO.getDepoOwnnm());		//예금주명
			inDTO.setDepoOwnRelCd(inVO.getDepoOwnRelCd());	//예금주관계코드
			inDTO.setAcntStatCd("11");						//계좌상태코드 (11:신규)
			inDTO.setEmpNo(inVO.getEmpNo());			//최종처리자
			inDTO.setLoanNo(inVO.getLoanNo());			//대출번호
			inDTO.setLoanSeq(inVO.getLoanSeq());			//대출순번

			cnt = autoTranAcntProcMapper.updateLoanBaseNew(inDTO);
		} catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-대출정보변경에러] - " + se.getMessage());
		}
		return cnt;
	}

	/**
	 * <p>매소드명 : updateContBaseNew</p>
	 * <p>설명 : [대출_기본] DB update 신규처리시</p>
	 * <p>매소드 인수1 : AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2 : ITransaction - </p>
	 * <p>매소드리턴값 : update건수 </p>
	 * <p>예외처리 : </p>
	 * @throws Exception
	 */
//	private int updateContBaseNew(AutoTranAcntProcDTO inVO) throws Exception {
//
//		StringBuffer sql = new StringBuffer(1024);
//		sql.append("\n UPDATE DBSSALE.ST_CONT_BASE A  ");
//		sql.append("\n SET                            ");
//		sql.append("\n     A.DUE_METH_CD       = ?,   ");
//		sql.append("\n     A.ACNT_SNUM         = ?,   ");
//		sql.append("\n     A.SETL_BANK_CD      = ?,   ");
//		sql.append("\n     A.SETL_ACNT_NO      = ?,   ");
//		sql.append("\n     A.DEPO_OWN_NO       = ?,   ");
//		sql.append("\n     A.DEPO_OWNNM        = ?,   ");
//		sql.append("\n     A.DEPO_OWN_RELCD    = ?,   ");
//		sql.append("\n     A.AUTO_TRAN_APLY_DT = TO_CHAR(SYSDATE, 'YYYY-MM-DD'),   ");
//		sql.append("\n     A.ACNT_STAT_CD      = ?,   ");
//		sql.append("\n     A.LAST_PROC_DT      = TO_CHAR(SYSDATE, 'YYYY-MM-DD'), ");
//		sql.append("\n     A.LAST_PROC_TM      = TO_CHAR(SYSDATE, 'HH24MISS'),   ");
//		sql.append("\n     A.LAST_PROC_EMP_NO  = ?    ");
//		sql.append("\n WHERE A.CONT_NO = ?            ");
//
//		List params = new ArrayList(9);
//		params.add( "02");	//납입방법코드(자동이체)
//		params.add( new Integer(inVO.getAcntSnum()));	//계좌_일련번호
//		params.add( inVO.getBankCd()); //은행코드
//		params.add( inVO.getAcntNo()); //계좌번호
//		params.add( inVO.getDepoOwnNo()); //예금주번호
//		params.add( inVO.getDepoOwnnm()); //예금주명
//		params.add( inVO.getDepoOwnRelCd()); //예금주관계코드
//		params.add( "11"); //계좌상태코드 ( 신규 )
//		params.add( inVO.getEmpNo());	//최종처리자
//
//		params.add( inVO.getLoanNo());	//대출번호
//
//		if (LOGGER.isDebugEnabled()) {
//			StringUtil.logSql(sql.toString(), params.toArray());
//		}
//
//		try{
//			return runner.update(tx.getConnection(), sql.toString(), params.toArray());
//		}catch(SQLException se) {
//			throw new Exception("[자동이체계좌처리-약정정보변경에러] - " + se.getMessage());
//		}
//	}

	/**
	 * <p>매소드명		: updateLoanBaseNew</p>
	 * <p>설명			: [대출_기본] DB update 신규처리시</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: update건수 </p>
	 * <p>예외처리		: Exception</p>
	 * @throws Exception
	 */
	private int updateAutoTranAcntApplDesc(AutoTranAcntProcDTO inVO) throws Exception {
		try{
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setLoanNo(inVO.getLoanNo());			//대출번호
			inDTO.setEmpNo(inVO.getEmpNo());			//대출순번
			inDTO.setSendStatCd("2");
			inDTO.setAcntOccrCd("2");

			return autoTranAcntProcMapper.updateAutoTranAcntApplDesc(inDTO);
		} catch(SQLException se) {
			throw new BizException("[자동이체계좌처리-자동이체계좌신청갱신실패] - " + se.getMessage(), se);
		}
	}

	/**
	 * <p>매소드명		: chngDueMeth</p>
	 * <p>설명			: 납입방법 변경</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction</p>
	 * <p>매소드리턴값	: N/A</p>
	 * <p>예외처리		: Exception</p>
	 */
	private void chngDueMeth(AutoTranAcntProcDTO inVO, String dueMethCd) throws Exception {

		try{

			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setAcntSnum(inVO.getAcntSnum());
			inDTO.setDueMethCd(dueMethCd);
			inDTO.setLoanNo(inVO.getLoanNo());			//대출번호
			inDTO.setLoanSeq(inVO.getLoanSeq());			//대출순번
			if (1 != autoTranAcntProcMapper.chngDueMeth(inDTO)) {
				throw new Exception("[자동이체계좌처리-자동이체해지 정보 대출원장 반영실패]");
			}
		} catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-자동이체해지정보갱신실패] - " + se.getMessage());
		}
	}

	/**
	 * <p>매소드명		: updateLoanBaseClos</p>
	 * <p>설명			: [대출_기본] DB update 해지처리시</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: update건수 </p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateLoanBaseClos(AutoTranAcntProcDTO inVO, String dueMeth) throws Exception {
		try {
			return autoTranAcntProcMapper.updateLoanBaseClos(inVO);
		} catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-자동이체해지정보갱신실패] - " + se.getMessage());
		}
	}

	/**
	 * <p>매소드명		: updateLoanRelMan</p>
	 * <p>설명			: [대출_관계] DB update 발송방법 수정</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: Connection - </p>
	 * <p>매소드리턴값	: update건수 </p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateLoanRelMan(AutoTranAcntProcDTO inVO, String askMeth) throws Exception {
		try {

			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setAskMeth(askMeth);
			inDTO.setEmpNo(inVO.getEmpNo());			//처리사원
			inDTO.setLoanNo(inVO.getLoanNo());			//대출번호
			inDTO.setLoanSeq(inVO.getLoanSeq());			//대출순번
			inDTO.setRlDueManNo(inVO.getRlDueManNo());		//실납입자번호

			return autoTranAcntProcMapper.updateLoanRelMan(inDTO);
		} catch(SQLException se) {
			//StringUtil.logSql(sql.toString(), new String[]{});
			throw new Exception("[자동이체계좌처리-대출관계갱신오류] - " + se.getMessage());
		}
	}

	/**
	 * <p>매소드명		: updateLoanRelMan</p>
	 * <p>설명			: [대출_관계] DB update 발송방법 수정</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: ITransaction - </p>
	 * <p>매소드리턴값	: update건수 </p>
	 * <p>예외처리		: Exception</p>
	 */
	private int insertLoanRlDueMan(AutoTranAcntProcDTO inVO, String dueMethCd, String emalAskFg, String sNum) throws Exception {


		try {
			AutoTranAcntProcDTO inDTO = new AutoTranAcntProcDTO();
			inDTO.setsNum(StringUtil.parseDouble(sNum));
			inDTO.setEmalAskFg(StringUtil.nvl(emalAskFg));
			inDTO.setDueMethCd(dueMethCd);
			inDTO.setEmpNo(inVO.getEmpNo());			//처리사원
			inDTO.setEmpNo(inVO.getEmpNo());			//처리사원
			inDTO.setLoanNo(inVO.getLoanNo());			//대출번호
			inDTO.setLoanSeq(inVO.getLoanSeq());			//대출순번
			inDTO.setRlDueManNo(inVO.getRlDueManNo());		//실납입자번호

			return autoTranAcntProcMapper.insertLoanRlDueMan(inDTO);
		} catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-실납입자등록오류] - " + se.getMessage());
		}
	}

	/**
	 *
	 * <p>매소드명		: updateLoanBaseUpdt</p>
	 * <p>설명			: [대출_기본] DB update 수정처리시</p>
	 * <p>매소드 인수1	: AutoTranAcntProcDTO - 계좌요청VO</p>
	 * <p>매소드 인수2	: Connection </p>
	 * <p>매소드리턴값	: update건수 </p>
	 * <p>예외처리		: Exception</p>
	 */
	private int updateLoanBaseUpdt(AutoTranAcntProcDTO inVO) throws Exception {
		int cnt = 0;
		try {
			cnt = autoTranAcntProcMapper.updateLoanBaseUpdt(inVO);
		} catch(SQLException se) {
			throw new Exception("[자동이체계좌처리-대출계좌적용일자 갱신실패] - " + se.getMessage());
		}
		return cnt;
	}

	/**
	 * TODO 미사용
	 * @param loanNo
	 * @param loanSeq
	 * @param acntSnum
	 * @param con
	 * @return
	 */
	//private RtAcntDescTDO getCurrentAcntDesc(String loanNo, String loanSeq, int acntSnum, Connection con){}

	/**
	 * TODO 미사용
	 * 신규신청시 파일 등록
	 * @param inVO
	 * @param tx
	 * @return
	 */
//	private long createFiles(AutoTranAcntProcDTO inVO){}

//	/**
//	 * <p>매소드명		: insertAcntGram</p>
//	 * <p>설명			: 자동이체 계좌전문 DB에 insert</p>
//	 * <p>매소드 인수1	: AutoTranAcntGramDO</p>
//	 * <p>매소드 인수2	: Connection</p>
//	 * <p>매소드리턴값	: insert 건수</p>
//	 * <p>예외처리		: Exception</p>
//	 */
//	public static int insertAcntGram(AutoTranAcntGramDO gramDO, Connection con) throws Exception {
//
//		StringBuffer sql = new StringBuffer(1024);
//		sql.append("\n	INSERT INTO DBSRQST.RT_ACNT_GRAM (  	");
//		sql.append("\n		  SNR_DTTM                      	");
//		sql.append("\n		, DEPO_OWN_NO                   	");
//		sql.append("\n		, TR_DT                         	");
//		sql.append("\n		, BANK_CD                       	");
//		sql.append("\n		, ACNT_NO                       	");
//		sql.append("\n		, RECV_FG                       	");
//		sql.append("\n		, FRST_REG_DT                   	");
//		sql.append("\n		, FRST_REG_TM                   	");
//		sql.append("\n		, FRST_REG_EMP_NO               	");
//		sql.append("\n		, LAST_PROC_DT                  	");
//		sql.append("\n		, LAST_PROC_TM                  	");
//		sql.append("\n		, LAST_PROC_EMP_NO              	");
//		sql.append("\n	) VALUES (                          	");
//		sql.append("\n	  	  ?                             	");
//		sql.append("\n		, ?                             	");
//		sql.append("\n		, ?                             	");
//		sql.append("\n		, ?                             	");
//		sql.append("\n		, ?                             	");
//		sql.append("\n		, '0'                           	");
//		sql.append("\n		, TO_CHAR(SYSDATE, 'YYYY-MM-DD')	");
//		sql.append("\n		, TO_CHAR(SYSDATE, 'HH24MISS')  	");
//		sql.append("\n		, ?                             	");
//		sql.append("\n		, TO_CHAR(SYSDATE, 'YYYY-MM-DD')	");
//		sql.append("\n		, TO_CHAR(SYSDATE, 'HH24MISS')  	");
//		sql.append("\n		, ?                             	");
//		sql.append("\n	)                                   	");
//
//		PreparedStatement pstmt = null;
//		int cnt = 0;
//
//		try {
//			pstmt = con.prepareStatement(sql.toString());
//			pstmt.setString(1, gramDO.getSnrDttm());		//전송시각
//			pstmt.setString(2, gramDO.getDepoOwnNo());		//예금주번호
//			pstmt.setString(3, gramDO.getTrDt());			//거래일자
//			pstmt.setString(4, gramDO.getBankCd());			//은행코드
//			pstmt.setString(5, gramDO.getAcntNo());			//계좌번호
//			pstmt.setString(6, gramDO.getEmpNo());			//최초등록사번
//			pstmt.setString(7, gramDO.getEmpNo());			//최종처리사번
//
//			cnt = pstmt.executeUpdate();
//
//		} catch(SQLException se) {
//			throw new Exception("[자동이체계좌전문 송신내역 INSERT 오류] - " + se.getMessage());
//		} finally {
//			DbUtils.closeQuietly(pstmt);
//		}
//		return cnt;
//	}
//
//	/**
//	 * <p>매소드명		: updateAcntGram</p>
//	 * <p>설명			: 자동이체 계좌전문 DB에 update</p>
//	 * <p>매소드 인수1	: AutoTranAcntGramDO</p>
//	 * <p>매소드 인수2	: Connection</p>
//	 * <p>매소드리턴값	: update 건수</p>
//	 * <p>예외처리		: Exception</p>
//	 */
//	public static int updateAcntGram(AutoTranAcntGramDO gramDO, Connection con) throws Exception {
//
//		StringBuffer sql = new StringBuffer(1024);
//		sql.append("\n	UPDATE                                             		");
//		sql.append("\n		DBSRQST.RT_ACNT_GRAM                           		");
//		sql.append("\n	SET                                                		");
//		sql.append("\n		  DEPO_OWN_NM      = ?                         		");
//		sql.append("\n		, RSPN_CD          = ?                         		");
//		sql.append("\n		, RECV_FG          = ?                         		");
//		sql.append("\n		, RECV_GRAM_TXT    = ?                         		");
//		sql.append("\n		, LAST_PROC_EMP_NO = ?                         		");
//		sql.append("\n		, LAST_PROC_DT = TO_CHAR(SYSDATE, 'YYYY-MM-DD')		");
//		sql.append("\n		, LAST_PROC_TM = TO_CHAR(SYSDATE, 'HH24MISS')  		");
//		sql.append("\n	WHERE                                              		");
//		sql.append("\n		SNR_DTTM = ?                                   		");
//		sql.append("\n		AND DEPO_OWN_NO = ?                            		");
//
//		PreparedStatement pstmt = null;
//		int cnt = 0;
//
//		try {
////			pstmt = con.prepareStatement(sql.toString());
//			pstmt = new LoggableStatement(con, sql.toString());
//
//			pstmt.setString(1, gramDO.getDepoOwnNm());		//예금주명
//			pstmt.setString(2, gramDO.getRspnCd());			//응답코드
//			pstmt.setString(3, "1");						//수신여부
//			pstmt.setString(4, gramDO.getRecvGramTxt());	//수신전문
//			pstmt.setString(5, gramDO.getEmpNo());			//최종처리사번
//			pstmt.setString(6, gramDO.getSnrDttm());		//전송시각
//			pstmt.setString(7, gramDO.getDepoOwnNo());		//예금주번호
//
//			cnt = pstmt.executeUpdate();
//
//		} catch(SQLException se) {
//			throw new Exception("[자동이체계좌전문 수신내역 UPDATE 오류] - " + se.getMessage());
//		} finally {
//			DbUtils.closeQuietly(pstmt);
//		}
//		return cnt;
//	}
//
//	/**
//	 * <p>매소드명		: selectAcntGram</p>
//	 * <p>설명			: 자동이체 계좌전문이 수신되었는지 조회</p>
//	 * <p>매소드 인수1	: AutoTranAcntGramDO</p>
//	 * <p>매소드 인수2	: Connection</p>
//	 * <p>매소드리턴값	: update 건수</p>
//	 * <p>예외처리		: Exception</p>
//	 */
//	public static String selectAcntGram(AutoTranAcntGramDO gramDO, Connection con) throws Exception {
//
//		StringBuffer sql = new StringBuffer(1024);
//		sql.append("\n	SELECT                  	");
//		sql.append("\n		RECV_GRAM_TXT       	");
//		sql.append("\n	FROM                    	");
//		sql.append("\n		DBSRQST.RT_ACNT_GRAM	");
//		sql.append("\n	WHERE                   	");
//		sql.append("\n		SNR_DTTM = ?        	");
//		sql.append("\n		AND DEPO_OWN_NO = ? 	");
//		sql.append("\n		AND RECV_FG = '1'   	");
//		sql.append("\n	FETCH                   	");
//		sql.append("\n		FIRST 1 ROW ONLY    	");
//		sql.append("\n	                 	");
//
//		String gramTxt = null;
//
//		PreparedStatement pstmt = null;
//		ResultSet rs = null;
//
//		try {
////			pstmt = con.prepareStatement(sql.toString());
//			pstmt = new LoggableStatement(con, sql.toString());
//
//			pstmt.setString(1, gramDO.getSnrDttm());		//전송시각
//			pstmt.setString(2, gramDO.getDepoOwnNo());		//예금주번호
//
//			rs = pstmt.executeQuery();
//
//			if (rs.next()) {
//				gramTxt = StringUtil.trim(rs.getString("RECV_GRAM_TXT"));	// 수신전문
//			}
//		} catch(SQLException se) {
//			throw new Exception("[자동이체계좌전문 수신내역 UPDATE 오류] - " + se.getMessage());
//		} finally {
//			DbUtils.closeQuietly(rs);
//			DbUtils.closeQuietly(pstmt);
//		}
//		return gramTxt;
//	}

	/**
	 * <p>매소드명		: makeResult</p>
	 * <p>설명			: 요청결과를 에러코드 - 에러메시지로 생성함. </p>
	 * <p>매소드 인수1	: errCd - 4자리 에러코드</p>
	 * <p>매소드 인수2	: addMsg - 에러메시지에 추가할 결과 Comment</p>
	 * <p>매소드리턴값	: List</p>
	 * <p>예외처리		: N/A</p>
	 */
	public AutoTranAcntProcOutVO makeResult(String errCd, String addMsg) {
		LOGGER.info("■ AutoTranAcntProcCC.proc.makeResult : errCd = "+errCd);
		LOGGER.info("■ AutoTranAcntProcCC.proc.makeResult : addMsg = "+addMsg);
		AutoTranAcntProcOutVO outVO = new AutoTranAcntProcOutVO();
		outVO.setRsltCd(errCd);
		outVO.setRsltCntn(errCd + " " + addMsg);
		LOGGER.info("■ AutoTranAcntProcCC.proc.makeResult : addMsg = "+outVO.getRsltCd());
		return outVO;
	}

	/**
	 * <p>매소드명		: getMsg</p>
	 * <p>설명			: 에러코드에 해당하는 에러메시지 얻기</p>
	 * <p>매소드 인수1	: errCd - 4자리 에러코드</p>
	 * <p>매소드리턴값	: 맵핑된 에러코드가 없을땐 "" 리턴.</p>
	 * <p>예외처리		: N/A</p>
	 */
	private String getMsg(String errCd) {
		String errMsg = StringUtil.nvl((String)errMap.get(errCd));
		return errMsg;
	}

	/**
	 * <p>매소드명		: getStrVal</p>
	 * <p>설명			: get String Value of Map</p>
	 * <p>매소드 인수1	: Map</p>
	 * <p>매소드 인수2	: String</p>
	 * <p>매소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	private String getStrVal(Map map, String key) {
		return  String.valueOf(map.get(key));
	}

	/**
	 * <p>매소드명		: getIntVal</p>
	 * <p>설명			: get Int Value of Map</p>
	 * <p>매소드 인수1	: Map</p>
	 * <p>매소드 인수2	: String</p>
	 * <p>매소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	private int getIntVal(Map map, String key) {
		return (int)StringUtil.parseDouble(String.valueOf(map.get(key)));
	}
}
