package hanalife.r.at.dl.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.DbsBatchSkipException;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.DateUtil;
import hanalife.r.at.ad.mapper.AutoTranCmsMapper;
import hanalife.r.at.ad.mapper.dto.AutoTranCmsInDTO;
import hanalife.r.at.ad.mapper.dto.AutoTranCmsOutDTO;
import hanalife.r.at.dl.service.RATDL0101Service;
import hanalife.r.at.dl.vo.RATDLInDTO;
import hanalife.r.at.dl.vo.RATDLOutDTO;
import hanalife.util.BizException;

@Service("RATDL0101Service")
public class RATDL0101ServiceImpl implements RATDL0101Service{

	private static final Logger log = LoggerFactory.getLogger(RATDL0101ServiceImpl.class);

	@Autowired
    private CommBizService commBiz;

	@Autowired
    private AutoTranCmsMapper autoTranCmsMapper;

	private static MsgEnum msgEnum;

    private String jobId; //작업ID
    private String jobDt;
    private String askYymm;
    private String planDt;
    private String trOrgCd;

    @Override
    public RATDLOutDTO getRATDL0101(RATDLInDTO reqInVO) throws Exception {
        log.info("################ getRATDL0101 START");
        RATDLOutDTO rtnDTO = new RATDLOutDTO();
        rtnDTO.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        rtnDTO.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        jobId = reqInVO.getJobId(); //작업ID
        jobDt = reqInVO.getJobDt();
        trOrgCd = reqInVO.getTrOrgCd();

        askYymm = DateUtil.addMonth(jobDt.substring(0, 6), 1); //청구년월
        planDt  = askYymm + "01";
        log.info("################ getRATDL0101 1");
        if (!commBiz.isWorkDt(jobDt)) {
            throw new BizException(jobDt + " 영업일이 아닙니다.");
        }
        // 날짜포맷 체크
        if (!DateUtil.isValid(askYymm, "yyyyMM")) {
            throw new BizException("잘못된 청구년월을 입력하셨습니다. (입력청구년월 : " + askYymm + ")");
        }
        if (!DateUtil.isValid(planDt, "yyyyMMdd")) {
            throw new BizException("잘못된 계획수립일자을 입력하셨습니다. (입력계획수립일자 : " + planDt + ")");
        }
        log.info("################ getRATDL0101 2");
        log.info("■ "+askYymm+" 기존 데이터 작업상태 확인");   // 이미 청구작업이 되었는지 등
        chkExistsPlan(); //기존에 존재하는 계획을 확인

        // 12월 15일 내년도 회계기준 정보, 알림 처리
        // TODO 미사용중
        // sendAcctCopyAlarm();

        log.info("■ "+askYymm+" [RT_AUTO_TRAN_PLAN_BASE] 자동이체계획 생성");
        AutoTranCmsInDTO createInDTO = new AutoTranCmsInDTO();
        createInDTO.setAskYymm(askYymm);
        createInDTO.setPlanDt(planDt);
        createInDTO.setTrOrgCd(trOrgCd);
        createInDTO.setJobId(jobId);

        /*** -- 공통 코드 --
        1. 직종코드     (H00371 : OCPT_CD)
            => A:관리직, B:영업직, C:채권직
        2. 성격구분코드 (H00530 : CHAR_DIV_CD)
            => AA0:정상
        3. 청구상태코드 (R00027 : ASK_STAT_CD)
            => 1:마감, 2:선정, 3:확정, 4:청구집계, 5:송신, 6:수신, 7:결과반영, 8:입금집계, 9:입금
        4. 처리상태코드 (R00025 : PROC_STAT_CD)
            => 0:대기, 1:작업중, 2:완료, 3:에러
        ***/
        log.info("################ getRATDL0101 3");
        int createCnt = autoTranCmsMapper.createAutoTranPlanBase(createInDTO);
        log.info("################ getRATDL0101 4");
        if (createCnt < 1) {
            throw new BizException("■ 해당 청구년월(" + askYymm + ")에 대해 등록된 계획수립이 없습니다.");
        }

        log.info("################ getRATDL0101 END");
        return rtnDTO;
    }

    /**
     * 기존에 존재하는 계획을 확인 한다.
     * @throws Exception
     */
    private void chkExistsPlan() throws Exception {
        log.info("■ [RT_AUTO_TRAN_PLAN_BASE] ASK_STAT_CD 체크");
        AutoTranCmsInDTO chkInDTO = new AutoTranCmsInDTO();
        chkInDTO.setAskYymm(askYymm);
        chkInDTO.setPlanDt(planDt);
        chkInDTO.setTrOrgCd(trOrgCd);

        AutoTranCmsOutDTO chkOutDTO = autoTranCmsMapper.chkAskYymm(chkInDTO); //자동이체 일정 처리 조회

        if (chkOutDTO==null) {
            throw new BizException("해당 청구년월("+askYymm+")의 청구상태확인 중 오류입니다.");
        }

        log.info("■ 청구년월 : " + askYymm);
        log.info("■ 계획수립일자 : " + planDt);

        int cnt = chkOutDTO.getTotCnt();
        int askCnt = chkOutDTO.getJobCnt();

        log.info("■ cnt : " + cnt + " / askCnt : " + askCnt);

        //해당청구년월에 대해 계획등록여부를 확인한다.
        if (askCnt > 0) {
            throw new BizException("해당 청구년월(" + askYymm + ")의 계획수립일자(" + planDt + ")에 대해 이미 청구진행 중입니다.");
        }

        // 수립된 계획일정이 존재하면 해당 계획을 삭제한다.
        if (cnt > 0) {
            AutoTranCmsInDTO delInDTO = new AutoTranCmsInDTO();
            chkInDTO.setAskYymm(askYymm);
            chkInDTO.setPlanDt(planDt);
            chkInDTO.setTrOrgCd(trOrgCd);

            int deleteCnt = autoTranCmsMapper.deleteAutoTranPlanBase(delInDTO);

            if (deleteCnt < 1) {
                throw new DbsBatchSkipException("해당 청구년월,계획수립일자(" + askYymm + "," + planDt + ")에 기마감건 삭제 실패했습니다.");
            }

            log.info("■ 기생성 데이터 존재 => 삭제건수: " + deleteCnt);
        }
    }
}
