package hanalife.r.at.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.DbsBatchException;
import hanalife.batch.ProcObj;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.StringUtil;
import hanalife.r.at.dl.service.AutoTranIamtService;
import hanalife.r.at.dl.service.RATDL0401Service;
import hanalife.r.at.dl.vo.AutoTranIamtOutVO;
import hanalife.r.at.dl.vo.RATDLInDTO;
import hanalife.r.at.dl.vo.RATDLOutDTO;
import hanalife.r.at.vo.bat.AutoTranIamtObj;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.rc.service.IamtUnrcvService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.IamtUnrcvVO;
import hanalife.util.BizException;

@Service("RATDL0401Service")
public class RATDL0401ServiceImpl implements RATDL0401Service{

	private static final Logger log = LoggerFactory.getLogger(RATDL0401ServiceImpl.class);

	@Autowired
    private CommBizService commBizService;

	@Autowired
    private AutoTranIamtService AutoTranIamt;

	@Autowired
    private AskUnrcvProcService askUnrcvProc;

	@Autowired
    private IamtUnrcvService IamtUnrcv;

	private static MsgEnum msgEnum;

    private List<AutoTranIamtObj> autoTranIamtObjList = null;
    private AskUnrcvVO askUnrcvVO = null;
    private IamtUnrcvVO iamtUnrcvVO = null;
    private ProcObj procObj = null;
    private int procCnt = 0;

    private String jobId; //작업ID
    private String jobDt;
    private int jobSnum  = -1;

    @Override
    public RATDLOutDTO getRATDL0401(RATDLInDTO reqInVO) throws Exception {

        RATDLOutDTO rtnDTO = new RATDLOutDTO();
        rtnDTO.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        rtnDTO.setRsltCntn(msgEnum.SUCCESS.getErrorCn());


        jobId = reqInVO.getJobId(); //작업ID
        jobDt = reqInVO.getJobDt();

        if (!commBizService.isWorkDt(jobDt)) {
            throw new BizException(jobDt + " 영업일이 아닙니다.");
        }

        int[] procJobSeqList = new int[]{1,2,3,4,5,6,7,8};
        if (jobSnum != 0) {
            procJobSeqList = new int[]{jobSnum};
        }

        for (int procSeq : procJobSeqList) {
            executeJob(procSeq);
        }

        return rtnDTO;
    }

    private void executeJob(int procSeq) throws Exception {

        //1. 배치작업 정보(처리사원/부서, 처리일자/시간) 조회
        //2. 작업계획 작업중으로 상태변경

        //청구입금배치부서코드 검색(처리사원/부서, 처리일자/시각을 조회)
        ProcObj procObj = commBizService.getBatchProcInfo();

        procObj.setJobDt(jobDt);
        procObj.setJobSnum(procSeq);
        procObj.setIsrtEmpNo(jobId);    //EMP_NO 배치명으로 설정
        procObj.setJobId(jobId);

        // 청구대상 데이터 확인
        chkAskRsv(procObj);

        // 자동이체계획 확인
        if (!chkPlan(procObj)) {
            // TODO 확인필요
            //con.commit();
            return;
        }

        //자동이체입금 배치처리
        procAutoTranIamt(procObj);

        //작업 마감
        procCls(procObj);

    }

    /**
     * 청구 vs 수신 데이터 검증
     * @param procObj
     * @throws Exception
     */
    private void chkAskRsv(ProcObj procObj) throws Exception {

        List<AutoTranIamtOutVO> outList = AutoTranIamt.chkIamtCond(procObj);
        for (int i=0; i<outList.size(); i++) {

            String trOrgCd = outList.get(i).getTrOrgCd();
            if (outList.get(i).getAskCnt() != outList.get(i).getRecvCnt()) {
                throw new DbsBatchException(" 청구건수(" + outList.get(i).getAskCnt()
                        +")와 수신건수(" +outList.get(i).getRecvCnt() +")가 다릅니다.");
            }

            if (outList.get(i).getTotPlanCnt() < 1) {
                throw new DbsBatchException(" 자동이체계획이 없습니다.");
            }

            if (outList.get(i).getPlanErrStatCnt() > 0) {
                //throw new Exception(trOrgCd+") 자동이체계획 상태를 확인하세요.");
                log.info("■■■■■ ("+trOrgCd+") 자동이체계획 상태를 확인하세요.");
                // TODO 확인필요
                // con.commit();
                continue;
            }

            if (outList.get(i).getIamtCnt() > 0 && outList.get(i).getJobCnt()<1) {
                throw new DbsBatchException(trOrgCd+") 작업계획 미등록");
            }
        }
    }


    /**
     * 입금 계획 확인
     * @param procObj
     * @throws Exception
     */
    private boolean chkPlan(ProcObj procObj) throws Exception {
        //작업계획 존재유무 확인
        procObj = AutoTranIamt.searchJobPlan(procObj);
        if (StringUtil.isNull(procObj.getStrtLoanNo())) {
            log.info("자동이체입금처리 대상이 없습니다. 1(" + procObj.getJobDt() + ", " + procObj.getJobId() + ", " + procObj.getJobSnum() + ")");
            return false;
        }

        if (AutoTranIamt.updateJobPlan("2", procObj) < 1) {
            log.info("작업계획 대상이 없습니다. (" + jobId + ", " + jobDt + "_" + jobSnum + ")");
            return false;
        }

        int cnt = AutoTranIamt.updateAutoTranPlanBase(procObj);

        //작업을 동시에 4개 실행해서 일단 작업 상태를 커밋 찍고 간다.
        // TODO 확인필요
        // con.commit();    // 여러건을 돌릴때 SKIP 하기 위함.

        if (cnt < 1) {
            log.info("자동이체계획 대상이 없습니다. (" + jobId + ", " + jobDt + "_" + jobSnum + ")");
            return false;
        }
        return true;
    }

    /**
     * <p>메소드명  : procAutoTranIamt</p>
     * <p>설    명    : 자동이체입금 처리</p>
     * <p>메소드인수 : ProcObj</p>
     * <p>리 턴 값 : N/A</p>
     */
    private void procAutoTranIamt(ProcObj procObj) throws Exception {

        this.procObj = procObj;
        initProc();

        try {

            //자동이체 입금대상 조회
            List<AutoTranIamtObj> outListDTO = AutoTranIamt.searchAutoTranIamtObj(procObj);

            log.info("자동이체입금대상 시작");

            for(AutoTranIamtObj iamtObj : outListDTO) {
                addProc(iamtObj);   //200건씩 처리대상 담음
            }

            proc();

            log.info("■ 자동이체청구 종료");

        } finally {
            log.info("자동이체 입금처리에 종료");
        }
    }

    /**
     * <p>메소드명  : procCls</p>
     * <p>설    명    : 자동이체입금 마감처리</p>
     * <p>메소드인수 : ProcObj</p>
     * <p>리 턴 값 : N/A</p>
     */
    private void procCls(ProcObj procObj) throws Exception {
        log.info("■ [RT_JOB_PLAN_BASE] JOB_STAT_CD = '3'");
        AutoTranIamt.updateJobPlan("3", procObj);

    }

    private void addProc(AutoTranIamtObj autoTranIamtObj) throws Exception {

        autoTranIamtObjList.add(autoTranIamtObj);
        askUnrcvVO.addAskUnrcvObj(getAskUnrcvObjVO(autoTranIamtObj));
        iamtUnrcvVO.addIamtUnrcvObjVO(getIamtUnrcvObjVO(autoTranIamtObj, procObj));

        if( 1 == autoTranIamtObjList.size() ){
            // 작업처리전 시작 대출번호를 저장한다.
            log.info("■ [RT_JOB_PLAN_BASE] JOB_LOAN_NO UPDATE (현재 작업대출 : " + autoTranIamtObj.getLoanNo() + ")");

            int exeCnt = AutoTranIamt.updateJobPlanBase(0, autoTranIamtObj.getLoanNo(), procObj);

            if( exeCnt < 1) {
                throw new BizException("자동이체입금 마감대상의 작업완료가 정상완료되지 않았습니다.(현재 작업대출 : " + autoTranIamtObj.getLoanNo() + ")");
            }
            // TODO 확인필요
            //commit(con);
        } else if (200 == autoTranIamtObjList.size()){
            proc();
        }
    }

    private AskUnrcvVO calcAskUnrcv(AskUnrcvVO askUnrcvVO) {
        try {
            askUnrcvProc.calcAskUnrcv(askUnrcvVO);
        } catch (Exception e) {
            throw new BizException("청구미수 계산에러("+e.getMessage()+")", e);
        }

        if (!askUnrcvVO.isSuccess()) {
            throw new BizException("청구미수 계산중 에러발생[" + askUnrcvVO.rsltCntn + "]");
        }
        return askUnrcvVO;
    }

    /**
     * <p>메소드명      : procIamtUnrcv
     * <p>설    명        : 입금미수 처리
     * <p>메소드 인수1   : IamtUnrcvVO iamtUnrcvVO
     * <p>메소드 인수2   : AskUnrcvVO askUnrcvVO
     * <p>메소드 인수3   : Connection con
     * <p>메소드 리턴값   : IamtUnrcvVO- 입금미수처리결과
     * <p>예외처리      : throws Exception
     */
    private IamtUnrcvVO procIamtUnrcv(IamtUnrcvVO iamtUnrcvVO, AskUnrcvVO askUnrcvVO) {

        IamtUnrcv.procRcpt(iamtUnrcvVO, askUnrcvVO);

        if ( !iamtUnrcvVO.isSuccess() ) {
            throw new BizException("입금미수 계산중 에러발생" + iamtUnrcvVO.rsltCntn);
        }
        return iamtUnrcvVO;
    }

    private void initProc(){
        autoTranIamtObjList = new ArrayList<>();
        askUnrcvVO = new AskUnrcvVO();
        askUnrcvVO.midRmbrUnCalcFg = Constants.YES; //중도상환금액 계산안함.
        iamtUnrcvVO = new IamtUnrcvVO();
        iamtUnrcvVO.autoSetlFg = "1";
        iamtUnrcvVO.tranUnprocFg = "1";
    }

    private void proc(){
        // 처리건수
        int tmpProcCnt = autoTranIamtObjList.size();

        if( tmpProcCnt < 1){
            return;
        }

        // 청구미수계산
        calcAskUnrcv(askUnrcvVO);

        // 입금미수처리
        iamtUnrcvVO = procIamtUnrcv(iamtUnrcvVO, askUnrcvVO);

        //자동이체거래내역의 결제번호를 수정한다.
        try {
            AutoTranIamt.updateAutoTranTrDesc(iamtUnrcvVO.getIamtUnrcvObjVOList(), procObj);
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }

        initProc();

        // 200건단위로 처리해서 에러발생시 시작대출번호부터 처리하도록
        // TODO 확인필요
        // commit(con);

        procCnt += tmpProcCnt;
    }

    private int getProcCnt(){
        return procCnt;
    }

    /**
     * <p>메소드명 : getAskUnrcvObjVO</p>
     * <p>설명 : 자동이체입금처리 대상에서 청구미수대상객체를 생성</p>
     * <p>메소드인수1 : AutoTranIamtObj autoTranIamtObj </p>
     * <p>메소드리턴값 : AskUnrcvObjVO </p>
     */
    private AskUnrcvObjVO getAskUnrcvObjVO(AutoTranIamtObj autoTranIamtObj) {
        AskUnrcvObjVO askUnrcvObjVO = new AskUnrcvObjVO();
        askUnrcvObjVO.loanNo = autoTranIamtObj.getLoanNo();
        askUnrcvObjVO.loanSeq = autoTranIamtObj.getLoanSeq();
        askUnrcvObjVO.setlDt = autoTranIamtObj.getSetlDt();
        askUnrcvObjVO.acctDt = autoTranIamtObj.getAcctDt();
        return askUnrcvObjVO;
    }

    /**
     * <p>메소드명 : getIamtUnrcvObjVO</p>
     * <p>설명 : 자동이체입금처리 대상에서 입금미수대상객체를 생성</p>
     * <p>메소드인수1 : AutoTranIamtObj autoTranIamtObj </p>
     * <p>메소드리턴값 : AskUnrcvObjVO </p>
     */
    private IamtUnrcvObjVO getIamtUnrcvObjVO(AutoTranIamtObj autoTranIamtObj, ProcObj procObj) {
        IamtUnrcvObjVO iamtUnrcvObjVO = new IamtUnrcvObjVO();
        iamtUnrcvObjVO.loanNo = autoTranIamtObj.getLoanNo();
        iamtUnrcvObjVO.loanSeq = autoTranIamtObj.getLoanSeq();
        iamtUnrcvObjVO.setlDt = autoTranIamtObj.getSetlDt();
        iamtUnrcvObjVO.acctUnitCd = autoTranIamtObj.getOccrAcctUnitCd();
        iamtUnrcvObjVO.acctDt = autoTranIamtObj.getAcctDt();
        iamtUnrcvObjVO.setlDivCd = autoTranIamtObj.getSetlDivCd();
        iamtUnrcvObjVO.bankCd = autoTranIamtObj.getBankCd();
        iamtUnrcvObjVO.acntNo = autoTranIamtObj.getAcntNo();
        iamtUnrcvObjVO.setlAmt = autoTranIamtObj.getSetlAmt();
        iamtUnrcvObjVO.rcptAmt = autoTranIamtObj.getRcptAmt();
        iamtUnrcvObjVO.cashAmt = autoTranIamtObj.getCashAmt();
        iamtUnrcvObjVO.rcptTpCd = autoTranIamtObj.getRcptTpCd();

        iamtUnrcvObjVO.isrtDeptCd = procObj.getIsrtDeptCd();
        iamtUnrcvObjVO.frstRegEmpNo = procObj.getIsrtEmpNo();


        return iamtUnrcvObjVO;
    }
}
