package hanalife.r.at.mn.web;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.lang3.RegExUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.StringUtil;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.co.vo.BndVo;
import hanalife.framework.comm.vo.UserSessionVO;
import hanalife.r.at.ac.vo.RtAcntCnfmDescTDO;
import hanalife.r.at.ad.mapper.dto.AutoTranAcntProcDTO;
import hanalife.r.at.ad.service.AutoTranAcntProcService;
import hanalife.r.at.ad.vo.AutoTranAcntProcOutVO;
import hanalife.r.at.mn.service.RATMNM01Service;
import hanalife.r.at.mn.vo.RATMNM01DSAPRVREGISTERVO;
import hanalife.r.at.mn.vo.RATMNM01DSBNDVO;
import hanalife.r.at.mn.vo.RATMNM01DSSDVO;
import hanalife.r.at.mn.vo.RATMNM01DSSEARCHVO;
import hanalife.r.at.mn.vo.RATMNM01S01InVO;
import hanalife.r.at.mn.vo.RATMNM01S01OutVO;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.at.service.AcntCnfmService;
import hanalife.r.co.at.vo.AcntChkGramVO;
import hanalife.r.co.la.service.LoanInfoProcMngService;
import hanalife.r.co.la.vo.LoanInfoProcMngInVO;
import hanalife.r.co.la.vo.LoanInfoProcMngOutVO;
import hanalife.util.BizException;
import hanalife.util.format.ServerSysDate;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM01Controller.java Class
 *
 * 클래스설명   : 자동이체계좌관리 (RATMNM01) Controller
 * 작성일자     : 2023. 4. 11.
 * 작성자명     : 70326 / 유현식 / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/at/mn")
@Controller
public class RATMNM01Controller {

	@Resource(name = "RATMNM01Service")
	private RATMNM01Service RATMNM01;

	@Resource(name = "LoanInfoProcMngService")
	private LoanInfoProcMngService loanInfo;

	@Resource(name = "AskUnrcvProcService")
	private AskUnrcvProcService askUnrcvProc;

	@Resource(name = "AutoTranAcntProcService")
	private AutoTranAcntProcService autoTranProc;

	@Resource(name = "AcntCnfmService")
	private AcntCnfmService acntCnfmService;

	@Resource(name = "CommBizService")
	private CommBizService commBizService;


	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM01Controller.class);

	public final String TR_DIV_ACNT_CNFM = "1";  // 계좌조회

	// 요청구분 코드
	private final String ACTION_SEARCH = "1"; // 메인화면 조회
	private final String ACTION_ACNT_DELETE = "2"; // 계좌 삭제
	private final String ACTION_MAIL_SEARCH = "4"; // 메일 보낼 정보 검색
	private final String ACTION_ALTERNATIVE_2 = "2"; // 등록
	private final String ACTION_ALTERNATIVE_3 = "3"; // 결과요청
	private final String ACTION_ALTERNATIVE_4 = "4"; // 확인취소
	private final String ACTION_ALTERNATIVE_5 = "5"; // 강제등록
	private final String ACTION_ALTERNATIVE_6 = "6"; // 메일발송
	private final String ACTION_ALTERNATIVE_7 = "7"; // 해지사유 회계팀 강제수정
	private final String ACTION_ALTERNATIVE_8 = "8"; // 계좌신청
	private final String ACTION_UPLOAD_FILE = "9"; // 증빙파일 업로드

	// 요청, 응답 Dataset명
	private final String DS_SM = "DS_SM"; // 대출정보
	private final String DS_SD = "DS_SD"; // 계좌내역
	//private final String DS_SD02 = "DS_SD02"; // 대출관계자리스트
	private final String DS_BND = "DS_BND"; // 채권정보
	private final String DS_SEARCH = "DS_SEARCH"; // 등록, 결과요청
	private final String DS_EMAIL = "DS_EMAIL"; // MAIL
	private final String DS_APRV_REGISTER = "DS_APRV_REGISTER"; //
	private final String DS_PROF_FILE = "DS_PROF_FILE"; // 증빙파일

	private final String NOT_FOUND_ERR = "ESC1004";

	// 계좌처리구분
	public final String ACNT_APPL_REG  = "1"; // 신규등록
	public final String ACNT_APPL_UPDT = "2"; // 수정
	public final String ACNT_APPL_CLOS = "3"; // 해지
	public final String ACNT_APPL_PASS = "9"; // 등록 (전문생략)

	private final String RSLT_ERROR = "-1";
	private final String RSLT_SUCS = "0";

	// 계좌상태코드
	public static final String ACNT_STAT_UN_REG         = "00"; // 미등록
	public static final String ACNT_STAT_ACNT_CNFM_CNCL = "02"; // 계좌확인취소
	public static final String ACNT_STAT_ACNT_CNFM_MID  = "01"; // 계좌확인중
	public static final String ACNT_STAT_ACNT_CNFM_SCS  = "03"; // 계좌확인성공
	public static final String ACNT_STAT_ACNT_CNFM_ERR  = "04"; // 계좌확인오류
	public static final String ACNT_STAT_ACNT_IVLT_REG  = "05"; // 계좌강제등록
	public static final String ACNT_STAT_NEW_APPL       = "11"; // 신규신청
	public static final String ACNT_STAT_NEW_APPL_MID   = "12"; // 신규신청중
	public static final String ACNT_STAT_NEW_NORM       = "13"; // 신규정상
	public static final String ACNT_STAT_NEW_ERR        = "14"; // 신규오류
	public static final String ACNT_STAT_CLOS_APPL      = "31"; // 해지신청
	public static final String ACNT_STAT_CLOS_APPL_MID  = "32"; // 해지신청중
	public static final String ACNT_STAT_CLOS           = "33"; // 해지

	private String loginEmpNo = "";

	/**
	 * <p>메소드명      : 자동이체계좌관리 대출정보 조회 /RATMNM01S01.do </p>
	 * <p>작성일자      : 2023. 4. 11.
	 * <p>작성자(author): 70326
	 * <p>설명          : 자동이체계좌관리 대출정보 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM01S01.do")
	public String RATMNM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RATMNM01Controller RATMNM01S01 Start #####");
		model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, "0000");
		model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, "정상 처리되었습니다.");

		try {
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

			/** 자동이체계좌관리 입력값 세팅 */
			RATMNM01DSSEARCHVO searchVo = new RATMNM01DSSEARCHVO();

			searchVo.setLoanNo((String)sourceMap.get("loanNo"));   /** 대출번호 */
			searchVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */

			/** 자동이체계좌관리 VO 세팅 */
			RATMNM01S01InVO targetVo = new RATMNM01S01InVO();
			RATMNM01S01OutVO outVo = new RATMNM01S01OutVO();

			/** 자동이체계좌관리 입력값 화면으로 다시 넘겨줌 */
          	List<RATMNM01DSSEARCHVO> resultList = new ArrayList<RATMNM01DSSEARCHVO>();
          	resultList.add(searchVo);
        	outVo.setRATMNM01DSSEARCHVO(resultList);

        	LOGGER.info("##### RATMNM01Controller RATMNM01S01 입력 InVO 세팅 #####");
        	/** 입력 InVO 세팅 */
        	targetVo.setRATMNM01DSSEARCHVO(searchVo);
        	LoanInfoProcMngOutVO resultVo = new LoanInfoProcMngOutVO();

        	/** 대출정보 조회 */
        	LOGGER.info("##### RATMNM01Controller RATMNM01S01 대출정보 조회 시작 #####");
        	resultVo = searchSmList(targetVo);

			if(resultVo == null) {
				throw new Exception("ESC1004");
			}
			LOGGER.info("##### RATMNM01Controller RATMNM01S01 대출정보 조회 완료 #####");
			/** 대출순번 SET */
			if(resultVo != null) {
				if(!resultVo.getListLoanInfoProcMngObjVO().isEmpty()) {
					targetVo.getRATMNM01DSSEARCHVO().setLoanSeq(resultVo.getListLoanInfoProcMngObjVO().get(0).getLoanSeq());
					XFrame5Util.setOutputData("DS_SM", resultVo.getListLoanInfoProcMngObjVO(), model);
				}
			}

			/** 화면으로 데이터셋 전달 */
			XFrame5Util.setOutputData("DS_SEARCH", outVo.getRATMNM01DSSEARCHVO(), model);

			/** 청구미수 정보조회 */
			LOGGER.info("##### RATMNM01Controller RATMNM01S01 청구미수 조회 시작 #####");
			AskUnrcvVO askUnrcvVo = null;
			askUnrcvVo = getAskUnrcv(targetVo);
			RATMNM01DSBNDVO bndVo = new RATMNM01DSBNDVO();
			LOGGER.info("##### RATMNM01Controller RATMNM01S01 청구미수 조회 완료 #####");

			if(askUnrcvVo != null) {
				List<RATMNM01DSBNDVO> bndInfo = new ArrayList<RATMNM01DSBNDVO>();

				bndVo.setThmmDueDt(askUnrcvVo.getBndVO(searchVo.getLoanNo(), searchVo.getLoanSeq()).thmmDueDt);
				bndVo.setAskAmt(askUnrcvVo.getBndVO(searchVo.getLoanNo(), searchVo.getLoanSeq()).askAmt);
				bndVo.setDlyAmt(askUnrcvVo.getBndVO(searchVo.getLoanNo(), searchVo.getLoanSeq()).dlyAmt);

				bndInfo.add(bndVo);

	        	outVo.setRATMNM01DSBNDVO(bndInfo);

				XFrame5Util.setOutputData("DS_BND", outVo.getRATMNM01DSBNDVO(), model);
			}

			List<RATMNM01DSSDVO> dsSdList = this.searchSdList(targetVo);
			if(dsSdList != null) {
				XFrame5Util.setOutputData("DS_SD",dsSdList , model);
			}


			LOGGER.info("##### RATMNM01Controller RATMNM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RATMNM02Controller RATMNM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 계좌확인 처리 /RATMNM01S02.do </p>
	 * <p>작성일자      : 2023. 4. 25.
	 * <p>작성자(author): 70326
	 * <p>설명          : 계좌확인 처리</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM01I02.do")
	public String RATMNM01I02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RATMNM01Controller RATMNM01I02 Start #####");
		model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, "0000");
		model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, "정상 처리되었습니다.");
		HttpSession session = request.getSession();
		UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

		loginEmpNo = sessionVO.getUserNo();
		LOGGER.info("로그인 사번 : " + loginEmpNo);

		try {
			Map<String, Object> dsSearchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);
			Map<String, Object> dsAprvMap   = XFrame5DataSetUtil.getXFrameDataSet("DS_APRV_REGISTER", request, response, model);

			/** 등록 입력값 세팅 */
			RATMNM01DSSEARCHVO searchVo = new RATMNM01DSSEARCHVO();
			RATMNM01DSAPRVREGISTERVO dsAprvVo = new RATMNM01DSAPRVREGISTERVO();

			/** 검색조건 세팅(대출번호, 대출순번) */
			searchVo.setLoanNo((String)dsSearchMap.get("loanNo"));					/** 대출번호 */
			searchVo.setLoanSeq((String)dsSearchMap.get("loanSeq"));				/** 대출순번 */

			/** insert/update 값 세팅 */
			String acntApplDivCd = (String)dsAprvMap.get("acntApplDivCd");	/** 신청구분 : 화면값 */

			dsAprvVo.setLoanNo((String)dsAprvMap.get("loanNo"));					/** 대출번호 */
			dsAprvVo.setLoanSeq((String)dsAprvMap.get("loanSeq"));					/** 대출순번 */
			dsAprvVo.setAcntSnum((String)dsAprvMap.get("acntSnum"));				/** 계좌일련번호 */
			dsAprvVo.setAcntApplDivCd((String)dsAprvMap.get("acntApplDivCd"));		/** 계좌_신청_구분코드[계좌신청구분코드(GUBUN_CODE:R00007)] */
			dsAprvVo.setBankCd((String)dsAprvMap.get("bankCd"));		            /** 은행_코드[은행코드(GUBUN_CODE: A00003)] */
			dsAprvVo.setAcntNo((String)dsAprvMap.get("acntNo"));                    /** 계좌번호 */
			dsAprvVo.setDepoOwnRelCd((String)dsAprvMap.get("depoOwnRelCd"));        /** 예금주_관계_코드[예금주관계코드(GUBUN_CODE: S00550)] */
			dsAprvVo.setDepoOwnNo((String)dsAprvMap.get("depoOwnNo"));              /** 예금주_번호 */
			dsAprvVo.setDepoOwnnm((String)dsAprvMap.get("depoOwnnm"));              /** 예금주명 */
			dsAprvVo.setApplManTel1((String)dsAprvMap.get("applManTel1"));          /** 신청_인_전화1 */
			dsAprvVo.setApplManTel2((String)dsAprvMap.get("applManTel2"));          /** 신청_인_전화2 */
			dsAprvVo.setApplManTel3((String)dsAprvMap.get("applManTel3"));          /** 신청_인_전화3 */
			dsAprvVo.setAcntAplyDt((String)dsAprvMap.get("acntAplyDt"));            /** 계좌_적용_일자 */
			dsAprvVo.setAcntClosRsnCd((String)dsAprvMap.get("acntClosRsnCd"));      /** 계좌_해지_사유_코드[계좌해지사유코드(GUBUN_CODE: R00057)] */
			dsAprvVo.setAcntStatCd((String)dsAprvMap.get("acntStatCd"));            /** 계좌_상태_코드[계좌상태코드(GUBUN_CODE:R00006)] */
			dsAprvVo.setAcntStatNm((String)dsAprvMap.get("acntStatNm"));            /** 계좌_상태_명 */
			dsAprvVo.setCnfmDepoOwnnm((String)dsAprvMap.get("cnfmDepoOwnnm"));      /** 확인_예금주명  */
			dsAprvVo.setAcntCnfmRsltCd((String)dsAprvMap.get("acntCnfmRsltCd"));    /** 계좌_확인_결과_코드  */
			dsAprvVo.setAcntCnfmRsltNm((String)dsAprvMap.get("acntCnfmRsltNm"));    /** 계좌_확인_결과_명 */
			dsAprvVo.setLastProcEmpNo(loginEmpNo);                                  /** 최종_처리_사원번호 */
			dsAprvVo.setSendDt((String)dsAprvMap.get("sendDt"));                    /** 전송_일자 */
			LOGGER.info("dsAprvVo" + (String)dsAprvMap.get("sendDt"));
			LOGGER.info("dsAprvVo" + dsAprvVo.getSendDt());
			dsAprvVo.setSendSnum((String)dsAprvMap.get("sendSnum"));				/** 전송_일련번호 */




			if("1".equals(acntApplDivCd)) {	// 신규
				LOGGER.info("1번 들어옴");
				this.acntChkProc("1",searchVo,dsAprvVo);
			}else {
				String acntStatCd = (String)dsAprvMap.get("acntStatCd");			/** 계좌상태코드 */

				String sendDt   = "";
				String sendSnum = "";

				// 계좌확인중, 계좌확인성공, 계좌확인오류, 신규신청, 신규신청중
				if("01".equals(acntStatCd) || "03".equals(acntStatCd) || "04".equals(acntStatCd) || "11".equals(acntStatCd) || "12".equals(acntStatCd)) {
					List<RtAcntCnfmDescTDO> result = this.selectAcntCnfmDesc(searchVo,dsAprvVo);

					if(result.size() > 0 ) {

						RtAcntCnfmDescTDO source = result.get(0);

						acntStatCd = source.getAcntStatCd();
						sendDt     = StringUtil.nvl(source.getSendDt());
						sendSnum   = StringUtil.nvl(source.getSendSnum());
					}

					if("02".equals(acntStatCd)) {
						throw new Exception("확인취소 계좌 내역은 수정불가 합니다.");
					}
				}

				// Update 계좌 확인 내역(적용일자, 전화번호)
				RtAcntCnfmDescTDO inRoleTDO = new RtAcntCnfmDescTDO();
					// where
					inRoleTDO.setSendDt     (sendDt);                     /* 발송일자 */
					inRoleTDO.setSendSnum   (sendSnum);                   /* 발송일련번호 */
					// set
					inRoleTDO.setAcntAplyDt (dsAprvVo.getAcntAplyDt());	  /* 계좌신청일자 */
					inRoleTDO.setApplManTel1(dsAprvVo.getApplManTel1());  /* 신청전화번호1 */
					inRoleTDO.setApplManTel2(dsAprvVo.getApplManTel2());  /* 신청전화번호2 */
					inRoleTDO.setApplManTel3(dsAprvVo.getApplManTel3());  /* 신청전화번호3 */

				RATMNM01.modifyRATMNM01U01(inRoleTDO);

				// 03: 계좌확인성공, 05:계좌강제등록
				if("03".equals(acntStatCd) || "05".equals(acntStatCd)){
					Map<String, Object> smdo   = XFrame5DataSetUtil.getXFrameDataSet("DS_APRV_REGISTER", request, response, model);

					RtAcntCnfmDescTDO acntDescTDO = new RtAcntCnfmDescTDO();

						acntDescTDO.setLoanNo       ((String) smdo.get("loanNo"));				   /* 대출번호 */
						acntDescTDO.setLoanSeq      ((String) smdo.get("loanSeq"));                /* 대출순번*/
						acntDescTDO.setAcntSnum     (StringUtil.nvl(smdo.get("acntSnum"), "0"));   /* 계좌일련번호*/
						acntDescTDO.setBankCd       ((String) smdo.get("bankCd"));                 /* 은행코드*/
						acntDescTDO.setAcntNo       ((String) smdo.get("acntNo"));                 /* 계좌번호 */
						acntDescTDO.setDepoOwnNo    ((String) smdo.get("depoOwnNo"));              /* 예금주번호 */
						acntDescTDO.setDepoOwnnm    ((String) smdo.get("depoOwnnm"));              /* 예금주명 */
						acntDescTDO.setDepoOwnRelCd ((String) smdo.get("depoOwnRelCd"));           /* 예금주관계코드 */
						acntDescTDO.setApplManTel1  ((String) smdo.get("applManTel1"));            /* 신청인전화1 */
						acntDescTDO.setApplManTel2  ((String) smdo.get("applManTel2"));            /* 신청인전화2 */
						acntDescTDO.setApplManTel3  ((String) smdo.get("applManTel3"));            /* 신청인전화3 */
						acntDescTDO.setAcntAplyDt   ((String) smdo.get("acntAplyDt"));             /* 계좌적용일자 */
						acntDescTDO.setAcntApplRsnCd((String) smdo.get("acntApplRsnCd"));          /* 계좌신청사유코드 */
						acntDescTDO.setAcntClosRsnCd((String) smdo.get("acntClosRsnCd"));          /* 계좌해지사유코드 */
						acntDescTDO.setLastProcEmpNo((String) smdo.get("lastProcEmpNo"));          /* 최종처리사원번호 */

						this.procAutoTranAcnt("2", acntDescTDO);
				}

			}

			/** 자동이체계좌관리 VO 세팅 */
			RATMNM01S01InVO targetVo = new RATMNM01S01InVO();
			RATMNM01S01OutVO outVo = new RATMNM01S01OutVO();

			/** 자동이체계좌관리 입력값 화면으로 다시 넘겨줌 */
          	List<RATMNM01DSSEARCHVO> resultList = new ArrayList<RATMNM01DSSEARCHVO>();
          	resultList.add(searchVo);
        	outVo.setRATMNM01DSSEARCHVO(resultList);

        	LOGGER.info("##### RATMNM01Controller RATMNM01S01 입력 InVO 세팅 #####");

			/** 화면으로 데이터셋 전달 */
			XFrame5Util.setOutputData("DS_SEARCH", outVo.getRATMNM01DSSEARCHVO(), model);

			LOGGER.info("##### RATMNM01Controller RATMNM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RATMNM02Controller RATMNM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 강제등록 /RATMNM01I01.do </p>
	 * <p>작성일자      : 2023. 4. 25.
	 * <p>작성자(author): 70326
	 * <p>설명          : 강제등록</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM01I01.do")
	public String RATMNM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		// 세션
		HttpSession session = request.getSession();
		UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");
		String empNo = sessionVO.getUserNo();

		Map<String, Object> dsSearchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);
		Map<String, Object> dsAprvMap   = XFrame5DataSetUtil.getXFrameDataSet("DS_APRV_REGISTER", request, response, model);

		/** 등록 입력값 세팅 */
		RATMNM01DSSEARCHVO searchVo = new RATMNM01DSSEARCHVO();
		RATMNM01DSAPRVREGISTERVO dsAprvVo = new RATMNM01DSAPRVREGISTERVO();

		/** 검색조건 세팅(대출번호, 대출순번) */
		searchVo.setLoanNo((String)dsSearchMap.get("loanNo"));					/** 대출번호 */
		searchVo.setLoanSeq((String)dsSearchMap.get("loanSeq"));				/** 대출순번 */

		/** insert/update 값 세팅 */
		dsAprvVo.setAcntNo((String)dsAprvMap.get("acntNo"));                    /** 계좌번호 */

		String loanNo = searchVo.getLoanNo();
		String loanSeq = searchVo.getLoanSeq();

		RtAcntCnfmDescTDO savedCnfmDesc = this.searchAcntCnfmDescRcnt(loanNo, loanSeq);

		if(savedCnfmDesc == null) {
			throw new Exception("ESC9999^계좌확인내역이 존재하지 않습니다.(계좌상태를 확인하세요!)");
		}

		String acntCnfmRsltCd = StringUtil.nvl(savedCnfmDesc.getAcntCnfmRsltCd());
		LOGGER.info("savedCnfmDesc.getAcntStatCd() : " + savedCnfmDesc.getAcntStatCd() + " / acntCnfmRsltCd : " + acntCnfmRsltCd);

		// 2018-08-01 강제 설정!! 주석처리 요망
		savedCnfmDesc.setAcntNo(dsAprvVo.getAcntNo());

		// 계좌오류(04), 계좌오류의 원인이 예금주명오류 일때
		if ("04".equals(savedCnfmDesc.getAcntStatCd()) && "9001".equals(acntCnfmRsltCd)) {
			RtAcntCnfmDescTDO updateAcntCnfmDesc = new RtAcntCnfmDescTDO();
				// where
				updateAcntCnfmDesc.setSendDt(savedCnfmDesc.getSendDt());
				updateAcntCnfmDesc.setSendSnum(savedCnfmDesc.getSendSnum());
				// set
				updateAcntCnfmDesc.setIvltRegFg("1");
				updateAcntCnfmDesc.setAcntStatCd("03"); 	// 계좌확인성공
				updateAcntCnfmDesc.setLastProcEmpNo(empNo);

				RATMNM01.modifyRATMNM01U02(updateAcntCnfmDesc);

				// 계좌처리 호출(자동이체계좌신규등록)
				savedCnfmDesc.setDepoOwnnm(savedCnfmDesc.getCnfmDepoOwnnm());	    // 강제등록시 예금주명 오류이므로 확인예금주명으로 수정
				savedCnfmDesc.setAcntClosRsnCd(savedCnfmDesc.getAcntApplRsnCd());	// 신규등록시 기존 계좌 해지사유 = 신청사유
				savedCnfmDesc.setFrstRegEmpNo(empNo);
				savedCnfmDesc.setLastProcEmpNo(empNo);

				AutoTranAcntProcDTO autoTranAcntProcCCDO = this.procAutoTranAcnt("1", savedCnfmDesc);

				int acntSnum = autoTranAcntProcCCDO.getAcntSnum() < 1 ? 1 : autoTranAcntProcCCDO.getAcntSnum();

				RtAcntCnfmDescTDO acntProcRsltAcntCnfmDesc = new RtAcntCnfmDescTDO();
				// set
				acntProcRsltAcntCnfmDesc.setIvltRegFg("1");
				acntProcRsltAcntCnfmDesc.setAcntSnum(String.valueOf(acntSnum)); // 계좌일련번호
				acntProcRsltAcntCnfmDesc.setLastProcEmpNo(empNo); // 마지막 사용자
				// where
				acntProcRsltAcntCnfmDesc.setSendDt(savedCnfmDesc.getSendDt());
				acntProcRsltAcntCnfmDesc.setSendSnum(savedCnfmDesc.getSendSnum());

				RATMNM01.modifyRATMNM01U03(acntProcRsltAcntCnfmDesc);
		}else {
			throw new Exception("계좌오류(예금주명오류)에서만 가능합니다.");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 확인취소 /RATMNM01U01.do </p>
	 * <p>작성일자      : 2023. 4. 25.
	 * <p>작성자(author): 70326
	 * <p>설명          : 확인취소</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM01U01.do")
	public String RATMNM01U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		Map<String, Object> dsSearchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

		/** 입력 VO 세팅 */
		RATMNM01DSSEARCHVO searchVo = new RATMNM01DSSEARCHVO();

		/** 검색조건 세팅(대출번호, 대출순번) */
		searchVo.setLoanNo((String)dsSearchMap.get("loanNo"));					/** 대출번호 */
		searchVo.setLoanSeq((String)dsSearchMap.get("loanSeq"));				/** 대출순번 */

		String loanNo = searchVo.getLoanNo();
		String loanSeq = searchVo.getLoanSeq();

		RtAcntCnfmDescTDO savedCnfmDesc = this.searchAcntCnfmDescRcnt(loanNo, loanSeq);

		if(savedCnfmDesc == null) {
			throw new Exception("ESC9999^계좌확인내역이 존재하지 않습니다.(계좌상태를 확인하세요!)");
		}

		//계좌상태코드 : 04(계좌오류), 01(계좌확인)
		if ("04".equals(savedCnfmDesc.getAcntStatCd()) || "01".equals(savedCnfmDesc.getAcntStatCd())) {
			RtAcntCnfmDescTDO updateAcntCnfmDesc = new RtAcntCnfmDescTDO();
				// set
				updateAcntCnfmDesc.setAcntStatCd("02");
				//where
				updateAcntCnfmDesc.setSendDt(savedCnfmDesc.getSendDt());
				updateAcntCnfmDesc.setSendSnum(savedCnfmDesc.getSendSnum());

				RATMNM01.modifyAcntStatCancel(updateAcntCnfmDesc);
		}else {
			throw new Exception("ESC9999^(계좌확인, 계좌오류)에서만 계좌확인취소가 가능합니다.");
		}

		return XFrame5View.XFRAME5_VIEW;
	}


	/**
	 * <p>메소드명      : 해지처리 /RATMNM01D01.do </p>
	 * <p>작성일자      : 2023. 4. 25.
	 * <p>작성자(author): 70326
	 * <p>설명          : 확인취소</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM01D01.do")
	public String RATMNM01D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		HttpSession session = request.getSession();
		UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");
		String empNo = sessionVO.getUserNo();

		Map<String, Object> dsAprvMap = XFrame5DataSetUtil.getXFrameDataSet("DS_APRV_REGISTER", request, response, model);

		/** 입력 VO 세팅 */
		RtAcntCnfmDescTDO inTDO = new RtAcntCnfmDescTDO();

		/** 검색조건 세팅(대출번호, 대출순번) */
		inTDO.setLoanNo((String)dsAprvMap.get("loanNo"));				/* 대출번호 */
		inTDO.setLoanSeq((String)dsAprvMap.get("loanSeq"));				/* 대출순번 */
		inTDO.setAcntSnum((String)dsAprvMap.get("acntSnum"));			/* 계좌일련번호 */
		inTDO.setAcntClosRsnCd((String)dsAprvMap.get("acntClosRsnCd")); /* 계좌해지사유코드 */
		LOGGER.info("inDTO : " + inTDO.getAcntClosRsnCd());
		inTDO.setLastProcEmpNo(empNo);									/* 사원번호 */

		this.procAutoTranAcnt("3", inTDO);

		return XFrame5View.XFRAME5_VIEW;
	}




	/**
	 * <p>메소드명    	   : searchSmList</p>
	 * <p>작성일자    	   : 2023. 4. 12.
	 * <p>작성자(author) : 70326
	 * <p>설명   	       : 대출정보조회 </p>
	 * <p>메소드인수1	   : RATMNM01S01InVO(loanNo, loanSeq)</p>
	 * <p>메소드리턴값     : LoanInfoProcMngOutVO</p>
	 * <p>예외처리		   : Exception</p>
	 */
	private LoanInfoProcMngOutVO searchSmList(RATMNM01S01InVO inVo) throws Exception {

		LoanInfoProcMngInVO searchVo = new LoanInfoProcMngInVO();

		searchVo.setLoanNo(inVo.getRATMNM01DSSEARCHVO().getLoanNo());		/** 대출번호 */
		searchVo.setLoanSeq(inVo.getRATMNM01DSSEARCHVO().getLoanSeq());		/** 대출순번 */

		return loanInfo.getLoanInfo(searchVo);
	}

	/**
	 * <p>메소드명    	   : getAskUnrcv</p>
	 * <p>작성일자    	   : 2023. 4. 12.
	 * <p>작성자(author) : 70326
	 * <p>설명   	       : 청구미수계산 </p>
	 * <p>메소드인수1	   : RATMNM01S01InVO(loanNo, loanSeq)</p>
	 * <p>메소드리턴값     : LoanInfoProcMngOutVO</p>
	 * <p>예외처리		   : Exception</p>
	 */
	private AskUnrcvVO getAskUnrcv(RATMNM01S01InVO inVo) throws Exception {

		AskUnrcvVO vo = new AskUnrcvVO();

		try {
			// 청구미수 계산
			AskUnrcvObjVO objVO1 = new AskUnrcvObjVO();
				objVO1.loanNo  = inVo.getRATMNM01DSSEARCHVO().getLoanNo();
				objVO1.loanSeq = inVo.getRATMNM01DSSEARCHVO().getLoanSeq();

				String yyyymmdd = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
				SimpleDateFormat sdfTime = new SimpleDateFormat("yyyyMMdd");
				long currentTime = System.currentTimeMillis();
		        String today = sdfTime.format(new Date(currentTime));

				objVO1.setlDt  = yyyymmdd;
				LOGGER.info("현재일자 : " + yyyymmdd );
				LOGGER.info("objVO1 setlDt :  " + objVO1.setlDt );
				vo.addAskUnrcvObj(objVO1);
				vo.midRmbrUnCalcFg = "1";
				LOGGER.info("[청구미수] getAskUnrcv VO : " + vo);
			vo = askUnrcvProc.calcAskUnrcv(vo);


//		    if(!"0000".equals(vo.rsltCd)) {
//		    	throw new Exception("[" + vo.rsltCntn + "]" );
//		    }

		    if(vo.sizeBndVOList() > 0) {
		    	BndVO bVo = vo.getBndVO(0);

		    	BndVo bndVo = new BndVo();
		    	bndVo.setThmmDueDt(bVo.thmmRlDueDt);
		    	bndVo.setAskAmt(bVo.askAmt);
		    	bndVo.setDlyAmt(bVo.dlyAmt);

		    	vo.addBndVO(bndVo);

		    }
		} catch (Exception e) {
			// 오류 메시지 정보 설정
			LOGGER.error("Error >>> " + e.getMessage());
			throw new Exception("[" + e.getMessage() + "]" );
		}

		return vo;
	}


	private List<RATMNM01DSSDVO> searchSdList(RATMNM01S01InVO inVo) throws Exception {

		List<RATMNM01DSSDVO> resultVo = new ArrayList<RATMNM01DSSDVO>();

		resultVo = RATMNM01.getRATMNM01S02(inVo);

		return resultVo;
	}


	private RATMNM01DSAPRVREGISTERVO acntChkProc(String trDivCd, RATMNM01DSSEARCHVO smSch, RATMNM01DSAPRVREGISTERVO smReg) throws Exception {

		LOGGER.info("trDivCd : " + trDivCd);
		if(trDivCd != "1" && trDivCd != "9") {
			throw new BizException("사용할수 없는 기능입니다.");
		}

		String loanNo = smSch.getLoanNo();
		String loanSeq = smSch.getLoanSeq();

		RtAcntCnfmDescTDO lastAcntCnfmDesc = this.searchAcntCnfmDescRcnt(loanNo,loanSeq);
		LOGGER.info("일련번호 : "+lastAcntCnfmDesc.getAcntSnum());
		// 계좌확인내역에 계좌신청중인 건이 있을때
		if (lastAcntCnfmDesc != null) {
			String acntStatCd = lastAcntCnfmDesc.getAcntStatCd();
			if (acntStatCd == "01" || acntStatCd == "04") {
				throw new Exception("계좌확인중인 계좌내역이 있습니다.(계좌내역의 계좌상태를 확인하세요)");
			}
		}
		smReg.setLoanNo(loanNo);
		smReg.setLoanSeq(loanSeq);
		smReg.setSendSnum(lastAcntCnfmDesc.getSendSnum());
		smReg.setAcntSnum(lastAcntCnfmDesc.getAcntSnum());
		lastAcntCnfmDesc = this.insertAcntCnfmDesc(smReg);
		LOGGER.info("AF : " + lastAcntCnfmDesc.getSendDt());
		/* NOTE 증빙파일은 업로드 하지 않는다.
		Dataset ds = event.getDataset(DS_APRV_REGISTER);
		String fileNm = ds.getColumnAsString(0, "fileNm");
		byte[] fileCntn = ds.getColumnAsByteArray(0, "fileCntn");
		chkUploadImage(fileNm, fileCntn);
		*/
		String fileNm = "";
		byte[] fileCntn = null;

		procAcntCnfmGram(trDivCd, lastAcntCnfmDesc);

		return smReg;
	}

	private RtAcntCnfmDescTDO searchAcntCnfmDescRcnt(String loanNo, String loanSeq) throws Exception {
		// 조회조건 셋팅
		RtAcntCnfmDescTDO searchTDO = new RtAcntCnfmDescTDO();
			searchTDO.setLoanNo (loanNo);
			searchTDO.setLoanSeq(loanSeq);
			List<RtAcntCnfmDescTDO> resultDto = RATMNM01.getRATMNM01S03(searchTDO);

		for(RtAcntCnfmDescTDO result : resultDto) {
			LOGGER.info("일련 : "+result.getAcntSnum());
			searchTDO.setSendDt(result.getSendDt());
			searchTDO.setSendSnum(result.getSendSnum());
			searchTDO.setLoanNo(result.getLoanNo());
			searchTDO.setLoanSeq(result.getLoanSeq());
			searchTDO.setAcntStatCd(result.getAcntStatCd());
			searchTDO.setAcntCnfmNo(result.getAcntCnfmNo());
			searchTDO.setAcntSnum(result.getAcntSnum());
			searchTDO.setBankCd(result.getBankCd());
			searchTDO.setAcntNo(result.getAcntNo());
			searchTDO.setDepoOwnNo(result.getDepoOwnNo());
			searchTDO.setDepoOwnnm(result.getDepoOwnnm());
			searchTDO.setDepoOwnRelCd(result.getDepoOwnRelCd());
			searchTDO.setApplManTel1(result.getApplManTel1());
			searchTDO.setApplManTel2(result.getApplManTel2());
			searchTDO.setApplManTel3(result.getApplManTel3());
			searchTDO.setAcntAplyDt(result.getAcntAplyDt());
			searchTDO.setCnfmDepoOwnnm(result.getCnfmDepoOwnnm());
			searchTDO.setAcntCnfmRsltCd(result.getAcntCnfmRsltCd());
			searchTDO.setAcntApplRsnCd(result.getAcntApplRsnCd());
			searchTDO.setLastProcEmpNo(result.getLastProcEmpNo());
		}
		return searchTDO;
	}

	/**
	 * <p>메소드명	: insertAcntCnfmDesc</p>
	 * <p>설　　명	: 계좌확인내역에 신청정보 등록</p>
	 * <p>메소드인수	: ITransaction, WrcDatasetWrapper, empNo</p>
	 * <p>리　턴　값	: RtAcntCnfmDescTDO</p>
	 */
	private RtAcntCnfmDescTDO insertAcntCnfmDesc(RATMNM01DSAPRVREGISTERVO smReg) throws Exception {
//
//
		RtAcntCnfmDescTDO insertAcntCnfmDescTDO = new RtAcntCnfmDescTDO();

			//insertAcntCnfmDescTDO.setSendSnum  (commBizService.getNextNumber("R001", smReg.getSendDt() , "", "", "", "", "", smReg.getLastProcEmpNo()));	// 채번
			int snum = Integer.parseInt(smReg.getSendSnum());
			snum = snum+1;
			LOGGER.info("snum : " + snum);
			LOGGER.info("sendDt bf : " + smReg.getSendDt());

			String yyyymmdd = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
			//yyyymmdd = DateFormatUtil.unformat(yyyymmdd);
			String hhmmss = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);
			//hhmmss = DateFormatUtil.unformat(hhmmss);

			insertAcntCnfmDescTDO.setSendDt(yyyymmdd);
			insertAcntCnfmDescTDO.setApplDt(yyyymmdd);
			insertAcntCnfmDescTDO.setAcntAplyDt(yyyymmdd);
			insertAcntCnfmDescTDO.setSendTm(hhmmss);
			LOGGER.info("sendDt af : " + insertAcntCnfmDescTDO.getSendDt());
			insertAcntCnfmDescTDO.setSendSnum(String.valueOf(snum));
			insertAcntCnfmDescTDO.setLoanNo(smReg.getLoanNo());
			insertAcntCnfmDescTDO.setLoanSeq(smReg.getLoanSeq());
			insertAcntCnfmDescTDO.setAcntSnum(smReg.getAcntSnum());
			insertAcntCnfmDescTDO.setBankCd(smReg.getBankCd());
			insertAcntCnfmDescTDO.setAcntNo(smReg.getAcntNo());
			insertAcntCnfmDescTDO.setDepoOwnNo(smReg.getDepoOwnNo());
			insertAcntCnfmDescTDO.setDepoOwnnm(smReg.getDepoOwnnm());
			insertAcntCnfmDescTDO.setDepoOwnRelCd(smReg.getDepoOwnRelCd());
			insertAcntCnfmDescTDO.setApplManTel1(smReg.getApplManTel1());
			insertAcntCnfmDescTDO.setApplManTel2(smReg.getApplManTel2());
			insertAcntCnfmDescTDO.setApplManTel3(smReg.getApplManTel3());
			insertAcntCnfmDescTDO.setAcntCnfmRsltCd(smReg.getAcntCnfmRsltCd());
			insertAcntCnfmDescTDO.setCnfmDepoOwnnm(smReg.getCnfmDepoOwnnm());
			insertAcntCnfmDescTDO.setAcntApplRsnCd(smReg.getAcntApplRsnCd());

			insertAcntCnfmDescTDO.setAcntStatCd("01"); // 01 - 계좌확인중...
			insertAcntCnfmDescTDO.setIvltRegFg ("0");
			insertAcntCnfmDescTDO.setFrstRegEmpNo (smReg.getLastProcEmpNo());
			insertAcntCnfmDescTDO.setLastProcEmpNo(smReg.getLastProcEmpNo());

//		log.debug("신규 계좌 확인내역에 등록 >> " + insertAcntCnfmDescTDO);
//		AbstractDAO bc = factory.getDAO(ACNT_BC);
//		((AcntDAO) bc).insert(insertAcntCnfmDescTDO, tx);
			RATMNM01.insertRATMNM01I01(insertAcntCnfmDescTDO);

		return insertAcntCnfmDescTDO;
	}


	/**
	 * <p>메소드명	: selectAcntCnfmDesc</p>
	 * <p>설　　명	: 계좌확인내역 조회</p>
	 * <p>메소드인수	: ITransaction, CommSMDO(DS_SEARCH), CommSMDO(DS_APRV_REGISTER)</p>
	 * <p>리　턴　값	: PagedArrayList</p>
	 */
	private List<RtAcntCnfmDescTDO> selectAcntCnfmDesc(RATMNM01DSSEARCHVO smSch, RATMNM01DSAPRVREGISTERVO smReg) throws Exception {

		RtAcntCnfmDescTDO inTDO = new RtAcntCnfmDescTDO();
			inTDO.setLoanNo  (smSch.getLoanNo());
			inTDO.setLoanSeq (smSch.getLoanSeq());
			inTDO.setSendDt  (smReg.getSendDt());
			inTDO.setSendSnum(smReg.getSendSnum());

			List<RtAcntCnfmDescTDO> result = RATMNM01.getRATMNM01S04(inTDO);

		return result;
	}

	/**
	 * <p>메소드명	: procAcntCnfmGram</p>
	 * <p>설　　명	: 자동이체계좌 처리</p>
	 * <p>메소드인수	: acntApplDiv(1:신규, 2:수정, 3:해지), sysPathCd, RtAcntCnfmDescTDO, fileNm, byte[], ITransaction</p>
	 * <p>리　턴　값	: AutoTranAcntProcCCDO</p>
	 */
	private AutoTranAcntProcDTO procAutoTranAcnt(String acntApplDiv, RtAcntCnfmDescTDO acntCnfmDesc) {

		String trDiv = StringUtil.in(acntApplDiv, "9")?"1":acntApplDiv;

		LOGGER.info("계좌처리대상 [" + acntCnfmDesc + "]");


		AutoTranAcntProcDTO reqVO = new AutoTranAcntProcDTO();
		reqVO.setAcntApplDiv  (trDiv); // 신규(1), 수정(2), 해지(3) 처리구분
		if("3".equals(trDiv)) {
			LOGGER.info("계좌처리대상 [" + acntCnfmDesc + "]");
			reqVO.setLoanNo       (acntCnfmDesc.getLoanNo());
			reqVO.setLoanSeq      (acntCnfmDesc.getLoanSeq());
			reqVO.setAcntSnum     (StringUtil.parseInt(acntCnfmDesc.getAcntSnum()));
			reqVO.setAcntClosRsnCd(acntCnfmDesc.getAcntClosRsnCd());
			reqVO.setEmpNo        (acntCnfmDesc.getLastProcEmpNo());
			LOGGER.info("해지이유 [" + reqVO.getAcntClosRsnCd() + "]");
		}else {
			reqVO.setLoanNo       (acntCnfmDesc.getLoanNo());
			reqVO.setLoanSeq      (acntCnfmDesc.getLoanSeq());
			reqVO.setAcntSnum     (StringUtil.parseInt(acntCnfmDesc.getAcntSnum()));
			reqVO.setBankCd       (acntCnfmDesc.getBankCd());
			reqVO.setAcntNo       (RegExUtils.replaceAll(acntCnfmDesc.getAcntNo(), "-", ""));
			reqVO.setDepoOwnNo    (RegExUtils.replaceAll(acntCnfmDesc.getDepoOwnNo(), "-", ""));

//			reqVO.setDepoOwnnm    (acntCnfmDesc.getDepoOwnnm());
			reqVO.setDepoOwnnm    (acntCnfmDesc.getCnfmDepoOwnnm());	// 확인예금주명으로..
			reqVO.setDepoOwnRelCd (acntCnfmDesc.getDepoOwnRelCd());
			reqVO.setAcntAplyDt   (" ");
			reqVO.setEmpNo        (acntCnfmDesc.getLastProcEmpNo());
			reqVO.setAcntApplRsnCd(acntCnfmDesc.getAcntApplRsnCd());
			reqVO.setAcntClosRsnCd(acntCnfmDesc.getAcntClosRsnCd());
			reqVO.setApplManTel1  (acntCnfmDesc.getApplManTel1());
			reqVO.setApplManTel2  (acntCnfmDesc.getApplManTel2());
			reqVO.setApplManTel3  (acntCnfmDesc.getApplManTel3());
//			reqVO.setSysPathCd    (sysPathCd);
//			reqVO.setFileNm       (fileNm);
//			reqVO.setFileCntn     (fileCntnBytes);	// 계좌신청시 증빙파일
		}

		LOGGER.info("proc before");
		AutoTranAcntProcOutVO result = autoTranProc.proc(reqVO);
		LOGGER.info("proc after");
		if (!"0000".equals(result.getRsltCd())) {
			throw new BizException("ESC9999^자동이체 계좌처리 에러 입니다.[" + result.getRsltCntn() + "]");
		}
		return reqVO;
	}


	/**
	 * <p>메소드명	    : procAcntCnfmGram</p>
	 * <p>설　　명	: 계좌확인 전문처리</p>
	 * <p>메소드인수	: trDivCd, RtAcntCnfmDescTDO </p>
	 * <p>리　턴　값	: N/A</p>
	 */
	private void procAcntCnfmGram(String trDivCd, RtAcntCnfmDescTDO reqAcntCnfmDesc) throws Exception {
		LOGGER.info("■ procAcntCnfmGram - 계좌확인 전문처리");

		if(trDivCd != "1" && trDivCd != "9") {
			throw new IllegalArgumentException("계좌확인전문 요청시 거래구분이 잘못입력되었습니다.");
		}
		String trDiv = StringUtil.in(trDivCd, ACNT_APPL_PASS)?"1":trDivCd;

		// 2. 계좌 확인 전문 처리...
		AcntChkGramVO acntChkGram = new AcntChkGramVO();
			acntChkGram.setBsnDivCd  ("R1");  // 업무구분 --> 필수
			acntChkGram.setTrDivCd   (trDiv); // 거래구분 --> 필수(CODE : 신규('1'), 확인('2'))
			acntChkGram.setProcEmpNo (reqAcntCnfmDesc.getLastProcEmpNo());
			acntChkGram.setAcntRsltCd("");
			acntChkGram.setBankCd    (reqAcntCnfmDesc.getBankCd());    // 은행코드
			acntChkGram.setAcntNo    (reqAcntCnfmDesc.getAcntNo());    // 계좌번호
			acntChkGram.setDepoOwnNo (reqAcntCnfmDesc.getDepoOwnNo()); // 예금주번호
			acntChkGram.setDepoOwnNm (reqAcntCnfmDesc.getDepoOwnnm()); // 예금주명
			acntChkGram.setTraceId   (loginEmpNo);

//		if (RUtil.in(trDivCd, ACNT_APPL_REG)) {
//			acntCnfmService.procSend(acntChkGram);
//		} else
//		if (RUtil.in(trDivCd, ACNT_APPL_PASS)) {
			acntCnfmService.procSend_noGram(acntChkGram);
//		}

		if (!acntChkGram.isSuccess() && !acntChkGram.isDepoNmError()) {
			throw new BizException(acntChkGram.getRsltCntn());
		}

		RtAcntCnfmDescTDO sendRsAcntCnfmDesc = new RtAcntCnfmDescTDO();
		// set(계좌상태코드, 계좌확인결과코드, 확인예금주명, 계좌확인번호)
		if (acntChkGram.isDepoNmError()) {
			sendRsAcntCnfmDesc.setAcntStatCd("04"); // 계좌상태코드(2)
		} else {
			sendRsAcntCnfmDesc.setAcntStatCd("03"); // 계좌상태코드(2)
		}
		sendRsAcntCnfmDesc.setAcntCnfmRsltCd(acntChkGram.getAcntRsltCd());	// 계좌확인결과코드(4)
		sendRsAcntCnfmDesc.setCnfmDepoOwnnm (acntChkGram.getCnfmDepoOwnnm()); // 확인예금주명(30)
		sendRsAcntCnfmDesc.setAcntCnfmNo    (acntChkGram.getAcntCnfmNo());	// 계좌확인번호(15)
		sendRsAcntCnfmDesc.setLastProcEmpNo (reqAcntCnfmDesc.getLastProcEmpNo());

		// 날짜세팅
		String yyyymmdd = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
		//yyyymmdd = DateFormatUtil.unformat(yyyymmdd);
		// 시간세팅
		String hhmmss = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);
		//hhmmss = DateFormatUtil.unformat(hhmmss);

		sendRsAcntCnfmDesc.setRecvDt        (yyyymmdd);
		sendRsAcntCnfmDesc.setRecvTm        (hhmmss);

		// where
		LOGGER.info("SENDDDTT : " + reqAcntCnfmDesc.getSendDt());
		sendRsAcntCnfmDesc.setSendDt(yyyymmdd);
		sendRsAcntCnfmDesc.setSendSnum(reqAcntCnfmDesc.getSendSnum());

		RATMNM01.modifySendRsAcntCnfmDesc(sendRsAcntCnfmDesc);

		// 계좌확인된후 자동이체 계좌신청처리
		reqAcntCnfmDesc.setAcntStatCd    (sendRsAcntCnfmDesc.getAcntStatCd());
		reqAcntCnfmDesc.setCnfmDepoOwnnm (sendRsAcntCnfmDesc.getCnfmDepoOwnnm());
		reqAcntCnfmDesc.setAcntCnfmNo    (sendRsAcntCnfmDesc.getAcntCnfmNo());
		reqAcntCnfmDesc.setAcntCnfmRsltCd(sendRsAcntCnfmDesc.getAcntCnfmRsltCd());
		reqAcntCnfmDesc.setAcntClosRsnCd (reqAcntCnfmDesc.getAcntApplRsnCd());

		LOGGER.info("■ 자동이체계좌처리 : 1:신규등록");
		AutoTranAcntProcDTO attrAcntProcCCDO = this.procAutoTranAcnt(ACNT_APPL_REG, reqAcntCnfmDesc); // 계좌처리 - 신규

		LOGGER.info("■ 계좌확인내역 UPDATE");
		RtAcntCnfmDescTDO acntProcRsltAcntCnfmDesc = new RtAcntCnfmDescTDO();
		int acntSnum = (attrAcntProcCCDO.getAcntSnum()<1) ? 1 : attrAcntProcCCDO.getAcntSnum();
		// set
		acntProcRsltAcntCnfmDesc.setAcntSnum     (String.valueOf(acntSnum)); // 계좌일련번호
		acntProcRsltAcntCnfmDesc.setLastProcEmpNo(reqAcntCnfmDesc.getLastProcEmpNo()); // 마지막 사용자
		// where
		acntProcRsltAcntCnfmDesc.setSendDt  (reqAcntCnfmDesc.getSendDt());
		acntProcRsltAcntCnfmDesc.setSendSnum(reqAcntCnfmDesc.getSendSnum());

		RATMNM01.modifyAcntProcRsltAcntCnfmDesc(acntProcRsltAcntCnfmDesc);
	}


}
