package hanalife.r.at.mn.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.at.mn.service.RATMNM02Service;
import hanalife.r.at.mn.vo.RATMNM02DSSEARCHVO;
import hanalife.r.at.mn.vo.RATMNM02S01InVO;
import hanalife.r.at.mn.vo.RATMNM02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM02Controller.java Class
 *
 * 클래스설명   : 자동이체계좌신청조회 (RATMNM02) Controller
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/at/mn")
@Controller
public class RATMNM02Controller {

	@Resource(name = "RATMNM02Service")
	private RATMNM02Service RATMNM02;

	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM02Controller.class);

	/**
	 * <p>메소드명      : 자동이체계좌신청조회 /RATMNM02S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : 자동이체계좌신청조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM02S01.do")
	public String RATMNM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RATMNM02Controller RATMNM02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

			/** 자동이체계좌신청조회내역조회 업무 서비스 호출 입력값 대입 */
			RATMNM02S01InVO targetVo = new RATMNM02S01InVO();
			RATMNM02DSSEARCHVO searchVo = new RATMNM02DSSEARCHVO();

			searchVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
			searchVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */
			searchVo.setSendDtFr((String)sourceMap.get("sendDtFr")); /** 전송일자시작 */
			searchVo.setSendDtTo((String)sourceMap.get("sendDtTo")); /** 전송일자종료 */
			searchVo.setAcntNo((String)sourceMap.get("acntNo")); /** 계좌번호 */
			searchVo.setTrOrgCd((String)sourceMap.get("trOrgCd")); /** 거래기관코드 */
			searchVo.setAcntOccrCd((String)sourceMap.get("acntOccrCd")); /** 계좌발생코드 */
			searchVo.setApplDivCd((String)sourceMap.get("applDivCd")); /** 신청구분코드 */
			searchVo.setAcntStatCd((String)sourceMap.get("acntStatCd")); /** 계좌상태코드 */
			searchVo.setAcntRsltCd((String)sourceMap.get("acntRsltCd")); /** 계좌결과코드 */
			searchVo.setMngDeptCd((String)sourceMap.get("mngDeptCd")); /** 관리부서코드 */
			searchVo.setMngDeptNm((String)sourceMap.get("mngDeptNm")); /** 관리부서명 */

			targetVo.setRATMNM02DSSEARCHVO(searchVo);

			/** 자동이체계좌신청조회내역조회 업무 서비스 호출 수행 */
			RATMNM02S01OutVO resultRATMNM02S01 = RATMNM02.getRATMNM02S01(targetVo);

			XFrame5Util.setOutputData("DS_SD_01", resultRATMNM02S01.getRATMNM02DSSD01VO(), model);

			LOGGER.info("##### RATMNM02Controller RATMNM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RATMNM02Controller RATMNM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
