package hanalife.r.at.mn.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.at.mn.service.RATMNM03Service;
import hanalife.r.at.mn.vo.RATMNM03DSSEARCHVO;
import hanalife.r.at.mn.vo.RATMNM03S01InVO;
import hanalife.r.at.mn.vo.RATMNM03S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM03Controller.java Class
 * 클래스설명   : 자동이체거래내역조회 (RATMNM03) Controller
 * 작성일자     : 2023. 4. 18.
 * 작성자명     : 70367 / ByeonJunoh / 가계대출 시스템 구축
 * Copyrightⓒ2033 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2033. 4. 18.][70367 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/at/mn")
@Controller
public class RATMNM03Controller {

	@Resource(name = "RATMNM03Service")
	private RATMNM03Service RATMNM03;

	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM03Controller.class);

	/**
	 * <p>메소드명      : 자동이체거래내역조회 /RATMNM03S01.do </p>
	 * <p>작성일자      : 2023. 4. 18.
	 * <p>작성자(author): 70367
	 * <p>설명          : 자동이체거래내역조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM03S01.do")
	public String RATMNM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RATMNM03Controller RATMNM03S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

			/** 자동이체계좌신청조회내역조회 업무 서비스 호출 입력값 대입 */

			RATMNM03DSSEARCHVO targetVo = new RATMNM03DSSEARCHVO();

			targetVo.setRlDueDtFr((String)sourceMap.get("rlDueDtFr")); /** 대출번호 */
			LOGGER.info("납입일자" + (String)sourceMap.get("rlDueDtFr"));
			targetVo.setRlDueDtTo((String)sourceMap.get("rlDueDtTo")); /** 대출순번 */
			targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 전송일자시작 */
			targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 전송일자종료 */
			targetVo.setTrOrgCd((String)sourceMap.get("trOrgCd")); /** 계좌번호 */
			targetVo.setBankCd((String)sourceMap.get("bankCd")); /** 거래기관코드 */
			targetVo.setMngDeptCd((String)sourceMap.get("mngDeptCd")); /** 계좌발생코드 */
			targetVo.setMngDeptNm((String)sourceMap.get("mngDeptNm")); /** 신청구분코드 */
			targetVo.setPrdtLrgeClasCd((String)sourceMap.get("prdtLrgeClasCd")); /** 계좌상태코드 */
			targetVo.setPrdtMidClasCd((String)sourceMap.get("prdtMidClasCd")); /** 계좌결과코드 */
			targetVo.setAskDivCd((String)sourceMap.get("askDivCd")); /** 관리부서코드 */
			targetVo.setOamtErrCd((String)sourceMap.get("oamtErrCd")); /** 관리부서명 */
			targetVo.setBndDivsEmpNo((String)sourceMap.get("bndDivsEmpNo"));
			targetVo.setBndDivsEmpNm((String)sourceMap.get("bndDivsEmpNm"));
			targetVo.setLnDivsEmpNo((String)sourceMap.get("lnDivsEmpNo"));
			targetVo.setLnDivsEmpNm((String)sourceMap.get("lnDivsEmpNm"));

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RATMNM03S01InVO InVO = new RATMNM03S01InVO();

			 /** 자동이체거래현황 조회 DS_SMDO 입력값 VO 객체 대입 */
			InVO.setRATMNM03DSSEARCHVO(targetVo);

			/** 자동이체계좌신청조회내역조회 업무 서비스 호출 수행 */
			RATMNM03S01OutVO resultRATMNM03S01 = RATMNM03.getRATMNM03S01(InVO);

			XFrame5Util.setOutputData("DS_SD_01", resultRATMNM03S01.getListRATMNM03DSSD01VO(), model);

			LOGGER.info("##### RATMNM03Controller RATMNM03S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RATMNM03Controller RATMNM03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
