package hanalife.r.at.mn.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.at.mn.service.RATMNM04Service;
import hanalife.r.at.mn.vo.RATMNM04DSSEARCHVO;
import hanalife.r.at.mn.vo.RATMNM04S01InVO;
import hanalife.r.at.mn.vo.RATMNM04S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM04Controller.java Class
 * 클래스설명   : 자동이체거래현황 (RATMNM04) Controller
 * 작성일자     : 2023. 3. 15.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 15.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/at/mn")
@Controller
public class RATMNM04Controller {

	@Resource(name = "RATMNM04Service")
	private RATMNM04Service RATMNM04;

	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM04Controller.class);

	/**
	 * <p>메소드명      : 자동이체거래현황 /RATMNM04S01.do </p>
	 * <p>작성일자      : 2023. 3. 15.
	 * <p>작성자(author): 70321
	 * <p>설명          : 자동이체거래현황을 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM04S01.do")
	public String RATMNM04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RATMNM04Controller RATMNM04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

			/** 자동이체거래현황 내역조회 업무 서비스 호출 입력값 대입 */
			RATMNM04DSSEARCHVO targetVo = new RATMNM04DSSEARCHVO();

			targetVo.setRlDueDtFr((String)sourceMap.get("rlDueDtFr")); /** 납입시작일자 */
			targetVo.setRlDueDtTo((String)sourceMap.get("rlDueDtTo")); /** 납입종료일자 */
			targetVo.setTrOrgCd((String)sourceMap.get("trOrgCd")); /** 거래기관 */
			targetVo.setMngDeptCd((String)sourceMap.get("mngDeptCd")); /** 관리부서코드 */
			targetVo.setMngDeptNm((String)sourceMap.get("mngDeptNm")); /** 관리부서이름 */
			targetVo.setBankCd((String)sourceMap.get("bankCd")); /** 은행코드 */
			targetVo.setPrdtLrgeClasCd((String)sourceMap.get("prdtLrgeClasCd")); /** 상품대분류코드 */
			targetVo.setPrdtMidClasCd((String)sourceMap.get("prdtMidClasCd")); /** 상품중분류코드 */
			targetVo.setChkRlDueDt((String)sourceMap.get("chkRlDueDt")); /** 납입일자체크 */
			targetVo.setChkTrOrgCd((String)sourceMap.get("chkTrOrgCd")); /** 거래기관체크 */
			targetVo.setChkMngDeptCd((String)sourceMap.get("chkMngDeptCd")); /** 관리부서체크 */
			targetVo.setChkBankCd((String)sourceMap.get("chkBankCd")); /** 은행체크 */
			targetVo.setChkPrdtClasCd((String)sourceMap.get("chkPrdtClasCd")); /** 상품체크 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RATMNM04S01InVO InVO = new RATMNM04S01InVO();
            InVO.setRATMNM04DSSEARCHVO(targetVo); /** 자동이체거래현황 조회 DS_SMDO 입력값 VO 객체 대입 */

			/** 자동이체거래현황 내역조회 업무 서비스 호출 수행 */
            RATMNM04S01OutVO resultRATMNM04S01 = RATMNM04.getRATMNM04S01(InVO);

			XFrame5Util.setOutputData("DS_SD01", resultRATMNM04S01.getListRATMNM04DSSD01VO(), model); /** 대출정보조회 */

			LOGGER.info("##### RATMNM04Controller RATMNM04S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RATMNM04Controller RATMNM04S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
