package hanalife.r.at.mn.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.at.mn.service.RATMNM05Service;
import hanalife.r.at.mn.vo.RATMNM05DSSEARCHVO;
import hanalife.r.at.mn.vo.RATMNM05S01InVO;
import hanalife.r.at.mn.vo.RATMNM05S01OutVo;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM05Controller.java Class
 *
 * 클래스설명   : 자동이체계좌상태조회 (RATMNM05) Controller
 * 작성일자     : 2023. 4. 18.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/at/mn")
@Controller
public class RATMNM05Controller {

	@Resource(name = "RATMNM05Service")
	private RATMNM05Service RATMNM05;

	private static final Logger LOGGER = LoggerFactory.getLogger(RATMNM05Controller.class);

	/**
	 * <p>메소드명      : 자동이체계좌상태조회 /RATMNM05S01.do </p>
	 * <p>작성일자      : 2023. 4. 18.
	 * <p>작성자(author): 70366
	 * <p>설명          : 자동이체계좌상태조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RATMNM05S01.do")
	public String RATMNM05S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RATMNM02Controller RATMNM05S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

			/** 자동이체계좌상태조회 업무 서비스 호출 입력값 대입 */
			RATMNM05S01InVO targetVo = new RATMNM05S01InVO();
			RATMNM05DSSEARCHVO searchVo = new RATMNM05DSSEARCHVO();
			LOGGER.info("대출번호 : " + (String)sourceMap.get("loanNo"));
			searchVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출_번호 */
			searchVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출_순번 */
			searchVo.setAcntStatCd((String)sourceMap.get("acntStatCd")); /** 계좌_상태_코드 */
			searchVo.setLoanDtFr((String)sourceMap.get("loanDtFr")); /** 대출_전송_일자_시작 */
			searchVo.setLoanDtTo((String)sourceMap.get("loanDtTo")); /** 대출_전송_일자_종료 */

			targetVo.setRATMNM05DSSEARCHVO(searchVo);

			/** 자동이체계좌상태조회 업무 서비스 호출 수행 */
			RATMNM05S01OutVo resultRATMNM05S01 = RATMNM05.getRATMNM05S01(targetVo);

			if(resultRATMNM05S01.getListRATMN05DSSD01VO().size() > 0) {
			    LOGGER.info("##### RATMNM05Controller RATMNM05S01 RATMNM05S01OutVo 대출번호 #####" +  resultRATMNM05S01.getListRATMN05DSSD01VO().get(0).getLoanNo());
			    XFrame5Util.setOutputData("DS_SD_01", resultRATMNM05S01.getListRATMN05DSSD01VO(), model);
			}
//			  XFrame5Util.setOutputData("DS_SD_01", resultRATMNM05S01.getListRATMN05DSSD01VO(), model);

			LOGGER.info("##### RATMNM05Controller RATMNM05S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RATMNM05Controller RATMNM05S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
