package hanalife.r.at.vo.bat;

import java.util.Arrays;

import org.apache.log4j.Logger;

import hanalife.c.co.util.StringUtil;
import hanalife.util.BizException;
import hanalife.util.LoggableVO;
import hanalife.util.gram.OnLineUtil;

/**
 * <pre>
 * 클래스명    : EI13Body
 * 클래스설명 : EI13Body
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class EI13Body extends LoggableVO {

	private static Logger log = Logger.getLogger(EI13Body.class.getName());
	private static final int FRONT_DATA_LENGTH = 119;
	private static final int BLOCK_LENGTH      = 1024;

	int[] iArr = {6,2,7,10,20,30,3,20,8,1,5,7,200,1024};

	private String bsnDivCd;		 // 업무구분코드
	private String recDiv;		     // Record 구분
	private String snum;		     // 일련번호
	private String filler1;		     // FILLER
	private String useOrgCd;	     // 이용기관코드
	private String payManNo;	     // 납부자번호
	private String ptcpOrgCd;		 // 참가기관(은행) 코드
	private String acntNo;			 // 계좌번호
	private String applDd;			 // 신청일
	private String profDataDiv;	     // 증빙자료 구분
	private String profDataExt;	     // 증빙자료 확장자
	private String profDataLth;	     // 증빙자료 길이
	private byte[] profData;         // 증빙자료 Data
	private String filler2;			 // FILLER

	private long blockCnt;

	public void setData(String gram) {
		try {
			byte[] b = gram.getBytes();

			int isum = iArr.length - 2;
			int[] iMergeLen = new int[isum];

			int icnt = 0;

			for (int i = 0; i < iArr.length; i++) {
				if( iArr[i] != 200 && iArr[i] != 1024 ){
					iMergeLen[icnt++] = iArr[i];
				}
			}

			String[] strArr = OnLineUtil.parseString(b, iMergeLen);

			int i = 0;
			setBsnDivCd	    (strArr[i++]); // 업무구분코드 6
			setRecDiv		(strArr[i++]); // Record 구분 2
			setSnum		    (strArr[i++]); // 일련번호 7
			setFiller1		(strArr[i++]); // FILLER 10
			setUseOrgCd	    (strArr[i++]); // 이용기관코드 20
			setPayManNo	    (strArr[i++]); // 납부자번호 30
			setPtcpOrgCd	(strArr[i++]); // 참가기관(은행) 코드 3
			setAcntNo		(strArr[i++]); // 계좌번호 20
			setApplDd		(strArr[i++]); // 신청일 8
			setProfDataDiv	(strArr[i++]); // 증빙자료 구분 1
			setProfDataExt	(strArr[i++]); // 증빙자료 확장자 5
			setProfDataLth	(strArr[i++]); // 증빙자료 길이 7
			setProfData	    (strArr[i++].getBytes()); // 증빙자료 Data 200
			setFiller2		(strArr[i++]); // FILLER 1024

			log.info("getProfData() = " + getProfData());

		} catch (Exception e) {
			throw new BizException("전문 EI13Body Parsing Error[" + e.getMessage() + "]", e);
		}
	}


	public byte[] getData() {

		/* 증빙파일 면제 시 주석처리
		 * 2020-10-31 주석해제
		 */
		/************************************************************************************************************************/
		byte[] bProfData = getProfData();
		int blockCnt = (int)Math.ceil( (FRONT_DATA_LENGTH + bProfData.length) / 1024.00);
		int fillerPadCnt = (BLOCK_LENGTH - (FRONT_DATA_LENGTH + bProfData.length) % BLOCK_LENGTH) % BLOCK_LENGTH;
		int totLength = FRONT_DATA_LENGTH + bProfData.length + fillerPadCnt;

		/* 증빙파일 면제 처리 시 사용
		int blockCnt = (int)Math.ceil( (FRONT_DATA_LENGTH + 0) / 1024.00);
		int fillerPadCnt = (BLOCK_LENGTH - (FRONT_DATA_LENGTH + 0) % BLOCK_LENGTH) % BLOCK_LENGTH;
		int totLength = FRONT_DATA_LENGTH + 0 + fillerPadCnt;
		*/
		/************************************************************************************************************************/

		byte[] bBodyGram = new byte[totLength];

		int i = 0;

		StringBuilder sb = new StringBuilder();
		try {
			sb.append(StringUtil.rpadByte(getBsnDivCd	(), iArr[i++], " ")); // 업무구분코드
			sb.append(StringUtil.rpadByte(getRecDiv		(), iArr[i++], " ")); // Record 구분
			sb.append(StringUtil.lpadByte(getSnum		(), iArr[i++], "0")); // 일련번호
			sb.append(StringUtil.rpadByte(getFiller1		(), iArr[i++], " ")); // FILLER
			sb.append(StringUtil.rpadByte(getUseOrgCd	(), iArr[i++], " ")); // 이용기관코드
			sb.append(StringUtil.rpadByte(getPayManNo	(), iArr[i++], " ")); // 납부자번호
			sb.append(StringUtil.rpadByte(getPtcpOrgCd	(), iArr[i++], "0")); // 참가기관(은행) 코드
			sb.append(StringUtil.rpadByte(getAcntNo		(), iArr[i++], " ")); // 계좌번호
			sb.append(StringUtil.rpadByte(getApplDd		(), iArr[i++], " ")); // 신청일
			sb.append(StringUtil.rpadByte(getProfDataDiv	(), iArr[i++], " ")); // 증빙자료 구분

			// FIXME 증빙파일 넣을경우
			/*******************************************************************************************/
			sb.append(StringUtil.rpadByte(getProfDataExt	(), iArr[i++], " ")); // 증빙자료 확장자
			sb.append(StringUtil.lpadByte(getProfDataLth	(), iArr[i++], "0")); // 증빙자료 길이
			/*******************************************************************************************/

			// FIXME 증빙파일 제외인 경우
			/*******************************************************************************************/
//			sb.append(StringUtil.rpadByte("", iArr[i++], " ")); // 증빙자료 확장자
//			sb.append(StringUtil.lpadByte("", iArr[i++], "0")); // 증빙자료 길이
			/*******************************************************************************************/

			// FIXME 증빙파일 넣을경우
			/*******************************************************************************************/
			byte[] b119Gram = sb.toString().getBytes();	//body담기

			//전문 1~12번째 항목 복사
			//System.arraycopy(원본, 원본복사시작위치, 복사대상, 원본복사할위치, 원본복사종료위치)
			System.arraycopy(b119Gram, 0, bBodyGram, 0, FRONT_DATA_LENGTH);	//b119Gram 복사 -> bBodyGram 0~119에 붙여넣기

			//전문 증빙자료 Data항목 복사(녹취 파일)
			System.arraycopy(bProfData, 0, bBodyGram, FRONT_DATA_LENGTH, bProfData.length);	//bProfData 복사 -> bBodyGram 119~bProfData.length에 붙여넣기

			//filler 항목에 스페이스문자로 채움
			Arrays.fill(bBodyGram, totLength - fillerPadCnt, totLength, (byte)0x20);
			/*******************************************************************************************/

			// FIXME 증빙파일 제외인 경우
			/*******************************************************************************************/
//			byte[] b119Gram = sb.toString().getBytes();
//			System.arraycopy(b119Gram, 0, bBodyGram, 0, FRONT_DATA_LENGTH);
//			Arrays.fill(bBodyGram, 1024 - 905, 1024, (byte)0x20);
			/*******************************************************************************************/

		} catch (Exception e) {
			throw new BizException("전문 생성 Error[" + e.getMessage() + "]",e);
		}

		setBlockCnt(blockCnt);

		return bBodyGram;
	}


	public int[] getiArr() {
		return iArr;
	}


	public void setiArr(int[] iArr) {
		this.iArr = iArr;
	}


	public String getBsnDivCd() {
		return bsnDivCd;
	}


	public void setBsnDivCd(String bsnDivCd) {
		this.bsnDivCd = bsnDivCd;
	}


	public String getRecDiv() {
		return recDiv;
	}


	public void setRecDiv(String recDiv) {
		this.recDiv = recDiv;
	}


	public String getSnum() {
		return snum;
	}


	public void setSnum(String snum) {
		this.snum = snum;
	}


	public String getFiller1() {
		return filler1;
	}


	public void setFiller1(String filler1) {
		this.filler1 = filler1;
	}


	public String getUseOrgCd() {
		return useOrgCd;
	}


	public void setUseOrgCd(String useOrgCd) {
		this.useOrgCd = useOrgCd;
	}


	public String getPayManNo() {
		return payManNo;
	}


	public void setPayManNo(String payManNo) {
		this.payManNo = payManNo;
	}


	public String getPtcpOrgCd() {
		return ptcpOrgCd;
	}


	public void setPtcpOrgCd(String ptcpOrgCd) {
		this.ptcpOrgCd = ptcpOrgCd;
	}


	public String getAcntNo() {
		return acntNo;
	}


	public void setAcntNo(String acntNo) {
		this.acntNo = acntNo;
	}


	public String getApplDd() {
		return applDd;
	}


	public void setApplDd(String applDd) {
		this.applDd = applDd;
	}


	public String getProfDataDiv() {
		return profDataDiv;
	}


	public void setProfDataDiv(String profDataDiv) {
		this.profDataDiv = profDataDiv;
	}


	public String getProfDataExt() {
		return profDataExt;
	}


	public void setProfDataExt(String profDataExt) {
		this.profDataExt = profDataExt;
	}


	public String getProfDataLth() {
		return profDataLth;
	}


	public void setProfDataLth(String profDataLth) {
		this.profDataLth = profDataLth;
	}


	public byte[] getProfData() {
		return profData;
	}


	public void setProfData(byte[] profData) {
		this.profData = profData;
	}


	public String getFiller2() {
		return filler2;
	}


	public void setFiller2(String filler2) {
		this.filler2 = filler2;
	}

	public long getBlockCnt() {
		return blockCnt;
	}

	public void setBlockCnt(long blockCnt) {
		this.blockCnt = blockCnt;
	}
}
