package hanalife.r.ch.mn.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.b.cl.dl.service.OnlnDlyReptService;
import hanalife.b.cl.dl.vo.OnlnDlyReptInVO;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.RtCyclDescMapper;
import hanalife.c.co.mapper.RtRcptDescMapper;
import hanalife.c.co.mapper.StLoanBaseMapper;
import hanalife.c.co.mapper.StLoanChngConsStagMapper;
import hanalife.c.co.mapper.StLoanPiamtMapper;
import hanalife.c.co.mapper.StSetlDdChngHistMapper;
import hanalife.c.co.mapper.dto.RtCyclDescDTO;
import hanalife.c.co.mapper.dto.RtRcptDescDTO;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.mapper.dto.StLoanChngConsStagDTO;
import hanalife.c.co.mapper.dto.StLoanPiamtDTO;
import hanalife.c.co.mapper.dto.StRmbrPlanDescDTO;
import hanalife.c.co.mapper.dto.StSetlDdChngHistDTO;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.StringUtil;
import hanalife.c.co.vo.SearchLoanSeqVO;
import hanalife.r.ch.mn.mapper.LoanChngMapper;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01DSSD01OutDTO;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01DSSD02OutDTO;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01DSSD03OutDTO;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01DSSD05OutDTO;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01DSSD06OutDTO;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01DSSD08OutDTO;
import hanalife.r.ch.mn.mapper.dto.RCHMNM01SrchDTO;
import hanalife.r.ch.mn.service.RCHMNM01Service;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS01VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS02VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS03VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS04VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS05VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS06VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS07VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS08VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS11VO;
import hanalife.r.ch.mn.vo.RCHMNM01InVO;
import hanalife.r.ch.mn.vo.RCHMNM01OutVO;
import hanalife.r.co.as.service.AskUnrcvProcService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.s.ln.ch.service.RmbrPlanUpdtService;
import hanalife.s.ln.ch.vo.PsgIntCalcObj;
import hanalife.s.ln.ch.vo.SetlDdChngObj;
import hanalife.util.format.ServerSysDate;

/**
 * <pre>
 * 클래스명    : RCHMNM01ServiceImpl.java Class
 * 클래스설명  : 결제일변경관리 (RCHMNM01) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("RCHMNM01Service")
public class RCHMNM01ServiceImpl implements RCHMNM01Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(RCHMNM01ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private LoanChngMapper loanChngMapper;                      // 대출변경
    @Autowired
    private StLoanBaseMapper stLoanBaseMapper;                  // 대출기본
    @Autowired
    private StLoanPiamtMapper stLoanPiamtMapper;                // 대출원리금
    @Autowired
    private StSetlDdChngHistMapper setlDdChngHistMapper;        // 결제일변경이력
    @Autowired
    private StLoanChngConsStagMapper loanChngConsStagMapper;    // 대출변경품의
    @Autowired
    private RtCyclDescMapper rtCyclDescMapper;                  // 결제주기내역
    @Autowired
    private RtRcptDescMapper rtRcptDescMapper;                  // 수납거래내역
    @Autowired
    private RmbrPlanUpdtService rmbrPlanUpdtCC;                 // 상환계획수정
    @Autowired
    private AskUnrcvProcService AskUnrcvProcCC;                 // 청구미수
    @Autowired
    private OnlnDlyReptService dlyReptCC;                       // 실시간연체갱신
    /**
     * 2023.03.30 younghwe.kim : 70317 :
     * CommBizUtil.java 에서 static 선언으로 DB 접속 불가하여 CommBizService.java, CommBizServiceImpl.java로 변경
     **/
    @Autowired
    private CommBizService commBizService;

    private String LOAN_CHNG_DIV_CD_CONS = "01";    // 대출변경품의결과코드(01:품의)
    private String LOAN_CHNG_DIV_CD_APRV = "02";    // 대출변경품의결과코드(02:승인)
    private String LOAN_CHNG_DIV_CD_RJCT = "03";    // 대출변경품의결과코드(03:반려)
    private String LOAN_CHNG_DIV_CD_CMPL = "05";    // 대출변경품의결과코드(05:완료)
    private String LOAN_CHNG_DIV_CD_CHG  = "07";    // 대출변경구분코드(07:결제일변경)

//    @Autowired
//    private RmbrPlanCrteService rmbrPlanCrteService;

    /**
     * <p>메소드명      : getRDMDLM01S01 : 결제일변경관리_대출등록정보 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_대출등록정보를 조회 한다.</p>
     * <p>메소드인수    : RDMDLM01SrchDTO </p>
     * <p>메소드리턴값  : RDMDLM01S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings({ "unchecked", "null" })
    @Override
    public RCHMNM01OutVO getSelectMainInfo(RCHMNM01InVO inVo) throws Exception{

        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        List<RCHMNM01DSDDSS01VO> returnList01 = new ArrayList<RCHMNM01DSDDSS01VO>();
        List<RCHMNM01DSDDSS02VO> returnList02 = new ArrayList<RCHMNM01DSDDSS02VO>();    // 고객연락처
        List<RCHMNM01DSDDSS03VO> returnList03 = new ArrayList<RCHMNM01DSDDSS03VO>();    // 고객주소
        List<RCHMNM01DSDDSS04VO> returnList04 = new ArrayList<RCHMNM01DSDDSS04VO>();    // 당월납입일자/변경납입일자 조회
        List<RCHMNM01DSDDSS05VO> returnList05 = new ArrayList<RCHMNM01DSDDSS05VO>();    // 대출결제일변경이력 조회
        List<RCHMNM01DSDDSS06VO> returnList06 = new ArrayList<RCHMNM01DSDDSS06VO>();    // 당월납입일자/변경납입일자 조회
        List<RCHMNM01DSDDSS08VO> returnList08 = new ArrayList<RCHMNM01DSDDSS08VO>();    // 결제내역 조회
        List<RCHMNM01DSDDSS11VO> returnList11 = new ArrayList<RCHMNM01DSDDSS11VO>();    // 결제주기 조회

        // 처리 전 대출번호, 대출순번, 관리번호
        String strLoanNo = inVo.getRCHMNM01DSSMVO().getLoanNo();
        String strLoanSeq = inVo.getRCHMNM01DSSMVO().getLoanSeq();
        String strMngNo = inVo.getRCHMNM01DSSMVO().getMngNo();

        SearchLoanSeqVO resultCommVO = commBizService.SearchLoanSeq(strLoanNo, strLoanSeq, strMngNo);

        if( resultCommVO.getRsltCd().equals(msgEnum.SUCCESS.getErrorCd())) {
            strLoanNo = resultCommVO.getLoanNo();
            strLoanSeq = resultCommVO.getLoanSeq();
        } else {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(msgEnum.IS_EMPTY.getErrorCn());

            /* 출력 결과값 대입 */
            resultVo.setRCHMNM01DSDDSS01VO(returnList01);
            resultVo.setRCHMNM01DSDDSS02VO(returnList02);
            resultVo.setRCHMNM01DSDDSS03VO(returnList03);
            resultVo.setRCHMNM01DSDDSS04VO(returnList04);
            resultVo.setRCHMNM01DSDDSS05VO(returnList05);
            resultVo.setRCHMNM01DSDDSS06VO(returnList06);
            resultVo.setRCHMNM01DSDDSS08VO(returnList08);
            resultVo.setRCHMNM01DSDDSS11VO(returnList11);

            return resultVo;
        }

        // 조회 조건 셋팅
        RCHMNM01SrchDTO inSrchDto = new RCHMNM01SrchDTO();
        inSrchDto.setLoanNo(strLoanNo);
        inSrchDto.setLoanSeq(strLoanSeq);
        inSrchDto.setMngNo(inVo.getRCHMNM01DSSMVO().getMngNo());

        // 기본정보 조회
        List<RCHMNM01DSSD01OutDTO> outList01 = loanChngMapper.searchSetlDdChngLoanBase(inSrchDto);
        // 결제일 변경이력에서 결제 정보 조회
        List<RCHMNM01DSSD01OutDTO> outList01_1 = loanChngMapper.searchStSetlDdChngHist(inSrchDto);

        for( RCHMNM01DSSD01OutDTO dto : outList01 ) {
            RCHMNM01DSDDSS01VO vo = new RCHMNM01DSDDSS01VO();

            vo.setLoanNo(dto.getLoanNo());                    // 대출_번호
            vo.setLoanSeq(dto.getLoanSeq());                  // 대출_순번
            vo.setMngNo(dto.getMngNo());                      // 관리번호
            vo.setContManNo(dto.getContManNo());              // 계약자_번호
            vo.setPrdtCd(dto.getPrdtCd());                    // 상품_코드
            vo.setLoanStatCd(dto.getLoanStatCd());            // 대출_상태_코드
            vo.setLoanStatNm(dto.getLoanStatNm());            // 대출_상태_코드
            vo.setDueMethCd(dto.getDueMethCd());              // 납입_방법_코드
            vo.setDueMethNm(dto.getDueMethNm());              // 납입_방법_코드
            vo.setLoanPamtRamt(dto.getLoanPamtRamt());        // 대출_원금_잔액
            vo.setLoanDt(dto.getLoanDt());                    // 대출_일자
            vo.setMngDeptCd(dto.getMngDeptCd());              // 관리_부서_코드
            vo.setCustNm(dto.getCustNm());                    // 고객명
            vo.setPrdtNm(dto.getPrdtNm());                    // 상품명
            vo.setGodsCd(dto.getGodsCd());                    // 물품_코드
            vo.setGodsNm(dto.getGodsNm());                    // 물품명
            vo.setBndStatCd(dto.getBndStatCd());              // 채권_상태_코드
            vo.setBndStatNm(dto.getBndStatNm());              // 채권_상태_코드
            vo.setDeptAbbrnm(dto.getDeptAbbrnm());            // 부서약칭
            vo.setAskPlcDivCd(dto.getAskPlcDivCd());          // 청구지_구분코드
            vo.setEmalAskFg(dto.getEmalAskFg());              // 전자메일_청구_여부
            vo.setFlotIzeDivCd(dto.getFlotIzeDivCd());        // 유동화구분코드
            vo.setLoanChngDivCd(dto.getLoanChngDivCd());      // 대출변경구분코드
            vo.setAcntStatCd(dto.getAcntStatCd());            // 계좌상태코드
            vo.setAcntStatNm(dto.getAcntStatNm());            // 계좌상태명
            vo.setPrdtLrgeClasCd(dto.getPrdtLrgeClasCd());    // 상품대분류
            vo.setPrdtMidClasCd(dto.getPrdtMidClasCd());      // 상품중분류
            vo.setMngPlcDivCd(dto.getMngPlcDivCd());          // 관리처
            vo.setMngPlcDivNm(dto.getMngPlcDivNm());          // 관리처명
            vo.setDlyAmt(dto.getDlyAmt());                    // 연체금액
            vo.setUnComgCnt(dto.getUnComgCnt());              // 잔여회차
            vo.setDlyDt(dto.getDlyDt());                      // 연체일자

            returnList01.add(vo);
        }

        // 결과값에 추가 정보 입력을 위해 변수로 처리
        RCHMNM01DSDDSS01VO vo = new RCHMNM01DSDDSS01VO();
        if( returnList01.size() > 0 ) {
            vo = returnList01.get(0);

            if( outList01_1.size() == 0 ) {
                vo.setSnum("");
                vo.setLoanChngConsRsltCd("");
                vo.setNtrmJstManCd("");
                vo.setArvmCd("");
                vo.setIsrtDeptCd("");

                returnList01.set(0, vo);
            } else {
                for( RCHMNM01DSSD01OutDTO dto : outList01_1 ) {
                    vo.setSnum(dto.getSnum());
                    vo.setLoanChngConsRsltCd(dto.getLoanChngConsRsltCd());
                    vo.setNtrmJstManCd(dto.getNtrmJstManCd());
                    vo.setArvmCd(dto.getArvmCd());
                    vo.setIsrtDeptCd(dto.getIsrtDeptCd());

                    returnList01.set(0, vo);
                }
            }
        }

        // 데이터가 있는 경우 하기 내용을 추가 조회 함
        if( returnList01.size() == 1 ) {
            // 대출건의 관리부서와 사용자의 부서코드가 같지 않으면 처리불가
//            if (!event.getMnbrDivCd().equals("1") && !ds.get(SetlDdChngSDDO01.mngDeptCd).equals(event.getBsnDeptCd())) {
//                throw new Exception("타본부는 조회할 수 없습니다.");
//            }
            // 청구미수호출

            // 첫번째 대출번호, 대출순번
            AskUnrcvVO askUnrcvo = new AskUnrcvVO();
            AskUnrcvObjVO objVO1 = new AskUnrcvObjVO();
            objVO1.loanNo = strLoanNo;
            objVO1.loanSeq = strLoanSeq;
            objVO1.setlDt = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
            askUnrcvo.addAskUnrcvObj(objVO1);
//[청구미수 완료시 연결]
            AskUnrcvVO result = AskUnrcvProcCC.calcAskUnrcv(askUnrcvo);
            String arg[] = new String[5];
//
            if (result.bndCnt == 1) {
                //// System.out.println(result.getBndVO(0).dlyAmt); //연체금액
                //// System.out.println(result.getBndVO(0).unComgCnt); //미도래건수
                //// System.out.println(result.getBndVO(0).dlyDt); //연체일자
                //// System.out.println(result.getBndVO(0).thmmDueTims); //당월
                //// System.out.println(result.getBndVO(0).thmmDueDt);    //당월_납입_일자
                arg[0] = "" + result.getBndVO(0).dlyAmt;
                arg[1] = "" + result.getBndVO(0).timsUnrcvCnt; // 회차미수건수
                arg[2] = "" + result.getBndVO(0).dlyDt;
                arg[3] = "" + result.getBndVO(0).thmmDueTims;
                arg[4] = "" + result.getBndVO(0).thmmDueDt;
            } else {
                throw new Exception("해당대출건에 청구미수 자료가 존재하지않습니다.");
            }
            vo.setDlyAmt(arg[0]);       // 청구미수 연체금액
            vo.setUnComgCnt(arg[1]);    // 청구미수 잔여회차
            vo.setDlyDt(arg[2]);        // 청구미수 연체일자

            // 대출고객주소 조회 sddo02
            RCHMNM01DSDDSS02VO vo02 = new RCHMNM01DSDDSS02VO();
            inSrchDto.setCustNo( vo.getContManNo() );
            List<RCHMNM01DSSD02OutDTO> outList02 = loanChngMapper.searchAskPlcChngCustAddr(inSrchDto);
            if( outList02.size() == 0 ) {
//                returnList02.add(vo02);
            } else {
                for( RCHMNM01DSSD02OutDTO dto : outList02 ) {
                    vo02.setAddrDivCd(dto.getAddrDivCd());    // 주소_구분코드
                    vo02.setZipCd(dto.getZipCd());            // 우편번호
                    vo02.setBaseAddr(dto.getBaseAddr());      // 기본_주소
                    vo02.setAddrSpec(dto.getAddrSpec());      // 주소_상세

                    returnList02.add(vo02);
                }
            }

            // 대출고객연락처 정보 조회 sddo03
            RCHMNM01DSDDSS03VO vo03 = new RCHMNM01DSDDSS03VO();
            List<RCHMNM01DSSD03OutDTO> outList03 = loanChngMapper.searchCustCntcPlc(inSrchDto);
            if( outList03.size() == 0 ) {
//                returnList03.add(vo03);
            } else {
                for( RCHMNM01DSSD03OutDTO dto : outList03 ) {
                    vo03.setCntcPlcDivCd(dto.getCntcPlcDivCd());        // 주소_구분코드
                    vo03.setCntcPlcTel0(dto.getCntcPlcTel0());          // 우편번호
                    vo03.setCntcPlcTel1(dto.getCntcPlcTel1());          // 주소_시
                    vo03.setCntcPlcTel2(dto.getCntcPlcTel2());          // 주소_구
                    vo03.setCntcPlcTel3(dto.getCntcPlcTel3());          // 주소_동
                    vo03.setCntcPlcTelInno(dto.getCntcPlcTelInno());    // 주소_상세

                    returnList03.add(vo03);
                }
            }
            // 당월납입일자 셋팅 sddo04
            String strLoanChngConsRsltCd = vo.getLoanChngConsRsltCd().trim();
            //String strLoanChngConsRsltCd = null;

            if( strLoanChngConsRsltCd == null || "".equals(strLoanChngConsRsltCd) || "04".equals(strLoanChngConsRsltCd) || "05".equals(strLoanChngConsRsltCd) ) {
            	RCHMNM01DSDDSS04VO vo04 = new RCHMNM01DSDDSS04VO();
            	vo04.setThmmDueTims(arg[3]); 	// 청구미수 당월납입회차
            	vo04.setThmmDueDt(arg[4]);		// 청구미수 당월납입일자

            	vo04.setChngTims(Long.parseLong(arg[3]));    // 청구미수 변경납입회차(당월납입회차)
            	vo04.setChngBfDueDt(arg[4]);          		// 청구미수 변경전납입일자(당월납입일자)

            	returnList04.add(vo04);
//            	returnList04.get(0).setThmmDueTims(arg[3]);         		// 청구미수 당월납입회차
//                returnList04.get(0).setThmmDueDt(arg[4]);            		// 청구미수 당월납입일자
//
//                returnList04.get(0).setChngTims(Long.parseLong(arg[3]));    // 청구미수 변경납입회차(당월납입회차)
//                returnList04.get(0).setChngBfDueDt(arg[4]);          		// 청구미수 변경전납입일자(당월납입일자)

                //resultVo.setRCHMNM01DSDDSS04VO(returnList04);

            	StRmbrPlanDescDTO dto = new StRmbrPlanDescDTO();
            	dto.setLoanNo(strLoanNo);
            	dto.setLoanSeq(strLoanSeq);
            	dto.setTims(Long.parseLong(arg[3]));
                // 변경전납입일자및 전회차 납입일자 조회 sddo06
                returnList06 = this.getSelectChngDueDtInfo(dto);
            } else {
                // 현재 품의 중인 내용 조회(대출결제일변경에서 가져옴) sddo04
                inSrchDto.setCurSnum( vo.getSnum() );
                RCHMNM01DSDDSS04VO vo04 = new RCHMNM01DSDDSS04VO();
                StSetlDdChngHistDTO setlddChngSrchDto = new StSetlDdChngHistDTO();
                setlddChngSrchDto.setLoanNo(vo.getLoanNo());
                setlddChngSrchDto.setLoanSeq(vo.getLoanSeq());
                setlddChngSrchDto.setSnum(Long.valueOf(vo.getSnum())); /* 2023.03.22. younghwe.kim : String을 Long으로 변경 */

                //List<RCHMNM01DSSD04OutDTO> outList04 = loanChngMapper.searchSetlDdChng(inSrchDto);
                List<StSetlDdChngHistDTO> outListDto = setlDdChngHistMapper.searchSetlDdChngList(setlddChngSrchDto);
                if( outListDto.size() > 0 ) {
                    for( StSetlDdChngHistDTO dto : outListDto ) {
//                        vo04.setThmmDueTims(dto.getThmmDueTims());
//                        vo04.setThmmDueDt(dto.getThmmDueDt());
                        vo04.setChngTims(dto.getChngTims());
                        vo04.setChngBfDueDt(dto.getChngBfDueDt());
                        vo04.setChngAfDueDt(dto.getChngAfDueDt());
                        vo04.setPsgInt(dto.getPsgInt().toString());
                        vo04.setAplyIntRt(String.valueOf(dto.getAplyIntRt()));
//                        vo04.setPsgDdCnt(dto.getPsgDdCnt());     // 경과일수
                    }
                }
                returnList04.add(vo04);
            }

            // 결제내역 sddo08
            //RCHMNM01DSDDSS08VO vo08 = new RCHMNM01DSDDSS08VO();
            //List<RCHMNM01DSDDSS08VO> returnList08 = new ArrayList<RCHMNM01DSDDSS08VO>();    // 결제내역 조회
            String arrParam[] = new String[4];
			arrParam[0] = strLoanNo;
			arrParam[1] = strLoanSeq;
			arrParam[2] = "";
			arrParam[3] = vo.getSnum(); // 일련번호

            returnList08 = this.getSelectConsHist(arrParam);
            //List<RCHMNM01DSSD08OutDTO> outList08 = loanChngMapper.searchSetlDdChngCons(inSrchDto);
//            if( outList08.size() > 0 ) {
//                for( RCHMNM01DSSD08OutDTO dto : outList08 ) {
//                    vo08.setLoanChngConsRsltCd(dto.getLoanChngConsRsltCd());
//                    vo08.setLoanChngConsRsltNm(dto.getLoanChngConsRsltNm());
//                    vo08.setJstEmpNo(dto.getJstEmpNo());
//                    vo08.setJstEmpNm(dto.getJstEmpNm());
//                    vo08.setJstDt(dto.getJstDt());
//                    vo08.setLoanChngOpn(dto.getLoanChngOpn());
//                    vo08.setNtrmSetlmanNm(dto.getNtrmSetlmanNm());
//
//                    returnList08.add(vo08);
//                }
//            }

            // 대출결제일변경이력 sddo05
            RCHMNM01DSDDSS05VO vo05 = new RCHMNM01DSDDSS05VO();
            List<RCHMNM01DSSD05OutDTO> outList05 = loanChngMapper.searchSetlDdChngHist(inSrchDto);
            if( outList05.size() > 0 ) {
                for( RCHMNM01DSSD05OutDTO dto : outList05 ) {
                    vo05.setLastProcDt(dto.getLastProcDt());
                    vo05.setLastProcTm(dto.getLastProcTm());
                    vo05.setSetlDdChngSnum(dto.getSetlDdChngSnum());
                    vo05.setChngTims(dto.getChngTims());
                    vo05.setChngBfDueDt(dto.getChngBfDueDt());
                    vo05.setChngAfDueDt(dto.getChngAfDueDt());
                    vo05.setPsgInt(dto.getPsgInt());
                    vo05.setIsrtDeptCd(dto.getIsrtDeptCd());
                    vo05.setIsrtDeptNm(dto.getIsrtDeptNm());
                    vo05.setLoanNo(dto.getLoanNo());
                    vo05.setLoanSeq(dto.getLoanSeq());
                    vo05.setSnum(dto.getSnum());
                    vo05.setEmpNm1(dto.getEmpNm1());
                    vo05.setEmpNm2(dto.getEmpNm2());
                    vo05.setCnclPossFg(dto.getCnclPossFg());

                    returnList05.add(vo05);
                }
            }
            // 결제주기 sddo11
            RCHMNM01DSDDSS11VO vo11 = new RCHMNM01DSDDSS11VO();
            //inSrchDto.setPrdtMidClasCd(vo.getPrdtMidClasCd());
            RtCyclDescDTO cyclSrchDto = new RtCyclDescDTO();

//            if( !vo.getPrdtMidClasCd().equals("") && vo.getPrdtMidClasCd().equals("22") ) {
//                cyclSrchDto.setCyclCd("0009");
//            } else {
                cyclSrchDto.setCyclCd("0001");
//            }

            //List<RCHMNM01DSSD11OutDTO> outList11 = loanChngMapper.searchSetlDdCycl(inSrchDto);
            List<RtCyclDescDTO> outList11 = rtCyclDescMapper.searchSetlDdCycl(cyclSrchDto);
            if( outList11.size() > 0 ) {
                for( RtCyclDescDTO dto : outList11 ) {
                    vo11.setSetlDd(dto.getSetlDd());

                    returnList11.add(vo11);
                }
            }
        }
        /* 출력 결과값 대입 */
        resultVo.setRCHMNM01DSDDSS01VO(returnList01);
        resultVo.setRCHMNM01DSDDSS02VO(returnList02);
        resultVo.setRCHMNM01DSDDSS03VO(returnList03);
        resultVo.setRCHMNM01DSDDSS04VO(returnList04);
        resultVo.setRCHMNM01DSDDSS05VO(returnList05);
        resultVo.setRCHMNM01DSDDSS06VO(returnList06);
        resultVo.setRCHMNM01DSDDSS08VO(returnList08);
        resultVo.setRCHMNM01DSDDSS11VO(returnList11);

        /* 상환계획 생성 TEST START */

//        LoanBaseObj loanBaseObj = new LoanBaseObj();
//        loanBaseObj.loanNo = "11111111111";
//        loanBaseObj.loanSeq = "01";
//        loanBaseObj.prdtDivCd = "";
//        loanBaseObj.prdtCd ="TEST01";
//        loanBaseObj.prdtMidClasCd = "21";
//        loanBaseObj.loanPamt = 1000000;
//        loanBaseObj.loanTerm = 24;
//        loanBaseObj.loanDt = "20230302";
//        loanBaseObj.fcntDueDt = "20230405";
//        loanBaseObj.fcntMopaCalcFg = "1";
//        loanBaseObj.empNo = "70277";
//        loanBaseObj.rmbrPlanTypeDivCd = "1";
//
//        loanBaseObj.cprtComTrtFee = 0;
//        loanBaseObj.custTrtFee = 0;
//        loanBaseObj.prFee = 0;
//        loanBaseObj.cprtFee = 0;
//        loanBaseObj.trtFeeIstpAmt = 0; // 취급수수료분납액
//        loanBaseObj.trtFeeIstpFg = ""; // 취급수수료분납여부
//        loanBaseObj.defrIntDistFg = ""; // 거치이자분납여부
//        loanBaseObj.frstStndPrFee = 0;//지급수수료
//        loanBaseObj.setFee        = 1;//설정료
//        loanBaseObj.comStmpFee    = 10000;//인지대_회사부담금
//        loanBaseObj.bsnAgntFeePay = 0;//대행수수료
//        loanBaseObj.salePayAmt    = 0;//판매수수료
//
//        List loanPiamtList = new ArrayList();
//
//        LoanPiamtObj loanPiamtObj = new LoanPiamtObj();
//
//        loanPiamtObj.loanNo = "11111111111";
//        loanPiamtObj.loanSeq = "01";
//        loanPiamtObj.trSnum = 1;
//        loanPiamtObj.frstRank = 1;
//        loanPiamtObj.rmbrFrmlCd = "1";
//        loanPiamtObj.loanPamt = 1000000;
//        loanPiamtObj.term = 24;
//        loanPiamtObj.strtTims = 1;
//        loanPiamtObj.intRt = 1;
//        loanPiamtObj.dueCycl = 1;
//        loanPiamtObj.dueStrtTims = 1;
//        loanPiamtObj.crteDivCd = "1";
//
//        loanPiamtList.add(loanPiamtObj);
//
//
//        loanBaseObj.piamtObjList = loanPiamtList;
//
//        loanBaseObj = rmbrPlanCrteService.createRmblPlan(loanBaseObj);
//
//        rmbrPlanCrteService.updateLoan(loanBaseObj);

        /* 상환계획 생성 TEST END */

        return resultVo;
    }

    /**
     * <p>메소드명      : getSelectChngDueDtInfo : 결제일변경관리_납입회차로 납입일자 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_납입회차로 납입일자를 조회 한다.</p>
     * <p>메소드인수    : RDMDLM01SrchDTO </p>
     * <p>메소드리턴값  : RDMDLM01S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<RCHMNM01DSDDSS06VO> getSelectChngDueDtInfo(StRmbrPlanDescDTO inVo) throws Exception{
        RCHMNM01SrchDTO inSrchDto = new RCHMNM01SrchDTO();
        inSrchDto.setLoanNo(inVo.getLoanNo());
        inSrchDto.setLoanSeq(inVo.getLoanSeq());
        inSrchDto.setCurTims("" + inVo.getTims());
        List<RCHMNM01DSDDSS06VO> returnList = new ArrayList<RCHMNM01DSDDSS06VO>();
        List<RCHMNM01DSSD06OutDTO> outList06 = loanChngMapper.searchSetlDdChngDueDt(inSrchDto);
        if( outList06.size() == 1 ) {
        	for( RCHMNM01DSSD06OutDTO dto : outList06 ) {
                RCHMNM01DSDDSS06VO vo06 = new RCHMNM01DSDDSS06VO();
                vo06.setLoanNo(inVo.getLoanNo());          // 대출_번호
                vo06.setLoanSeq(inVo.getLoanSeq());        // 대출_순번
                vo06.setTims("" +inVo.getTims());          // 회차
                vo06.setDueDt1(dto.getDueDt1());       // 변경전납입일자
                vo06.setDueDt2(dto.getDueDt2());       // 변경전납입일자
                vo06.setRcptTims(dto.getRcptTims());   // 변경전납입일자
                // 도래영업일 조회(1: 당일포함, 0: 당일제외)
                String wkDt = commBizService.isArrvWkdt(ServerSysDate.getServerDate(4), "1");
                vo06.setSaleDt(wkDt);          			  // 익영업일
                returnList.add(vo06);
            }
        }
        /* 출력 결과값 대입 */
        return returnList;
    }

    /**
     * <p>메소드명      : getSelectConsHist : 결제일변경관리_납입회차로 납입일자 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_납입회차로 납입일자를 조회 한다.</p>
     * <p>메소드인수    : RDMDLM01SrchDTO </p>
     * <p>메소드리턴값  : RDMDLM01S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<RCHMNM01DSDDSS08VO> getSelectConsHist(String[] inVo) throws Exception{

        RCHMNM01SrchDTO inSrchDto = new RCHMNM01SrchDTO();
        inSrchDto.setLoanNo(inVo[0]);
        inSrchDto.setLoanSeq(inVo[1]);
        inSrchDto.setCurSnum(inVo[3]);

        List<RCHMNM01DSDDSS08VO> returnList = new ArrayList<RCHMNM01DSDDSS08VO>();
        List<RCHMNM01DSSD08OutDTO> outList = loanChngMapper.searchSetlDdChngCons(inSrchDto);

        if( outList.size() > 0 ) {
            for( RCHMNM01DSSD08OutDTO dto : outList ) {
            	RCHMNM01DSDDSS08VO vo = new RCHMNM01DSDDSS08VO();
                vo.setLoanChngConsRsltCd(dto.getLoanChngConsRsltCd());
                vo.setLoanChngConsRsltNm(dto.getLoanChngConsRsltNm());
                vo.setJstEmpNo(dto.getJstEmpNo());
                vo.setJstEmpNm(dto.getJstEmpNm());
                vo.setJstDt(dto.getJstDt());
                vo.setLoanChngOpn(dto.getLoanChngOpn());
                vo.setNtrmSetlmanNm(dto.getNtrmSetlmanNm());

                returnList.add(vo);
            }
        }

        /* 출력 결과값 대입 */
        return returnList;
    }

    /**
     * <p>메소드명      : registerRCHMNM01I01 : 결제일변경관리_품의등록 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_품의등록을 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RCHMNM01OutVO registerRCHMNM01I01(RCHMNM01InVO inVo) throws Exception{
        /** 품의등록 업무 서비스 호출 수행 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();

        // 등록 전 데이터 체크
        String strLoanNo  = inVo.getRCHMNM01DSSMVO().getLoanNo().toString();
        String strLoanSeq = inVo.getRCHMNM01DSSMVO().getLoanSeq().toString();
        String strArvmCd  = inVo.getRCHMNM01DSDDSS01VO().getArvmCd().toString();

        // 품의등록 전 변경하려는 회차 이후에 수납내역이 있는지 확인
        RtRcptDescDTO srchDto = new RtRcptDescDTO();
        srchDto.setLoanNo(strLoanNo);
        srchDto.setLoanNo(strLoanSeq);
        srchDto.setTims(Long.valueOf(inVo.getRCHMNM01DSDDSS04VO().getChngTims()));

        List<RtRcptDescDTO> rcptDescOutDTO = rtRcptDescMapper.searchRcptDesc(srchDto);
        if( rcptDescOutDTO.size() > 0 ) {
            throw new Exception("변경회차 이후에 수납내역이 존재합니다. 수납취소후 처리하시기 바랍니다.");
        }

        // 당월납입일자/변경납입일자 조회
        List<RCHMNM01DSDDSS06VO> returnList06 = new ArrayList<RCHMNM01DSDDSS06VO>();
        StRmbrPlanDescDTO dto = new StRmbrPlanDescDTO();
    	dto.setLoanNo(strLoanNo);
    	dto.setLoanSeq(strLoanSeq);
    	dto.setTims(Long.valueOf(inVo.getRCHMNM01DSDDSS04VO().getChngTims()));
        LOGGER.info("품의결과 無 ==> 1");
        // 변경전납입일자및 전회차 납입일자 조회 sddo06
        LOGGER.info("품의결과 無 ==> 2");
        returnList06 = this.getSelectChngDueDtInfo(dto);

        String strDueDt1 = returnList06.get(0).getDueDt1();                       // 납입일자
        String strChngBfDueDt = inVo.getRCHMNM01DSDDSS04VO().getChngBfDueDt();    // 변경전납입일자

        if( !strDueDt1.equals(strChngBfDueDt) ) {
            throw new Exception("변경납입회차와 변경전납입일자가 올바르지않습니다.");
        }

        if( strArvmCd.equals("10") ) {
            resultVo = this.updateSaveProc(inVo);
        } else {
            resultVo = this.updateConsProc(inVo);
        }

        if( resultVo.getRsltCd().equals("0000") ) {
            // 등록 후 재조회
            resultVo = this.getSelectMainInfo(inVo);
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : registerRCHMNM01I02 : 결제일변경관리_품의승인 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_품의승인을 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RCHMNM01OutVO registerRCHMNM01I02(RCHMNM01InVO inVo) throws Exception{
        /** 품의등록 업무 서비스 호출 수행 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        String[] arrParam = new String[10];
        arrParam[0] = inVo.getRCHMNM01DSDDSS01VO().getLoanNo();
        arrParam[1] = inVo.getRCHMNM01DSDDSS01VO().getLoanSeq();
        arrParam[2] = inVo.getRCHMNM01DSDDSS01VO().getSnum();
        arrParam[3] = inVo.getRCHMNM01DSDDSS01VO().getNtrmJstManCd(); //"" + Integer.parseInt(Util.nullToZero(sddo01.get(SetlDdChngSDDO01.ntrmJstManCd))   ); // 변경전차기결재자코드
        arrParam[4] = inVo.getRCHMNM01DSDDSS01VO().getNtrmJstManCd(); //"" + (Integer.parseInt(Util.nullToZero(sddo01.get(SetlDdChngSDDO01.ntrmJstManCd))) ); // +10 제거
        // 차기결재자코드+10
        //arrParam[4] = "" + (Integer.parseInt(Util.nullToZero(sddo01.get(SetlDdChngSDDO01.ntrmJstManCd))) + 10); // 2018-10-30 막음 cjh

        arrParam[5] = "02"; // 대출변경품의결과코드(02:승인)
        arrParam[6] = inVo.getRCHMNM01DSDDSS09VO().getJstEmpNo(); // sddo09.get(SetlDdChngSDDO09.jstEmpNo); // 처리사원
        arrParam[7] = inVo.getRCHMNM01DSDDSS09VO().getLoanChngOpn(); // sddo09.get(SetlDdChngSDDO09.loanChngOpn); // 결재의견
        arrParam[8] = inVo.getRCHMNM01DSDDSS01VO().getArvmCd(); // sddo01.get(SetlDdChngSDDO01.arvmCd); // 전결권자 코드

        // (차기전결권자)=(전결권자)인 경우
        if (arrParam[3].equals(arrParam[8])) {
            arrParam[4] = "99"; // 차기결재자코드
            arrParam[5] = "05"; // 대출변경품의결과코드(05:완료)
        }
        // [대출 결제일 변경 이력] 수정, [대출 변경 품의 단계] 수정
        resultVo = this.updateConsProc(inVo);

        // (차기전결권자)=(전결권자)인 경우 (즉 최종승인일 경우)
        if (arrParam[3].equals(arrParam[8])) {
         // 품의등록 전 변경하려는 회차 이후에 수납내역이 있는지 확인
            RtRcptDescDTO srchDto = new RtRcptDescDTO();
            srchDto.setLoanNo(arrParam[0]);
            srchDto.setLoanNo(arrParam[1]);
            srchDto.setTims(Long.valueOf(inVo.getRCHMNM01DSDDSS04VO().getChngTims()));

            List<RtRcptDescDTO> rcptDescOutDTO = rtRcptDescMapper.searchRcptDesc(srchDto);
            if( rcptDescOutDTO.size() > 0 ) {
                throw new Exception("변경회차 이후에 수납내역이 존재합니다. 수납취소후 처리하시기 바랍니다.");
            }

            // 1.대출기본 테이블 수정
            StLoanBaseDTO stLoanBaseTdo = new StLoanBaseDTO();
            stLoanBaseTdo.setLoanNo(arrParam[0]);
            stLoanBaseTdo.setLoanSeq(arrParam[1]);
            stLoanBaseTdo.setSetlDd(inVo.getRCHMNM01DSDDSS04VO().getChngAfDueDt().substring(6));
            //1회차 변경인 경우 초회납입일 변경
            if(inVo.getRCHMNM01DSDDSS04VO().getChngTims() != 0 &&
               inVo.getRCHMNM01DSDDSS04VO().getChngTims() == 1 ) {
                stLoanBaseTdo.setFcntDueDt(inVo.getRCHMNM01DSDDSS04VO().getChngAfDueDt());
            }
            stLoanBaseTdo.setLastProcEmpNo(arrParam[6]);
            //StLoanBaseTDO stLoanBaseTdo = SetlDdChngConverter.convertSddoToStLoanBaseTDO(sddo01, sddo04, event);
            try {
                stLoanBaseMapper.updateSetlDdChngStLoanBase(stLoanBaseTdo);
            }  catch (Exception e) {
                LOGGER.error("[대출변경수정오류] :대출기본원장 수정 중 오류  " + e.getMessage());
                resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
                resultVo.setRsltCntn( e.getMessage() );
            }

            // 2.대출변경이력등록 <==대출변경이력 테이블 안쓴다네 ㅜㅜ
            /*
             * StLoanChngHistTDO stLoanChngHistTdo =
             * SetlDdChngConverter.convertSddoToStLoanChngHistTDO(sddo01,
             * sddo04, event); //대출변경이력의 변경순번 Max 채번 String strMaxNum02 =
             * ((LoanChngHistDAO)
             * bc3).searchLoanChngHistMaxNum(stLoanChngHistTdo, tx);
             * stLoanChngHistTdo.setChngSeq(strMaxNum02);
             * stLoanChngHistTdo.setSetlDdChngSnum(arrParam[2]);
             * ((LoanChngHistDAO)
             * bc3).insertSetlDdChngstLoanChngHist(stLoanChngHistTdo, tx);
             */

            // 3.상환계획수정 중 {결제일변경} 모듈 호출
            SetlDdChngObj obj = new SetlDdChngObj();
            obj.loanNo = arrParam[0]; // 대출번호
            obj.loanSeq = arrParam[1]; // 대출순번
            obj.chngTims = Integer.parseInt("" +inVo.getRCHMNM01DSDDSS04VO().getChngTims());//  sddo04.get(SetlDdChngSDDO04.chngTims)); // 변경회차

            //// System.out.println("변경납입일자"+DateFormatUtil.format(sddo04.get(SetlDdChngSDDO04.chngAfDueDt)));
            obj.chngDueDt = inVo.getRCHMNM01DSDDSS04VO().getChngAfDueDt(); //sddo04.get(SetlDdChngSDDO04.chngAfDueDt); // 변경납입일자
            obj.empNo = inVo.getRCHMNM01DSDDSS09VO().getJstEmpNo(); // 사용자번호
            rmbrPlanUpdtCC.setlDdChng(obj);

            // 연체갱신 2018-08-01 채권팀 요청
            OnlnDlyReptInVO onlnDlyInVO = new OnlnDlyReptInVO();
            onlnDlyInVO.setLoanNo(obj.loanNo);
            onlnDlyInVO.setLoanSeq(obj.loanSeq);
            onlnDlyInVO.setSetlDt(ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD));

            dlyReptCC.ProcRealTmpDlyInfo(onlnDlyInVO);
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : registerRCHMNM01I03 : 결제일변경관리_거절 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_품의거절을 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RCHMNM01OutVO registerRCHMNM01I03(RCHMNM01InVO inVo) throws Exception{
        /** 품의등록 업무 서비스 호출 수행 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();

        // 등록 전 데이터 체크
        String strLoanNo       = inVo.getRCHMNM01DSSMVO().getLoanNo().toString();                                         // 대출_번호
        String strLoanSeq      = inVo.getRCHMNM01DSSMVO().getLoanSeq().toString();                                        // 대출_순번
        String strSnum         = inVo.getRCHMNM01DSDDSS01VO().getSnum().toString();                                       // 기 등록한 순번 등록 해야 함
        String strNtrmJstManCd = inVo.getRCHMNM01DSDDSS01VO().getNtrmJstManCd().toString();                               // 대출변경품의결과코드(03:반려)
        String strJstEmpNo     = StringUtil.nvl(inVo.getRCHMNM01DSDDSS09VO().getJstEmpNo().toString(), "TEST");           // 처리사원
        String strLoanChngOpn  = StringUtil.nvl(inVo.getRCHMNM01DSDDSS09VO().getLoanChngOpn().toString(), "TEST OPN");    // 결재의견

        // [대출 결제일 변경 이력] 수정
        StSetlDdChngHistDTO updDTO1 = setSetlDdChngHistDTO(inVo);
        /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO1.setSnum(Long.valueOf(strSnum));
        updDTO1.setLoanChngDivCd(LOAN_CHNG_DIV_CD_RJCT);

        try {
            setlDdChngHistMapper.updateStSetlDdChngHist(updDTO1);
        }  catch (Exception e) {
            LOGGER.error("[대출변경수정오류] : 대출 결제일 변경 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        // [대출 변경 품의 단계]수정
        StLoanChngConsStagDTO updDTO2 = new StLoanChngConsStagDTO();
        updDTO2.setLoanNo(strLoanNo);                            // 대출_번호
        updDTO2.setLoanSeq(strLoanSeq);                          // 대출_순번
        /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO2.setSnum(Long.valueOf(strSnum));                  // 기 등록한 순번 등록 해야 함
        updDTO2.setLoanChngConsRsltCd(LOAN_CHNG_DIV_CD_RJCT);    // 대출변경품의결과코드(03:반려)
        updDTO2.setJstEmpNo(strJstEmpNo);                        // 처리사원
        updDTO2.setLoanChngOpn(strLoanChngOpn);                  // 결재의견
        updDTO2.setNtrmSetlmanCd(strNtrmJstManCd);               // 차기결제자  3
        updDTO2.setLastProcEmpNo(strJstEmpNo);                   // 최종등록자

        try {
            loanChngConsStagMapper.updateStLoanChngConsStag(updDTO2);
        }  catch (Exception e) {
            LOGGER.error("[대출변경수정오류] : 대출 변경 품의 단계 수정 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : registerRCHMNM01I04 : 결제일변경관리_결제일변경취소 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_결제일변경취소 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @Override
    @SuppressWarnings("unchecked")
    public RCHMNM01OutVO registerRCHMNM01I04(RCHMNM01InVO inVo) throws Exception{
        /** 품의등록 업무 서비스 호출 수행 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();

        String strLoanNo       = inVo.getRCHMNM01DSSMVO().getLoanNo().toString();                                         // 대출_번호
        String strLoanSeq      = inVo.getRCHMNM01DSSMVO().getLoanSeq().toString();                                        // 대출_순번
        String strSnum         = inVo.getRCHMNM01DSDDSS01VO().getSnum().toString();                                       // 기 등록한 순번 등록 해야 함
        String strNtrmJstManCd = inVo.getRCHMNM01DSDDSS01VO().getNtrmJstManCd().toString();                               // 대출변경품의결과코드(03:반려)
        String strJstEmpNo     = StringUtil.nvl(inVo.getRCHMNM01DSDDSS09VO().getJstEmpNo().toString(), "TEST");           // 처리사원
        String strLoanChngOpn  = StringUtil.nvl(inVo.getRCHMNM01DSDDSS09VO().getLoanChngOpn().toString(), "TEST OPN");    // 결재의견

        // 등록 전 데이터 체크 : 결제일 변경 이력 조회
        StSetlDdChngHistDTO setlddChngSrchDto = new StSetlDdChngHistDTO();
        setlddChngSrchDto.setLoanNo(strLoanNo);
        setlddChngSrchDto.setLoanSeq(strLoanSeq);

        RCHMNM01DSDDSS04VO dsddss04Vo = new RCHMNM01DSDDSS04VO();
        try {
            List<StSetlDdChngHistDTO> srchOutDto = setlDdChngHistMapper.searchSetlDdChngHist2(setlddChngSrchDto);

            if( srchOutDto.size() == 0 || srchOutDto == null ) {
                // 취소 가능 한 내역이 없습니다.
                resultVo.setRsltCd( msgEnum.SETL_DD_CHNG_CNCL_CHK_POSS_FG.getErrorCd());
                resultVo.setRsltCntn( msgEnum.SETL_DD_CHNG_CNCL_CHK_POSS_FG.getErrorCn() );

                return resultVo;
            } else {
                // 변경회차, 변경후납입일자, 변경전납입일자 셋팅
                StSetlDdChngHistDTO rsltDTO = srchOutDto.get(0);
                dsddss04Vo.setChngTims(rsltDTO.getChngTims());
                dsddss04Vo.setChngAfDueDt(rsltDTO.getChngAfDueDt());
                dsddss04Vo.setChngBfDueDt(rsltDTO.getChngBfDueDt());

                inVo.setRCHMNM01DSDDSS04VO(dsddss04Vo);

                // 변경
                inVo.getRCHMNM01DSSMVO().setSnum(Long.valueOf(rsltDTO.getSnum()));
            }

        }  catch (Exception e) {
            LOGGER.error("[결제일변경취소] : 결제일 변경 이력 조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        // 변경회차 이후 수납내역이 있으면 에러처리- 결제일변경취소 시 다시한번 체크
        //  - 결제일변경취소 전 변경하려는 회차 이후에 수납내역이 있는지 확인
        RtRcptDescDTO srchDto = new RtRcptDescDTO();
        srchDto.setLoanNo(strLoanNo);
        srchDto.setLoanNo(strLoanSeq);
        srchDto.setTims(inVo.getRCHMNM01DSDDSS04VO().getChngTims());

        try {
            List<RtRcptDescDTO> rcptDescOutDTO = rtRcptDescMapper.searchRcptDesc(srchDto);

            if( rcptDescOutDTO.size() > 0 ) {
                // 변경회차 이후에 수납내역이 존재합니다. 수납취소후 처리하시기 바랍니다.
                resultVo.setRsltCd( msgEnum.SETL_DD_CHNG_CNCL_CHK_RCPT_SRCH.getErrorCd());
                resultVo.setRsltCntn( msgEnum.SETL_DD_CHNG_CNCL_CHK_RCPT_SRCH.getErrorCn() );

                return resultVo;
            }

        }  catch (Exception e) {
            LOGGER.error("[결제일변경취소] : 수납내역 조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        // 대출기본 테이블 수정 & 상환스케줄 생성
        RCHMNM01OutVO updRstlVo = this.updateLoanInfo(inVo, strLoanNo, strLoanSeq, "1");

        return updRstlVo;
    }

    /**
     * <p>메소드명      : updateSaveProc - 품의등록 시 처리 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리- 품의등록 시 처리 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public RCHMNM01OutVO updateSaveProc(RCHMNM01InVO inVo) throws Exception {
        // 등록 전 데이터 체크
        String strLoanNo  = inVo.getRCHMNM01DSSMVO().getLoanNo().toString();
        String strLoanSeq = inVo.getRCHMNM01DSSMVO().getLoanSeq().toString();
        String strArvmCd  = inVo.getRCHMNM01DSDDSS01VO().getArvmCd().toString();
        String strLoanChngConsRsltCd = inVo.getRCHMNM01DSDDSS01VO().getLoanChngConsRsltCd().toString();

        // 경과이자 계산 호출 하여 inVo의 RCHMNM01DSDDSS04VO에 셋팅 해 준다
        String strPsgInt = "";
        String strAplyIntRt = "";
        String strPsgDdCnt = "";
        PsgIntCalcObj psgIntObj = inquireCalPsgInt(inVo);
        if( psgIntObj.rsltCd.equals("0000") ) {
            strPsgInt = String.valueOf(psgIntObj.psgInt);
            strAplyIntRt = String.valueOf(psgIntObj.aplyIntRt);
            strPsgDdCnt = String.valueOf(psgIntObj.psgDdCnt);
        }

        RCHMNM01DSDDSS04VO setVo = new RCHMNM01DSDDSS04VO();
        setVo.setPsgInt(strPsgInt);
        setVo.setAplyIntRt(strAplyIntRt);
        setVo.setPsgDdCnt(strPsgDdCnt);
        inVo.setRCHMNM01DSDDSS04VO(setVo);

        if( strLoanChngConsRsltCd.equals("") || strLoanChngConsRsltCd.equals("04") || strLoanChngConsRsltCd.equals("05") ) {
            StLoanPiamtDTO srchInDTO = new StLoanPiamtDTO();
            srchInDTO.setLoanNo(strLoanNo);
            srchInDTO.setLoanSeq(strLoanSeq);
            StLoanPiamtDTO stchOutDTO = stLoanPiamtMapper.searchMaxTrSnum(srchInDTO);

            // 1. [대출 결제일 변경 이력] 생성
            StSetlDdChngHistDTO insDTO1 = setSetlDdChngHistDTO(inVo);
            insDTO1.setTrSnum(stchOutDTO.getTrSnum());      // 거래순번

            setlDdChngHistMapper.insertStSetlDdChngHist(insDTO1);

            // 2. [대출 변경 품의] 생성
            for (int i = Integer.parseInt(strArvmCd); i <= Integer.parseInt(strArvmCd); i = i + 10) {
                if( i != 20 ) {
                    StLoanChngConsStagDTO insDTO2 = new StLoanChngConsStagDTO();
                    insDTO2.setLoanNo(strLoanNo);                   // 대출_번호
                    insDTO2.setLoanSeq(strLoanSeq);                 // 대출_순번
                    insDTO2.setNtrmSetlmanCd(String.valueOf(i));    // 차기결제자
                    insDTO2.setFrstRegEmpNo("TEST");                // 최초등록자
                    insDTO2.setLastProcEmpNo("TEST");               // 최종등록자

                    loanChngConsStagMapper.insertStLoanChngConsStag(insDTO2);
                }
            }
        }

        // 3. [대출 결제일 변경 이력] 수정
        //  - max 순번 조회
        StSetlDdChngHistDTO srchDTO1 = new StSetlDdChngHistDTO();
        srchDTO1.setLoanNo(strLoanNo);
        srchDTO1.setLoanSeq(strLoanSeq);
        String strSnum = setlDdChngHistMapper.searchMaxSnum(srchDTO1);

        StSetlDdChngHistDTO updDTO1 = setSetlDdChngHistDTO(inVo);
        updDTO1.setSnum(Long.valueOf(strSnum)); /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO1.setLoanChngDivCd(LOAN_CHNG_DIV_CD_CMPL);

        setlDdChngHistMapper.updateStSetlDdChngHist(updDTO1);

        // 4. [대출 변경 품의 단계]수정
        StLoanChngConsStagDTO updDTO2 = new StLoanChngConsStagDTO();
        updDTO2.setLoanNo(strLoanNo);                   // 대출_번호
        updDTO2.setLoanSeq(strLoanSeq);                 // 대출_순번
        updDTO2.setSnum(0);                             // 기 등록한 순번 등록 해야 함 /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO2.setLoanChngConsRsltCd(strLoanChngConsRsltCd);
        updDTO2.setJstEmpNo("TEST");
        updDTO2.setLoanChngOpn(strLoanChngConsRsltCd);
        updDTO2.setNtrmSetlmanCd(strArvmCd);            // 차기결제자  3
        updDTO2.setLastProcEmpNo("TEST");               // 최종등록자

        loanChngConsStagMapper.updateStLoanChngConsStag(updDTO2);

        // 대출기본 테이블 수정 & 상환스케줄 생성
        RCHMNM01OutVO updRstlVo = this.updateLoanInfo(inVo, strLoanNo, strLoanSeq, "0");

        return updRstlVo;
    }

    /**
     * <p>메소드명      : updateConsProc - 품의등록 시 처리 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리- 품의등록 시 처리 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public RCHMNM01OutVO updateConsProc(RCHMNM01InVO inVo) throws Exception {

        RCHMNM01OutVO returnVo = new RCHMNM01OutVO();

        // 등록 전 데이터 체크
        String strLoanNo  = inVo.getRCHMNM01DSSMVO().getLoanNo().toString();
        String strLoanSeq = inVo.getRCHMNM01DSSMVO().getLoanSeq().toString();
        String strArvmCd  = inVo.getRCHMNM01DSDDSS01VO().getArvmCd().toString();
        String strLoanChngConsRsltCd = inVo.getRCHMNM01DSDDSS01VO().getLoanChngConsRsltCd().toString();
        String strChngOpn = inVo.getRCHMNM01DSDDSS09VO().getLoanChngOpn().toString().trim(); // 9

        // 경과이자 계산 호출 하여 inVo의 RCHMNM01DSDDSS04VO에 셋팅 해 준다
        String strPsgInt = "";
        String strAplyIntRt = "";
        String strPsgDdCnt = "";
        PsgIntCalcObj psgIntObj = inquireCalPsgInt(inVo);
        if( psgIntObj.rsltCd.equals("0000") ) {
            strPsgInt = String.valueOf(psgIntObj.psgInt);
            strAplyIntRt = String.valueOf(psgIntObj.aplyIntRt);
            strPsgDdCnt = String.valueOf(psgIntObj.psgDdCnt);
        }

        RCHMNM01DSDDSS04VO setVo = new RCHMNM01DSDDSS04VO();
        setVo.setPsgInt(strPsgInt);
        setVo.setAplyIntRt(strAplyIntRt);
        setVo.setPsgDdCnt(strPsgDdCnt);
        inVo.setRCHMNM01DSDDSS04VO(setVo);

        if( strLoanChngConsRsltCd.equals("") || strLoanChngConsRsltCd.equals("04") || strLoanChngConsRsltCd.equals("05") ) {
            // 거래일련번호 채번
            StLoanPiamtDTO srchInDTO = new StLoanPiamtDTO();
            srchInDTO.setLoanNo(strLoanNo);
            srchInDTO.setLoanSeq(strLoanSeq);
            StLoanPiamtDTO stchOutDTO = stLoanPiamtMapper.searchMaxTrSnum(srchInDTO);

            // 1. [대출 결제일 변경 이력] 생성
            StSetlDdChngHistDTO insDTO1 = setSetlDdChngHistDTO(inVo);
            insDTO1.setArvmCd("10");
            insDTO1.setTrSnum(Long.valueOf(stchOutDTO.getTrSnum()));      // 거래순번 /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */

            setlDdChngHistMapper.insertStSetlDdChngHist(insDTO1);

            // 2. [대출 변경 품의] 생성
            for (int i = Integer.parseInt(strArvmCd); i <= Integer.parseInt(strArvmCd); i = i + 10) {
                if( i != 20 ) {
                    StLoanChngConsStagDTO insDTO2 = new StLoanChngConsStagDTO();
                    insDTO2.setLoanNo(strLoanNo);                   // 대출_번호
                    insDTO2.setLoanSeq(strLoanSeq);                 // 대출_순번
                    insDTO2.setNtrmSetlmanCd(String.valueOf(i));    // 차기결제자
                    insDTO2.setFrstRegEmpNo("TEST");                // 최초등록자
                    insDTO2.setLastProcEmpNo("TEST");               // 최종등록자

                    loanChngConsStagMapper.insertStLoanChngConsStag(insDTO2);
                }
            }
        }

        // 3. [대출 결제일 변경 이력] 수정
        //  - max 순번 조회
        StSetlDdChngHistDTO srchDTO1 = new StSetlDdChngHistDTO();
        srchDTO1.setLoanNo(strLoanNo);
        srchDTO1.setLoanSeq(strLoanSeq);
        String strSnum = setlDdChngHistMapper.searchMaxSnum(srchDTO1);

        StSetlDdChngHistDTO updDTO1 = setSetlDdChngHistDTO(inVo);
        updDTO1.setSnum(Long.valueOf(strSnum)); /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO1.setLoanChngDivCd(LOAN_CHNG_DIV_CD_CMPL);

        try {
            setlDdChngHistMapper.updateStSetlDdChngHist(updDTO1);
        }  catch (Exception e) {
            LOGGER.error("[대출변경수정오류] : 결제일 변경 중 오류  " + e.getMessage());
            returnVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            returnVo.setRsltCd( e.getMessage() );
        }

        // 4. [대출 변경 품의 단계]수정
        StLoanChngConsStagDTO updDTO2 = new StLoanChngConsStagDTO();

        try {
            updDTO2.setLoanNo(strLoanNo);                   // 대출_번호
            updDTO2.setLoanSeq(strLoanSeq);                 // 대출_순번
            updDTO2.setSnum(0);                             // 기 등록한 순번 등록 해야 함 /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
            updDTO2.setLoanChngConsRsltCd(strLoanChngConsRsltCd);
            updDTO2.setJstEmpNo("TEST");
            updDTO2.setLoanChngOpn(strChngOpn);
            updDTO2.setNtrmSetlmanCd(strArvmCd);    // 차기결제자  3
            updDTO2.setLastProcEmpNo("TEST");               // 최종등록자

            loanChngConsStagMapper.updateStLoanChngConsStag(updDTO2);
            returnVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
            returnVo.setRsltCd(msgEnum.SUCCESS.getErrorCn());
        } catch (Exception e) {
            LOGGER.error("[대출변경수정오류] : 결제일 변경 중 오류  " + e.getMessage());
            returnVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            returnVo.setRsltCd( e.getMessage() );
        }

        return returnVo;
    }
    /**
     * <p>메소드명      : updateAprvPrc - 품의승인 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리- 품의승인 시 처리 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : RCHMNM01OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public RCHMNM01OutVO updateAprvProc(RCHMNM01InVO inVo) throws Exception {

        /** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        StSetlDdChngHistDTO   updDTO  = new StSetlDdChngHistDTO();      // 결제일변경이력 UPD
        StLoanChngConsStagDTO updDTO1 = new StLoanChngConsStagDTO();    // 대출변경품의 UPD

        String strLoanNo       = inVo.getRCHMNM01DSSMVO().getLoanNo().toString();    // 대출번호
        String strLoanSeq      = inVo.getRCHMNM01DSSMVO().getLoanSeq().toString();   // 대출순번
        String strSnum         = inVo.getRCHMNM01DSDDSS01VO().getSnum().toString();  // 품의순번
        String strNtrmJstManCd = inVo.getRCHMNM01DSDDSS01VO().getNtrmJstManCd().toString();  // 3 차기결재자코드
        String strChngOpn      = inVo.getRCHMNM01DSDDSS09VO().getLoanChngOpn().toString().trim(); // 9
        String strArvmCd       = inVo.getRCHMNM01DSDDSS01VO().getArvmCd().toString();  // 8
        //LOAN_CHNG_DIV_CD_APRV  5
        boolean bChekLastYn = false;
        // (차기전결권자)=(전결권자)인 경우
        if( strNtrmJstManCd.equals(strArvmCd) ) {
            bChekLastYn = true;
        }

        // 1. [대출 결제일 변경 이력] 수정
        updDTO.setLoanNo(strLoanNo);
        updDTO.setLoanSeq(strLoanSeq);
        updDTO.setSnum(Long.valueOf(strSnum)); /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO.setNtrmJstManCd(strNtrmJstManCd);
        updDTO.setLoanChngDivCd(LOAN_CHNG_DIV_CD_CMPL);

        if( bChekLastYn ) {
            updDTO.setNtrmJstManCd("99");
            updDTO.setLoanChngConsRsltCd(LOAN_CHNG_DIV_CD_CMPL);  // 05:완료
        }

        // 대출변경품의결과코드가 02:승인
        if( updDTO.getNtrmJstManCd().equals(LOAN_CHNG_DIV_CD_APRV) ) {
            if( strNtrmJstManCd.equals(strArvmCd)) {
                updDTO.setCnclPossFg("1");                        // 취소가능여부
            }
        }
        updDTO.setLastProcEmpNo("TEST");                          // 로그인 사번으로 변경 해야 함

        try {
            setlDdChngHistMapper.updateStSetlDdChngHist(updDTO);
        } catch (Exception e) {
            LOGGER.error("[품의승인] : 대출 결제일 변경 이력 수정 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        // 2. [대출 변경 품의 단계] 수정
        updDTO1.setLoanNo(strLoanNo);                   // 대출_번호
        updDTO1.setLoanSeq(strLoanSeq);                 // 대출_순번
        updDTO1.setSnum(Long.valueOf(strSnum));         // 기 등록한 순번 등록 해야 함 /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */
        updDTO1.setLoanChngConsRsltCd(LOAN_CHNG_DIV_CD_APRV);
        if( bChekLastYn ) {
            updDTO1.setLoanChngConsRsltCd(LOAN_CHNG_DIV_CD_CMPL);
        }
        updDTO1.setJstEmpNo("TEST");
        updDTO1.setLoanChngOpn(strChngOpn);
        updDTO1.setNtrmSetlmanCd(strArvmCd);            // 차기결제자  3
        updDTO1.setLastProcEmpNo("TEST");               // 최종등록자

        try {
            loanChngConsStagMapper.updateStLoanChngConsStag(updDTO1);
        } catch (Exception e) {
            LOGGER.error("[품의승인] : 대출 변경 품의 단계 수정 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

        // (차기전결권자)=(전결권자)인 경우 (즉 최종승인일 경우)
        if( bChekLastYn ) {
            // 변경회차 이후 수납내역이 있으면 에러처리- 최종승인시 다시한번 체크
            //  - 품의등록 전 변경하려는 회차 이후에 수납내역이 있는지 확인
            RtRcptDescDTO srchDto = new RtRcptDescDTO();
            srchDto.setLoanNo(strLoanNo);
            srchDto.setLoanNo(strLoanSeq);
            srchDto.setTims(Long.valueOf(inVo.getRCHMNM01DSDDSS04VO().getChngTims())); /* 2023.03.22 younghwe.kim : DTO DataType 변경에 따른 수정 */

            try {
                List<RtRcptDescDTO> rcptDescOutDTO = rtRcptDescMapper.searchRcptDesc(srchDto);

                if( rcptDescOutDTO.size() > 0 ) {
                    // 변경회차 이후에 수납내역이 존재합니다. 수납취소후 처리하시기 바랍니다.
                    resultVo.setRsltCd( msgEnum.SETL_DD_CHNG_CNCL_CHK_RCPT_SRCH.getErrorCd());
                    resultVo.setRsltCntn( msgEnum.SETL_DD_CHNG_CNCL_CHK_RCPT_SRCH.getErrorCn() );

                    return resultVo;
                }

            }  catch (Exception e) {
                LOGGER.error("[결제일변경취소] : 수납내역 조회 중 오류  " + e.getMessage());
                resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
                resultVo.setRsltCntn( e.getMessage() );
            }

            // 대출기본 테이블 수정 & 상환스케줄 생성
            RCHMNM01OutVO updRstlVo = this.updateLoanInfo(inVo, strLoanNo, strLoanSeq, "0");
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : setSetlDdChngHistDTO - 품의등록 시 DTO 셋팅 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리- 품의등록 시 DTO 셋팅 한다.</p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : StSetlDdChngHistDTO</p>
     * <p>예외처리      : Exception</p>
     */
    public StSetlDdChngHistDTO setSetlDdChngHistDTO(RCHMNM01InVO inVO) throws Exception{
        StSetlDdChngHistDTO rtnDTO = new StSetlDdChngHistDTO();

        String strNtrmJstManCd = inVO.getRCHMNM01DSDDSS01VO().getNtrmJstManCd().toString();

        rtnDTO.setLoanNo(inVO.getRCHMNM01DSSMVO().getLoanNo().toString());                                         // 대출_번호
        rtnDTO.setLoanSeq(inVO.getRCHMNM01DSSMVO().getLoanSeq().toString());                                       // 대출_순번
        rtnDTO.setLoanChngDivCd(LOAN_CHNG_DIV_CD_CHG);                                                             // 대출변경구분코드
        rtnDTO.setNtrmJstManCd(String.valueOf(Integer.parseInt(strNtrmJstManCd) + 10));                            // 차기결재자코드+10
        rtnDTO.setArvmCd(inVO.getRCHMNM01DSDDSS01VO().getArvmCd().toString());                                     // 전결권자코드
        rtnDTO.setChngTims(Long.valueOf(inVO.getRCHMNM01DSDDSS04VO().getChngTims()));                              // 변경_회차
        rtnDTO.setChngBfDueDt(inVO.getRCHMNM01DSDDSS04VO().getChngBfDueDt().toString());                           // 변경전_납입_일자
        rtnDTO.setChngAfDueDt(inVO.getRCHMNM01DSDDSS04VO().getChngAfDueDt().toString());                           // 변경후_납입_일자
        rtnDTO.setPsgInt(new BigDecimal(inVO.getRCHMNM01DSDDSS04VO().getPsgInt()));                                // 경과이자 : 경과이자 계산 모듈 out
        rtnDTO.setAplyIntRt(Long.valueOf(inVO.getRCHMNM01DSDDSS04VO().getAplyIntRt().toString()));                 // 적용이자율 : 경과이자 계산 모듈 out
        rtnDTO.setPsgDdcnt(Long.valueOf(inVO.getRCHMNM01DSDDSS04VO().getPsgDdCnt().toString()));                   // 경과일수
        rtnDTO.setPsgInt(new BigDecimal(inVO.getRCHMNM01DSDDSS04VO().getPsgInt()));                                // 경과이자 : 경과이자 계산 모듈 out
        rtnDTO.setIsrtDeptCd("000000");                                                                            // 입력부서코드
        rtnDTO.setCnclPossFg("1");                                                                                 // 취소가능여부
        rtnDTO.setFrstRegEmpNo("TEST");
        rtnDTO.setLastProcEmpNo("TEST");

        return rtnDTO;
    }

    /**
     * <p>메소드명      : updateLoanInfo - 품의 승인 시 상환스케줄 & 대출원장 수정 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리- 품의 승인 시 상환스케줄 & 대출원장 수정 </p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : StSetlDdChngHistDTO</p>
     * <p>예외처리      : Exception</p>
     */
    public RCHMNM01OutVO updateLoanInfo(RCHMNM01InVO psInVo, String psLoanNo, String psLoanSeq, String psCnclFg) throws Exception {

        /** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        String strChngAfDueDt = psInVo.getRCHMNM01DSDDSS04VO().getChngAfDueDt().toString().trim();
        String strSetlDd      = strChngAfDueDt.substring(6, 8);
        Long   lChngTims      = psInVo.getRCHMNM01DSDDSS04VO().getChngTims();

        // 대출원장 update
        StLoanBaseDTO updLoanDTO = new StLoanBaseDTO();
        updLoanDTO.setLoanNo(psLoanNo);
        updLoanDTO.setLoanSeq(psLoanSeq);
        updLoanDTO.setSetlDd(strSetlDd);
        if( lChngTims == 1 ) {
            updLoanDTO.setFcntDueDt(strChngAfDueDt);
        }

        try {
            stLoanBaseMapper.updateSetlDdChngStLoanBase(updLoanDTO);
        }  catch (Exception e) {
            LOGGER.error("[대출변경취소오류] : 대출원장 변경 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        // 상환계획수정 중 {결제일변경} 모듈 호출
        SetlDdChngObj objVo = new SetlDdChngObj();
        objVo.loanNo    = psLoanNo;                                       // 대출번호
        objVo.loanSeq   = psLoanSeq;                                      // 대출순번
        objVo.chngTims  = Integer.parseInt(String.valueOf(lChngTims));    // 변경회차
        objVo.chngDueDt = strChngAfDueDt;                                 // 변경납입일자
        objVo.empNo     = "TEST";                                         // 사용자번호
        objVo.cnclFg    = psCnclFg;                                       // 취소여부

        try {
            SetlDdChngObj outObjVO = rmbrPlanUpdtCC.setlDdChng(objVo);

            // 상환계획수정 모듈에서 리턴된 값 셋팅
            if( outObjVO.rsltCd.toString().equals(msgEnum.SUCCESS.getErrorCd()) ) {
                psInVo.getRCHMNM01DSDDSS04VO().setPsgInt(String.valueOf(outObjVO.psgInt));
                psInVo.getRCHMNM01DSDDSS04VO().setAplyIntRt(String.valueOf(outObjVO.aplyIntRt));
                psInVo.getRCHMNM01DSDDSS04VO().setPsgDdCnt(String.valueOf(outObjVO.psgDdCnt));
            } else {
                resultVo.setRsltCd( outObjVO.rsltCd.toString() );
                resultVo.setRsltCd( outObjVO.rsltCntn.toString());

                return resultVo;
            }

        }  catch (Exception e) {
            LOGGER.error("[대출변경취소오류] : 대출원장 변경 중 오류  " + e.getMessage());
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        // 7. 연체갱신 - 업무 확인 필요 함
//        OnlnDlyReptCC dlyReptCC = new OnlnDlyReptCC();
//        dlyReptCC.ProcRealTmpDlyInfo(obj.loanNo, obj.loanSeq,
//                ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD_WITH_DELIMETER), tx.getConnection());

        // 결제일변경취소 일 경우 추가 작업 진행
        if( psCnclFg.equals("1") ) {
            // 기존 변경이력 수정
            StSetlDdChngHistDTO histDto = new StSetlDdChngHistDTO();
            histDto.setLoanNo(psLoanNo);
            histDto.setLoanSeq(psLoanSeq);
            histDto.setSnum(psInVo.getRCHMNM01DSSMVO().getSnum());
            histDto.setCnclPossFg("0");
            histDto.setLastProcEmpNo(psInVo.getRCHMNM01DSDDSS09VO().getJstEmpNo().toString());

            try {
                setlDdChngHistMapper.updateStSetlDdChngHist(histDto);
            }  catch (Exception e) {
                LOGGER.error("[대출변경수정오류] : 대출 결제일 변경 중 오류  " + e.getMessage());
                resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
                resultVo.setRsltCntn( e.getMessage() );

                return resultVo;
            }

            // 대출 결제일 변경 이력 생성
            histDto = setSetlDdChngHistDTO(psInVo);
            histDto.setLoanChngConsRsltCd(LOAN_CHNG_DIV_CD_CMPL);
            histDto.setNtrmJstManCd("99"); // 차기결재권자
            histDto.setArvmCd("40"); // 전결권자 코드
            histDto.setTrSnum(Long.valueOf("0"));

            try {
                setlDdChngHistMapper.insertStSetlDdChngHist(histDto);
            }  catch (Exception e) {
                LOGGER.error("[대출변경취소오류] : 대출 결제일 변경 이력 생성 중 오류  " + e.getMessage());
                resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
                resultVo.setRsltCntn( e.getMessage() );

                return resultVo;
            }

            // 대출 변경 품의 생성
            StLoanChngConsStagDTO stagInsDto = new StLoanChngConsStagDTO();
            stagInsDto.setLoanNo(psLoanNo);
            stagInsDto.setLoanSeq(psLoanSeq);
            stagInsDto.setSnum(psInVo.getRCHMNM01DSSMVO().getSnum());
            stagInsDto.setNtrmSetlmanCd("40");
            stagInsDto.setLoanChngConsRsltCd("05");
            stagInsDto.setLoanChngOpn(psInVo.getRCHMNM01DSDDSS09VO().getLoanChngOpn());
            stagInsDto.setJstEmpNo("TEST");
            stagInsDto.setFrstRegEmpNo("TEST");                // 최초등록자
            stagInsDto.setLastProcEmpNo("TEST");               // 최종등록자

            try {
                loanChngConsStagMapper.insertStLoanChngConsStag(stagInsDto);
            }  catch (Exception e) {
                LOGGER.error("[대출변경취소오류] : 대출 결제일 변경 이력 생성 중 오류  " + e.getMessage());
                resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
                resultVo.setRsltCntn( e.getMessage() );

                return resultVo;
            }
        }

        return resultVo;
    }

    /**
     * <p>메소드명      : inquireCalPsgInt - 경과이자 조회 </p>
     * <p>작성일자      : 2023. 3. 13.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리- 경과이자 조회 </p>
     * <p>메소드인수    : RCHMNM01InVO </p>
     * <p>메소드리턴값  : StSetlDdChngHistDTO</p>
     * <p>예외처리      : Exception</p>
     */
    public PsgIntCalcObj inquireCalPsgInt(RCHMNM01InVO psInVo) throws Exception {

        PsgIntCalcObj obj = new PsgIntCalcObj();
        int iChngTims = Integer.parseInt(String.valueOf(psInVo.getRCHMNM01DSDDSS04VO().getChngTims()));

        obj.loanNo    = psInVo.getRCHMNM01DSSMVO().getLoanNo().toString();                                  // 대출번호
        obj.loanSeq   = psInVo.getRCHMNM01DSSMVO().getLoanSeq().toString();                                 // 대출순번
        obj.chngTims  = iChngTims ;                                                                         // 변경회차
        obj.chngDueDt = psInVo.getRCHMNM01DSDDSS04VO().getChngAfDueDt().toString();                        // 변경납입일자

        obj = rmbrPlanUpdtCC.psgIntCalc(obj);

        return obj;
    }

    /**
     * <p>메소드명      : 결제일변경관리_납입회차로 납입일자 조회 /SelectChngDueDtInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_납입회차로 납입일자 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
	@Override
	public RCHMNM01OutVO getSelectChngDueDtInfo(RCHMNM01InVO inVo) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
        RCHMNM01OutVO resultVo = new RCHMNM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        List<RCHMNM01DSDDSS06VO> returnList06 = new ArrayList<RCHMNM01DSDDSS06VO>();    // 당월납입일자/변경납입일자 조회

        StRmbrPlanDescDTO dto = new StRmbrPlanDescDTO();
    	dto.setLoanNo(inVo.getRCHMNM01DSSMVO().getLoanNo());
    	dto.setLoanSeq(inVo.getRCHMNM01DSSMVO().getLoanSeq());
    	dto.setTims(Long.parseLong(inVo.getRCHMNM01DSSMVO().getTims()));

        // 변경전납입일자및 전회차 납입일자 조회 sddo06
        returnList06 = this.getSelectChngDueDtInfo(dto);

        resultVo.setRCHMNM01DSDDSS06VO(returnList06);

		return resultVo;
	}

	 /**
     * <p>메소드명      : 경과이자 조회 /getSelectPsgIntInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 경과이자를 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
	@Override
	public RCHMNM01OutVO getSelectPsgIntInfo(RCHMNM01InVO inVo) throws Exception {

		RCHMNM01OutVO resultVo = new RCHMNM01OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        List<RCHMNM01DSDDSS07VO> returnList07 = new ArrayList<RCHMNM01DSDDSS07VO>();    // 경과이자 조회

        PsgIntCalcObj psgIntCalcObj = new PsgIntCalcObj();
        psgIntCalcObj.loanNo = inVo.getRCHMNM01DSSMVO().getLoanNo();
        psgIntCalcObj.loanSeq = inVo.getRCHMNM01DSSMVO().getLoanSeq();
        psgIntCalcObj.chngTims = Integer.parseInt(inVo.getRCHMNM01DSSMVO().getChngTims()) ;
        psgIntCalcObj.chngDueDt = inVo.getRCHMNM01DSSMVO().getChngAfDueDt();

        try {
        	//상환계획 수정의 경과이자 조회
        	psgIntCalcObj = rmbrPlanUpdtCC.psgIntCalc(psgIntCalcObj);
        } catch (Exception e) {
        	e.printStackTrace();
        	resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
        }
        //결과값 세팅
        RCHMNM01DSDDSS07VO SDDSS07VO = new RCHMNM01DSDDSS07VO();
        SDDSS07VO.setPsgInt("" + psgIntCalcObj.psgInt);
        SDDSS07VO.setAplyIntRt("" + psgIntCalcObj.aplyIntRt);
        SDDSS07VO.setPsgDdCnt("" + psgIntCalcObj.psgDdCnt);

        returnList07.add(SDDSS07VO);

        resultVo.setRCHMNM01DSDDSS07VO(returnList07);

		return resultVo;
	}
}