package hanalife.r.ch.mn.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.ch.mn.service.RCHMNM01Service;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS01VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS04VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS08VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSDDSS09VO;
import hanalife.r.ch.mn.vo.RCHMNM01DSSMVO;
import hanalife.r.ch.mn.vo.RCHMNM01InVO;
import hanalife.r.ch.mn.vo.RCHMNM01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RCHMNM01Controller.java Class
 * 클래스설명   : 결제일 변경관리 (RCHMNM01) Controller
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("r/ch/mn")
@Controller
public class RCHMNM01Controller {

    @Resource(name = "RCHMNM01Service")
    private RCHMNM01Service RCHMNM01;

    private static final Logger LOGGER = LoggerFactory.getLogger(RCHMNM01Controller.class);

    /**
     * <p>메소드명      : 결제일변경관리 기본 조회 /selectMainInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리 기본 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/selectMainInfo.do")
    public String RCHMNM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM01S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SM", request, response, model);

            /** RCHMNM01S01 내역조회 업무 서비스 호출 입력값 대입 */
            RCHMNM01DSSMVO targetVo = new RCHMNM01DSSMVO();
            targetVo.setLoanNo((String) sourceMap.get("loanNo"));      /** 대출번호 */
            targetVo.setLoanSeq((String) sourceMap.get("loanSeq"));    /** 대출순번 */
            targetVo.setMngNo((String) sourceMap.get("mngNo"));        /** 관리번호 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            RCHMNM01InVO InVO = new RCHMNM01InVO();
             InVO.setRCHMNM01DSSMVO(targetVo);    /** 결제일변경관리 DS_SMDO 입력값 VO 객체 대입 */

            /** RCHMNM01S01 내역조회 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultList = RCHMNM01.getSelectMainInfo(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD01", resultList.getRCHMNM01DSDDSS01VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD02", resultList.getRCHMNM01DSDDSS02VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD03", resultList.getRCHMNM01DSDDSS03VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD04", resultList.getRCHMNM01DSDDSS04VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD05", resultList.getRCHMNM01DSDDSS05VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD06", resultList.getRCHMNM01DSDDSS06VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD08", resultList.getRCHMNM01DSDDSS08VO(), model);
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD11", resultList.getRCHMNM01DSDDSS11VO(), model);

            LOGGER.info("##### RCHMNM01Controller RCHMNM01S01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.toString());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.toString());

            LOGGER.info("##### RCHMNM01Controller RCHMNM01S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 결제일변경관리_납입회차로 납입일자 조회 /SelectChngDueDtInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_납입회차로 납입일자 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SelectChngDueDtInfo.do")
    public String RCHMNM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM01S02 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
        	Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD06", request, response, model);

            /** RCHMNM01S01 내역조회 업무 서비스 호출 입력값 대입 */
            RCHMNM01DSSMVO targetVo = new RCHMNM01DSSMVO();
            targetVo.setLoanNo((String) sourceMap.get("loanNo"));      /** 대출번호 */
            targetVo.setLoanSeq((String) sourceMap.get("loanSeq"));    /** 대출순번 */
            targetVo.setTims((String) sourceMap.get("tims"));         /** 회차 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            RCHMNM01InVO InVO = new RCHMNM01InVO();
             InVO.setRCHMNM01DSSMVO(targetVo);    /** 결제일변경관리 DS_SMDO 입력값 VO 객체 대입 */

            /** RCHMNM01S01 내역조회 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultList = RCHMNM01.getSelectChngDueDtInfo(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD06", resultList.getRCHMNM01DSDDSS06VO(), model);

            LOGGER.info("##### RCHMNM01Controller RCHMNM01S02 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM01S02 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 결제일변경관리_경과이자 조회 /selectPsgIntInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_경과이자 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/selectPsgIntInfo.do")
    public String RCHMNM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM01S02 Start #####");

        try {
        	/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
        	Map<String, Object> sourceMapSM = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SM", request, response, model);
        	Map<String, Object> sourceMap04 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD04", request, response, model);

            /** RCHMNM01S01 내역조회 업무 서비스 호출 입력값 대입 */
            RCHMNM01DSSMVO targetVo = new RCHMNM01DSSMVO();
            targetVo.setLoanNo((String) sourceMapSM.get("loanNo"));              /** 대출번호 */
            targetVo.setLoanSeq((String) sourceMapSM.get("loanSeq"));            /** 대출순번 */
            targetVo.setChngTims((String) sourceMap04.get("chngTims"));          /** 회차 */
            targetVo.setChngAfDueDt((String) sourceMap04.get("chngAfDueDt"));    /** 변경납입일자 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            RCHMNM01InVO InVO = new RCHMNM01InVO();
            InVO.setRCHMNM01DSSMVO(targetVo);    /** 결제일변경관리 DS_SMDO 입력값 VO 객체 대입 */

            /** RCHMNM01S01 내역조회 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultList = RCHMNM01.getSelectPsgIntInfo(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD07", resultList.getRCHMNM01DSDDSS07VO(), model);

            LOGGER.info("##### RCHMNM01Controller RCHMNM01S03 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM01S03 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 결제일변경관리_품의등록 /registerConsProc.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_경과이자 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/registerConsProc.do")
    public String RCHMNM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMapSM = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SM", request, response, model);
            Map<String, Object> sourceMap01 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD01", request, response, model);
            Map<String, Object> sourceMap04 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD04", request, response, model);
            Map<String, Object> sourceMap08 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD08", request, response, model);
            Map<String, Object> sourceMap09 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD09", request, response, model);

            /** 품의등록 업무 서비스 호출 입력값 대입 */
            // sddoSM, 01, 04, 08, 09
            RCHMNM01InVO InVO = new RCHMNM01InVO();

            RCHMNM01DSSMVO inDsSm = new RCHMNM01DSSMVO();
            inDsSm.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSm.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSm.setTims((String) sourceMap04.get("chngTims"));

            /** 데이터 등록에 필요한 SDDO 셋팅 */
            RCHMNM01DSDDSS01VO inDsSdVo01 = new RCHMNM01DSDDSS01VO();
            inDsSdVo01.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSdVo01.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSdVo01.setMngNo((String) sourceMapSM.get("mngNo"));
            inDsSdVo01.setContManNo((String) sourceMap01.get("contManNo"));
            inDsSdVo01.setPrdtCd((String) sourceMap01.get("prdtCd"));
            inDsSdVo01.setLoanStatCd((String) sourceMap01.get("loanStatCd"));
            inDsSdVo01.setLoanStatNm((String) sourceMap01.get("loanStatNm"));
            inDsSdVo01.setDueMethCd((String) sourceMap01.get("dueMethCd"));
            inDsSdVo01.setDueMethNm((String) sourceMap01.get("dueMethNm"));
            inDsSdVo01.setLoanPamtRamt((String) sourceMap01.get("loanPamtRamt"));
            inDsSdVo01.setLoanDt((String) sourceMap01.get("loanDt"));
            inDsSdVo01.setMngDeptCd((String) sourceMap01.get("mngDeptCd"));
            inDsSdVo01.setCustNm((String) sourceMap01.get("custNm"));
            inDsSdVo01.setPrdtNm((String) sourceMap01.get("prdtNm"));
            inDsSdVo01.setGodsCd((String) sourceMap01.get("godsCd"));
            inDsSdVo01.setGodsNm((String) sourceMap01.get("godsNm"));
            inDsSdVo01.setBndStatCd((String) sourceMap01.get("bndStatCd"));
            inDsSdVo01.setBndStatNm((String) sourceMap01.get("bndStatNm"));
            inDsSdVo01.setDeptAbbrnm((String) sourceMap01.get("deptAbbrnm"));
            inDsSdVo01.setAskPlcDivCd((String) sourceMap01.get("askPlcDivCd"));
            inDsSdVo01.setEmalAskFg((String) sourceMap01.get("emalAskFg"));
            inDsSdVo01.setFlotIzeDivCd((String) sourceMap01.get("flotIzeDivCd"));
            inDsSdVo01.setDlyAmt((String) sourceMap01.get("dlyAmt"));
            inDsSdVo01.setUnComgCnt((String) sourceMap01.get("unComgCnt"));
            inDsSdVo01.setDlyDt((String) sourceMap01.get("dlyDt"));
            inDsSdVo01.setSnum((String) sourceMap01.get("snum"));
            inDsSdVo01.setLoanChngConsRsltCd((String) sourceMap01.get("loanChngConsRsltCd"));
            inDsSdVo01.setNtrmJstManCd((String) sourceMap01.get("ntrmJstManCd"));
            inDsSdVo01.setArvmCd((String) sourceMap01.get("arvmCd"));
            inDsSdVo01.setLoanChngDivCd((String) sourceMap01.get("loanChngDivCd"));
            inDsSdVo01.setAcntStatCd((String) sourceMap01.get("acntStatCd"));
            inDsSdVo01.setAcntStatNm((String) sourceMap01.get("acntStatNm"));
            inDsSdVo01.setPrdtLrgeClasCd((String) sourceMap01.get("prdtLrgeClasCd"));
            inDsSdVo01.setPrdtMidClasCd((String) sourceMap01.get("prdtMidClasCd"));
            inDsSdVo01.setIsrtDeptCd((String) sourceMap01.get("isrtDeptCd"));
            inDsSdVo01.setMngPlcDivCd((String) sourceMap01.get("mngPlcDivCd"));
            inDsSdVo01.setMngPlcDivNm((String) sourceMap01.get("mngPlcDivNm"));

            RCHMNM01DSDDSS04VO inDsSdVo04 = new RCHMNM01DSDDSS04VO();
            inDsSdVo04.setThmmDueTims((String) sourceMap04.get("thmmDueTims"));
            inDsSdVo04.setThmmDueDt((String) sourceMap04.get("thmmDueDt"));
            inDsSdVo04.setChngTims(Long.parseLong(sourceMap04.get("chngTims").toString()));
            inDsSdVo04.setChngBfDueDt((String) sourceMap04.get("chngBfDueDt"));
            inDsSdVo04.setChngAfDueDt((String) sourceMap04.get("chngAfDueDt"));
            inDsSdVo04.setPsgInt((String) sourceMap04.get("psgInt"));
            inDsSdVo04.setPsgIntYn((String) sourceMap04.get("psqIntYn"));
            inDsSdVo04.setAplyIntRt((String) sourceMap04.get("aplyIntRt"));
            inDsSdVo04.setPsgDdCnt((String) sourceMap04.get("psgDdCnt"));

            RCHMNM01DSDDSS08VO inDsSdVo08 = new RCHMNM01DSDDSS08VO();
            inDsSdVo08.setLoanChngConsRsltCd((String) sourceMap08.get("loanChngConsRsltCd"));
            inDsSdVo08.setLoanChngConsRsltNm((String) sourceMap08.get("loanChngConsRsltNm"));
            inDsSdVo08.setJstEmpNo((String) sourceMap08.get("jstEmpNo"));
            inDsSdVo08.setJstEmpNm((String) sourceMap08.get("jstEmpNm"));
            inDsSdVo08.setJstDt((String) sourceMap08.get("jstDt"));
            inDsSdVo08.setLoanChngOpn((String) sourceMap08.get("loanChngOpn"));
            inDsSdVo08.setNtrmSetlmanNm((String) sourceMap08.get("ntrmSetlmanNm"));

            RCHMNM01DSDDSS09VO inDsSdVo09 = new RCHMNM01DSDDSS09VO();
            inDsSdVo09.setJstEmpNo((String) sourceMap09.get("jstEmpNo"));
            inDsSdVo09.setJstEmpNm((String) sourceMap09.get("jstEmpNm"));
            inDsSdVo09.setLoanChngOpn((String) sourceMap09.get("loanChngOpn"));

            InVO.setRCHMNM01DSSMVO(inDsSm);
            InVO.setRCHMNM01DSDDSS01VO(inDsSdVo01);
            InVO.setRCHMNM01DSDDSS04VO(inDsSdVo04);
            InVO.setRCHMNM01DSDDSS08VO(inDsSdVo08);
            InVO.setRCHMNM01DSDDSS09VO(inDsSdVo09);

            /** 품의등록 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultI01 = RCHMNM01.registerRCHMNM01I01(InVO);

            // 등록 후 조회
            RCHMNM01OutVO resultIOut = RCHMNM01.getSelectMainInfo(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD01", resultIOut.getRCHMNM01DSDDSS01VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD02", resultIOut.getRCHMNM01DSDDSS02VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD03", resultIOut.getRCHMNM01DSDDSS03VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD04", resultIOut.getRCHMNM01DSDDSS04VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD05", resultIOut.getRCHMNM01DSDDSS05VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD08", resultIOut.getRCHMNM01DSDDSS08VO(), model); /**  */

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 결제일변경관리_품의승인 /registerAprvProc.do </p>
     * <p>작성일자      : 2023. 3. 17.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_품의승인 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/registerAprvProc.do")
    public String RCHMNM01I02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM01U01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMapSM = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SM", request, response, model);
            Map<String, Object> sourceMap01 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD01", request, response, model);
            Map<String, Object> sourceMap04 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD04", request, response, model);
            Map<String, Object> sourceMap08 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD08", request, response, model);
            Map<String, Object> sourceMap09 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD09", request, response, model);

            /** 품의등록 업무 서비스 호출 입력값 대입 */
            // sddoSM, 01, 04, 08, 09
            RCHMNM01InVO InVO = new RCHMNM01InVO();

            RCHMNM01DSSMVO inDsSm = new RCHMNM01DSSMVO();
            inDsSm.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSm.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSm.setTims((String) sourceMap04.get("chngTims"));

            /** 데이터 등록에 필요한 SDDO 셋팅 */
            RCHMNM01DSDDSS01VO inDsSdVo01 = new RCHMNM01DSDDSS01VO();
            inDsSdVo01.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSdVo01.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSdVo01.setMngNo((String) sourceMapSM.get("mngNo"));
            inDsSdVo01.setContManNo((String) sourceMap01.get("contManNo"));
            inDsSdVo01.setPrdtCd((String) sourceMap01.get("prdtCd"));
            inDsSdVo01.setLoanStatCd((String) sourceMap01.get("loanStatCd"));
            inDsSdVo01.setLoanStatNm((String) sourceMap01.get("loanStatNm"));
            inDsSdVo01.setDueMethCd((String) sourceMap01.get("dueMethCd"));
            inDsSdVo01.setDueMethNm((String) sourceMap01.get("dueMethNm"));
            inDsSdVo01.setLoanPamtRamt((String) sourceMap01.get("loanPamtRamt"));
            inDsSdVo01.setLoanDt((String) sourceMap01.get("loanDt"));
            inDsSdVo01.setMngDeptCd((String) sourceMap01.get("mngDeptCd"));
            inDsSdVo01.setCustNm((String) sourceMap01.get("custNm"));
            inDsSdVo01.setPrdtNm((String) sourceMap01.get("prdtNm"));
            inDsSdVo01.setGodsCd((String) sourceMap01.get("godsCd"));
            inDsSdVo01.setGodsNm((String) sourceMap01.get("godsNm"));
            inDsSdVo01.setBndStatCd((String) sourceMap01.get("bndStatCd"));
            inDsSdVo01.setBndStatNm((String) sourceMap01.get("bndStatNm"));
            inDsSdVo01.setDeptAbbrnm((String) sourceMap01.get("deptAbbrnm"));
            inDsSdVo01.setAskPlcDivCd((String) sourceMap01.get("askPlcDivCd"));
            inDsSdVo01.setEmalAskFg((String) sourceMap01.get("emalAskFg"));
            inDsSdVo01.setFlotIzeDivCd((String) sourceMap01.get("flotIzeDivCd"));
            inDsSdVo01.setDlyAmt((String) sourceMap01.get("dlyAmt"));
            inDsSdVo01.setUnComgCnt((String) sourceMap01.get("unComgCnt"));
            inDsSdVo01.setDlyDt((String) sourceMap01.get("dlyDt"));
            inDsSdVo01.setSnum((String) sourceMap01.get("snum"));
            inDsSdVo01.setLoanChngConsRsltCd((String) sourceMap01.get("loanChngConsRsltCd"));
            inDsSdVo01.setNtrmJstManCd((String) sourceMap01.get("ntrmJstManCd"));
            inDsSdVo01.setArvmCd((String) sourceMap01.get("arvmCd"));
            inDsSdVo01.setLoanChngDivCd((String) sourceMap01.get("loanChngDivCd"));
            inDsSdVo01.setAcntStatCd((String) sourceMap01.get("acntStatCd"));
            inDsSdVo01.setAcntStatNm((String) sourceMap01.get("acntStatNm"));
            inDsSdVo01.setPrdtLrgeClasCd((String) sourceMap01.get("prdtLrgeClasCd"));
            inDsSdVo01.setPrdtMidClasCd((String) sourceMap01.get("prdtMidClasCd"));
            inDsSdVo01.setIsrtDeptCd((String) sourceMap01.get("isrtDeptCd"));
            inDsSdVo01.setMngPlcDivCd((String) sourceMap01.get("mngPlcDivCd"));
            inDsSdVo01.setMngPlcDivNm((String) sourceMap01.get("mngPlcDivNm"));

            RCHMNM01DSDDSS04VO inDsSdVo04 = new RCHMNM01DSDDSS04VO();
            inDsSdVo04.setThmmDueTims((String) sourceMap04.get("thmmDueTims"));
            inDsSdVo04.setThmmDueDt((String) sourceMap04.get("thmmDueDt"));
            inDsSdVo04.setChngTims(Long.parseLong(sourceMap04.get("chngTims").toString()));
            inDsSdVo04.setChngBfDueDt((String) sourceMap04.get("chngBfDueDt"));
            inDsSdVo04.setChngAfDueDt((String) sourceMap04.get("chngAfDueDt"));
            inDsSdVo04.setPsgInt((String) sourceMap04.get("psgInt"));
            inDsSdVo04.setPsgIntYn((String) sourceMap04.get("psqIntYn"));
            inDsSdVo04.setAplyIntRt((String) sourceMap04.get("aplyIntRt"));
            inDsSdVo04.setPsgDdCnt((String) sourceMap04.get("psgDdCnt"));

            RCHMNM01DSDDSS08VO inDsSdVo08 = new RCHMNM01DSDDSS08VO();
            inDsSdVo08.setLoanChngConsRsltCd((String) sourceMap08.get("loanChngConsRsltCd"));
            inDsSdVo08.setLoanChngConsRsltNm((String) sourceMap08.get("loanChngConsRsltNm"));
            inDsSdVo08.setJstEmpNo((String) sourceMap08.get("jstEmpNo"));
            inDsSdVo08.setJstEmpNm((String) sourceMap08.get("jstEmpNm"));
            inDsSdVo08.setJstDt((String) sourceMap08.get("jstDt"));
            inDsSdVo08.setLoanChngOpn((String) sourceMap08.get("loanChngOpn"));
            inDsSdVo08.setNtrmSetlmanNm((String) sourceMap08.get("ntrmSetlmanNm"));

            RCHMNM01DSDDSS09VO inDsSdVo09 = new RCHMNM01DSDDSS09VO();
            inDsSdVo09.setJstEmpNo((String) sourceMap09.get("jstEmpNo"));
            inDsSdVo09.setJstEmpNm((String) sourceMap09.get("jstEmpNm"));
            inDsSdVo09.setLoanChngOpn((String) sourceMap09.get("loanChngOpn"));

            InVO.setRCHMNM01DSSMVO(inDsSm);
            InVO.setRCHMNM01DSDDSS01VO(inDsSdVo01);
            InVO.setRCHMNM01DSDDSS04VO(inDsSdVo04);
            InVO.setRCHMNM01DSDDSS08VO(inDsSdVo08);
            InVO.setRCHMNM01DSDDSS09VO(inDsSdVo09);

            /** 승인 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultOut = RCHMNM01.registerRCHMNM01I02(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD01", resultOut.getRCHMNM01DSDDSS01VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD02", resultOut.getRCHMNM01DSDDSS02VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD03", resultOut.getRCHMNM01DSDDSS03VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD04", resultOut.getRCHMNM01DSDDSS04VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD05", resultOut.getRCHMNM01DSDDSS05VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD08", resultOut.getRCHMNM01DSDDSS08VO(), model); /**  */

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 결제일변경관리_거절 /registerRjctProc.do </p>
     * <p>작성일자      : 2023. 3. 17.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_거절 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/registerRjctProc.do")
    public String RCHMNM01I03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM01U01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMapSM = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SM", request, response, model);
            Map<String, Object> sourceMap01 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD01", request, response, model);
            Map<String, Object> sourceMap04 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD04", request, response, model);
            Map<String, Object> sourceMap08 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD08", request, response, model);
            Map<String, Object> sourceMap09 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD09", request, response, model);

            /** 품의등록 업무 서비스 호출 입력값 대입 */
            // sddoSM, 01, 04, 08, 09
            RCHMNM01InVO InVO = new RCHMNM01InVO();

            RCHMNM01DSSMVO inDsSm = new RCHMNM01DSSMVO();
            inDsSm.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSm.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSm.setTims((String) sourceMap04.get("chngTims"));

            /** 데이터 등록에 필요한 SDDO 셋팅 */
            RCHMNM01DSDDSS01VO inDsSdVo01 = new RCHMNM01DSDDSS01VO();
            inDsSdVo01.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSdVo01.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSdVo01.setMngNo((String) sourceMapSM.get("mngNo"));
            inDsSdVo01.setContManNo((String) sourceMap01.get("contManNo"));
            inDsSdVo01.setPrdtCd((String) sourceMap01.get("prdtCd"));
            inDsSdVo01.setLoanStatCd((String) sourceMap01.get("loanStatCd"));
            inDsSdVo01.setLoanStatNm((String) sourceMap01.get("loanStatNm"));
            inDsSdVo01.setDueMethCd((String) sourceMap01.get("dueMethCd"));
            inDsSdVo01.setDueMethNm((String) sourceMap01.get("dueMethNm"));
            inDsSdVo01.setLoanPamtRamt((String) sourceMap01.get("loanPamtRamt"));
            inDsSdVo01.setLoanDt((String) sourceMap01.get("loanDt"));
            inDsSdVo01.setMngDeptCd((String) sourceMap01.get("mngDeptCd"));
            inDsSdVo01.setCustNm((String) sourceMap01.get("custNm"));
            inDsSdVo01.setPrdtNm((String) sourceMap01.get("prdtNm"));
            inDsSdVo01.setGodsCd((String) sourceMap01.get("godsCd"));
            inDsSdVo01.setGodsNm((String) sourceMap01.get("godsNm"));
            inDsSdVo01.setBndStatCd((String) sourceMap01.get("bndStatCd"));
            inDsSdVo01.setBndStatNm((String) sourceMap01.get("bndStatNm"));
            inDsSdVo01.setDeptAbbrnm((String) sourceMap01.get("deptAbbrnm"));
            inDsSdVo01.setAskPlcDivCd((String) sourceMap01.get("askPlcDivCd"));
            inDsSdVo01.setEmalAskFg((String) sourceMap01.get("emalAskFg"));
            inDsSdVo01.setFlotIzeDivCd((String) sourceMap01.get("flotIzeDivCd"));
            inDsSdVo01.setDlyAmt((String) sourceMap01.get("dlyAmt"));
            inDsSdVo01.setUnComgCnt((String) sourceMap01.get("unComgCnt"));
            inDsSdVo01.setDlyDt((String) sourceMap01.get("dlyDt"));
            inDsSdVo01.setSnum((String) sourceMap01.get("snum"));
            inDsSdVo01.setLoanChngConsRsltCd((String) sourceMap01.get("loanChngConsRsltCd"));
            inDsSdVo01.setNtrmJstManCd((String) sourceMap01.get("ntrmJstManCd"));
            inDsSdVo01.setArvmCd((String) sourceMap01.get("arvmCd"));
            inDsSdVo01.setLoanChngDivCd((String) sourceMap01.get("loanChngDivCd"));
            inDsSdVo01.setAcntStatCd((String) sourceMap01.get("acntStatCd"));
            inDsSdVo01.setAcntStatNm((String) sourceMap01.get("acntStatNm"));
            inDsSdVo01.setPrdtLrgeClasCd((String) sourceMap01.get("prdtLrgeClasCd"));
            inDsSdVo01.setPrdtMidClasCd((String) sourceMap01.get("prdtMidClasCd"));
            inDsSdVo01.setIsrtDeptCd((String) sourceMap01.get("isrtDeptCd"));
            inDsSdVo01.setMngPlcDivCd((String) sourceMap01.get("mngPlcDivCd"));
            inDsSdVo01.setMngPlcDivNm((String) sourceMap01.get("mngPlcDivNm"));

            RCHMNM01DSDDSS04VO inDsSdVo04 = new RCHMNM01DSDDSS04VO();
            inDsSdVo04.setThmmDueTims((String) sourceMap04.get("thmmDueTims"));
            inDsSdVo04.setThmmDueDt((String) sourceMap04.get("thmmDueDt"));
            inDsSdVo04.setChngTims(Long.parseLong(sourceMap04.get("chngTims").toString()));
            inDsSdVo04.setChngBfDueDt((String) sourceMap04.get("chngBfDueDt"));
            inDsSdVo04.setChngAfDueDt((String) sourceMap04.get("chngAfDueDt"));
            inDsSdVo04.setPsgInt((String) sourceMap04.get("psgInt"));
            inDsSdVo04.setPsgIntYn((String) sourceMap04.get("psqIntYn"));
            inDsSdVo04.setAplyIntRt((String) sourceMap04.get("aplyIntRt"));
            inDsSdVo04.setPsgDdCnt((String) sourceMap04.get("psgDdCnt"));

            RCHMNM01DSDDSS08VO inDsSdVo08 = new RCHMNM01DSDDSS08VO();
            inDsSdVo08.setLoanChngConsRsltCd((String) sourceMap08.get("loanChngConsRsltCd"));
            inDsSdVo08.setLoanChngConsRsltNm((String) sourceMap08.get("loanChngConsRsltNm"));
            inDsSdVo08.setJstEmpNo((String) sourceMap08.get("jstEmpNo"));
            inDsSdVo08.setJstEmpNm((String) sourceMap08.get("jstEmpNm"));
            inDsSdVo08.setJstDt((String) sourceMap08.get("jstDt"));
            inDsSdVo08.setLoanChngOpn((String) sourceMap08.get("loanChngOpn"));
            inDsSdVo08.setNtrmSetlmanNm((String) sourceMap08.get("ntrmSetlmanNm"));

            RCHMNM01DSDDSS09VO inDsSdVo09 = new RCHMNM01DSDDSS09VO();
            inDsSdVo09.setJstEmpNo((String) sourceMap09.get("jstEmpNo"));
            inDsSdVo09.setJstEmpNm((String) sourceMap09.get("jstEmpNm"));
            inDsSdVo09.setLoanChngOpn((String) sourceMap09.get("loanChngOpn"));

            InVO.setRCHMNM01DSSMVO(inDsSm);
            InVO.setRCHMNM01DSDDSS01VO(inDsSdVo01);
            InVO.setRCHMNM01DSDDSS04VO(inDsSdVo04);
            InVO.setRCHMNM01DSDDSS08VO(inDsSdVo08);
            InVO.setRCHMNM01DSDDSS09VO(inDsSdVo09);

            /** 거절 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultOut = RCHMNM01.registerRCHMNM01I03(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD01", resultOut.getRCHMNM01DSDDSS01VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD02", resultOut.getRCHMNM01DSDDSS02VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD03", resultOut.getRCHMNM01DSDDSS03VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD04", resultOut.getRCHMNM01DSDDSS04VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD05", resultOut.getRCHMNM01DSDDSS05VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD08", resultOut.getRCHMNM01DSDDSS08VO(), model); /**  */

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명      : 결제일변경관리_결제일변경취소 /registerCnclProc.do </p>
     * <p>작성일자      : 2023. 3. 17.
     * <p>작성자(author): 70319
     * <p>설명          : 결제일변경관리_결제일변경취소 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/registerCnclProc.do")
    public String RCHMNM01I04(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RCHMNM01Controller RCHMNM01I04 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMapSM = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SM", request, response, model);
            Map<String, Object> sourceMap01 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD01", request, response, model);
            Map<String, Object> sourceMap04 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD04", request, response, model);
            Map<String, Object> sourceMap08 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD08", request, response, model);
            Map<String, Object> sourceMap09 = XFrame5DataSetUtil.getXFrameDataSet("DS_SETL_DD_CHNG_SD09", request, response, model);

            /** 품의등록 업무 서비스 호출 입력값 대입 */
            // sddoSM, 01, 04, 08, 09
            RCHMNM01InVO InVO = new RCHMNM01InVO();

            RCHMNM01DSSMVO inDsSm = new RCHMNM01DSSMVO();
            inDsSm.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSm.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSm.setTims((String) sourceMap04.get("chngTims"));

            /** 데이터 등록에 필요한 SDDO 셋팅 */
            RCHMNM01DSDDSS01VO inDsSdVo01 = new RCHMNM01DSDDSS01VO();
            inDsSdVo01.setLoanNo((String) sourceMapSM.get("loanNo"));
            inDsSdVo01.setLoanSeq((String) sourceMapSM.get("loanSeq"));
            inDsSdVo01.setMngNo((String) sourceMapSM.get("mngNo"));
            inDsSdVo01.setContManNo((String) sourceMap01.get("contManNo"));
            inDsSdVo01.setPrdtCd((String) sourceMap01.get("prdtCd"));
            inDsSdVo01.setLoanStatCd((String) sourceMap01.get("loanStatCd"));
            inDsSdVo01.setLoanStatNm((String) sourceMap01.get("loanStatNm"));
            inDsSdVo01.setDueMethCd((String) sourceMap01.get("dueMethCd"));
            inDsSdVo01.setDueMethNm((String) sourceMap01.get("dueMethNm"));
            inDsSdVo01.setLoanPamtRamt((String) sourceMap01.get("loanPamtRamt"));
            inDsSdVo01.setLoanDt((String) sourceMap01.get("loanDt"));
            inDsSdVo01.setMngDeptCd((String) sourceMap01.get("mngDeptCd"));
            inDsSdVo01.setCustNm((String) sourceMap01.get("custNm"));
            inDsSdVo01.setPrdtNm((String) sourceMap01.get("prdtNm"));
            inDsSdVo01.setGodsCd((String) sourceMap01.get("godsCd"));
            inDsSdVo01.setGodsNm((String) sourceMap01.get("godsNm"));
            inDsSdVo01.setBndStatCd((String) sourceMap01.get("bndStatCd"));
            inDsSdVo01.setBndStatNm((String) sourceMap01.get("bndStatNm"));
            inDsSdVo01.setDeptAbbrnm((String) sourceMap01.get("deptAbbrnm"));
            inDsSdVo01.setAskPlcDivCd((String) sourceMap01.get("askPlcDivCd"));
            inDsSdVo01.setEmalAskFg((String) sourceMap01.get("emalAskFg"));
            inDsSdVo01.setFlotIzeDivCd((String) sourceMap01.get("flotIzeDivCd"));
            inDsSdVo01.setDlyAmt((String) sourceMap01.get("dlyAmt"));
            inDsSdVo01.setUnComgCnt((String) sourceMap01.get("unComgCnt"));
            inDsSdVo01.setDlyDt((String) sourceMap01.get("dlyDt"));
            inDsSdVo01.setSnum((String) sourceMap01.get("snum"));
            inDsSdVo01.setLoanChngConsRsltCd((String) sourceMap01.get("loanChngConsRsltCd"));
            inDsSdVo01.setNtrmJstManCd((String) sourceMap01.get("ntrmJstManCd"));
            inDsSdVo01.setArvmCd((String) sourceMap01.get("arvmCd"));
            inDsSdVo01.setLoanChngDivCd((String) sourceMap01.get("loanChngDivCd"));
            inDsSdVo01.setAcntStatCd((String) sourceMap01.get("acntStatCd"));
            inDsSdVo01.setAcntStatNm((String) sourceMap01.get("acntStatNm"));
            inDsSdVo01.setPrdtLrgeClasCd((String) sourceMap01.get("prdtLrgeClasCd"));
            inDsSdVo01.setPrdtMidClasCd((String) sourceMap01.get("prdtMidClasCd"));
            inDsSdVo01.setIsrtDeptCd((String) sourceMap01.get("isrtDeptCd"));
            inDsSdVo01.setMngPlcDivCd((String) sourceMap01.get("mngPlcDivCd"));
            inDsSdVo01.setMngPlcDivNm((String) sourceMap01.get("mngPlcDivNm"));

            RCHMNM01DSDDSS04VO inDsSdVo04 = new RCHMNM01DSDDSS04VO();
            inDsSdVo04.setThmmDueTims((String) sourceMap04.get("thmmDueTims"));
            inDsSdVo04.setThmmDueDt((String) sourceMap04.get("thmmDueDt"));
            inDsSdVo04.setChngTims(Long.parseLong(sourceMap04.get("chngTims").toString()));
            inDsSdVo04.setChngBfDueDt((String) sourceMap04.get("chngBfDueDt"));
            inDsSdVo04.setChngAfDueDt((String) sourceMap04.get("chngAfDueDt"));
            inDsSdVo04.setPsgInt((String) sourceMap04.get("psgInt"));
            inDsSdVo04.setPsgIntYn((String) sourceMap04.get("psqIntYn"));
            inDsSdVo04.setAplyIntRt((String) sourceMap04.get("aplyIntRt"));
            inDsSdVo04.setPsgDdCnt((String) sourceMap04.get("psgDdCnt"));

            RCHMNM01DSDDSS08VO inDsSdVo08 = new RCHMNM01DSDDSS08VO();
            inDsSdVo08.setLoanChngConsRsltCd((String) sourceMap08.get("loanChngConsRsltCd"));
            inDsSdVo08.setLoanChngConsRsltNm((String) sourceMap08.get("loanChngConsRsltNm"));
            inDsSdVo08.setJstEmpNo((String) sourceMap08.get("jstEmpNo"));
            inDsSdVo08.setJstEmpNm((String) sourceMap08.get("jstEmpNm"));
            inDsSdVo08.setJstDt((String) sourceMap08.get("jstDt"));
            inDsSdVo08.setLoanChngOpn((String) sourceMap08.get("loanChngOpn"));
            inDsSdVo08.setNtrmSetlmanNm((String) sourceMap08.get("ntrmSetlmanNm"));

            RCHMNM01DSDDSS09VO inDsSdVo09 = new RCHMNM01DSDDSS09VO();
            inDsSdVo09.setJstEmpNo((String) sourceMap09.get("jstEmpNo"));
            inDsSdVo09.setJstEmpNm((String) sourceMap09.get("jstEmpNm"));
            inDsSdVo09.setLoanChngOpn((String) sourceMap09.get("loanChngOpn"));

            InVO.setRCHMNM01DSSMVO(inDsSm);
            InVO.setRCHMNM01DSDDSS01VO(inDsSdVo01);
            InVO.setRCHMNM01DSDDSS04VO(inDsSdVo04);
            InVO.setRCHMNM01DSDDSS08VO(inDsSdVo08);
            InVO.setRCHMNM01DSDDSS09VO(inDsSdVo09);

            /** 결제일변경취소 업무 서비스 호출 수행 */
            RCHMNM01OutVO resultOut = RCHMNM01.registerRCHMNM01I04(InVO);

            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD01", resultOut.getRCHMNM01DSDDSS01VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD02", resultOut.getRCHMNM01DSDDSS02VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD03", resultOut.getRCHMNM01DSDDSS03VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD04", resultOut.getRCHMNM01DSDDSS04VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD05", resultOut.getRCHMNM01DSDDSS05VO(), model); /**  */
            XFrame5Util.setOutputData("DS_SETL_DD_CHNG_SD08", resultOut.getRCHMNM01DSDDSS08VO(), model); /**  */

            LOGGER.info("##### RCHMNM01Controller RCHMNM01I04 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM01I04 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}
