package hanalife.r.co.as.service;

import hanalife.r.co.as.vo.AskUnrcvVO;

/**
 * <pre>
 * 클래스명    : AskUnrcvProcService
 * 클래스설명  : 청구미수Service
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface AskUnrcvProcService {

	/**
	 * <p>메소드명	: calcAskUnrcv</p>
	 * <p>설　　명	: 청구미수 계산</p>
	 * <p>메소드인수	: AskUnrcvVO, ITransaction</p>
	 * <p>리　턴　값	: AskUnrcvVO</p>
	 */
	public AskUnrcvVO calcAskUnrcv(String loanNo, String loanSeq, String setlDt) throws Exception;


	/**
	 * <p>메소드명	: calcAskUnrcv</p>
	 * <p>설　　명	: 청구미수 계산</p>
	 * <p>메소드인수	: AskUnrcvVO, Connection
	 *				청구미수(요청) 객체 AskUnrcvObjVO 가 개별 요청단위 Object이다.
	 * 				개별요청단위(대출건 - 대출번호, 대출순번)는 대출번호순으로 sorting 되어 add 해야한다.
	 * 				중복대출번호가 있거나, 같은 대출번호에 다른 대출순번을 가져서는 안된다.</p>
	 * <p>리　턴　값	: AskUnrcvVO - 청구미수 객체</p>
	 */
	public AskUnrcvVO calcAskUnrcv(AskUnrcvVO askUnrcvVO) throws Exception;

	/**
	 * <p>메소드명	: calcDsrcRamt</p>
	 * <p>설　　명	: 대출의 예가수정보를 조회하여 BndVO에 결과를 담아 리턴한다.</p>
	 * <p>메소드인수	: AskUnrcvVO, Connection</p>
	 * 					AskUnrcvObjVO는 대출번호, 순번을 필수로, 예가수번호는 optional이다. (대출번호 순서대로 add해야하며 중복 추가 불가)
	 * <p>리　턴　값	: AskUnrcvVO - 예가수정보가 BndVO에 대상객체와 1:1로 담긴다.</p>
	 */
	public AskUnrcvVO calcDsrcRamt(AskUnrcvVO askUnrcvVO) throws Exception;

	/**
	 * <p>메소드명	: calcMidRmbr</p>
	 * <p>설　　명	: 중도상환계산</p>
	 * <p>메소드인수	: AskUnrcvVO, Connection</p>
	 * <p>리　턴　값	: AskUnrcvVO</p>
	 */
	public AskUnrcvVO calcMidRmbr(AskUnrcvVO askUnrcvVO) throws Exception;


	/**
	 * <p>메소드명	: isLease</p>
	 * <p>설　　명	: 리스 여부</p>
	 * <p>메소드인수	: String</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	public boolean isLease(String prdtLcd);

}
