package hanalife.r.co.as.service.impl;

import java.sql.SQLException;
import java.text.NumberFormat;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.mapper.AskUnrcvProcMapper;
import hanalife.r.co.as.mapper.dto.RtTempUnrcvObjDescDTO;
import hanalife.r.co.as.mapper.dto.SearchDfeeINDTO;
import hanalife.r.co.as.mapper.dto.SearchDfeeOUTDTO;
import hanalife.r.co.as.mapper.dto.SearchLoseDueDtByAddTimsINDTO;
import hanalife.r.co.as.mapper.dto.SearchLoseDueDtByAddTimsOUTDTO;
import hanalife.r.co.as.mapper.dto.SearchLoseDueDtByRlDueDtINDTO;
import hanalife.r.co.as.mapper.dto.SearchLoseDueDtByRlDueDtOUTDTO;
import hanalife.r.co.as.mapper.dto.SearchLoseDueDtByTimsINDTO;
import hanalife.r.co.as.mapper.dto.SearchLoseDueDtByTimsOUTDTO;
import hanalife.r.co.as.mapper.dto.SearchPreLoseINDTO;
import hanalife.r.co.as.mapper.dto.SearchPreLoseOUTDTO;
import hanalife.r.co.as.mapper.dto.SelectLoanBaseForBatchObjINDTO;
import hanalife.r.co.as.mapper.dto.SelectLoanBaseForBatchObjOUTDTO;
import hanalife.r.co.as.service.AskUnrcvService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.DlyCalcVO;
import hanalife.util.BizException;


/**
 * <pre>
 * 클래스　명 : AskUnrcvServiceImpl
 * 클래스설명 : 청구미수계산Impl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 16.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("AskUnrcvService")
public class AskUnrcvServiceImpl implements AskUnrcvService {

	private static final Logger log = LoggerFactory.getLogger(AskUnrcvServiceImpl.class);

	@Autowired
	private AskUnrcvProcMapper askUnrcvProcMapper;

	/** 공통오류코드 및 오류메시지 내용 전역 변수 선언 */
    private MsgEnum msgEnum;

	/**
	 * <p>메소드명	: searchLoanBase</p>
	 * <p>설    명	: 대상객체의 필요속성 추가 셋팅([대출_기본]을 조회한다.)</p>
	 * <p>메소드인수	: AskUnrcvObjVO askUnrcvObjVO - 대상객체 </p>
	 * <p>메소드 인수2	: Connection con - Connection 객체 </p>
	 * <p>리 턴 값	: N/A </p>
	 * <p>예외처리	: Exception </p>
	 */
	@Override
	public AskUnrcvVO searchLoanBaseForBatch(AskUnrcvVO askUnrcvVO) {

		SelectLoanBaseForBatchObjINDTO inDto = new SelectLoanBaseForBatchObjINDTO();
		inDto.setUnrcvOccrTpcd(Constants.UNRCV_OCCR_CUST_STMP_FEE);

		try {

			List<SelectLoanBaseForBatchObjOUTDTO> outDTO = askUnrcvProcMapper.selectLoanBaseForBatchObj(inDto);

			for (SelectLoanBaseForBatchObjOUTDTO sourceIO : outDTO) {
				AskUnrcvObjVO askUnrcvObjVO = askUnrcvVO.getAskUnrcvObj(sourceIO.getLoanNo(), sourceIO.getLoanSeq());
				askUnrcvObjVO = setLoanInfo(sourceIO, askUnrcvObjVO);
				askUnrcvVO.addAskUnrcvObj(askUnrcvObjVO);
			}
		} catch (Exception e) {
			throw new BizException("청구미수 계산 대상 조회 실패", e);
		}

		return askUnrcvVO;
	}

	/**
	 * 청구미수 요청정보에 대출정보 셋팅
	 * @param rs
	 * @param askUnrcvObjVO
	 * @throws SQLException
	 */
	private AskUnrcvObjVO setLoanInfo(SelectLoanBaseForBatchObjOUTDTO outDTO, AskUnrcvObjVO askUnrcvObjVO) throws Exception {

		if (askUnrcvObjVO != null) {
			askUnrcvObjVO.prdtCd = StringUtil.trim(outDTO.getPrdtCd());
			askUnrcvObjVO.prdtLrgeClasCd = StringUtil.trim(outDTO.getPrdtLrgeClasCd());
			askUnrcvObjVO.prdtMidClasCd = StringUtil.trim(outDTO.getPrdtMidClasCd());
			askUnrcvObjVO.prdtSmClasCd = StringUtil.trim(outDTO.getPrdtSmClasCd());
			askUnrcvObjVO.asymmAcctFg = StringUtil.trim(outDTO.getAsymmAcctFg());
			askUnrcvObjVO.loanAmt = outDTO.getLoanPamt();
			askUnrcvObjVO.loanIntRt = outDTO.getLoanIntRt();
			askUnrcvObjVO.loanDt = StringUtil.trim(outDTO.getLoanDt());
			askUnrcvObjVO.loanStatCd = StringUtil.trim(outDTO.getLoanStatCd());
			askUnrcvObjVO.crdtRcvrUnrcvAmt = outDTO.getCrdtRcvrUnrcvAmt();
			askUnrcvObjVO.rmbrCrdtRcvrUnrcvAmt = outDTO.getRmbrCrdtRcvrUnrcvAmt();
			askUnrcvObjVO.crdtRcvrUnrcvAmtRamt = askUnrcvObjVO.crdtRcvrUnrcvAmt-askUnrcvObjVO.rmbrCrdtRcvrUnrcvAmt;
			askUnrcvObjVO.leglActnCostRamt = outDTO.getLeglActsCostRamt();
			askUnrcvObjVO.adjLeglActnCost = outDTO.getRmbrLeglActsCost();
			askUnrcvObjVO.occrLeglActnCost = outDTO.getLeglActsCost();
			askUnrcvObjVO.loseCalcFg = getFg(outDTO.getLoseCalcFg());
			askUnrcvObjVO.loseCalcCd = outDTO.getLoseCalcCd();
			askUnrcvObjVO.loseCalcVal = outDTO.getLoseCalcVal();
			askUnrcvObjVO.sixPreDt = StringUtil.trim(outDTO.getSixPreDt());
			askUnrcvObjVO.endAfAskStatCd = StringUtil.trim(outDTO.getEndAfAskStatCd());
			askUnrcvObjVO.eprtAskMethCd = StringUtil.trim(outDTO.getEprtAskMethCd());
			askUnrcvObjVO.guarAmtAdjFg = getFg(outDTO.getGuarAmtAdjFg());
			askUnrcvObjVO.guarAmt = outDTO.getGuarAmt();
			askUnrcvObjVO.ramtAmt = outDTO.getRamtAmt();
			askUnrcvObjVO.leasEprtDt = StringUtil.trim(outDTO.getLeasEprtDt());
			askUnrcvObjVO.leasRlEprtDt = StringUtil.trim(outDTO.getLeasRlEprtDt());
			askUnrcvObjVO.leasEprtDlyDt = StringUtil.trim(outDTO.getLeasEprtDlyDt());
			askUnrcvObjVO.unrcvProcDt = StringUtil.trim(outDTO.getUnrcvProcDt());
			askUnrcvObjVO.mainFrstRank = outDTO.getMainFrstRank();
			askUnrcvObjVO.mainEndTims = StringUtil.parseInt(outDTO.getMainEndTims());
			//2018-08-01 두비스 리스승계건인지 확인을 위해
			askUnrcvObjVO.loanOccrCd = StringUtil.trim(outDTO.getLoanOccrCd());
			askUnrcvObjVO.execDt = StringUtil.trim(outDTO.getExecDt());
			askUnrcvObjVO.trtFee = outDTO.getTrtFee();
			//2018-08-01 두비스 약정 연체료율
			askUnrcvObjVO.dfeeRt = outDTO.getDfeeRt();
			askUnrcvObjVO.psgMmCnt = outDTO.getPsgMmCnt();
			askUnrcvObjVO.ddayPrftLoseStrtTims = outDTO.getDdayPrftLoseStrtTims();
			askUnrcvObjVO.depsRamt = outDTO.getDepsRamt();
			askUnrcvObjVO.stmpFeeUnrcvNo = outDTO.getUnrcvNo();
			askUnrcvObjVO.stmpFeeOccrAmt = outDTO.getUnrcvOccrAmt();
			askUnrcvObjVO.stmpFeeAdjAmt = outDTO.getUnrcvAdjAmt();
			askUnrcvObjVO.stmpFeeRamt = outDTO.getUnrcvRamt();
			askUnrcvObjVO.bndStatCd = outDTO.getBndStatCd();
		}
		return askUnrcvObjVO;
	}

	/**
	 * <p>메소드명	: createAskUnrcvObj</p>
	 * <p>설    명	: 대상객체를 임시테이블에 insert한다.</p>
	 * <p>메소드인수	: List, Connection</p>
	 * <p>리 턴 값	: int</p>
	 */
	//public int createAskUnrcvObj(List askUnrcvObjVOList) throws Exception {

    /**
     * <p>메소드명	: createAskUnrcvObj</p>
     * <p>설    명	: 대상객체를 임시테이블에 insert한다.</p>
     * <p>메소드인수	: List, Connection</p>
     * <p>리 턴 값	: int</p>
     */
	@Override
	public void createAskUnrcvObjForBatch(List askUnrcvObjVOList) {
        // 요청목록건을 가공
    	String loanNoList = null;
        String loanSeqList = null;
        String dsrcNoList = null;
        String partRmbrPamtList = null;
        String setlDtList = null;
        String acctDtList = null;

        try {
	        int logCnt = 0; String logLoan = "■ 청구미수 대출 - ";

	        for (int i = 0, n = askUnrcvObjVOList.size(); i < n; i++) {
				AskUnrcvObjVO askUnrcvObjVO = (AskUnrcvObjVO) askUnrcvObjVOList.get(i);

				logCnt++; logLoan += (", "+askUnrcvObjVO.loanNo+"-"+askUnrcvObjVO.loanSeq);
				if (logCnt==10) {
					log.info(logLoan);
					logCnt = 0; logLoan = "■ 청구미수 대출 - ";
				}

				if (loanNoList == null) {
					loanNoList = StringUtil.nvl(askUnrcvObjVO.loanNo);
					loanSeqList = StringUtil.nvl(askUnrcvObjVO.loanSeq);
					dsrcNoList = StringUtil.nvl(askUnrcvObjVO.dsrcNo);
					partRmbrPamtList = String.valueOf(askUnrcvObjVO.partRmbrPamt);
					setlDtList = StringUtil.nvl(askUnrcvObjVO.setlDt);
					acctDtList = StringUtil.nvl(askUnrcvObjVO.acctDt);
				} else {
					loanNoList += "," + StringUtil.nvl(askUnrcvObjVO.loanNo);
					loanSeqList += "," +  StringUtil.nvl(askUnrcvObjVO.loanSeq);
					dsrcNoList += "," +  StringUtil.nvl(askUnrcvObjVO.dsrcNo);
					partRmbrPamtList += "," +  String.valueOf(askUnrcvObjVO.partRmbrPamt);
					setlDtList += "," +   StringUtil.nvl(askUnrcvObjVO.setlDt);
					acctDtList += "," +   StringUtil.nvl(askUnrcvObjVO.acctDt);
				}
	        }
	        if (logCnt%10!=0) log.info(logLoan);

	        RtTempUnrcvObjDescDTO inDTO = new RtTempUnrcvObjDescDTO();

			inDTO.setLoanNoList(loanNoList);
			inDTO.setLoanSeqList(loanSeqList);
			inDTO.setDsrcNoList(dsrcNoList);
			inDTO.setPartRmbrPamtList(partRmbrPamtList);
			inDTO.setSetlDtList(setlDtList);
			inDTO.setAcctDtList(acctDtList);

			askUnrcvProcMapper.insertObjBatch(inDTO);

		} catch (Exception e) {
			throw new BizException("청구미수 계산 대출정보 확인 오류", e);
		}

	}

	@Override
	public void deleteAskUnrcvObj() throws Exception {
		askUnrcvProcMapper.deleteObj();
	}

	@Override
	public DlyCalcVO calcDfee(DlyCalcVO dlyCalcVO) {

		try {

			int yearGap =  Integer.parseInt(StringUtils.left(dlyCalcVO.setlDt,4)) - Integer.parseInt(StringUtils.left(dlyCalcVO.dlyCalcDt,4));

			SearchDfeeINDTO inDTO = new SearchDfeeINDTO();

			inDTO.setRlDueDt(dlyCalcVO.rlDueDt);
			inDTO.setLoseDt(StringUtil.nvl(dlyCalcVO.loseDt,"1111-11-11"));						// LOSE_DT
			inDTO.setLoseFg(StringUtil.nvl(dlyCalcVO.loseFg,"1111-11-11"));						// LOSE_FG
			inDTO.setLoseIntPsgStrtDt(StringUtil.nvl(dlyCalcVO.loseIntPsgStrtDt,"1111-11-11"));	// LOSE_INT_PSG_STRT_DT
			inDTO.setLoseIntPsgEndDt(StringUtil.nvl(dlyCalcVO.loseIntPsgEndDt,"1111-11-11"));	// LOSE_INT_PSG_END_DT
			inDTO.setLoseObjPsgInt(dlyCalcVO.loseObjPsgInt);								// LOSE_OBJ_PSG_INT
			inDTO.setLoseBalPamt(dlyCalcVO.loseBalPamt);									// LOSE_BAL_PAMT
			inDTO.setLoseCalcEndDt(StringUtil.nvl(dlyCalcVO.loseCalcEndDt, "1111-11-11"));		// LOSE_CALC_END_DT
			inDTO.setLoseCalcStrtDt(StringUtil.nvl(dlyCalcVO.loseCalcStrtDt, "1111-11-11"));		// LOSE_CALC_STRT_DT
			inDTO.setLoseIntCalcStrtDt(StringUtil.nvl(dlyCalcVO.loseIntCalcStrtDt, "1111-11-11"));	// LOSE_INT_CALC_STRT_DT
			inDTO.setLoseIntCalcEndDt(StringUtil.nvl(dlyCalcVO.loseIntCalcEndDt, "1111-11-11"));	// LOSE_INT_CALC_END_DT
			inDTO.setLoseDueDt(StringUtil.nvl(dlyCalcVO.loseDueDt, "1111-11-11"));				// LOSE_DUE_DT
			inDTO.setLastSetlDt(StringUtil.nvl(dlyCalcVO.lastSetlDt, "1111-11-11"));				// LAST_SETL_DT
			inDTO.setDlyAmt(dlyCalcVO.dlyAmt);												// DLY_AMT
			inDTO.setSetlDt(StringUtil.nvl(dlyCalcVO.setlDt, "1111-11-11"));						// SETL_DT
			inDTO.setDlyCalcDt(StringUtil.nvl(dlyCalcVO.dlyCalcDt, "1111-11-11"));				// DLY_CALC_DT
			inDTO.setDfeeCalcDt(StringUtil.nvl(dlyCalcVO.dfeeCalcDt, "1111-11-11"));				// DFEE_CALC_DT
			inDTO.setDueDt(StringUtil.nvl(dlyCalcVO.dueDt, "1111-11-11"));						// DUE_DT
			inDTO.setThmmDueDt(StringUtil.nvl(dlyCalcVO.thmmDueDt, "1111-11-11"));				// THMM_DUE_DT
			inDTO.setThmmRlDueDt(StringUtil.nvl(dlyCalcVO.thmmRlDueDt, "1111-11-11"));			// THMM_RL_DUE_DT
			inDTO.setTims(dlyCalcVO.tims);													// TIMS
			inDTO.setThmmDueTims(dlyCalcVO.thmmDueTims);									// THMM_DUE_TIMS
			inDTO.setIsAddOneDayDfee((dlyCalcVO.isAddOneDayDfee?1:0));						// ADD_DAY_DFEE
			inDTO.setIsAddOneDayLoseDfee((dlyCalcVO.isAddOneDayLoseDfee?1:0));				// ADD_DAY_DFEE
			inDTO.setLoanNo(dlyCalcVO.loanNo);
			inDTO.setLoanSeq(dlyCalcVO.loanSeq);
			inDTO.setYearGap(yearGap);
			inDTO.setDfeeStrtDt(StringUtil.nvl(dlyCalcVO.dlyCalcDt, "1111-11-11"));
			inDTO.setDfeeEndDt(StringUtil.nvl(dlyCalcVO.setlDt, "1111-11-11"));
			inDTO.setDfeeStrtYyyy(StringUtils.left(StringUtil.nvl(dlyCalcVO.dlyCalcDt, "1111-11-11"),4));

			SearchDfeeOUTDTO outDTO = askUnrcvProcMapper.searchDfee(inDTO);

			if(outDTO != null ) {
				dlyCalcVO.dfee = outDTO.getDfee(); // 연체료
				dlyCalcVO.dlyDdcnt = outDTO.getDlyDdcnt(); // 연체일수
				dlyCalcVO.occrDlyDdcnt = outDTO.getOccrDlyDdcnt(); // 발생연체일수
				dlyCalcVO.dlyMmCnt = outDTO.getDlyMmCnt(); // 연체개월수
				dlyCalcVO.dlyTcnt = outDTO.getDlyTcnt(); // 연체횟수
				dlyCalcVO.dfeeRt = outDTO.getDfeeRt(); // 연체료율

				dlyCalcVO.loseRamtDfee  = outDTO.getLoseRamtDfee();
				dlyCalcVO.losePsgInt    = outDTO.getLosePsgInt();
				dlyCalcVO.losePsgDdcnt  = outDTO.getLosePsgDdcnt();
				dlyCalcVO.loseIntPsgDdcnt  = outDTO.getLoseIntPsgDdcnt();

				dlyCalcVO.loseTimsDdcnt = outDTO.getLoseTimsDdcnt();

				// 발생연체료 계산 구간
				dlyCalcVO.dlyCalcSdt = dlyCalcVO.dlyCalcDt;
				dlyCalcVO.dlyCalcEdt = dlyCalcVO.setlDt;

				if (dlyCalcVO.isTooltipShow() && StringUtils.isNotBlank(dlyCalcVO.dlyCalcDt)
					&& StringUtils.isNotBlank(dlyCalcVO.setlDt)
					&& dlyCalcVO.setlDt.compareTo(dlyCalcVO.dlyCalcDt) >= 0) {

					StringBuilder dlyToolTip = new StringBuilder(1024);
					int dlyCalcDdCnt = outDTO.getDlyCalcDdCnt();

					if (dlyCalcDdCnt >= 0 &&  dlyCalcVO.dfee > 0) {
						NumberFormat numberFormat = NumberFormat.getInstance();
						long ddCnt365 = outDTO.getDdCnt365();
						long ddCnt366 = outDTO.getDdCnt366();

						if (ddCnt365 > 0) {
							dlyToolTip.append("365 : " + numberFormat.format(ddCnt365));
						}

						if (ddCnt366 > 0) {
							if (dlyToolTip.length() > 0) {
								dlyToolTip.append(" ,");
							}
							dlyToolTip.append("366 : " + numberFormat.format(ddCnt366));
						}

						dlyToolTip.append(")");
						dlyToolTip.insert(0,"(");

						dlyCalcVO.dlyToolTip = dlyToolTip.toString();
					}
				}
			}
		} catch (Exception e) {
			throw new BizException("연체료 계산오류(" + e.getMessage() +")", e);
		}

		return dlyCalcVO;
	}

	/**
	 * <p>메소드명	: searchPreLose</p>
	 * <p>설    명	: 이전 연체수납건중 기한이익상실 수납건이 존재하는지 확인</p>
	 * <p>메소드인수	: DlyCalcVO dlyCalcVO, Connection </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	@Override
	public DlyCalcVO searchPreLose(DlyCalcVO dlyCalcVO) throws Exception {
		try {

			SearchPreLoseINDTO inDTO = new SearchPreLoseINDTO();

			inDTO.setLoanNo(dlyCalcVO.loanNo);
			inDTO.setLoanSeq(dlyCalcVO.loanSeq);

			SearchPreLoseOUTDTO outDTO = askUnrcvProcMapper.searchPreLose(inDTO);

			if(outDTO != null ) {
				dlyCalcVO.loseFg     = outDTO.getLoseFg();
				dlyCalcVO.loseDueDt  = outDTO.getLoseDueDt();
				dlyCalcVO.loseDt     = outDTO.getLoseDt();
				dlyCalcVO.dueDt      = outDTO.getDueDt();
				dlyCalcVO.setlDt     = outDTO.getSetlDt();
				dlyCalcVO.dfee       = outDTO.getUnrcvDfee();
				dlyCalcVO.loseRvvlFg = StringUtil.trim(outDTO.getLoseRvvlFg());
			}

		} catch (Exception e) {
			throw new BizException("기한이익상실 수납건 체크 오류(" + e.getMessage() +")", e);
		}

		return dlyCalcVO;
	}

	/**
	 * <p>메소드명	: searchLoseDueDt</p>
	 * <p>설    명	: 기한상실 일자 조회</p>
	 * <p>메소드인수	: loanNo, loanSeq, tims </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	@Override
	public DlyCalcVO searchLoseDueDt(String loanNo, String loanSeq, int tims) throws Exception {
		DlyCalcVO calVO = new DlyCalcVO();

		try {

			SearchLoseDueDtByTimsINDTO inDTO = new SearchLoseDueDtByTimsINDTO();
			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setTims(tims);

			SearchLoseDueDtByTimsOUTDTO outDTO = askUnrcvProcMapper.searchLoseDueDtByTims(inDTO);

			if(outDTO != null ) {
				calVO.dueDt   = outDTO.getDueDt();
				calVO.rlDueDt = outDTO.getRlDueDt();
			}

		} catch (Exception e) {
			throw new BizException("기한상실 일자 조회 오류(" + e.getMessage() +")", e);
		}

		return calVO;
	}

	/**
	 * <p>메소드명	: searchLoseDueDtAddTims</p>
	 * <p>설    명	: 기한상실 회차 추가 몇회차 이후</p>
	 * <p>메소드인수	: loanNo, loanSeq, addtims </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	@Override
	public DlyCalcVO searchLoseDueDtAddTims(String loanNo, String loanSeq, int addtims) throws Exception {

		DlyCalcVO calVO = new DlyCalcVO();

		try {
			SearchLoseDueDtByAddTimsINDTO inDTO = new SearchLoseDueDtByAddTimsINDTO();
			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setAddtims(addtims);

			SearchLoseDueDtByAddTimsOUTDTO outDTO = askUnrcvProcMapper.searchLoseDueDtByAddTims(inDTO);

			if(outDTO != null ) {
				calVO.dueDt   = outDTO.getDueDt();
				calVO.rlDueDt = outDTO.getRlDueDt();
				calVO.tims    = outDTO.getTims();
			}

		} catch (Exception e) {
			throw new BizException("기한상실 회차 추가 몇회차 이후 조회 오류(" + e.getMessage() +")", e);
		}

		return calVO;
	}

	/**
	 * <p>메소드명	: searchLoseDueDt</p>
	 * <p>설    명	: 기한상실납입일</p>
	 * <p>메소드인수	: loanNo, loanSeq, rlDueDt </p>
	 * <p>리 턴 값	: DlyCalcVO </p>
	 */
	@Override
	public DlyCalcVO searchLoseDueDt(String loanNo, String loanSeq, String rlDueDt) throws Exception {

		DlyCalcVO calVO = new DlyCalcVO();

		try {
			SearchLoseDueDtByRlDueDtINDTO inDTO = new SearchLoseDueDtByRlDueDtINDTO();
			inDTO.setLoanNo(loanNo);
			inDTO.setLoanSeq(loanSeq);
			inDTO.setRlDueDt(rlDueDt);

			SearchLoseDueDtByRlDueDtOUTDTO outDTO = askUnrcvProcMapper.searchLoseDueDtByRlDueDt(inDTO);
			if(outDTO != null ) {
				calVO.dueDt   = outDTO.getDueDt();
				calVO.rlDueDt = outDTO.getRlDueDt();
			}

		} catch (Exception e) {
			throw new BizException("기한상실납입일 조회 오류(" + e.getMessage() +")", e);
		}

		return calVO;
	}

	/**
	 * <p>메소드명	: getFg</p>
	 * <p>설    명	: Flag값을 리턴</p>
	 * <p>메소드인수	: String inVal</p>
	 * <p>리 턴 값	: String</p>
	 */
	private String getFg(String inVal) {
		if (StringUtil.isNull(inVal)) {
			return Constants.NO;
		} else {
			return inVal;
		}
	}

}
