package hanalife.r.co.as.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.mapper.AskUnrcvProcMapper;
import hanalife.r.co.as.mapper.dto.DsrcSearchINDTO;
import hanalife.r.co.as.mapper.dto.DsrcSearchOUTDTO;
import hanalife.r.co.as.mapper.dto.SelectDlyDdCntINDTO;
import hanalife.r.co.as.mapper.dto.SelectMidRmbrINDTO;
import hanalife.r.co.as.mapper.dto.SelectMidRmbrOUTDTO;
import hanalife.r.co.as.mapper.dto.SelectTermMidRmbrINDTO;
import hanalife.r.co.as.mapper.dto.SelectTermMidRmbrOUTDTO;
import hanalife.r.co.as.service.RcptASService;
import hanalife.r.co.as.vo.AskUnrcvObjVO;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.util.BizException;


/**
 * <pre>
 * 클래스　명 : RcptServiceImpl
 * 클래스설명 : 대출관련Impl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 16.
 *  * 작성자명    : 70279 / jung
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RcptASService")
public class RcptASServiceImpl implements RcptASService {

	private static final Logger log = LoggerFactory.getLogger(RcptASServiceImpl.class);

	@Autowired
	private AskUnrcvProcMapper askUnrcvProcMapper;

	/**
	 * <p>메소드명	: calcLngsDlyDdcnt</p>
	 * <p>설    명	: 최장연체일수 계산</p>
	 * <p>메소드인수	: BndVO, Connection</p>
	 * <p>리 턴 값	: BndVO</p>
	 */
	@Override
	public BndVO calcLngsDlyDdcnt(BndVO bndVO) throws Exception {

		try {

			SelectDlyDdCntINDTO inDTO = new SelectDlyDdCntINDTO();

			inDTO.setLoanNo(bndVO.loanNo);
			inDTO.setLoanSeq(bndVO.loanSeq);
			inDTO.setLastSetlDt("");

			bndVO.lngsDlyDdcnt = askUnrcvProcMapper.selectLngsDlyDdCnt(inDTO);

		} catch (Exception e) {
			throw new BizException("최장연체일수 계산 실패", e);
		}

		return bndVO;
	}

	/**
	 * <p>메소드명	: calcTotDlyDdcnt</p>
	 * <p>설    명	: 누적연체일수 계산</p>
	 * <p>메소드인수	: BndVO, Connection</p>
	 * <p>리 턴 값	: BndVO</p>
	 */
	@Override
	public BndVO calcTotDlyDdcnt(BndVO bndVO) throws Exception {

		try {

			SelectDlyDdCntINDTO inDTO = new SelectDlyDdCntINDTO();

			inDTO.setLoanNo(bndVO.loanNo);
			inDTO.setLoanSeq(bndVO.loanSeq);
			inDTO.setLastSetlDt("");

			bndVO.totDlyDdcnt = askUnrcvProcMapper.selectTotDlyDdCnt(inDTO);

		} catch (Exception e) {
			throw new BizException("누적연체일수 계산 실패", e);
		}

		return bndVO;
	}

	/**
	 * <p>메소드명	: calcDsrc</p>
	 * <p>설    명	: 예가수 정보 조회</p>
	 * <p>메소드인수	: BndVO, Connection</p>
	 * <p>리 턴 값	: BndVO</p>
	 */
	@Override
	public BndVO calcDsrc(BndVO bndVO) throws Exception {

		try {

			DsrcSearchINDTO 	inDTO = new DsrcSearchINDTO();
			DsrcSearchOUTDTO	outDTO = new DsrcSearchOUTDTO();

			if (StringUtil.isNull(bndVO.dsrcNo)) {

				inDTO.setSetlDt(bndVO.setlDt);
				inDTO.setLoanNo(bndVO.loanNo);
				inDTO.setLoanSeq(bndVO.loanSeq);

				outDTO = askUnrcvProcMapper.dsrcSearch(inDTO);
			}
			else {

				inDTO.setSetlDt(bndVO.setlDt);
				inDTO.setDsrcNo(bndVO.dsrcNo);

				outDTO = askUnrcvProcMapper.dsrcSearchByDsrcno(inDTO);
			}

			if(outDTO != null ) {
				bndVO.dsrcSnum           = outDTO.getDsrcSnum();
				bndVO.rfndSnum           = outDTO.getRfndSnum();
				bndVO.dsrcOccrAmt        = outDTO.getOccrDsrcAmt();
				bndVO.dsrcAdjAmt         = outDTO.getAdjDsrcAmt();
				bndVO.dsrcRamt           = outDTO.getDsrcRamt();
				bndVO.rfndStatCd         = outDTO.getRfndStatCd();
				bndVO.dsrcSetlDt         = outDTO.getDsrcSetlDt();
				bndVO.dsrcOccrCd         = outDTO.getDsrcOccrCd();
				bndVO.dsrcAdjDeptCd      = outDTO.getAdjDeptCd();
				bndVO.brcvAmtLeasfeeRamt = outDTO.getBrcvAmtLeasfeeRamt();
				bndVO.dsrcOccrAcctDt     = outDTO.getAcctDt();
				bndVO.srcpRamt           = outDTO.getSrcpRamt();
				bndVO.bfLoanNo           = outDTO.getBfLoanNo();
				bndVO.bfLoanSeq          = outDTO.getBfLoanSeq();
				bndVO.loanNo             = outDTO.getLoanNo();
				bndVO.loanSeq            = outDTO.getLoanSeq();
			}

		} catch (Exception e) {
			throw new BizException("예가수 정보 조회 실패", e);
		}

		return bndVO;
	}

	/**
	 * <p>메소드명	: calcMidRmbr</p>
	 * <p>설    명	: 중도상환 각종 수수료, 할인 금액 등을 계산한다. (할부/일반대출)</p>
	 * <p>메소드인수	: AskUnrcvVO, AskUnrcvObjVO, BndVO, Connection</p>
	 * <p>리 턴 값	: BndVO</p>
	 */
	@Override
	public BndVO calcMidRmbr(AskUnrcvVO askUnrcvVO, AskUnrcvObjVO askUnrcvObjVO, BndVO bndVO) {

		try {

			SelectMidRmbrINDTO inDTO = new SelectMidRmbrINDTO();

			inDTO.setLoanNo(bndVO.loanNo);
			inDTO.setLoanSeq(bndVO.loanSeq);
			inDTO.setSetlDt(bndVO.setlDt);
			if (StringUtil.trim(bndVO.setlDt).compareTo(StringUtil.trim(bndVO.loanEprtDt)) > 0) {    //종료이후일때 결제일보정
				inDTO.setMidPsgIntEndDt(bndVO.loanEprtDt);
				bndVO.calcMidIntEndDt = bndVO.loanEprtDt;
			} else {
				inDTO.setMidPsgIntEndDt(bndVO.setlDt);
				bndVO.calcMidIntEndDt = bndVO.setlDt;
			}
//			if (bndVO.getBfMidRmbrTims()!=null) {
//				bndVO.midIntStrtDt = bndVO.getBfMidRmbrTims().intStrtDt;
//				bndVO.midIntEndDt = bndVO.getBfMidRmbrTims().intEndDt;
//			}

			inDTO.setMidIntStrtDt(bndVO.midIntStrtDt);
			inDTO.setMidIntEndDt(bndVO.midIntEndDt);
			inDTO.setRlTamtRmbrPamt(bndVO.rlTamtRmbrPamt);
			inDTO.setRlPartRmbrPamt(bndVO.rlPartRmbrPamt);
			inDTO.setMidTermPartInt(bndVO.midTermPartInt);
			inDTO.setPrdtCd(bndVO.prdtCd);
			inDTO.setMidRmbrTims(bndVO.midRmbrTims);

			String rmbrRt = String.format("%3.2f", Double.parseDouble(((bndVO.loanAmt - bndVO.pamtRamt) / bndVO.loanAmt * 100)+""));

			inDTO.setPsgMmCnt(askUnrcvObjVO.psgMmCnt);
			inDTO.setRmbrRt(rmbrRt);
			inDTO.setTotTims(bndVO.totTims);
			inDTO.setLoanIntRt(bndVO.loanIntRt);

			SelectMidRmbrOUTDTO outDTO = askUnrcvProcMapper.selectMidRmbr(inDTO);

			if(outDTO != null ) {

				bndVO.midRmbrInt           = outDTO.getMidRmbrInt();           //중도상환이자
				bndVO.tamtRmbrFee          = outDTO.getTamtRmbrFee();          //전액상환수수료
				bndVO.partRmbrFee          = outDTO.getPartRmbrFee();          //부분상환수수료
				bndVO.trtFeeRt             = outDTO.getTrtFeeRt();             //취급_수수료율
				bndVO.midRmbrBalDdcnt      = (int)StringUtil.parseNature(outDTO.getMidRmbrBalDdcnt());      //중도상환잔여일수
				bndVO.origMidRmbrBalDdcnt  = outDTO.getCalcMidRmbrBalDdcnt();  //중도상환잔여개월수
				bndVO.loanTotDdcnt         = outDTO.getLoanTotDdcnt();         //대출총일수
				bndVO.origLoanTotDdcnt     = outDTO.getCalcLoanTotDdcnt();     //대출총일수
				bndVO.midRmbrFeeRt         = outDTO.getMidRmbrFeeRt();         //중도_상환_수수료율
				bndVO.loanIntRt            = outDTO.getLoanIntRt();            //대출_이자율
				bndVO.loanPsgDdcnt         = StringUtil.parseInt(StringUtil.dateDiff(bndVO.loanDt, bndVO.setlDt));         //대출경과일수
				bndVO.psgDdcnt             = outDTO.getPsgDdcnt();             //이자경과일수
				bndVO.psgMmcnt             = outDTO.getPsgMmcnt();             //경과월수
				bndVO.orgIntDdcnt          = outDTO.getOrgIntDdcnt();          //원이자일수
				bndVO.loanTotMmCnt         = outDTO.getLoanTotMmCnt();         //대출총개월수
				bndVO.midRmbrBalMmCnt      = outDTO.getMidRmbrBalMmCnt();      //중도상환잔여개월수
				bndVO.balTermCalcFg        = outDTO.getBalTermCalcFg();        //잔여기간계산여부
				bndVO.custTrtFee           = outDTO.getCustTrtFee();           //고객취급수수료
				bndVO.termPartPamtRmbrInt  = outDTO.getTermPartPamtRmbrInt();  //거치분할부분상환이자
				bndVO.termPartTamtRmbrInt  = outDTO.getTermPartTamtRmbrInt();  //거치분할전액상환이자
				bndVO.trtFeeDiscExclFg     = outDTO.getTrtFeeDiscExclFg();     //취급_수수료_할인_제외_여부
				bndVO.custTrtFeeDisc       = outDTO.getCustTrtFeeDisc();       //취급_수수료_할인
				bndVO.mmTrtFeeDisc         = outDTO.getMmTrtFeeDisc();         //분할취급수수료할인
				bndVO.tamtRmbrExtsPamt     = outDTO.getExcpExtsPamt();     		//전액상환유예원금
				bndVO.tamtRmbrExtsFg       = outDTO.getExtsPamtExclFg();       //전액상환유예여부
				bndVO.intUplmitRt          = outDTO.getIntUplmitRt();          //법정_최고_이자율
				bndVO.incdCostRt           = StringUtil.parseDouble(outDTO.getIncdCostRt());           //부대비용율
				bndVO.partRmbrRcptFg       = StringUtil.parseInt(outDTO.getPartRmbrRcptFg()) > 0 ? Constants.YES : Constants.NO;
			}

		} catch (Exception e) {
			throw new BizException("중도상환 계산 SQL오류(" + e.getMessage() +")", e);
		}

		return bndVO;
	}

	/**
	 * <p>메소드명	: calcTermMidRmbr_Term</p>
	 * <p>설    명	: 거치 중도상환 금액을 계산한다.</p>
	 * <p>메소드인수	: BndVO, Connection</p>
	 * <p>리 턴 값	: BndVO</p>
	 */
	@Override
	public BndVO calcTermMidRmbr_Term(BndVO bndVO) throws Exception {

		try {

			SelectTermMidRmbrINDTO inDTO = new SelectTermMidRmbrINDTO();

			inDTO.setSetlDt(bndVO.setlDt);					//채권.중도상환대상이자
			inDTO.setRlPartRmbrPamt(bndVO.rlPartRmbrPamt);	//실부분상환원금
			inDTO.setRlTamtRmbrPamt(bndVO.rlTamtRmbrPamt);	//실전액상환원금
			inDTO.setLoanNo(bndVO.loanNo);					//대출_번호
			inDTO.setLoanSeq(bndVO.loanSeq);				//대출_순번

			SelectTermMidRmbrOUTDTO outDTO = askUnrcvProcMapper.selectTermMidRmbr(inDTO);

			if(outDTO != null ) {
				bndVO.termPartDdcnt 		= outDTO.getTermPartDdcnt(); 		//거치분할일수
				bndVO.termPartIntStrtDt 	= outDTO.getTermPartIntStrtDt(); 	//거치분할이자시작일자
				bndVO.termPartIntEndDt 		= outDTO.getTermPartIntEndDt(); 	//거치분할이자종료일자
				bndVO.termPartIntRt 		= outDTO.getTermPartIntRt(); 		//거치분할이자율
				bndVO.termPartPamtRmbrInt 	= outDTO.getTermPartPamtRmbrInt(); 	//거치분할부분상환이자
				bndVO.termPartTamtRmbrInt 	= outDTO.getTermPartTamtRmbrInt(); 	//거치분할전액상환이자
			}

		} catch (Exception e) {
			throw new BizException("거치 중도상환 금액을 계산정보 조회 실패", e);
		}

		return bndVO;
	}


}
