package hanalife.r.co.as.vo;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;

import hanalife.b.cl.dl.vo.tmp.AskUnrcvConst;
import hanalife.c.co.util.StringUtil;

@SuppressWarnings({"unchecked","rawtypes"})
/**
 * <pre>
 * 클래스명    : AskUnrcvVO
 * 클래스설명 : 청구미수계산 요청/응답 객체 VO
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class AskUnrcvVO {

	private List askUnrcvObjVOList; // 대상정보 객체리스트
	private Map<String, AskUnrcvObjVO> askUnrcvObjVOMap;
	private List bndVOList; // 채권객체 리스트
	private Map<String, BndVO> bndVOMap;
	private List timsUnrcvVOList; // 회차미수객체 리스트

	private List rmbrPlanVOList;	// 상환계획개체 리스트 ( 내부계산용 )
	private List dlyCalcVOList;		// 연체계산객체 리스트 ( 내부 계산용 )
	public String isrtDt;			//입력시스템일자

	// 기한이익상실 예상 계산여부 (5영업일 후 상실일지 계산)
	public String loseExptCalcFg = "1";	// 상실예상계산여부	//2022-12-07 예정일 조회여부

	// 중도상환미계산여부 : "1" - 중도상환금액을 계산안한다. "0" - 중도상환금액을 계산한다.(default)
	public String midRmbrUnCalcFg;

	// 파산면책계산여부( 중도상환수수료, 취급수수료할인 계산안함 )
	public String bkrpExemCalcFg;

	// 툴팁계산 여부
	public String tooltipFg;

	public String rsltCd;	//결과_코드 (출력용)
	public String rsltCntn;	//결과_내용 (출력용)

	public int askUnrcvObjCnt; //대상_건수(내부용, ※ 외부용 : sizeAskUnrcvObjList())
	public int askUnrcvObjIdx; //대상_인덱스(내부용)
	public int bndCnt; //채권_건수(내부용, ※ 외부용 : sizeBndVOList())
	public int bndIdx; //채권_인덱스(내부용)
	public int rmbrPlanCnt; //상환_계획_건수(내부용)
	public int rmbrPlanIdx; //상환_계획_인덱스(내부용)
	public int timsUnrcvCnt; //회차_미수_건수(내부용)
	public int timsUnrcvIdx; //회차_미수_인덱스(내부용)

	public AskUnrcvVO(){
		init();
	}

	/**
	 * <p>메소드명		: getAskUnrcvObj</p>
	 * <p>설    명		: 해당 Index의 청구미수 객체를 리턴</p>
	 * <p>메소드 인수1	: int idx</p>
	 * <p>메소드 리턴값	: AskUnrcvObjVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public AskUnrcvObjVO getAskUnrcvObj(int idx) {
		if (!chkListIdx(askUnrcvObjVOList, idx)) {
			return null;
		}
		return (AskUnrcvObjVO) askUnrcvObjVOList.get(idx);
	}

	public void setAskUnrcvObj(int idx, AskUnrcvObjVO askUnrcvObjVO){
		askUnrcvObjVOList.set(idx, askUnrcvObjVO);
	}

	/**
	 * <p>메소드명		: getAskUnrcvObjList</p>
	 * <p>설    명		: 청구미수 객체 리스트를 리턴</p>
	 * <p>메소드 인수1	: N/A</p>
	 * <p>메소드 리턴값	: List askUnrcvObjVOList</p>
	 * <p>예외처리		: N/A</p>
	 */
	public List getAskUnrcvObjList(){
		return askUnrcvObjVOList;
	}

	/**
	 * @deprecated 사용하지 말것!!
	 *
	 * <p>메소드명		: getAskUnrcvObjList</p>
	 * <p>설    명		: 청구미수 객체 리스트를 Set</p>
	 * <p>메소드 인수1	: List askUnrcvObjVOList</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Deprecated
	public void setAskUnrcvObjList(List inList){
		askUnrcvObjVOList = inList;
	}

	/**
	 * <p>메소드명		: askUnrcvObjVOList</p>
	 * <p>설    명		: 청구미수대상 객체 add</p>
	 * <p>메소드 인수1	: Object</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void addAskUnrcvObj(Object obj){
		askUnrcvObjVOList.add(obj);
		if( obj != null ){
			if( obj instanceof AskUnrcvObjVO){
				AskUnrcvObjVO tmp = (AskUnrcvObjVO)obj;
				if( !StringUtil  .isNull(tmp.loanNo) && !StringUtil.isNull(tmp.loanSeq)){
					askUnrcvObjVOMap.put(tmp.loanNo + tmp.loanSeq, tmp);
				}
			}
		}
	}

	/**
	 * <p>메소드명		: sizeAskUnrcvObjList</p>
	 * <p>설    명		: 청구미수대상 List size</p>
	 * <p>메소드 인수1	: N/A</p>
	 * <p>메소드 리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public int sizeAskUnrcvObjList(){
		return sizeList(askUnrcvObjVOList);
	}

	/**
	 * @deprecated 요청리스트와 싱크가 맞지 않아서 사용하지 말것!
	 * <p>메소드명		: sortAskUnrcvObj</p>
	 * <p>설    명		: 청구미수대상 List sort</p>
	 * <p>메소드 인수1	: N/A</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Deprecated
	public void sortAskUnrcvObj(){
		Collections.sort(askUnrcvObjVOList);
	}

	/**
	 * <p>메소드명		: getAskUnrcvObj</p>
	 * <p>설    명		: 대출번호,순번에 해당하는 청구미수객채 리턴</p>
	 * <p>메소드 인수1	: String inLoanNo</p>
	 * <p>메소드 인수2	: String inLoanSeq</p>
	 * <p>메소드 리턴값	: AskUnrcvObjVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public AskUnrcvObjVO getAskUnrcvObj(String inLoanNo, String inLoanSeq) {
		if( askUnrcvObjVOMap == null ){
			return null;
		}
		return askUnrcvObjVOMap.get(inLoanNo + inLoanSeq);
	}


	/**
	 * <p>메소드명		: indexOfAskObj</p>
	 * <p>설    명		: 대출번호,순번에 해당하는 청구미수객채의 Index를 리턴</p>
	 * <p>메소드 인수1	: String inLoanNo</p>
	 * <p>메소드 인수2	: String inLoanSeq</p>
	 * <p>메소드 리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public int indexOfAskObj(String inLoanNo, String inLoanSeq ){
		AskUnrcvObjVO keyObj = new AskUnrcvObjVO();
			keyObj.loanNo = inLoanNo;
			keyObj.loanSeq = inLoanSeq;
		return  Collections.binarySearch(askUnrcvObjVOList, keyObj);
	}


	/**
	 * <p>메소드명		: addBndVO</p>
	 * <p>설    명		: 청구미수 채권객채 add</p>
	 * <p>메소드 인수1	: Object</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void addBndVO(Object obj ){
		bndVOList.add(obj);
		if( obj != null ){
			if( obj instanceof BndVO){
				BndVO tmp = (BndVO)obj;
				if( !StringUtil.isNull(tmp.loanNo) && !StringUtil.isNull(tmp.loanSeq)){
					bndVOMap.put(tmp.loanNo + tmp.loanSeq, tmp);
				}
			}
		}
	}

	/**
	 * <p>메소드명		: getBndVO</p>
	 * <p>설    명		: 해당 Index의 채권객채 리턴</p>
	 * <p>메소드 인수1	: Object</p>
	 * <p>메소드 리턴값	: BndVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public BndVO getBndVO(int idx){
		if (!chkListIdx(bndVOList, idx)) {
			return null;
		}
		return (BndVO) bndVOList.get(idx);
	}

	public void setBndVOList(int idx, BndVO bndVO){
		bndVOList.set(idx, bndVO);
	}


	/**
	 * <p>메소드명		: getBndVOList</p>
	 * <p>설    명		: 채권객채리스트 리턴</p>
	 * <p>메소드 인수1	: N/A</p>
	 * <p>메소드 리턴값	: List bndVOList</p>
	 * <p>예외처리		: N/A</p>
	 */
	public List getBndVOList(){
		return bndVOList;
	}

	/**
	 * <p>메소드명		: setBndVOList</p>
	 * <p>설    명		: 채권객채리스트 Set</p>
	 * <p>메소드 인수1	: N/A</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void setBndVOList(List inList){
		bndVOList = inList;
	}

	/**
	 * <p>메소드명		: sizeBndVOList</p>
	 * <p>설명			: 채권객채리스트 size</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public int sizeBndVOList(){
		return sizeList(bndVOList);
	}

	/**
	 * <p>메소드명		: sortBndVO</p>
	 * <p>설    명		: 채권객채리스트 sort</p>
	 * <p>메소드 인수1	: N/A</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void sortBndVO(){
		Collections.sort(bndVOList);
	}

	/**
	 * <p>메소드명		: getBndVO</p>
	 * <p>설    명		: 대출번호,순번에 해당하는  채권객채 리턴</p>
	 * <p>메소드 인수1	: String inLoanNo</p>
	 * <p>메소드 인수2	: String inLoanSeq</p>
	 * <p>메소드 리턴값	: BndVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public BndVO getBndVO(String inLoanNo, String inLoanSeq) {
		if( bndVOMap == null ){
			return null;
		}
		return bndVOMap.get(inLoanNo + inLoanSeq);
	}

	/**
	 * <p>메소드명		: getBndVO</p>
	 * <p>설    명		: 청구미수객체에 해당하는 채권객체 리턴(대출번호,순번으로 매핑)</p>
	 * <p>메소드 인수1	: AskUnrcvObjVO</p>
	 * <p>메소드 리턴값	: BndVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public BndVO getBndVO(AskUnrcvObjVO objVO){
		if(objVO==null){
			return null;
		}
		return getBndVO(objVO.loanNo, objVO.loanSeq);
	}

	/**
	 * <p>메소드명		: indexOfBndVO</p>
	 * <p>설명			: 대출번호,순번에 해당하는 채권객체리스트의 Index리턴</p>
	 * <p>메소드인수1	: String inLoanNo</p>
	 * <p>메소드인수2	: String inLoanSeq</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public int indexOfBndVO(String inLoanNo, String inLoanSeq) {
		BndVO keyBndVO = new BndVO();
		keyBndVO.loanNo = inLoanNo;
		keyBndVO.loanSeq = inLoanSeq;
		return  Collections.binarySearch(bndVOList, keyBndVO);
	}

	/**
	 * <p>메소드명		: getTimsUnrcv</p>
	 * <p>설명			: Index에 해당하는 회차미수객체 리턴</p>
	 * <p>메소드인수1	: int idx</p>
	 * <p>메소드리턴값	: TimsUnrcvVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public TimsUnrcvVO getTimsUnrcv(int idx) {
		if( !chkListIdx(timsUnrcvVOList, idx)) {
			return null;
		}
		return (TimsUnrcvVO) timsUnrcvVOList.get(idx);
	}

	/**
	 * <p>메소드명		: getTimsUnrcvList</p>
	 * <p>설명			: 회차미수객체 리스트 리턴</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: List timsUnrcvVOList</p>
	 * <p>예외처리		: N/A</p>
	 */
	public List getTimsUnrcvList(){
		return timsUnrcvVOList;
	}

	/**
	 * <p>메소드명		: setTimsUnrcvList</p>
	 * <p>설명			: 회차미수객체 리스트 Set</p>
	 * <p>메소드인수1	: List timsUnrcvVOList</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void setTimsUnrcvList( List inList){
		timsUnrcvVOList = inList;
	}

	/**
	 * <p>메소드명		: addTimsUnrcv</p>
	 * <p>설명			: 회차미수객체 add</p>
	 * <p>메소드인수1	: Object</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void addTimsUnrcv(Object obj) {
		timsUnrcvCnt++;
		timsUnrcvIdx++;
		timsUnrcvVOList.add(obj);
	}

	/**
	 * <p>메소드명		: addRmbrPlan</p>
	 * <p>설명			: 상환계획객체 add/p>
	 * <p>메소드인수1	: Object</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void addRmbrPlan(Object obj) {
		rmbrPlanCnt++;
		rmbrPlanIdx++;
		rmbrPlanVOList.add(obj);
	}

	/**
	 * <p>메소드명		: addDlyCalc</p>
	 * <p>설명			: 연체계산객체 add/p>
	 * <p>메소드인수1	: Object</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void addDlyCalc(Object obj) {
		dlyCalcVOList.add(obj);
	}

	/**
	 * <p>메소드명		: getRmbrPlan</p>
	 * <p>설명			: index에 해당하는 상환계획객체 리턴</p>
	 * <p>메소드인수1	: int idx</p>
	 * <p>메소드리턴값	: RmbrPlanVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public RmbrPlanVO getRmbrPlan(int idx){
		if (!chkListIdx(rmbrPlanVOList, idx)) {
			return null;
		}
		return (RmbrPlanVO) rmbrPlanVOList.get(idx);
	}

	/**
	 * <p>메소드명		: getDlyCalc</p>
	 * <p>설명			: index에 해당하는 연체계산객체 리턴</p>
	 * <p>메소드인수1	: int idx</p>
	 * <p>메소드리턴값	: DlyCalcVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public DlyCalcVO getDlyCalc(int idx) {
		if( !chkListIdx(dlyCalcVOList, idx)) {
			return null;
		}
		return (DlyCalcVO) dlyCalcVOList.get(idx);
	}

	/**
	 * <p>메소드명		: init</p>
	 * <p>설명			: 청구미수 초기화</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void init(){
		this.askUnrcvObjVOList = initList(this.askUnrcvObjVOList);
		this.askUnrcvObjVOMap = new HashMap<>();
		this.timsUnrcvVOList = initList(this.timsUnrcvVOList);
		this.bndVOList = initList(this.bndVOList);
		this.bndVOMap = new HashMap<>();
		this.rmbrPlanVOList = initList(this.rmbrPlanVOList);
		this.dlyCalcVOList = initList(this.dlyCalcVOList);

		isrtDt = StringUtils.EMPTY;
		askUnrcvObjCnt = 0; //대상_건수
		askUnrcvObjIdx = -1; //대상_인덱스
		bndCnt = 0; //채권_건수
		bndIdx = -1; //채권_\인덱스
		rmbrPlanCnt = 0; //상환_계획_건수
		rmbrPlanIdx = -1; //상환_계획_인덱스
		timsUnrcvCnt = 0; //회차_미수_건수
		timsUnrcvIdx = -1; //회차_미수_인덱스

		midRmbrUnCalcFg = "0";
		bkrpExemCalcFg = "0";
		tooltipFg ="0";
		rsltCd = "0000"; //결과_코드
		rsltCntn = StringUtils.EMPTY; //결과_내용
	}

	/**
	 * <p>메소드명		: initList</p>
	 * <p>설명			: List 초기화</p>
	 * <p>메소드인수1	: List</p>
	 * <p>메소드리턴값	: List</p>
	 * <p>예외처리		: N/A</p>
	 */
	private List initList(List inList){
		if(inList==null){
			inList = new ArrayList();
		} else {
			inList.clear();
		}
		return inList;
	}

	/**
	 * <p>메소드명		: sizeList</p>
	 * <p>설명			: List size</p>
	 * <p>메소드인수1	: List</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	private int sizeList(List inList){
		if(inList == null){
			return 0;
		}
		return inList.size();
	}

	/**
	 * <p>메소드명		: chkListIdx</p>
	 * <p>설명			: List에 해당 인덱스가 존재하는지 체크</p>
	 * <p>메소드인수1	: List</p>
	 * <p>메소드인수2	: int idx</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	private boolean chkListIdx(List inList, int idx) {
		if (idx<0) {
			return false;
		}
		return sizeList(inList)>idx;
	}

	/**
	 * <p>메소드명		: isSuccess</p>
	 * <p>설명			: 결과코드 성공여부 리턴</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public boolean isSuccess() {
		return "0000".equals(rsltCd);
	}

	/**
	 * <p>메소드명		: toString</p>
	 * <p>설명			: toString</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public String toString(){
		StringBuffer buff = new StringBuffer(100); //default

		buff.append( this.getClass().getName() );
		buff.append(" [");
		buff.append(this.hashCode());
		buff.append(']');
		buff.append("\n{\n" );

		appendAttrbute(buff, "rsltCD", rsltCd );
		appendAttrbute(buff, "rsltCntn", rsltCntn );

		if (sizeList(askUnrcvObjVOList) < 100) { //100개이하일때만
			appendList(buff, "1) 요청대상리스트 ", askUnrcvObjVOList);
			appendList(buff, "2) 상환계획 리스트 ", rmbrPlanVOList);
			appendList(buff, "3) 채권 리스트  ", bndVOList);
			appendList(buff, "4) 회차미수 리스트 ", timsUnrcvVOList);
		}

		buff.append("}\n" );
		return buff.toString();
	}

	private void appendIntend(StringBuffer buff, Object cntn , int intend  ){
		for(int i=0; i < intend; i++){
			buff.append("\t");
		}
		buff.append(cntn);
	}
	private void appendList( StringBuffer buff, String title, List list){
		appendIntend( buff, title , 1);
		buff.append("(건수:").append( list.size()).append(')').append("\n");
		for(int i=0,n=list.size(); i < n; i++){
			appendIntend( buff, '[' + String.valueOf(i) + ']' + list.get(i) , 1);
			buff.append("\n");
		}
	}
	private void appendAttrbute(StringBuffer buff, String name, String cntn ){
		appendIntend( buff, name, 1);
		buff.append(" = |");
		buff.append(cntn);
		buff.append("|\n");
	}
	public void free() {
		if(rmbrPlanVOList!=null)rmbrPlanVOList.clear();
		if(dlyCalcVOList!=null)dlyCalcVOList.clear();
		rmbrPlanVOList = null;
		dlyCalcVOList = null;
	}

	public boolean isTooltipShow(){
		return AskUnrcvConst.YES.equals(this.tooltipFg);
	}

}
