package hanalife.r.co.la.service.impl;



import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.dto.RtAutoTranTrDescDTO;
import hanalife.c.co.mapper.dto.RtDlvrDescDTO;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.util.StringUtil;
import hanalife.r.at.at.mapper.dto.PreSetlSDDODTO;
import hanalife.r.at.at.service.AutoTranService;
import hanalife.r.at.at.vo.PreSetlSDDOOUTVO;
import hanalife.r.at.at.vo.PreSetlSDDOVO;
import hanalife.r.co.la.service.LoanInfoProcMngService;
import hanalife.r.co.la.vo.LoanInfoProcMngInVO;
import hanalife.r.co.la.vo.LoanInfoProcMngObjVO;
import hanalife.r.co.la.vo.LoanInfoProcMngOutVO;
import hanalife.r.dl.dl.service.DlvrService;
import hanalife.r.rc.rc.service.RcptDAOService;
import hanalife.r.rc.rc.vo.RcptDAOS01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : LoanInfoProcMngImpl.java Class
 * 클래스설명   : 수납관리 대출정보  (LoanInfoProcMng) Service Implements
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70322 ][최초작성-수납내역상세조회에서 대출정보를 조회(getLoanInfo 에서 searchLoanInfo)하는 부분만 작업]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getLoanInfo : 대출정보 목록조회
 * </pre>
 */
@Service("LoanInfoProcMngService")
public class LoanInfoProcMngServiceImpl implements LoanInfoProcMngService {

	private static final Logger LOGGER = LoggerFactory.getLogger(LoanInfoProcMngServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

	@Autowired
	private RcptDAOService rcptDAO; // 해당 부분은 RcptDAOService 구현시 주석 해제

	@Autowired
	private AutoTranService autoTran;

	@Autowired
	private DlvrService dlvrService;

//	@Autowired
//    private RcptMapper  rcptMapper;

//    @Autowired
//    private AutoTranMapper autoTranMapper;

//    @Autowired
//    private DlvrMapper  dlvrMapper;

    //사용 BC
//    private final String LOAN_BC = "com.dobscap.r.rc.rc.dao.RcptDAOImpl";
//    private final String ATTR_BC = "com.dobscap.r.at.at.dao.AutoTranDAOImpl";
//    private final String DLVR_BC = "com.dobscap.r.dl.dl.dao.DlvrDAOImpl";

    //요청, 응답 Dataset명
//    private final String DS_LOANINFO = "DS_LOANINFO";   //대출정보
//    private final String DS_PRESETL  = "DS_PRESETL";    //선결제정보
//    private final String DS_MID_RMBR_FEE_RT = "DS_MID_RMBR_FEE_RT";     //중도수수료율구간정보
//    private final String DS_DFEE_RT         = "DS_DFEE_RT";             //연체료율구간정보
//    private final String DS_POPUP_SD        = "DS_POPUP_SD";            //연체료율계산정보

//	@Override
//    public LoanInfoProcMngOutVO getLoanInfo(String loanNo, String loanSeq) throws Exception {
//        return this.getLoanInfo(loanNo, loanSeq, RUtil.getKSTDate());
//    }

    /*
       ### 대출정보 ###
      Input Param  : loan_no  -> 필수
                     loan_seq -> Option (없을 경우 null)
                     Itransaction -> 필수
      Output Param : Dataset
     */
//    public Dataset getPreSetl(String loanNo, String loanSeq, ITransaction tx) throws DAOException {
//        AbstractDAO bc = factory.getDAO(ATTR_BC);
//        Dataset outDs = null;
//
//        RtAutoTranTrDescTDO attrDescVO = new RtAutoTranTrDescTDO();
//            attrDescVO.setLoanNo(loanNo);
//            attrDescVO.setLoanSeq(loanSeq);
//
//        PagedArrayList doList = ((AutoTranDAO) bc).searchAutoTranTrForSetl(attrDescVO, tx);
//        if (RUtil.size(doList)>0) {
//            outDs = SdoFactory.getDataset(PreSetlSDDO.class, DS_PRESETL);
//
//            for (int i = 0; i < doList.size(); i++) {
//                outDs.appendRow(); //row 증가
//                LoanInfoProcConverter.convertPreSetlToSDDO((String[]) doList.get(i), new WrcDatasetWrapper(outDs, i));
//            }
//        }
//        return outDs;
//    }

    @Override
	public LoanInfoProcMngOutVO getLoanInfo(LoanInfoProcMngInVO inVo) throws Exception{

    	LoanInfoProcMngOutVO outDs = new LoanInfoProcMngOutVO();
    	//대출 정보를 조회한다.
    	StLoanBaseDTO loanBaseTDO = new StLoanBaseDTO();
    		loanBaseTDO.setLoanNo(inVo.getLoanNo());
    		loanBaseTDO.setLoanSeq(StringUtil.trimToNull(inVo.getLoanSeq()));
    	if (StringUtil.isNull(inVo.getLoanSeq())) {
    		loanBaseTDO.setLoanLastFg("1");
    	}

    	RcptDAOS01OutVO resultVo = null;
    	// 조회
		try {
			resultVo = rcptDAO.searchLoanInfo(loanBaseTDO);
			LOGGER.info("resultVo : " + resultVo.getListRcptDAODSLOANINFOVO().get(0).getContManNo());
			LOGGER.info("dueMethNm : " + resultVo.getListRcptDAODSLOANINFOVO().get(0).getDueMethNm());
			LOGGER.info("askMethNm : " + resultVo.getListRcptDAODSLOANINFOVO().get(0).getAskMethNm());
		} catch (Exception e) {
			LOGGER.error("대출 정보 조회 중 에러");
		}

    	if (resultVo == null) {
    		return null; //대출정보가 없습니다.
    	}

    	//대출_순번을 조회결과에서 얻는다.
    	inVo.setLoanSeq(resultVo.getListRcptDAODSLOANINFOVO().get(0).getLoanSeq());

    	//자동이체청구 정보를 조회한다.
    	RtAutoTranTrDescDTO inTDO = new RtAutoTranTrDescDTO();
    		inTDO.setLoanNo(inVo.getLoanNo());
    		inTDO.setLoanSeq(inVo.getLoanSeq());
    		inTDO.setAskDivCd("00");

    	RtAutoTranTrDescDTO outTDO = new RtAutoTranTrDescDTO();
        // 자동이체청구정보 조회
    	try {
    		outTDO = autoTran.searchAutoTranTrForLoan(inTDO);
    		LOGGER.debug("자동이체청구정보 조회 완료");
    	} catch (Exception e) {
    		LOGGER.error("자동이체청구정보 조회 중 에러");
    	}

    	// 발송안내 정보를 조회한다.
		RtDlvrDescDTO searchDO = new RtDlvrDescDTO();
			searchDO.setLoanNo(inVo.getLoanNo());
			searchDO.setLoanSeq(inVo.getLoanSeq());

		RtDlvrDescDTO guidInfo = new RtDlvrDescDTO();
		try {
			guidInfo = dlvrService.searchForLoan(searchDO);
			LOGGER.debug("발송안내 정보 조회 완료");
		} catch (Exception e) {
			LOGGER.error("발송안내 정보 조회 중 에러");
		}

    	 /** DS_SM에 세팅할 대출정보 세팅 */
    	LoanInfoProcMngObjVO targetIO = new LoanInfoProcMngObjVO();
    	targetIO = this.convertLoanInfo(resultVo,outTDO,guidInfo);

      	List<LoanInfoProcMngObjVO> resultList = new ArrayList<LoanInfoProcMngObjVO>();

    	resultList.add(targetIO);

    	outDs.setListLoanInfoProcMngObjVO(resultList);

    	return outDs;
    }

    // 아웃풋값 조립
    private LoanInfoProcMngObjVO convertLoanInfo(RcptDAOS01OutVO loan, RtAutoTranTrDescDTO autoTranAsk, RtDlvrDescDTO guidInfo){

    	LoanInfoProcMngObjVO result = new LoanInfoProcMngObjVO();

    	// 대출정보 세팅
    	result.setLoanNo        (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanNo        ());
    	result.setLoanSeq       (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanSeq       ());
    	result.setContManNo     (loan.getListRcptDAODSLOANINFOVO().get(0).getContManNo     ());
    	result.setCustNm        (loan.getListRcptDAODSLOANINFOVO().get(0).getCustNm        ());
    	result.setRlDueManNo    (loan.getListRcptDAODSLOANINFOVO().get(0).getRlDueManNo    ());
    	result.setRlDueManNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getRlDueManNm    ());
    	result.setPrdtLrgeClasCd(loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtLrgeClasCd());
    	result.setPrdtLrgeClasNm(loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtLrgeClasNm());
    	result.setPrdtMidClasCd (loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtMidClasCd ());
    	result.setPrdtMidClasNm (loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtMidClasNm ());
    	result.setPrdtSmClasCd  (loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtSmClasCd  ());
    	result.setPrdtSmClasNm  (loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtSmClasNm  ());
    	result.setRmbrFrmlNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getRmbrFrmlNm    ());
    	result.setAcctUnitCd    (loan.getListRcptDAODSLOANINFOVO().get(0).getAcctUnitCd    ());
    	result.setAcctUnitNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getAcctUnitNm    ());
    	result.setMngDeptCd     (loan.getListRcptDAODSLOANINFOVO().get(0).getMngDeptCd     ());
    	result.setMngDeptNm     (loan.getListRcptDAODSLOANINFOVO().get(0).getMngDeptNm     ());
    	result.setMrtgSmClasNm  (loan.getListRcptDAODSLOANINFOVO().get(0).getMrtgSmClasNm  ());
    	result.setLoanStatCd    (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanStatCd    ());
    	result.setLoanStatNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanStatNm    ());
    	result.setBndStatCd     (loan.getListRcptDAODSLOANINFOVO().get(0).getBndStatCd     ());
    	result.setBndStatNm     (loan.getListRcptDAODSLOANINFOVO().get(0).getBndStatNm     ());
    	result.setSetlBankCd    (loan.getListRcptDAODSLOANINFOVO().get(0).getSetlBankCd    ());
    	result.setSetlBankNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getSetlBankNm    ());
    	result.setSetlAcntNo    (loan.getListRcptDAODSLOANINFOVO().get(0).getSetlAcntNo    ());
    	result.setSetlAcntDisp  (loan.getListRcptDAODSLOANINFOVO().get(0).getSetlAcntDisp  ());
    	result.setAcntStatNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getAcntStatNm    ());
    	result.setAutoTranAplyDt(loan.getListRcptDAODSLOANINFOVO().get(0).getAutoTranAplyDt());
    	result.setImgAcntNo     (loan.getListRcptDAODSLOANINFOVO().get(0).getImgAcntNo     ());
    	result.setImgAcntBankCd (loan.getListRcptDAODSLOANINFOVO().get(0).getImgAcntBankCd ());
    	result.setImgAcntBankNm (loan.getListRcptDAODSLOANINFOVO().get(0).getImgAcntBankNm ());
    	result.setLoanTerm      (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanTerm      ());
    	//result.setLoanMmPiamt   (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanMmPiamt   ());
    	result.setLoanPamt      (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanPamt      ());
    	result.setLoanInt       (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanInt       ());
    	//result.setRmbrMmPamt    (loan.getListRcptDAODSLOANINFOVO().get(0).getRmbrMmPamt    ());
    	result.setRmbrPamt      (loan.getListRcptDAODSLOANINFOVO().get(0).getRmbrPamt      ());
    	result.setRmbrInt       (loan.getListRcptDAODSLOANINFOVO().get(0).getRmbrInt       ());
    	result.setRmbrDfee      (loan.getListRcptDAODSLOANINFOVO().get(0).getRmbrDfee      ());
    	result.setLoanRamt      (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanRamt      ());
    	result.setLoanPamtRamt  (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanPamtRamt  ());
    	result.setLoanIntRamt   (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanIntRamt   ());
    	result.setSetlNo        (loan.getListRcptDAODSLOANINFOVO().get(0).getSetlNo        ());
    	result.setLoanDt        (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanDt        ());
    	result.setEprtDt        (loan.getListRcptDAODSLOANINFOVO().get(0).getEprtDt        ());
    	result.setEndDt         (loan.getListRcptDAODSLOANINFOVO().get(0).getEndDt         ());
    	result.setDeliDt        (loan.getListRcptDAODSLOANINFOVO().get(0).getDeliDt        ());
    	result.setFcntDueDt     (loan.getListRcptDAODSLOANINFOVO().get(0).getFcntDueDt     ());
    	result.setLoanIntRt     (loan.getListRcptDAODSLOANINFOVO().get(0).getLoanIntRt     ());
    	result.setDfeeRt        (loan.getListRcptDAODSLOANINFOVO().get(0).getDfeeRt        ());
    	result.setTrtFeeRt      (loan.getListRcptDAODSLOANINFOVO().get(0).getTrtFeeRt         ());
    	result.setMidRmbrFeeRt  (loan.getListRcptDAODSLOANINFOVO().get(0).getMidRmbrFeeRt     ());
    	result.setContCnt       (loan.getListRcptDAODSLOANINFOVO().get(0).getContCnt          ());
    	result.setGuarCnt       (loan.getListRcptDAODSLOANINFOVO().get(0).getGuarCnt          ());
    	result.setAskMethCd     (loan.getListRcptDAODSLOANINFOVO().get(0).getAskMethCd        ());
    	result.setAskMethNm     (loan.getListRcptDAODSLOANINFOVO().get(0).getAskMethNm        ());
    	result.setDueMethCd     (loan.getListRcptDAODSLOANINFOVO().get(0).getDueMethCd        ());
    	result.setDueMethNm     (loan.getListRcptDAODSLOANINFOVO().get(0).getDueMethNm        ());
    	result.setSetlDd        (loan.getListRcptDAODSLOANINFOVO().get(0).getSetlDd           ());
    	result.setRcntSetlDt    (loan.getListRcptDAODSLOANINFOVO().get(0).getRcntSetlDt       ());
    	result.setDlvrThngCd    (loan.getListRcptDAODSLOANINFOVO().get(0).getDlvrThngCd       ());
    	result.setDlvrThngNm    (loan.getListRcptDAODSLOANINFOVO().get(0).getDlvrThngNm       ());
    	result.setDlvrDt        (loan.getListRcptDAODSLOANINFOVO().get(0).getDlvrDt           ());
    	result.setGuidDueDt     (loan.getListRcptDAODSLOANINFOVO().get(0).getGuidDueDt        ());
    	result.setOffcNm        (loan.getListRcptDAODSLOANINFOVO().get(0).getOffcNm           ());
    	result.setCntcTel1      (loan.getListRcptDAODSLOANINFOVO().get(0).getCntcTel1         ());
    	result.setCntcTel2      (loan.getListRcptDAODSLOANINFOVO().get(0).getCntcTel2         ());
    	result.setCntcTel3      (loan.getListRcptDAODSLOANINFOVO().get(0).getCntcTel3         ());
    	result.setAddr          (loan.getListRcptDAODSLOANINFOVO().get(0).getAddr             ());
    	result.setDepsRamt      (loan.getListRcptDAODSLOANINFOVO().get(0).getDepsRamt         ());
    	result.setPrdtCd        (loan.getListRcptDAODSLOANINFOVO().get(0).getPrdtCd           ());
    	result.setTermIntCalcFg (loan.getListRcptDAODSLOANINFOVO().get(0).getTermIntCalcFg    ());
    	result.setAddTermInt    (loan.getListRcptDAODSLOANINFOVO().get(0).getAddTermInt       ());
    	result.setGodsNm        (loan.getListRcptDAODSLOANINFOVO().get(0).getGodsNm           ());
    	result.setGodsCd        (loan.getListRcptDAODSLOANINFOVO().get(0).getGodsCd           ());
    	result.setGodsQty       (loan.getListRcptDAODSLOANINFOVO().get(0).getGodsQty          ());
    	result.setDocKeepPlcNo  (loan.getListRcptDAODSLOANINFOVO().get(0).getDocKeepPlcNo     ());

    	// 자동이체청구정보
    	result.setAskDt         (autoTranAsk.getAskDt());
    	result.setAskAmt        (autoTranAsk.getAskAmt());
    	LOGGER.info("" +  result);

    	// 발송물정보
    	result.setDlvrThngCd(guidInfo.getDlvrThngCd());
    	result.setDlvrThngNm(guidInfo.getDlvrThngNm());
    	result.setDlvrDt(guidInfo.getDlvrDt());
    	result.setGuidDueDt(guidInfo.getGuidDueDt());

    	return result;

    }

	@Override
	public PreSetlSDDOOUTVO getPreSetl(LoanInfoProcMngInVO inVO) throws Exception {

		PreSetlSDDOOUTVO outDs = new PreSetlSDDOOUTVO();
    	//대출 정보를 조회한다.
		RtAutoTranTrDescDTO attrDescVO = new RtAutoTranTrDescDTO();
			attrDescVO.setLoanNo(inVO.getLoanNo());
			attrDescVO.setLoanSeq(inVO.getLoanSeq());

    	PreSetlSDDODTO outTDO = new PreSetlSDDODTO();

        // 자동이체청구정보 조회
    	try {
    		outTDO = autoTran.searchAutoTranTrForSetl(attrDescVO);
    	} catch (Exception e) {
    		LOGGER.error("자동이체청구정보 조회 중 에러");
    	}

    	if(outTDO != null) {
    		/** DS_SM에 세팅할 대출정보 세팅 */
    		PreSetlSDDOVO targetIO = new PreSetlSDDOVO();
        	targetIO = this.convertAutoTran(outTDO);

          	List<PreSetlSDDOVO> resultList = new ArrayList<PreSetlSDDOVO>();

        	resultList.add(targetIO);

        	outDs.setPreSetlSDDOVO(resultList);

    	}

		return outDs;
	}
	 // 아웃풋값 조립
    private PreSetlSDDOVO convertAutoTran(PreSetlSDDODTO inVo){

    	PreSetlSDDOVO result = new PreSetlSDDOVO();

    	// 대출정보 세팅
    	result.setRcptTpCd  (inVo.getRcptTpCd  ());
    	result.setRcptTpNm  (inVo.getRcptTpNm  ());
    	result.setRlDueDt   (inVo.getRlDueDt   ());
    	result.setAcctDt    (inVo.getAcctDt    ());
    	result.setSetlAmt   (inVo.getSetlAmt   ());
    	result.setBankCd    (inVo.getBankCd    ());
    	result.setAcntNo    (inVo.getAcntNo    ());
    	result.setIsrtDeptCd(inVo.getIsrtDeptCd());
    	result.setTrOrgCd   (inVo.getTrOrgCd   ());
    	result.setGiroDivCd (inVo.getGiroDivCd ());
    	result.setGiroSnum  (inVo.getGiroSnum  ());
    	result.setAcctUnitCd(inVo.getAcctUnitCd());

    	return result;
    }
}
