package hanalife.r.co.rc.service;

import java.util.List;

import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.IamtUnrcvVO;
import hanalife.r.co.rc.vo.RcptBaseVO;

/**
 * <pre>
 * 클래스명    : IamtUnrcvService
 * 클래스설명  : 입금미수Service
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 27.
 * 작성자명    : 70279 / jung
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 27.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public interface IamtUnrcvService {

	/**
	 * <p>메소드명	: procRcpt</p>
	 * <p>설　　명	: 수납처리(원리금/중도상환 수납, 예가수정산, 예가수발생 처리 등)</p>
	 * <p>메소드인수	: IamtUnrcvVO, AskUnrcvVO</p>
	 * <p>리　턴　값	: IamtUnrcvVO</p>
	 */
	public IamtUnrcvVO procRcpt(IamtUnrcvVO iamtUnrcvVO, AskUnrcvVO askUnrcvVO);

	/**
	 * <p>메소드명	: procLtrmBrcvAmt</p>
	 * <p>설　　명	: 장기선수금수납</p>
	 * <p>메소드인수	: IamtUnrcvVO, AskUnrcvVO</p>
	 * <p>리　턴　값	: IamtUnrcvVO</p>
	 */
	public IamtUnrcvVO procLtrmBrcvAmt(IamtUnrcvVO iamtUnrcvVO, AskUnrcvVO askUnrcvVO) throws Exception;

	/**
	 * <p>메소드명	: procRcptDsrcAdj</p>
	 * <p>설　　명	: 예가수 정산처리 - 예가수정산(02), 잡수익(03), 환불(04), 대출번호수정(21), 정산점변경(22) 일때 처리한다.
	 * <p>메소드인수	: IamtUnrcvVO, AskUnrcvVO</p>
	 * <p>리　턴　값	: IamtUnrcvVO</p>
	 */
	public IamtUnrcvVO procRcptDsrcAdj(IamtUnrcvVO iamtUnrcvVO, AskUnrcvVO askUnrcvVO);

	/**
	 * <p>메소드명	: calcRcptDsrcAdj</p>
	 * <p>설　　명	: 예가수 정산처리 (환불,잡수익 등 일반예가수 정산 외)</p>
	 * <p>메소드인수	: IamtUnrcvVO, AskUnrcvVO</p>
	 * <p>리　턴　값	: IamtUnrcvVO</p>
	 */
	public IamtUnrcvVO calcRcptDsrcAdj(IamtUnrcvVO iamtUnrcvVO, AskUnrcvVO askUrcvVO) throws Exception;

	/**
	 * <p>메소드명	: procRcptCncl</p>
	 * <p>설　　명	: 수납취소 처리(취소는 한건씩만 가능)</p>
	 * <p>메소드인수	: IamtUnrcvVO</p>
	 * <p>리　턴　값	: IamtUnrcvVO</p>
	 */
	public IamtUnrcvVO procRcptCncl(IamtUnrcvVO iamtUnrcvVO);

	/**
	 * <p>메소드명	: getRcptBase</p>
	 * <p>설　　명	: 수납정보를 구성한다.</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, BndVO</p>
	 * <p>리　턴　값	: RcptBaseVO</p>
	 */
	public RcptBaseVO getRcptBase(IamtUnrcvObjVO iamtUnrcvObjVO, BndVO bndVO);

	/**
	 * <p>메소드명	: getVochNo</p>
	 * <p>설　　명	: 거래내역구성</P>
	 * <p>메소드인수	: IamtUnrcvVO, iamtUnrcvObjList, rcptBaseList</p>
	 * <p>리　턴　값	: int</p>
	 */
	public int procTrDesc(IamtUnrcvVO iamtUnrcvVO, List iamtUnrcvObjList, List rcptBaseList);

	/**
	 * <p>메소드명	: procTrDesc</p>
	 * <p>설　　명	: 거래내역구성</P>
	 * <p>메소드인수	: autoSetlFg, tranUnprocFg, iamtUnrcvObjList, rcptBaseList</p>
	 * <p>리　턴　값	: vochNo</p>
	 */
	public int procTrDesc(String autoSetlFg, String tranUnprocFg, List iamtUnrcvObjList, List rcptBaseList);

	/**
	 * <p>메소드명	: procTrDesc</p>
	 * <p>설　　명	: 거래내역구성</P>
	 * <p>메소드인수	: autoSetlFg, iamtUnrcvObjList, rcptBaseList</p>
	 * <p>리　턴　값	: vochNo</p>
	 */
	public int procTrDesc(String autoSetlFg, List iamtUnrcvObjList, List rcptBaseList);

	/**
	 * <p>메소드명	: getTrStagCd</p>
	 * <p>설　　명	: 거래단계코드 얻기</P>
	 * <p>메소드인수	: occrAcctUnitCd, mngAcctUnitCd, isrtDeptCd, mngDeptCd</p>
	 * <p>리　턴　값	: trStagCd</p>
	 */
	public String getTrStagCd(String occrAcctUnitCd, String mngAcctUnitCd, String isrtDeptCd, String mngDeptCd);

	/**
	 * TODO 데이터 변환 완료
	 * <p>메소드명		: procExmp</p>
	 * <p>설    명		: 면제처리</p>
	 * <p>메소드 인수1 	: String procDiv ( "U" 수납, "C" 취소 )</p>
	 * <p>메소드 인수2 	: List iamtUnrcvObjList</p>
	 * <p>메소드 인수3 	: Connection</p>
	 * <p>메소드 리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void procExmp(String procDiv, List iamtUnrcvObjList);

	/**
	 * <p>메소드명	: validAutoTran</p>
	 * <p>설　　명	: 자동이체입금 처리중인지 체크</p>
	 * <p>메소드인수	: IamtUnrcvObjVO, Connection</p>
	 * <p>리 턴 값	: N/A</p>
	 */
	public void validAutoTran(IamtUnrcvObjVO iamtUnrcvObj);
}
