package hanalife.r.co.rc.service.impl;

import java.sql.SQLException;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.RtAutoTranTrDescDTO;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.IsExistAutoTranTrINDTO;
import hanalife.r.co.rc.service.AutoTranTrService;
import hanalife.r.co.rc.vo.AutoTranTrDescVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : AutoTranTrServiceImpl
 * 클래스설명 : 자동이체거래ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 4. 4.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 4.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("AutoTranTrService")
public class AutoTranTrServiceImpl implements AutoTranTrService {

	private static final Logger log = LoggerFactory.getLogger(AutoTranTrServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * (선결제)자동이체거래내역 갱신
	 * !! NOTE 자동이체거래내역 리스트가 있을때 부르는게 좋겠슴.
	 * @param autoTranTrUpdtVOList
	 * @return int
	 * @throws SQLException
	 */
	@Override
	public int updateAutoTranTrDesc(List autoTranTrUpdtVOList) {

		int exeCnt = 0;

		try {
			for (int i = 0; i < autoTranTrUpdtVOList.size(); i++) {
				AutoTranTrDescVO autoTranUptVO = (AutoTranTrDescVO) autoTranTrUpdtVOList.get(i);

				RtAutoTranTrDescDTO inDTO = new RtAutoTranTrDescDTO();

				inDTO.setSetlNo(autoTranUptVO.setlNo);
				inDTO.setLastProcEmpNo(autoTranUptVO.procEmpNo);
				inDTO.setRlDueDt(autoTranUptVO.rlDueDt);
				inDTO.setTrOrgCd(autoTranUptVO.trOrgCd);
				inDTO.setLoanNo(autoTranUptVO.loanNo);
				inDTO.setLoanSeq(autoTranUptVO.loanSeq);

				exeCnt = iamtUnrcvMapper.updateAutoTranTrDescPreSetl(inDTO);

			}
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("자동이체거래내역 갱신실패", se);
			throw new BizException("자동이체거래내역 갱신실패", se);
		}


		return exeCnt;
	}

	/**
	 * 자동이체거래내역 갱신
	 * @param IamtUnrcvObjVO
	 * @return boolean
	 * @throws SQLException
	 */
	@Override
	public boolean chkAutoTranTr(IamtUnrcvObjVO iamtUnrcvObj) {

		boolean bRtn = false;
		try {
			IsExistAutoTranTrINDTO inDTO = new IsExistAutoTranTrINDTO();

			inDTO.setLoanNo(iamtUnrcvObj.loanNo);
			inDTO.setSetlAmt(0);
			inDTO.setSetlNo(0);
			inDTO.setAskStatCd("9");	//청구상태 : 입금
			inDTO.setProcStatCd("1");	//처리상태 : 처리중

			String sExist = iamtUnrcvMapper.getIsExistAutoTranTr(inDTO);

			if(Constants.YES.equals(sExist)) {
				bRtn = true;
			}
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("자동이체거래내역 갱신실패", se);
			throw new BizException("자동이체거래내역 갱신실패", se);
		}
		return bRtn;
	}

}
