package hanalife.r.co.rc.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.RtGiroDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.service.GiroService;
import hanalife.r.co.rc.vo.GiroDescVO;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : AskUnrcvServiceImpl
 * 클래스설명 : 청구미수계산ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 16.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("GiroService")
public class GiroServiceImpl implements GiroService {

	private static final Logger log = LoggerFactory.getLogger(GiroServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	//[지로_내역] 수정
	@Override
	public int updateGiroDesc(List giroDescUptVOList){


		int totCnt = 0;
		try {
			String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
			String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

			GiroDescVO giroDescUptVO = null;
			for (int i = 0, idx = 1, n = giroDescUptVOList.size(); i < n; i++, idx = 1) {

				giroDescUptVO = (GiroDescVO) giroDescUptVOList.get(i);
				RtGiroDescDTO inDTO = new RtGiroDescDTO();

				//set
				inDTO.setSetlNo(giroDescUptVO.setlNo); //예가수_잔액
				inDTO.setLastProcDt(procDt); //최종_처리_일자
				inDTO.setLastProcTm(procTm); //최종_처리_시각
				inDTO.setLastProcEmpNo(procTm); //최종_처리_사원번호
				//where
				inDTO.setTranDt(giroDescUptVO.tranDt);         // 전송_일자
				inDTO.setGiroNo(giroDescUptVO.giroNo);         // 지로_번호
				inDTO.setGiroDivCd(giroDescUptVO.giroDivCd);   // 지로_구분_코드
				inDTO.setGiroSnum(giroDescUptVO.giroSnum);     // 지로_일련번호
				inDTO.setAdjLoanNo(giroDescUptVO.adjLoanNo);   // 대출_번호
				inDTO.setAdjLoanSeq(giroDescUptVO.adjLoanSeq); // 대출_순번

				iamtUnrcvMapper.updateGiroDescPreSetl(inDTO);

				totCnt = totCnt + 1;
			}

		} catch(Exception e) {
			// TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("지로내역 갱신실패", se);
			throw new BizException("지로내역 갱신실패", e);
		}

		return totCnt;
	}

}
