package hanalife.r.co.rc.service.impl;

import java.sql.SQLException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.mapper.dto.StPayFeeClawbkBaseDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.CreatePayFeeClawbkBaseINDTO;
import hanalife.r.co.rc.mapper.dto.LeglActsCostRamtINDTO;
import hanalife.r.co.rc.mapper.dto.SelectOrgINDTO;
import hanalife.r.co.rc.mapper.dto.SelectOrgOUTDTO;
import hanalife.r.co.rc.mapper.dto.UpdateLoanBaseINDTO;
import hanalife.r.co.rc.service.LoanService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.RcptBaseVO;
import hanalife.util.BizException;
import hanalife.util.IamtUtil;



/**
 * <pre>
 * 클래스　명 : LoanServiceImpl
 * 클래스설명 : 입금미수관련 대출정보ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("LoanService")
public class LoanServiceImpl implements LoanService {

	private static final Logger log = LoggerFactory.getLogger(PdueServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * 메소드명		: updateLoanBase
	 * 설명			: 수납결과를 [ST_LOAN_BASE]에 반영
	 * 메소드인수1 	: String cnclFg
	 * 메소드인수2 	: IamtUnrcvObjVO
	 * 메소드인수3 	: RcptBaseVO
	 * 메소드리턴값	: int
	 * 예외처리		: N/A
	 */
	@Override
	public int updateLoanBase(String cnclFg, IamtUnrcvObjVO iamtUnrcvObjVO, RcptBaseVO rcptBaseVO) {


		int exeCnt = 0;

		try {

			UpdateLoanBaseINDTO inDTO = new UpdateLoanBaseINDTO();
			inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);
			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);

			inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
			inDTO.setLastProcDt(DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER));
			inDTO.setLastProcTm(DateUtil.getServerDate(DateUtil.HHMMSS));
			inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
			inDTO.setCnclDiv("1".equals(cnclFg) ? "-1" : "1");

			String endDt      = StringUtil.nvl(iamtUnrcvObjVO.endDt);
			String rsltCnclDt = StringUtil.nvl(iamtUnrcvObjVO.rsltCnclDt);
			String loanStatCd = StringUtil.nvl(iamtUnrcvObjVO.adjLoanStatCd);
			int cpayTims      = iamtUnrcvObjVO.curCpayTims;

			if (cnclFg.equals("1")) {  //취소일때
				loanStatCd = iamtUnrcvObjVO.curLoanStatCd; //현재 대출상태코드

				// 거래의 결제구분 비교를 바꿈
//				if (iamtUnrcvObjVO.setlDivCd.equals( Constants.SETL_DIV_PIAMT ) ||
//						iamtUnrcvObjVO.setlDivCd.equals(Constants.SETL_DIV_MIDRMBR_TAMT)) {
				// 조건 중 중도부분상환포함-연체건 중도부분상환 후 취소 시 대출원장.CPAY_TIMS가 UPDATE되지 않음.
				if (rcptBaseVO.setlDivCd.equals(Constants.SETL_DIV_PIAMT) || IamtUtil.isMidRmbr(rcptBaseVO.setlDivCd)) {
					//강제해지리스채권 추가 2018-08-01
					if (!isLease(iamtUnrcvObjVO.prdtLrgeClasCd) || isIvltClsBnd(iamtUnrcvObjVO)){
						if (StringUtil.in(loanStatCd, new String[]{"31", "32", "3C", "36"})) {
							loanStatCd = iamtUnrcvObjVO.loanStatCd; //원수납할때의 대출상태코드
							endDt = "";
							rsltCnclDt = "";
						}
					}

					//기존수납당시 시작회차 - 1이 원결제할때의 완납회차
					if (iamtUnrcvObjVO.orgRcptStrtTims -1 < 1) {
						cpayTims = 0;
					} else {
						cpayTims = iamtUnrcvObjVO.orgRcptStrtTims -1;
					}
				}

			} else { //입금일때

				if (iamtUnrcvObjVO.cpayTims > 0) {
					cpayTims = iamtUnrcvObjVO.cpayTims;	//완납회차가 존재시 현재완납회차를 변경한다.
				}

				if (StringUtil.in(loanStatCd, new String[]{"31", "32", "3C"})
						&& StringUtil.in(rcptBaseVO.setlDivCd, new String[]{"1", "4"})) { //만료일때
					endDt = iamtUnrcvObjVO.acctDt;
					rsltCnclDt = iamtUnrcvMapper.getSaleRsltDtByLoanNo(endDt);
				}
			}

			String SqlFlg = Constants.NO;
			if(!IamtUtil.isLease(iamtUnrcvObjVO) || IamtUtil.isIvltClsBnd(iamtUnrcvObjVO)) {
				SqlFlg = Constants.YES;
			}

			inDTO.setSqlFlg(SqlFlg);
			inDTO.setLoanStatCd(StringUtil.nvl(loanStatCd));
			inDTO.setEndDt(StringUtil.nvl(endDt));
			inDTO.setCpayTims(StringUtil.nvl(cpayTims+""));
			//영업마감시간 이후의 실적취소에 대한 익일 반영
			inDTO.setRsltCnclDt(StringUtil.nvl(rsltCnclDt));

			exeCnt = iamtUnrcvMapper.getUpdateLoanBase(inDTO);

		} catch(Exception e) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("대출기본 갱신실패", e);
			throw new BizException("지로내역 갱신실패", e);
		}
		return exeCnt;
	}

	/**
	 * TODO 리스 미사용
	 * 메소드명		: updateLoanBase
	 * 설명			: 수납결과를 [ST_LEAS_BASE]에 반영
	 * 메소드인수1 	: String cnclFg
	 * 메소드인수2 	: IamtUnrcvObjVO
	 * 메소드인수3 	: RcptBaseVO
	 * 메소드리턴값	: int
	 * 예외처리		: N/A
	 */
	/*
	@Override
	public int updateLeaseBase(String cnclFg, IamtUnrcvObjVO iamtUnrcvObjVO, RcptBaseVO rcptBaseVO) {

		int exeCnt = 0;
		try {
			UpdateLeaseBaseINDTO inDTO = new UpdateLeaseBaseINDTO();

			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo );	//대출_번호
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);	//대출_순번
			inDTO.setLastProcDt(DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER));
			inDTO.setLastProcTm(DateUtil.getServerDate(DateUtil.HHMMSS));
			inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
			inDTO.setLeasStatCd("710"); //리스상태 정상종료

			exeCnt = iamtUnrcvMapper.getUpdateLeaseBase(inDTO);

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("리스기본 갱신실패", se);
			throw new BizException("리스기본 갱신실패", se);
		}
		return exeCnt;
	}
	*/

	/**
	 * 메소드명		: updateLoanBaseSetlNo
	 * 설명			: [ST_LOAN_BASE] 결제번호 증가
	 * 메소드인수1 	: String loanNo
	 * 메소드인수2 	: String loanSeq
	 * 메소드리턴값	: int
	 * 예외처리		: N/A
	 */
	@Override
	public int updateLoanBaseSetlNo(String loanNo, String loanSeq) {
		int exeCnt = 0;
		try {
			StLoanBaseDTO inDTO = new StLoanBaseDTO();

			inDTO.setLoanNo(loanNo );	//대출_번호
			inDTO.setLoanSeq(loanSeq);	//대출_순번

			exeCnt = iamtUnrcvMapper.updateSetlNo(inDTO);

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("대출기본 수납결제번호 갱신실패", se);
			throw new BizException("대출기본 수납결제번호 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * 메소드명		: searchOrg
	 * 설명			: 제휴정보 얻기
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	@Override
	public IamtUnrcvObjVO searchOrg(IamtUnrcvObjVO iamtUnrcvObjVO) {

		try {
			SelectOrgINDTO inDTO = new SelectOrgINDTO();

			inDTO.setEmpNo(iamtUnrcvObjVO.frstRegEmpNo);;	// 사원번호_번호

			SelectOrgOUTDTO outDTO = iamtUnrcvMapper.selectOrg(inDTO);

			if(outDTO != null) {
				iamtUnrcvObjVO.comDivCd   = StringUtil.trim(outDTO.getComDivCd());			//회사_구분코드
				iamtUnrcvObjVO.cprtBranDivCd = StringUtil.trim(outDTO.getCprtBranDivCd());	//제휴점_구분코드
				iamtUnrcvObjVO.mnbrDivCd  = StringUtil.trim(outDTO.getMnbrDivCd());			//본사_구분코드
			}

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("입력사원의 부서정보조회실패", se);
		}

		return iamtUnrcvObjVO;
	}

	/**
	 * 메소드명		: getLeglActsCostRamt
	 * 설명			: 입력된 채권에 대한 법적조치비용 잔액구하기
	 * 메소드인수1 	: String loanNo
	 * 메소드인수2 	: String loanSeq
	 * 메소드인수3 	: Connection
	 * 메소드리턴값	: long
	 * 예외처리		: N/A
	 */
	@Override
	public long getLeglActsCostRamt( String loanNo, String loanSeq) {

		long leglActsCostRamt = 0;

		try {
			LeglActsCostRamtINDTO inDTO = new LeglActsCostRamtINDTO();

			inDTO.setLoanNo(loanNo );	//대출_번호
			inDTO.setLoanSeq(loanSeq);	//대출_순번

			leglActsCostRamt = iamtUnrcvMapper.getGetLeglActsCostRamt(inDTO);

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("법적조치비잔액조회 DB장애", se);
			throw new BizException("법적조치비잔액조회 DB장애", se);
		}
		return leglActsCostRamt;
	}

	/**
	 * TODO 미사용
	 * 메소드명		: isBsnCls
	 * 설명			: 입력 회계일자, 부서에 대해 업무마감 여부
	 * 메소드인수1 	: String acctDt
	 * 메소드인수2 	: String deptCd
	 * 메소드인수3 	: Connection
	 * 메소드리턴값	: boolean
	 * 예외처리		: N/A
	 */
	/*
	@Override
	public static boolean isBsnCls(String acctDt, String deptCd, Connection con) {

		PreparedStatement pstmt = null;
		ResultSet rs = null;
		boolean bsnClsFg = false;

		try {
			pstmt = con.prepareStatement(IamtUnrcvCCQuery.getBsnClsFg());
			pstmt.setString(1, acctDt); //회계일자
			pstmt.setString(2, deptCd); //부서코드

			rs = pstmt.executeQuery();
			if(rs.next()){
				if( StringUtils.equals(rs.getString(1), "1")){
					bsnClsFg = true;
				}
			}
		} catch(SQLException se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("업무마감여부 체크시 DB장애", se);
		} finally {
			DbUtils.closeQuietly(rs);
			DbUtils.closeQuietly(pstmt);
		}
		return bsnClsFg;
	}
	 */
	/**
	 * TODO 미사용
	 * 메소드명		: searchUnwinding
	 * 설명			: 충당금처리대상금액 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드인수2 	: Connection
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	/*@Override
	public static long[] searchUnwinding(IamtUnrcvObjVO iamtUnrcvObjVO, Connection con) {
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		long[] amtArr = null;
		try {
//			pstmt = new LoggableStatement(con, IamtUnrcvCCQuery.SELECT_UNWINDING);
			pstmt = con.prepareStatement(IamtUnrcvCCQuery.SELECT_UNWINDING);

			int i=1;
			//where
			pstmt.setString(i++, iamtUnrcvObjVO.loanNo);
			pstmt.setString(i++, iamtUnrcvObjVO.loanSeq);
			pstmt.setString(i++, iamtUnrcvObjVO.loanNo);
			pstmt.setString(i++, iamtUnrcvObjVO.loanSeq);
			pstmt.setString(i++, iamtUnrcvObjVO.loanNo);
			pstmt.setString(i++, iamtUnrcvObjVO.loanSeq);

			rs = pstmt.executeQuery();
			if(rs.next()) {
				amtArr = new long[3];
				amtArr[0] = rs.getLong("DEPR_PAMT_RAMT");	//원금
				amtArr[1] = rs.getLong("DEPR_INT_RAMT");	//이자
				amtArr[2] = rs.getLong("UN_UNWND_AMT");		//충당금
			}
		} catch(SQLException se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("충당금 전표처리 대상 조회 중 에러발생", se);
		} finally {
			DbUtils.closeQuietly(rs);
			DbUtils.closeQuietly(pstmt);
		}
		return amtArr;
	}*/

	/**
	 * TODO 미사용
	 * 메소드명		: searchUnwindingCncl
	 * 설명			: 충당금처리대상취소금액 조회 (수납취소 시 전표 역분개를 위해 충당금 조회)
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드인수2 	: Connection
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	/*@Override
	public static long[] searchUnwindingCncl(IamtUnrcvObjVO iamtUnrcvObjVO, Connection con) {
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		long[] amtArr = null;
		try {
			pstmt = new LoggableStatement(con, IamtUnrcvCCQuery.SELECT_UNWINDING_CNCL);
//			pstmt = con.prepareStatement(IamtUnrcvCCQuery.SELECT_UNWINDING_CNCL);

			int i=1;
			//where
			pstmt.setInt(i++, iamtUnrcvObjVO.trSnum);
			pstmt.setString(i++, iamtUnrcvObjVO.loanNo);
			pstmt.setString(i++, iamtUnrcvObjVO.loanSeq);

			rs = pstmt.executeQuery();
			if(rs.next()) {
				amtArr = new long[4];
				amtArr[0] = rs.getLong("DEPR_PAMT_RAMT");	//원금
				amtArr[1] = rs.getLong("DEPR_INT_RAMT");	//이자
				amtArr[2] = rs.getLong("UN_UNWND_AMT1");	//충당금(중도완납)
				amtArr[3] = rs.getLong("UN_UNWND_AMT2");	//충당금(정상완납)
			}
		} catch(SQLException se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("충당금 전표처리 대상 조회 중 에러발생", se);
		} finally {
			DbUtils.closeQuietly(rs);
			DbUtils.closeQuietly(pstmt);
		}
		return amtArr;
	}*/

	/**
	 * TODO 미사용
	 * 메소드명		: searchHairCut
	 * 설명			: WO 이전 HairCut수납처리 금액 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드인수2 	: Connection
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	/*@Override
	public static long[] searchHairCut(IamtUnrcvObjVO iamtUnrcvObjVO, Connection con) {
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		long[] amtArr = null;
		try {
//			pstmt = new LoggableStatement(con, IamtUnrcvCCQuery.SELECT_HAIR_CUT);
			pstmt = con.prepareStatement(IamtUnrcvCCQuery.SELECT_HAIR_CUT);

			int i=1;
			//where
			pstmt.setString(i++, iamtUnrcvObjVO.bfSaleDt);
			pstmt.setString(i++, iamtUnrcvObjVO.bfSaleDt);
			pstmt.setString(i++, iamtUnrcvObjVO.setlDt);
			pstmt.setString(i++, iamtUnrcvObjVO.loanNo);
			pstmt.setString(i++, iamtUnrcvObjVO.loanSeq);

			rs = pstmt.executeQuery();
			if(rs.next()) {
				amtArr = new long[5];
				amtArr[0] = rs.getLong("BFDT_INT");		//[AT_보정_작업]전영업일_미수이자
				amtArr[1] = rs.getLong("BFDT_DFEE");	//[AT_보정_작업]전영업일_미수연체료
				amtArr[2] = rs.getLong("RCPT_PAMT");	//[RT_RCPT_BASE]수납_원금
				amtArr[3] = rs.getLong("RCPT_INT");		//[RT_RCPT_BASE]수납_이자
				amtArr[4] = rs.getLong("RCPT_DFEE");	//[RT_RCPT_BASE]수납_연체료
			}
		} catch(SQLException se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("HairCut 전표처리금액 조회 중 에러발생", se);
		} finally {
			DbUtils.closeQuietly(rs);
			DbUtils.closeQuietly(pstmt);
		}
		return amtArr;
	}*/

	/**
	 * TODO 미사용
	 * 메소드명		: searchHairCut
	 * 설명			: WO 이전 HairCut수납취소처리 금액 조회
	 * 메소드인수1 	: IamtUnrcvObjVO
	 * 메소드인수2 	: Connection
	 * 메소드리턴값	: N/A
	 * 예외처리		: N/A
	 */
	/*@Override
	public static long[] searchHairCutCncl(IamtUnrcvObjVO iamtUnrcvObjVO, Connection con) {
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		long[] amtArr = null;
		try {
//			pstmt = new LoggableStatement(con, IamtUnrcvCCQuery.SELECT_HAIR_CUT_CNCL);
			pstmt = con.prepareStatement(IamtUnrcvCCQuery.SELECT_HAIR_CUT_CNCL);

			int i=1;
			//where
			pstmt.setInt(i++, iamtUnrcvObjVO.trSnum);
			pstmt.setString(i++, iamtUnrcvObjVO.loanNo);
			pstmt.setString(i++, iamtUnrcvObjVO.loanSeq);

			rs = pstmt.executeQuery();
			if(rs.next()) {
				amtArr = new long[7];
				amtArr[0] = rs.getLong("PAMT");			//원금
				amtArr[1] = rs.getLong("INT");			//이자
				amtArr[2] = rs.getLong("DFEE");			//연체료
				amtArr[3] = rs.getLong("ETC_PRFT");		//잡이익
				amtArr[4] = rs.getLong("EXMP_PAMT");	//대손상각_원금
				amtArr[5] = rs.getLong("EXMP_INT");		//대손상각_이자
				amtArr[6] = rs.getLong("EXMP_DFEE");	//대손상각_연체료
			}
		} catch(SQLException se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("HairCut 전표처리금액 조회 중 에러발생", se);
		} finally {
			DbUtils.closeQuietly(rs);
			DbUtils.closeQuietly(pstmt);
		}
		return amtArr;
	}*/

	/**
	 * 메소드명		: getRetnRt
	 * 설명			: 입력된 채권에 대한 환입율 조회
	 * 메소드인수1 	: String loanNo
	 * 메소드인수2 	: String loanSeq
	 * 메소드인수3 	: Connection
	 * 메소드리턴값	: String
	 * 예외처리		: N/A
	 */
	@Override
	public String getRetnRt( IamtUnrcvObjVO iamtUnrcvObjVO) {

		String retnRt = "";

		try {

			StLoanBaseDTO inDTO = new StLoanBaseDTO();

			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);	//대출_번호
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);	//대출_순번

			retnRt = iamtUnrcvMapper.getRntnRt(inDTO);

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("환입율조회 DB장애", se);
			throw new BizException("환입율조회 DB장애", se);
		}

		return retnRt;
	}

	/**
	 * <p>지급수수료환입율 신규등록
	 * @param clawbkBaseVOList
	 * @param con
	 * @return
	 * @throws SQLException
	 */
	@Override
	public int createClawbkBase(IamtUnrcvObjVO iamtUnrcvObjVO){

		int exeCnt = 0;
		try {
			CreatePayFeeClawbkBaseINDTO inDTO = new CreatePayFeeClawbkBaseINDTO();

			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번

			inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);				//회계_일자
			inDTO.setSetlDivCd(iamtUnrcvObjVO.setlDivCd);		//결제_구분코드
			inDTO.setProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);	//등록_사원번호

			exeCnt = iamtUnrcvMapper.getCreatePayFeeClawbkBase(inDTO);

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("지급수수료환입율 생성", se);
			throw new BizException("지급수수료환입율 생성", se);
		}

		return exeCnt;
	}

	/**
	 * <p>지급수수료환입율 삭제
	 * @param clawbkBaseVOList
	 * @param con
	 * @return
	 * @throws SQLException
	 */
	@Override
	public int deleteClawbkBase(IamtUnrcvObjVO iamtUnrcvObjVO){

		int exeCnt = 0;
		try {

			StPayFeeClawbkBaseDTO inDTO = new StPayFeeClawbkBaseDTO();

			inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);	//대출_번호
			inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);	//대출_순번

			exeCnt = iamtUnrcvMapper.getDeletePayFeeClawbkBase(inDTO);

		} catch(Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("지급수수료환입율 삭제", se);
			throw new BizException("지급수수료환입율 삭제", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: isIvltClsBnd</p>
	 * <p>설명			: 강제해지상품여부 </p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	private boolean isIvltClsBnd(IamtUnrcvObjVO iamtUnrcvObjVO){
		if (iamtUnrcvObjVO.prdtSmClasCd.equals("6")) {
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isLease</p>
	 * <p>설명			: 리스여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	@SuppressWarnings("unused")
	private static boolean isLease(IamtUnrcvObjVO iamtUnrcvObjVO) {
		return isLease(iamtUnrcvObjVO.prdtLrgeClasCd);
	}
	private static boolean isLease(String prdtLrgeClasCd){
		if (StringUtil.in(prdtLrgeClasCd, new String[]{"3", "4"})) {
			return true;
		} else {
			return false;
		}
	}

}
