package hanalife.r.co.rc.service.impl;

import java.math.BigDecimal;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.RtRcptPdueDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.CreatePdueDescForCnclINDTO;
import hanalife.r.co.rc.mapper.dto.CreatePdueDescForCnclPiamtINDTO;
import hanalife.r.co.rc.service.PdueService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.PdueDescVO;
import hanalife.util.BizException;
import hanalife.util.IamtUtil;



/**
 * <pre>
 * 클래스　명 : PdueServiceImpl
 * 클래스설명 : 선납내역 관리 ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("PdueService")
public class PdueServiceImpl implements PdueService {

	private static final Logger log = LoggerFactory.getLogger(PdueServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * <p>메소드명 : updatePdueDescForCncl</p>
	 * <p>설명 : 수납_선납_내역 테이블을 수정한다.(취소) </p>
	 * <p>메소드인수1 : IamtUnrcvObjVO iamtUnrcvObjVO</p>
	 * <p>메소드리턴값 : int - 반영건수 </p>
	 */
	@Override
	public int updatePdueDescForCncl(IamtUnrcvObjVO inObj) {

		int exeCnt = 0;

		RtRcptPdueDescDTO inDTO = new RtRcptPdueDescDTO();

		//set
		inDTO.setCnclFg(inObj.cnclFg);				//취소여부
		inDTO.setCnclDt(inObj.acctDt); 				//회계일자
		inDTO.setLastProcEmpNo(inObj.frstRegEmpNo); //처리사원번호

		//where
		inDTO.setLoanNo(inObj.loanNo);				//대출_번호
		inDTO.setLoanSeq(inObj.loanSeq);			//대출_순번
		inDTO.setSetlNo(inObj.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updatePdueDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("선납내역 갱신실패", se);
			throw new BizException("선납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * 원리금수납 취소
	 * @param inObj
	 * @return
	 * @throws Exception
	 */
	@Override
	public int updatePdueDescForCnclPiamt(IamtUnrcvObjVO inObj) {
		int exeCnt = 0;

		RtRcptPdueDescDTO inDTO = new RtRcptPdueDescDTO();

		//set
		inDTO.setPartCnclCd(inObj.partCnclCd);		//부분_취소_코드
		inDTO.setCnclDt(inObj.acctDt); 				//취소_일자
		inDTO.setCnclFg(Constants.YES); 			//취소_여부
		inDTO.setLastProcEmpNo(inObj.frstRegEmpNo); //처리사원번호

		//where
		inDTO.setLoanNo(inObj.loanNo);				//대출_번호
		inDTO.setLoanSeq(inObj.loanSeq);			//대출_순번
		inDTO.setSetlNo(inObj.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updatePdueDescForCnclPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("선납내역 갱신실패", se);
			throw new BizException("선납내역 갱신실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명 : createPdueDescForCncl</p>
	 * <p>설명 : 수납_선납_내역 테이블을 신규등록 한다.(취소) </p>
	 * <p>메소드인수1 : IamtUnrcvObjVO iamtUnrcvObjVO</p>
	 * <p>메소드리턴값 : int - 반영건수 </p>
	 */
	@Override
	public int createPdueDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		CreatePdueDescForCnclINDTO inDTO = new CreatePdueDescForCnclINDTO();

		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);		//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.getCreatePdueDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("선납내역 생성실패(취소)", se);
			throw new BizException("선납내역 생성실패(취소)", se);
		}

		return exeCnt;
	}

	/**
	 * 원리금수납 취소
	 * @param iamtUnrcvObjVO
	 * @return
	 * @throws Exception
	 */
	@Override
	public int createPdueDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		CreatePdueDescForCnclPiamtINDTO inDTO = new CreatePdueDescForCnclPiamtINDTO();

		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);
		inDTO.setPartCnclCd(iamtUnrcvObjVO.partCnclCd);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.getCreatePdueDescForCnclPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("선납내역 생성실패(부분취소)", se);
			throw new BizException("선납내역 생성실패(부분취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>선납수납내역 신규등록
	 * @param pdueDescVOList
	 * @return
	 * @throws Exception
	 */
	@Override
	public int createPdueDesc(List pdueDescVOList) {

		int exeCnt = 0;

		try {

			String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
			String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

			RtRcptPdueDescDTO inDTO = new RtRcptPdueDescDTO();

			PdueDescVO pdueDescVO = null;

			for (int i = 0, n = IamtUtil.sizeOfList(pdueDescVOList); i < n; i++) {

				pdueDescVO = (PdueDescVO) pdueDescVOList.get(i);

				inDTO.setLoanNo(pdueDescVO.loanNo); //대출_번호
				inDTO.setLoanSeq(pdueDescVO.loanSeq); //대출_순번
				inDTO.setSetlNo(pdueDescVO.setlNo); //결제_번호
				inDTO.setSetlSnum(pdueDescVO.setlSnum); //결제_일련번호
				inDTO.setOccrAdjDivCd(pdueDescVO.occrAdjDivCd); //발생_정산_구분코드
				inDTO.setPdueDiscDfee(new BigDecimal(pdueDescVO.pdueDiscDfee)); //선납_할인_연체료
				inDTO.setCnclFg(pdueDescVO.cnclFg); //취소_여부
				inDTO.setCnclDt(pdueDescVO.cnclDt); //취소_일자
				inDTO.setFrstRegDt(procDt); //최초_등록_일자
				inDTO.setFrstRegTm(procTm); //최초_등록_시각
				inDTO.setFrstRegEmpNo(pdueDescVO.procEmpNo); //최초_등록_사원번호
				inDTO.setLastProcDt(procDt); //최종_처리_일자
				inDTO.setLastProcTm(procTm); //최종_처리_시각
				inDTO.setLastProcEmpNo(pdueDescVO.procEmpNo); //최종_처리_사원번호

				exeCnt += iamtUnrcvMapper.insertPdueDesc(inDTO);
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("선납내역 생성실패", se);
			throw new BizException("선납내역 생성실패", se);
		}

		return exeCnt;
	}

}
