package hanalife.r.co.rc.service.impl;

import java.math.BigDecimal;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.mapper.dto.RtRcptDlyDescDTO;
import hanalife.c.co.util.DateUtil;
import hanalife.r.co.rc.mapper.IamtUnrcvMapper;
import hanalife.r.co.rc.mapper.dto.CreateRcptDlyDescForCnclINDTO;
import hanalife.r.co.rc.mapper.dto.CreateRcptDlyDescForCnclPiamtINDTO;
import hanalife.r.co.rc.service.RcptDlyService;
import hanalife.r.co.rc.vo.DlyDescVO;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.util.BizException;



/**
 * <pre>
 * 클래스　명 : RcptDlyServiceImpl
 * 클래스설명 : 수납연체관련 ServiceImpl
 * 프로젝트명 : DOBSCAP
 * 작성　일자 : 2023. 3. 22.
 * 변경　이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 22.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("RcptDlyService")
public class RcptDlyServiceImpl implements RcptDlyService {

	private static final Logger log = LoggerFactory.getLogger(RcptDlyServiceImpl.class);

	@Autowired
	private IamtUnrcvMapper iamtUnrcvMapper;

	/**
	 * <p>메소드명		: updateRcptDlyDescForCncl</p>
	 * <p>설명			: 취소일때 수납연체내역 수정</p>
	 * <p>메소드인수1		: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public int updateRcptDlyDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO) {
		int exeCnt = 0;

		RtRcptDlyDescDTO inDTO = new RtRcptDlyDescDTO();

		//set
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);				//취소여부
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt); 				//회계일자
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo); //처리사원번호

		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptDlyDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납연체내역 수정실패(취소)", se);
			throw new BizException("수납연체내역 수정실패(취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: updateRcptDlyDescForCnclPiamt</p>
	 * <p>설명			: 원리금수납취소(부분취소)</p>
	 * <p>메소드인수1		: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public int updateRcptDlyDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		RtRcptDlyDescDTO inDTO = new RtRcptDlyDescDTO();

		//set
		inDTO.setPartCnclCd(iamtUnrcvObjVO.partCnclCd);			//취소여부
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt); 				//회계일자
		inDTO.setCnclFg(Constants.YES); 						//취소여부
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo); 	//처리사원번호

		//where
		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setSetlNo(iamtUnrcvObjVO.orgSetlNo);			//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.updateRcptDlyDescForCnclPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("수납연체내역 수정실패(부분취소)", se);
			throw new BizException("수납연체내역 수정실패(부분취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: updateRcptDlyDescForCnclPiamt</p>
	 * <p>설명			: [수납_연체_내역]등록</p>
	 * <p>메소드인수1		: List rcptDlyVOList</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public int createRcptDlyDesc(List rcptDlyVOList) {

		int exeCnt = 0;

		try {

			String procDt = DateUtil.getServerDate(DateUtil.YYYYMMDD_WITH_DELIMETER);
			String procTm = DateUtil.getServerDate(DateUtil.HHMMSS); //hhmmss

			RtRcptDlyDescDTO inDTO = new RtRcptDlyDescDTO();


			DlyDescVO dlyDescVO = null;

			for (int i = 0; i < rcptDlyVOList.size(); i++) {

				dlyDescVO = (DlyDescVO) rcptDlyVOList.get(i);

				inDTO.setLoanNo(dlyDescVO.loanNo);                           	//대출번호
				inDTO.setLoanSeq(dlyDescVO.loanSeq);                         	//상담/대출순번
				inDTO.setSetlNo(dlyDescVO.setlNo);                           	//결제_번호
				inDTO.setSetlSnum(dlyDescVO.setlSnum);                       	//입금_번호
				inDTO.setTims(dlyDescVO.tims);                               	//회차
				inDTO.setDueDt(dlyDescVO.dueDt);                             	//유효일
				inDTO.setAcctDt(dlyDescVO.acctDt);                           	//회계_일자
				inDTO.setSetlDt(dlyDescVO.setlDt);                           	//결제일자
				inDTO.setMmPamt(new BigDecimal(dlyDescVO.mmPamt));              //월_원금
				inDTO.setMmInt(new BigDecimal(dlyDescVO.mmInt));                //월_이자
				inDTO.setDfee(new BigDecimal(dlyDescVO.dfee));                  //연체료
				inDTO.setDlyDdcnt(dlyDescVO.dlyDdcnt);                       	//연체_일수
				inDTO.setDlyMmCnt(dlyDescVO.dlyMmCnt);                       	//연체_개월_수
				inDTO.setOccrDfee(new BigDecimal(dlyDescVO.occrDfee));          //발생_연체료
				inDTO.setUnrcvDfee(new BigDecimal(dlyDescVO.unrcvDfee));        //미수_연체료
				inDTO.setAdjDfee(new BigDecimal(dlyDescVO.adjDfee));            //정산_연체료
				inDTO.setExmpDfee(new BigDecimal(dlyDescVO.exmpDfee));          //면제_연체료
				inDTO.setPdueDiscDfee(new BigDecimal(dlyDescVO.pdueDiscDfee));  //선납_할인_연체료
				inDTO.setLoseDlyStrtDt(dlyDescVO.loseDlyStrtDt);             	//상실_연체_시작_일자
				inDTO.setLoseDueDt(dlyDescVO.loseDueDt);                     	//상실_납입_일자
				inDTO.setLoseDt(dlyDescVO.loseDt);                           	//상실_일자
				inDTO.setLoseMmPamt(new BigDecimal(dlyDescVO.loseMmPamt));      //상실_월_원금
				inDTO.setLoseMmInt(new BigDecimal(dlyDescVO.loseMmInt));        //상실_월_이자
				inDTO.setLosePamtRamt(new BigDecimal(dlyDescVO.losePamtRamt));  //상실_원금_잔액
				inDTO.setLosePiamtDfee(new BigDecimal(dlyDescVO.losePiamtDfee));//상실_원리금_연체료
				inDTO.setLoseIntDfee(new BigDecimal(dlyDescVO.loseIntDfee));    //상실_이자_연체료
				inDTO.setLoseRamtDfee(new BigDecimal(dlyDescVO.loseRamtDfee));  //상실_잔액_연체료
				inDTO.setLoseFg(dlyDescVO.loseFg);                           	//상실_여부
				inDTO.setLastSetlDt(dlyDescVO.lastSetlDt);                   	//최종_결제일자
				inDTO.setCnclFg(dlyDescVO.cnclFg);                           	//취소여부
				inDTO.setCnclDt(dlyDescVO.cnclDt);                           	//취소일자
				inDTO.setFrstRegDt(procDt);                           			//최초등록일자
				inDTO.setFrstRegTm(procTm);                           			//최초등록시각
				inDTO.setFrstRegEmpNo(dlyDescVO.procEmpNo);                     //최초등록자사번
				inDTO.setLastProcDt(procDt);                          			//최종처리일자
				inDTO.setLastProcTm(procTm);                           			//최종처리일
				inDTO.setLastProcEmpNo(dlyDescVO.procEmpNo);                 	//최종처리자
				inDTO.setPartCnclCd(dlyDescVO.partCnclCd);                   	//부분_취소_코드
				inDTO.setPpayInt(new BigDecimal(dlyDescVO.ppayInt));        	//선급이자
				inDTO.setAddInsuFee(new BigDecimal(dlyDescVO.addInsuFee));   	//보험료
				inDTO.setAddCartax(new BigDecimal(dlyDescVO.addCartax));     	//차세
				inDTO.setAddEnvImprBrdnamt(new BigDecimal(dlyDescVO.addEnvImprBrdnamt));     //환개금
				inDTO.setAddAsfee(new BigDecimal(dlyDescVO.addAsfee));       	//가산_정비료
				inDTO.setIpayInsuFee(new BigDecimal(dlyDescVO.ipayInsuFee)); 	//대지급_보험료
				inDTO.setIpayCartax(new BigDecimal(dlyDescVO.ipayCartax));   	//대지급_자동차세
				inDTO.setIpayEnvImprBrdnamt(new BigDecimal(dlyDescVO.ipayEnvImprBrdnamt));   //대지급_환경_개선_부담금
				inDTO.setIpayPnltAmt(new BigDecimal(dlyDescVO.ipayPnltAmt)); 	//대지급_범칙금
				inDTO.setIpayEtc(new BigDecimal(dlyDescVO.ipayEtc));         	//대지급_기타
				inDTO.setVtax(new BigDecimal(dlyDescVO.vtax));               	//부가세
				inDTO.setLtrmBrcvAmt(new BigDecimal(dlyDescVO.ltrmBrcvAmt)); 	//장기_선수금
				inDTO.setRamtAmt(new BigDecimal(dlyDescVO.ramtAmt));         	//잔가_금액
				inDTO.setGuarAmt(new BigDecimal(dlyDescVO.guarAmt));         	//보증금
				inDTO.setTrtFee(new BigDecimal(dlyDescVO.trtFee));           	//취급수수료
				inDTO.setLoseRvvlFg(dlyDescVO.loseRvvlFg);                   	//상실부활여부
				inDTO.setRlDueDt(dlyDescVO.rlDueDt);                         	//실납입일자
				inDTO.setDlyStrtDt(dlyDescVO.dlyStrtDt);                     	//연체시작일자
				inDTO.setDlyCalcStrtDt(dlyDescVO.dlyCalcStrtDt);             	//연체계산시작일자
				inDTO.setLoseDlyEndDt(dlyDescVO.loseDlyEndDt);               	//상실연체종료일자
				inDTO.setLoseObjInt(new BigDecimal(dlyDescVO.loseObjInt));   	//상실이자

				exeCnt += iamtUnrcvMapper.insertRcptDlyDesc(inDTO);
			}

		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("연체내역 생성실패", se);
			throw new BizException("연체내역 생성실패", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: createRcptDlyDescForCncl</p>
	 * <p>설명			: [수납_연체_내역] 취소내역 등록</p>
	 * <p>메소드인수1		: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public int createRcptDlyDescForCncl(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		CreateRcptDlyDescForCnclINDTO inDTO = new CreateRcptDlyDescForCnclINDTO();

		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setCnclFg(iamtUnrcvObjVO.cnclFg);
		inDTO.setCnclDt(iamtUnrcvObjVO.acctDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);			//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);		//대출_순번
		inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);	//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.getCreateRcptDlyDescForCncl(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("연체내역 생성실패(취소)", se);
			throw new BizException("연체내역 생성실패(취소)", se);
		}

		return exeCnt;
	}

	/**
	 * <p>메소드명		: createRcptDlyDescForCnclPiamt</p>
	 * <p>설명			: 원리금수납(부분수납) 취소</p>
	 * <p>메소드인수1		: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public int createRcptDlyDescForCnclPiamt(IamtUnrcvObjVO iamtUnrcvObjVO) {

		int exeCnt = 0;

		CreateRcptDlyDescForCnclPiamtINDTO inDTO = new CreateRcptDlyDescForCnclPiamtINDTO();

		inDTO.setSetlNo(iamtUnrcvObjVO.setlNo);
		inDTO.setAcctDt(iamtUnrcvObjVO.acctDt);
		inDTO.setCnclDt(iamtUnrcvObjVO.cnclDt);
		inDTO.setFrstRegEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setLastProcEmpNo(iamtUnrcvObjVO.frstRegEmpNo);
		inDTO.setPartCnclCd(iamtUnrcvObjVO.partCnclCd);

		inDTO.setLoanNo(iamtUnrcvObjVO.loanNo);				//대출_번호
		inDTO.setLoanSeq(iamtUnrcvObjVO.loanSeq);			//대출_순번
		inDTO.setOrgSetlNo(iamtUnrcvObjVO.orgSetlNo);		//결제_번호

		try {
			exeCnt = iamtUnrcvMapper.getCreateRcptDlyDescForCnclPiamt(inDTO);
		} catch (Exception se) {
			//TODO 에러처리 확인 - IamtExceptionHandler.throwIamtException("연체내역 생성실패(부분취소)", se);
			throw new BizException("연체내역 생성실패(부분취소)", se);
		}

		return exeCnt;
	}

}
