package hanalife.r.co.rc.vo;

import java.io.Serializable;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : IamtUnrcvInVO.java Class
 * 클래스설명   : 입금미수 대상 객체(입력)를(을) 위한 VO
 * 작성일자     : 2023. 3. 16.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 16.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@SuppressWarnings({"unchecked","rawtypes"})
public class IamtUnrcvInVO implements Serializable{

    private static final long serialVersionUID = 1L;

    /** 입력 */
    public String loanNo;           //대출_번호
    public String loanSeq;          //대출_순번
    public String custNo;           //수납고객번호
    public String acctUnitCd;       //회계_단위_코드
    public String acctDt;           //회계_일자
    public String setlDt;           //결제_일자
    public String isrtDt;           //입력_일자(내부에서 현재일자를 구함)
    public String setlDivCd;        //결제_구분코드
    public String setlDivNm;        //결제_구분명 (전표 Remark 용)
    public String setlFrstRank;     //결제_우선_순위
    public String rcptTpCd;         //수납_유형_코드
    public String isrtDeptCd;       //입력_부서_코드
    public String adjDeptCd;        //정산_부서_코드
    public String mngDeptCd;        //관리_부서_코드
    public String frstRegEmpNo;     //최초_등록_사원번호
    public String bankCd;           //은행_코드
    public String acntNo;           //계좌번호
    public String leglUnCalcFg;     //가지급금미계산여부
    public String setlDtChkFg;      //결제일자체크여부
    public String sysPathCd;        //시스템경로코드
    public String spclBndProcPossFg;//특수채권처리가능여부
    public String cnclAcctDtChkFg;  //취소회계일자체크여부

    public String dsrcNo;           //예가수_번호
    public String dsrcOccrCd;       //예가수_발생_코드
    public String dsrcAdjCd;        //예가수_정산_코드
    public long dsrcOccrAmt;        //예가수_발생_금액
    public int dsrcSnum;            //환불시 예가수일련번호 리턴
    public String forceDsrcOccrFg;  //예가수_강제_발생_여부

    public long setlAmt;            //결제_금액(현재 시제로 발생한 금액, 현금_금액 + 수표_금액)
    public long cashAmt;            //현금_금액
    public long chkAmt;             //수표_금액
    public long dsrcAdjAmt;         //예가수_정산_금액
    public long ltrmBrcvAmt;        //장기선수금(대체)
    public long execGuarAmtTrnsAmt; //실행보증금대체
    public long deprDeprTamt;       //감가_상각_누계액
    public long dspLossApprAmt;     //처분_손실_충당금
    public long oprLeasAset;        //운용_리스_자산
    public long prFee;              //판촉_수수료
    public long gramSmanFee;        //전문_영업직_수수료
    public long dferIncdPrft;       //이연_부대_수익

    public long rcptAmt;    //수납_금액(정산시 총사용한금액 -> 결제금액,예가수정산금액,장기선수금,할인금,면제금 등)
    public String rmk;      //적요

    // 렌터카공제조합 추가 (회계에서 모계좌 잔액관리를 위하여 추가)
    public String moBankCd; //모계좌은행코드
    public String moAcntNo; //모계좌번호

//    /**
//     * 바로사용하지 말것!
//     * {@link #addChkDescVO(ChkDescVO)}, {@link #getChkDescVO(int)}, {@link #sizeChkDescVO()}를 이용
//     */
//    public List<ChkDescVO> chkDescVOList; //수표리스트
//
//    /**
//     * 바로사용하지 말것!
//     * {@link #addIntgDsrcDescVO(intgDsrcDescVO)}, {@link #getIntgDsrcDescVO(int)}, {@link #sizeIntgDsrcDescVO()}를 이용
//     */
//    public List<IntgDsrcDescVO> intgDsrcDescVOList; //예가수 리스트

    /**
     * 선결제
     */
    public String preRcptTpCd;  //선결제_수납_유형_코드
    public String preTrOrgCd;   //선결제_거래_기관_코드
    public int preGiroSnum;     //선결제_지로_일련번호
    public String preGiroDivCd; //선결제_지로_일련번호

    /**
     * 면제금 관련
     * 면제금액 = 면제원금, 면제이자, 면제연체료, 면제법적조치비용, 면제중도상환수수료, 명의이전면제보증금
     */
    public String exmpConsNo;           //면제_품의번호
    public long exmpAmt;                //면제_금액
    public long exmpPamt;               //면제_원금
    public long exmpInt;                //면제_이자
    public long exmpTrtFee;             //면제_취급수수료
    public long exmpDfee;               //면제_연체료
    public long exmpLeglActnCost;       //면제_법적조치비용
    public long exmpMidRmbrFee;         //면제_중도상환수수료
    public long exmpNmChngExmpGuarAmt;  //명의이전면제보증금

    /**
     * 취소시 입력
     */
    public String partCnclCd;       //부분취소코드
    public String cnclFg;           //취소_여부
    public String cnclDt;           //취소_일자
    public String orgAcctDt;        //원_회계_일자
    public String orgRegDt;         //원_등록_일자
    public int orgSetlNo;           //원_결제_번호
    public long orgSetlAmt;         //원결제금액
    public String orgRcptTpCd;      //원_수납_유형_코드
    public String orgSetlDt;        //원회계일자
    public String orgIsrtDeptCd;    //원_입력_부서_코드
    public int orgRcptStrtTims;     //원거래의 수납시작회차
    public String cnclAftDsrcUnOccrFg;      //2018-08-01 두비스 추가
    public String cnclAftDsrcForthOccrFg;   //2018-08-01 두비스 추가(취소후 예가수발생 )
    public String ivltCnclFg;       //2018-08-01 두비스 강제취소여부
    public String extsDt;           //2018-08-01 두비스 유예일자
    public String bfmmLastDt;       //전월마지막 일자

    /**
     * 처리결과
     */
    public String rsltCd;           //결과_코드
    public String rsltCntn;         //결과명
    public String nmChngDsrcNo;     //명의_변경_예가수_번호
    public String carsSellDsrcNo;   //차량_매각_예가수_번호

    /**
     * 내부사용 필드등...
     */
    public String rsltCnclDt;       //결과취소일자 2018-08-01 추가
    public String bfSaleDt;         //2018-08-01 직전영업일자
    public String mngAcctUnitCd;    //관리_회계_단위_코드(2018-08-01 추가)
    public String loanStatCd;       //대출_상태_코드(대출기본,미확인대출원장)
    public String adjLoanStatCd;    //정산대출상태코드
    public String curLoanStatCd;    //현재대출상태코드
    public String endDt;            //종료일자(대출기본)
    public String rcntSetlDt;       //최근결제일자(수납기본.최신원리금/부분/전액중도상환일자)
    public String rcntAcctDt;       //최근회계일자
    public String prdtCd;           //상품_코드(대출기본,미확인대출원장)
    public String godsCd;           //물품_코드(물품기본,미확인대출원장)
    public String loanDt;           //대출_일자(대출기본,입력결제일자)
    public String prdtLrgeClasCd;   //상품_대분류_코드(대출기본,미확인대출원장)
    public String prdtMidClasCd;    //상품_중분류_코드(대출기본,미확인대출원장)
    public String prdtSmClasCd;     //상품_소분류_코드(대출기본,미확인대출원장)
    public String asymmAcctFg;      //비대칭회계여부
    public double loanIntRt;        //대출_이자율(대출기본,미확인대출원장)
    public String bndStatCd;        //채권_상태_코드(채권마감기본,미확인대출원장)
    public String bndDivsEmpNo;     //채권_담당_사원번호(대출기본,미확인대출원장)
    public int curCpayTims;         //현재완납회차(대출.완납회차)
    public String loanApplDt;       //대출신청일자

    public int setlNo;      //결제_번호(채번)
    public int setlSnum;    //결제_일련번호(채번)
    public String unCnfmFg; //미_확인_여부

    public String trTpCd;   //거래_유형_코드
    public String tranTpCd; //이체_유형_코드
    public int trSnum;      //거래_내역_번호 (DBSRQST.RT_CLS_TR_DESC 의 TR_DESC_NO이다. 이름을 틀리게 쓰고있음)
    public int trTranNo;    //거래_이체_번호
    /**
     * 사용자의 결제구분과 별개로 내부적으로 처리시 조건에 의해 결제방법을 바꿔야할때 사용한다.
     * ex) 사용자 요청은 원리금수납이었는데 내부적으로 보니 예가수발생이라면
     *     처리결제구분코드는 예가수발생이고 기존 결제구분은 원리금수납으로 원래 결제구분값이 덮어쓰여지지 않도록한다.
     */
    public String procSetlDivCd;    //처리결제구분코드
    public String cprtComNo;        //제휴사_번호
    public String comDivCd;         //회사_구분코드(사원기본.회사_구분코드)
    public String cprtBranDivCd;    //제휴점_구분코드(부서.제휴점_구분코드)
    public String mnbrDivCd;        //본사_구분코드

    /**
     * 결제정산시 사용금액필드
     */
    public int tempSetlSnum;            //임시_결제_순번
    public long tempSetlAmt;            //임시_결제_금액
    public long tempFrstAdjAmt;         //임시선정산금액(원금우선순위 결제일때 사용.)
    public long tempFrstAdjIntAmt;      //임시선정산이자금액(원금우선순위 결제일때 사용.)
    public long tempFrstAdjTrtFee;      //임시선정산이자금액(원금우선순위 결제일때 사용.)
    public long tempExmpAmt;            //임시_면제_금액(면제원금+면제이자+면제연체료+면제법적조치비용+면제중도상환수수료)
    public long tempExmpPamt;           //임시_면제_원금
    public long tempExmpInt;            //임시_면제_이자
    public long tempExmpTrtFee;         //임시_취급수수료
    public long tempExmpDfee;           //임시_면제_연체료
    public long tempNmChngExmpGuarAmt;  //명의이전면제보증금
    public long tempExmpLeglActnCost;   //임시_면제_법적_조치_비용
    public long tempExmpMidRmbrFee;     //임시_면제_중도_상환_수수료
    public long tempPdueDiscDfee;       //임시_선납_할인_연체료
    public long tempLtrmBrcvAmt ;       //장기_선수_금액
    public long tempFrstAdjDfee ;       //임시선정산금액(연체료 우선공제를 위하여 사용) SCCK 요청사항 연체료먼저 공제처리함

    public long adjAmt;                 //정산_금액
    public long adjExmpAmt;             //정산_면제_금액
    public long adjLeglActnCost;        //정산_법적_조치_비용
    public long adjStmpFee;             //정산_인지세
    public long adjExmpLeglActnCost;    //정산_면제_법적_조치_비용
    public long adjPamt;                //정산_원금(정산_면제_원금 포함)
    public long adjExmpPamt;            //정산_면제_원금
    public long adjInt;                 //정산_이자(정산_면제_이자 포함)
    public long adjTrtFee;              //정산_취급수수(정산_취급수수료 포함)
    public long adjExmpInt;             //정산_면제_이자
    public long adjExmpTrtFee;          //정산_취급수수료
    public long adjDfee;                //정산_연체료(정산_면제_연체료,정산_선납_할인_연체료포함)
    public long adjExmpDfee;            //정산_면제_연체료
    public long adjPdueDiscDfee;        //정산_선납_할인_연체료
    public long adjVtax               ;   //부가세
    public long adjPpayInt            ;   //선급_이자
    public long adjAddInsuFee         ;   //보험료
    public long adjAddCartax          ;   //차세
    public long adjAddEnvImprBrdnamt  ;   //환개금
    public long adjAddAsfee           ;   //가산_정비료
    public long adjIpayInsuFee        ;   //대지급_보험료
    public long adjIpayCartax         ;   //대지급_자동차세
    public long adjIpayEnvImprBrdnamt ;   //대지급_환경_개선_부담금
    public long adjIpayPnltAmt        ;   //대지급_범칙금
    public long adjIpayEtc            ;   //대지급_기타
    public long adjLtrmBrcvAmt        ;   //장기_선수_금액
    public long adjNmChngGuarAmt      ;   //정산명의이전보증금
    public long adjNmChngExmpGuarAmt  ;   //정산명의이전면제보증
    public long adjMidRmbrFee         ;   //정산_중도_상환_수수료
    public long adjExmpMidRmbrFee     ;   //정산_면제_중도_상환_수수료
    public long adjTrtFeeDisc         ;   //정산_취급_수수료_할인
    public long adjMidRmbrPamt        ;   //정산중도상환원금
    public long adjMidRmbrInt         ;   //정산중도상환이자
    public long adjMidRmbrTrtFee      ;   //정산중도상환취급수수료
    public long totAdjAmt             ;   //정산금액총액

    /**
     * 금액정산완료여부
     */
    public String vtaxCpayFg                ;   //부가세
    public String ppayIntCpayFg             ;   //선급_이자
    public String addInsuFeeCpayFg          ;   //보험료
    public String addCartaxCpayFg           ;   //차세
    public String addEnvImprBrdnamtCpayFg   ;   //환개금
    public String addAsfeeCpayFg            ;   //가산_정비료
    public String ipayInsuFeeCpayFg         ;   //대지급_보험료
    public String ipayCartaxCpayFg          ;   //대지급_자동차세
    public String ipayEnvImprBrdnamtCpayFg  ;   //대지급_환경_개선_부담금
    public String ipayPnltAmtCpayFg         ;   //대지급_범칙금
    public String ipayEtcCpayFg             ;   //대지급_기타
    public String dlyCpayFg;    //연체완납여부
    public String intCpayFg;    //이자완납여부
    public String trtFeeCpayFg; //취급수수료완납여부
    public String pamtCpayFg;   //원금완납여부
    public int cpayTims;        //완납회차
    public int unCpayCnt;       //미완납건수

}
