package hanalife.r.co.rc.vo;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.apache.commons.lang.StringUtils;

import hanalife.c.co.contants.Constants;

@SuppressWarnings({"unchecked","rawtypes"})
/**
 * <pre>
 * 클래스명    : IamtUnrcvVO
 * 클래스설명 : 입금미수객체 VO
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class IamtUnrcvVO {

	private List iamtUnrcvObjVOList; //입금미수대상 리스트

	public String autoSetlFg; //자동_결제_여부
	public String vochUnprocFg; //전표미처리여부
	public String tranUnprocFg;	// 이체 미처리 여부
	public String pdueIvltProcFg;	//선납강제처리여부
	public int trDescNo;	//거래내역번호(자동전표번호)
	public String pduePossFg;	// 선납가능여부 ( 화면에서만 셋팅해야함)

	public String rsltCd;
	public String rsltCntn;
	public int errObjIdx;
	public String errLoanNo;
	public String errLoanSeq;

	public IamtUnrcvVO() {
		init();
	}

	/**
	 * <p>메소드명		: init</p>
	 * <p>설명			: 입금미수객체 초기화</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void init(){
		iamtUnrcvObjVOList = initList(iamtUnrcvObjVOList);
		autoSetlFg = Constants.NO;
		vochUnprocFg = Constants.NO; //전표미처리여부 : 1 -> 전표처리하지 않음. 0 -> 전표처리함.(디폴트값)
		tranUnprocFg = Constants.NO; //이체 미처리 여부
		pdueIvltProcFg = Constants.NO;
		pduePossFg = Constants.NO;
		trDescNo = -1;

		rsltCd = Constants.SUCCESS;
		rsltCntn = StringUtils.EMPTY;
		errObjIdx = -1;
		errLoanNo = StringUtils.EMPTY;
		errLoanSeq = StringUtils.EMPTY;

	}

	/**
	 * <p>메소드명		: sortIamtUnrcvObj</p>
	 * <p>설명			: iamtUnrcvObjVOList 소팅</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void sortIamtUnrcvObj(){
		Collections.sort(iamtUnrcvObjVOList);
	}

	/**
	 * <p>메소드명		: sizeIamtUnrcvObjVO</p>
	 * <p>설명			: 입금미수대상 size 리턴</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public int sizeIamtUnrcvObjVO(){
		return sizeList(iamtUnrcvObjVOList);
	}

	/**
	 * <p>메소드명		: getIamtUnrcvObjVO</p>
	 * <p>설명			: 해당 Index의 입금미수대상을 리턴</p>
	 * <p>메소드인수1	: index</p>
	 * <p>메소드리턴값	: IamtUnrcvObjVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public IamtUnrcvObjVO getIamtUnrcvObjVO(int idx) {
		if(!chkListIdx(iamtUnrcvObjVOList, idx)) {
			return null;
		}
		return (IamtUnrcvObjVO) iamtUnrcvObjVOList.get(idx);
	}

	public void setIamtUnrcvObjVO(int idx, IamtUnrcvObjVO iamtUnrcvObjVO) {
		iamtUnrcvObjVOList.set(idx, iamtUnrcvObjVO);
	}

	/**
	 * <p>메소드명		: addIamtUnrcvObjVO</p>
	 * <p>설명			: 입금미수대상을 Add</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public void addIamtUnrcvObjVO(IamtUnrcvObjVO iamtUnrcvObjVO) {
		iamtUnrcvObjVOList.add(iamtUnrcvObjVO);
	}

	/**
	 * <p>메소드명		: isAutoSetl</p>
	 * <p>설명			: 자동결제 여부를 리턴</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public boolean isAutoSetl(){
		return autoSetlFg==null?false:autoSetlFg.equals("1");
	}

	/**
	 * <p>메소드명		: isSuccess</p>
	 * <p>설명			: Constants SUCCESS 여부를 리턴</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public boolean isSuccess() {
		return Constants.SUCCESS.equals(rsltCd);
	}

	/**
	 * <p>메소드명		: initList</p>
	 * <p>설명			: List 초기화</p>
	 * <p>메소드인수1	: N/A</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	private List initList(List list){
		if (list==null)	list = new ArrayList();
		else			list.clear();

		return list;
	}

	/**
	 * <p>메소드명		: chkListIdx</p>
	 * <p>설명			: List의 index의 존재여부 체크</p>
	 * <p>메소드인수1	: List</p>
	 * <p>메소드인수2	: index of List</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	private boolean chkListIdx(List inList, int idx) {
		if (idx<0) return false;
		return sizeList(inList)>idx;
	}

	/**
	 * <p>메소드명		: sizeList</p>
	 * <p>설명			: List의 size를 리턴</p>
	 * <p>메소드인수1	: List</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	private int sizeList(List inList){
		return inList==null?0:inList.size();
	}

	// Getter/Setter <List iamtUnrcvObjVOList> 입금미수대상 리스트
	public List getIamtUnrcvObjVOList(){
		return iamtUnrcvObjVOList;
	}
	public void setIamtUnrcvObjVOList(List objList){
		iamtUnrcvObjVOList = objList;
	}
	public boolean isPduePoss(){
		return "1".equals(pduePossFg);
	}
}
