package hanalife.r.co.vo.service;

import java.util.List;

import hanalife.r.co.vo.mapper.dto.ProcVochCreateINOUTDTO;
import hanalife.r.co.vo.vo.VochVO;
import hanalife.util.BizException;

/**
 * <pre>
 * 클래스명    : VochCCService.java
 * 클래스설명  : 전표처리CC, 입력된 거래를 등록하고 전표처리
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 4. 18.
 * 작성자명    : 70279 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
public interface VochCCService {

	/**
	 * 회계단위를 발생,관리로 구분하여 전표처리한다.
	 * @param inVO
	 * @param con
	 * @return
	 * @throws BizException
	 */
	public VochVO procVochWithAcctUnit(VochVO inVo) throws Exception;


	/**
	 * 거래유형조회
	 * @param trTpCd
	 * @param trStagDivCd
	 * @return String[]
	 * @throws Exception
	 */
	public String[] searchTrTp(String trTpCd, String trStagDivCd) throws Exception;

	/**
	 * 전표 오류발생시 입력값을 로깅처리함.
	 * @param acctDt
	 * @param acctDeptCd
	 * @param tranTpCd
	 * @param tranNo
	 * @param acctUnitCd
	 * @throws Exception
	 */
	public void chkVochCreateBefore(String acctDt, String acctDeptCd,
			   String tranTpCd, int tranNo, String acctUnitCd) throws Exception;

	/**
     * 전표이체처리를 위한 정보 조회(배치용)
     * @param jobDt
     * @return ProcVochCreateINOUTDTO
     * @throws Exception
     */
    public List<ProcVochCreateINOUTDTO> searchVochTran(String jobDt) throws Exception;

    /**
     * 회계전표처리(이체)
     * @param acctDt
     * @param acctDeptCd
     * @param tranTpCd
     * @param tranNo
     * @param acctUnitCd
     * @param isrtEmpNo
     * @return int
     * @throws Exception
     */
    public void procVochCreate(String acctDt, String acctDeptCd, String tranTpCd, int tranNo, String acctUnitCd, String isrtEmpNo) throws Exception;

}
