package hanalife.r.dm.dl.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.r.dm.dl.mapper.DlvrDescReadMapper;
import hanalife.r.dm.dl.mapper.dto.DlvrDescReadDSSD01DTO;
import hanalife.r.dm.dl.mapper.dto.DlvrDescReadDSSMDTO;
import hanalife.r.dm.dl.service.RDMDLM02Service;
import hanalife.r.dm.dl.vo.RDMDLM02DSSD01VO;
import hanalife.r.dm.dl.vo.RDMDLM02DSSD02VO;
import hanalife.r.dm.dl.vo.RDMDLM02S01InVO;
import hanalife.r.dm.dl.vo.RDMDLM02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RDMDLM02ServiceImpl.java Class
 * 클래스설명   : 발송내역 (RDMDLM02) Service Implements
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : searchSdList : 발송내역목록조회
 *          updateDlvrDesc : 발송내역수정
 *          deleteDlvr : 발송내역삭제
 * </pre>
 */
@Service("RDMDLM02Service")
public class RDMDLM02ServiceImpl implements RDMDLM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RDMDLM02ServiceImpl.class);

	/** 공통오류코드 및 오류메시지 내용 전역 변수 선언 */
    private MsgEnum msgEnum;

	@Autowired
	private DlvrDescReadMapper dlvrDescReadMapper;

	/**
	 * <p>메소드명      : getRDMDLM02S01 : 발송내역목록조회</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70321 / KimMinSeok
	 * <p>설명          : 발송내역목록을 조회 한다.</p>
	 * <p>메소드인수    : RDMDLM02S01InVo </p>
	 * <p>메소드리턴값  : RDMDLM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RDMDLM02S01OutVO searchSdList(RDMDLM02S01InVO inVo) throws Exception {

		/** 발송내역 조회 서비스 결과값 객체 생성 */
		RDMDLM02S01OutVO resultVo = new RDMDLM02S01OutVO();

		/** 발송내역에 대한 조회 조건 입력값 객체 생성 및 대입 수행 */
		DlvrDescReadDSSMDTO targetDto = new DlvrDescReadDSSMDTO();

		targetDto.setDueDtFr(inVo.getRDMDLM02DSSMVO().getDueDtFr()); /** 발송일자 */
		targetDto.setDueDtTo(inVo.getRDMDLM02DSSMVO().getDueDtTo()); /** 발송일자 */
		targetDto.setDlvrThngCd(inVo.getRDMDLM02DSSMVO().getDlvrThngCd()); /** 발송종류 */
		targetDto.setDlvrThngKind(inVo.getRDMDLM02DSSMVO().getDlvrThngKind()); /** 발송종류 */
		targetDto.setMngDeptCd(inVo.getRDMDLM02DSSMVO().getMngDeptCd()); /** 관리부서코드 */
		targetDto.setDlvrDtTo(inVo.getRDMDLM02DSSMVO().getDlvrDtTo()); /** 납입일자 */

		String PrdtClasCd = inVo.getRDMDLM02DSSMVO().getPrdtMidClasCd();
		if(PrdtClasCd != null && PrdtClasCd.length() > 0) {
			targetDto.setPrdtLrgeClasCd(PrdtClasCd.substring(0, 1)); /** 상품대분류코드 */
			targetDto.setPrdtMidClasCd(PrdtClasCd.substring(1, 3)); /** 상품중분류코드 */
		}

		targetDto.setLoanNo(inVo.getRDMDLM02DSSMVO().getLoanNo()); /** 대출번호 */
		targetDto.setLoanSeq(inVo.getRDMDLM02DSSMVO().getLoanSeq()); /** 대출일련번호 */
		targetDto.setDlvrDtFr(inVo.getRDMDLM02DSSMVO().getDlvrDtFr()); /** 납입일자 */
		targetDto.setClsSnum(inVo.getRDMDLM02DSSMVO().getClsSnum()); /** 마감일련번호 */
		targetDto.setClsDt(inVo.getRDMDLM02DSSMVO().getClsDt()); /** 마감일자 */
		targetDto.setDlvrKind(inVo.getRDMDLM02DSSMVO().getDlvrKind()); /** 발송방법 */
		/** 회계단위코드 사용X */
//		targetDto.setAcctUnitCd(inVo.getRDMDLM02DSSMVO().getAcctUnitCd()); /** 회계단위코드 */
//		targetDto.setAcctUnitNm(inVo.getRDMDLM02DSSMVO().getAcctUnitNm()); /** 회계단위명 */
		targetDto.setRecvManNo(inVo.getRDMDLM02DSSMVO().getRecvManNo()); /** 수신자번호 */
		targetDto.setHpNo1(inVo.getRDMDLM02DSSMVO().getHpNo1()); /** 핸드폰번호1 */
		targetDto.setHpNo2(inVo.getRDMDLM02DSSMVO().getHpNo2()); /** 핸드폰번호2 */
		targetDto.setHpNo3(inVo.getRDMDLM02DSSMVO().getHpNo3()); /** 핸드폰번호3 */
		targetDto.setRecvFax1(inVo.getRDMDLM02DSSMVO().getRecvFax1()); /** 팩스번호1 */
		targetDto.setRecvFax2(inVo.getRDMDLM02DSSMVO().getRecvFax2()); /** 팩스번호2 */
		targetDto.setRecvFax3(inVo.getRDMDLM02DSSMVO().getRecvFax3()); /** 팩스번호3 */
		targetDto.setDlvrExclFg(inVo.getRDMDLM02DSSMVO().getDlvrExclFg()); /** 발송물제외 */

		/** 발송내역에 대한 조회 쿼리 Mapper 호출 수행 */
		List<DlvrDescReadDSSD01DTO> resultDTO = dlvrDescReadMapper.searchSdList(targetDto);

		/** 발송내역 조회 화면 출력을 위한 결과값 List VO 객체 생성 */
		List<RDMDLM02DSSD01VO> resultList = new ArrayList<RDMDLM02DSSD01VO>();

		for (DlvrDescReadDSSD01DTO sourceIO : resultDTO) {
			/** 발송내역 VO에 조회된 Mapper DTO 값을 대입 */
			RDMDLM02DSSD01VO targetIO = new RDMDLM02DSSD01VO();

			targetIO.setSnum(sourceIO.getSnum()); /** 일련번호 */
			targetIO.setDueDt(sourceIO.getDueDt()); /** 납입일자 */
			targetIO.setDlvrDt(sourceIO.getDlvrDt()); /** 연체일자 */
			targetIO.setDlvrThngCd(sourceIO.getDlvrThngCd()); /** 발송물코드 */
			targetIO.setDlvrThngNm(sourceIO.getDlvrThngNm()); /** 발송물 */
			targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /** 관리부서코드 */
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /** 관리부서 */
			targetIO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd()); /** 상품중분류코드 */
			targetIO.setPrdtMidClasNm(sourceIO.getPrdtMidClasNm()); /** 상품 */
			targetIO.setContMan(sourceIO.getContMan()); /** 고객명 */
			targetIO.setLoanNo(sourceIO.getLoanNo()); /** 대출번호 */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /** 대출일련번호 */
			targetIO.setLoanRelCd(sourceIO.getLoanRelCd()); /** 대출관계코드 */
			targetIO.setLoanRelNm(sourceIO.getLoanRelNm()); /** 대출관계 */
			targetIO.setRecvMan(sourceIO.getRecvMan()); /** 수신자 */
			targetIO.setRlDueManFg(sourceIO.getRlDueManFg()); /** 실납입여부 */
			targetIO.setAskAmt(sourceIO.getAskAmt()); /** 청구금액 */
			targetIO.setSetlDd(sourceIO.getSetlDd()); /** 결제일 */
			targetIO.setAskPamt(sourceIO.getAskPamt()); /** 청구원금 */
			targetIO.setAskInt(sourceIO.getAskInt()); /** 청구이자 */
			targetIO.setAskDfee(sourceIO.getAskDfee()); /** 청구연체료 */
			targetIO.setAskLeglActnCost(sourceIO.getAskLeglActnCost()); /** 청구가지급금 */
			targetIO.setNormPamt(sourceIO.getNormPamt()); /** 정상원금 */
			targetIO.setNormInt(sourceIO.getNormInt()); /** 정상이자 */
			targetIO.setDlyPamt(sourceIO.getDlyPamt()); /** 연체원금 */
			targetIO.setDlyInt(sourceIO.getDlyInt()); /** 연체이자 */
			targetIO.setDlyTcnt(sourceIO.getDlyTcnt()); /** 연체횟수 */
			targetIO.setDlyDdcnt(sourceIO.getDlyDdcnt()); /** 연체일수 */
			targetIO.setDlyStrtDt(sourceIO.getDlyStrtDt()); /** 연체시작일자 */
			targetIO.setLoanDt(sourceIO.getLoanDt()); /** 대출일자 */
			targetIO.setEprtDt(sourceIO.getEprtDt()); /** 만기일자 */
			targetIO.setFcntDueDt(sourceIO.getFcntDueDt()); /** 최초납입일자 */
			targetIO.setClsDt(sourceIO.getClsDt()); /** 마감일자 */
			targetIO.setClsSnum(sourceIO.getClsSnum()); /** 마감일련번호 */
			targetIO.setRsndFg(sourceIO.getRsndFg()); /** 반송여부 */
			targetIO.setCorrFg(sourceIO.getCorrFg()); /** 보정여부 */
			targetIO.setRecvAddr(sourceIO.getRecvAddr()); /** 주소 */
			targetIO.setLastEmpNo(sourceIO.getLastEmpNo()); /** 등록사번 */
			targetIO.setLastEmpNm(sourceIO.getLastEmpNm()); /** 등록자명 */
			targetIO.setRegDtTm(sourceIO.getRegDtTm()); /** 등록일시 */
			targetIO.setAcctUnitCd(sourceIO.getAcctUnitCd()); /**  */
			targetIO.setAcctUnitNm(sourceIO.getAcctUnitNm()); /**  */
			targetIO.setIntgDlvrFg(sourceIO.getIntgDlvrFg()); /** 통합여부 */
			targetIO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd()); /** 상품대분류코드 */
			targetIO.setAskTrtFee(sourceIO.getAskTrtFee()); /** 청구취급수수료 */
			targetIO.setNormTrtFee(sourceIO.getNormTrtFee()); /** 정상취급수수료 */
			targetIO.setDlyTrtFee(sourceIO.getDlyTrtFee()); /** 연체취급수수료 */
			targetIO.setTrtFeeIstpFg(sourceIO.getTrtFeeIstpFg()); /**  */
			targetIO.setSubDlvrFg(sourceIO.getSubDlvrFg()); /**  */
			targetIO.setSmsSendFg(sourceIO.getSmsSendFg()); /**  */
			targetIO.setFaxRqstFilePath(sourceIO.getFaxRqstFilePath()); /**  */
			targetIO.setSmsCntn(sourceIO.getSmsCntn()); /**  */
			targetIO.setDdayLoseRsn(sourceIO.getDdayLoseRsn()); /**  */
			targetIO.setRlDlvrDt(sourceIO.getRlDlvrDt()); /** 발송일자 */
			targetIO.setSubDlvrThngCd(sourceIO.getSubDlvrThngCd()); /** 발송제외코드 */
			targetIO.setSubDlvrThngNm(sourceIO.getSubDlvrThngNm()); /** 발송제외 */

			/** 상단의 발송내역 조회 결과 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);
		}

		/** 발송내역 조회 서비스 결과값 객체에 조회 결과 List 추가 */
		resultVo.setListRDMDLM02DSSD01VO(resultList);

		return resultVo;

	}

	/**
	 * <p>메소드명      : modifyRDMDLM02U01 - 발송내역수정</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70321 / KimMinSeok
	 * <p>설명          : 삭제 카운트가 1개 이상일 경우 발송내역수정</p>
	 * <p>메소드인수    : RDMDLM02U01InVo </p>
	 * <p>메소드리턴값  : RDMDLM02U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RDMDLM02S01OutVO updateDlvrDesc(RDMDLM02S01InVO inVo) throws Exception {

		/** 발송내역 수정 서비스 결과값 객체 생성 */
		RDMDLM02S01OutVO resultVo = new RDMDLM02S01OutVO();

		/** 발송내역에 대한 수정 조건 입력값 객체 생성 및 대입 수행 */
		DlvrDescReadDSSMDTO targetDto = new DlvrDescReadDSSMDTO();

		targetDto.setClsSnum(inVo.getRDMDLM02DSSMVO().getClsSnum()); /** 마감일련번호 */
		targetDto.setClsDt(inVo.getRDMDLM02DSSMVO().getClsDt()); /** 마감일자 */
		targetDto.setDlvrStatCd( "3" ); /** 발송상태 코드 */
		targetDto.setLastProcEmpNo(inVo.getRDMDLM02DSSMVO().getEmpNo()); /** 사원번호 */

		List<RDMDLM02DSSD02VO> resultList = new ArrayList<RDMDLM02DSSD02VO>();

		/** 발송내역 VO에 수정 후 결과 코드 DTO 설정 */
		RDMDLM02DSSD02VO targetIO = new RDMDLM02DSSD02VO();

		try {

			/** 발송내역에 대한 수정 쿼리 Mapper 호출 수행 */
			int rsltCnt = this.dlvrDescReadMapper.updateDlvrClsDesc(targetDto);

			/** 결과값의 수가 1개 미만일 경우 에러 */
//			if( rsltCnt > 1 ) {
//				targetIO.setRsltCd(MsgEnum.NOT_FOUND.getErrorCd());
//				targetIO.setRsltCntn(MsgEnum.NOT_FOUND.getDescription());
//			}else {
//				targetIO.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
//				targetIO.setRsltCntn(MsgEnum.SUCCESS.getDescription());
//			}

		}catch (Exception e) {
		}

		/** 상단의 발송내역 수정 결과 코드, 메시지 List 객체에 추가하도록 수행 */
        resultList.add(targetIO);

		/** 발송내역 수정 서비스 결과 리스트 VO에 추가 */
		resultVo.setListRDMDLM02DSSD02VO(resultList);

		/** 결과 코드, 메시지 리턴 */
		return resultVo;

	}

	/**
	 * <p>메소드명      : removeRDMDLM02D01 - 발송내역삭제</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70321 / KimMinSeok
	 * <p>설명          : 발송내역삭제</p>
	 * <p>메소드인수    : RDMDLM02D01InVo </p>
	 * <p>메소드리턴값  : RDMDLM02D01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RDMDLM02S01OutVO deleteDlvr(RDMDLM02S01InVO inVo) throws Exception {

		/** 발송내역 삭제 서비스 결과값 객체 생성 */
		RDMDLM02S01OutVO resultVo = new RDMDLM02S01OutVO();

		/** 발송내역에 대한 삭제 조건 입력값 객체 생성 및 대입 수행 */
		DlvrDescReadDSSMDTO targetDto = new DlvrDescReadDSSMDTO();

		targetDto.setClsSnum(inVo.getRDMDLM02DSSMVO().getClsSnum()); /** 마감일련번호 */
		targetDto.setClsDt(inVo.getRDMDLM02DSSMVO().getClsDt()); /** 마감일자 */

		List<RDMDLM02DSSD02VO> resultList = new ArrayList<RDMDLM02DSSD02VO>();

		/** 발송내역 VO에 삭제 후 결과 코드 DTO 설정 */
		RDMDLM02DSSD02VO targetIO = new RDMDLM02DSSD02VO();

		try {

			/** 발송내역에 대한 삭제 쿼리 Mapper 호출 수행 */
			int rsltCnt = this.dlvrDescReadMapper.deleteDlvr(targetDto);

			/** 결과값의 수가 1개 이상일 경우 업데이트 서비스 수행 */
			if( rsltCnt >= 1 ) {
				resultVo = updateDlvrDesc(inVo);

				/** 결과 코드, 메시지 리턴 */
//				return resultVo;
			}

		}catch (Exception e) {
		}

		/** 상단의 발송내역 삭제 결과 코드, 메시지 List 객체에 추가하도록 수행 */
        resultList.add(targetIO);

		/** 발송내역 삭제 서비스 결과 리스트 VO에 추가 */
		resultVo.setListRDMDLM02DSSD02VO(resultList);

		/** 결과 코드, 메시지 리턴 */
		return resultVo;

	}

}
