package hanalife.r.dm.dl.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.r.dm.dl.mapper.DlvrDescReadSmsMapper;
import hanalife.r.dm.dl.mapper.dto.DlvrDescReadSmsDSSD01DTO;
import hanalife.r.dm.dl.mapper.dto.DlvrDescReadSmsDSSM01DTO;
import hanalife.r.dm.dl.service.RDMDLM04Service;
import hanalife.r.dm.dl.vo.RDMDLM04DSSD01VO;
import hanalife.r.dm.dl.vo.RDMDLM04S01InVO;
import hanalife.r.dm.dl.vo.RDMDLM04S01OutVO;


/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RDMDLM04ServiceImpl.java Class
 * 클래스설명   : 발송내역(SMS) (RDMDLM04) Service Implements
 * 작성일자     : 2023. 4. 26.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 26.][70366 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : searchDssm01List : 발송내역(SMS) 목록조회
 *
 *
 * </pre>
 */
@Service("RDMDLM04Service")
public class RDMDLM04ServiceImpl implements RDMDLM04Service{

    @Autowired
    private DlvrDescReadSmsMapper dlvrDescReadSmsMapper;

    private static final Logger LOGGER = LoggerFactory.getLogger(RDMDLM02ServiceImpl.class);

    /** 공통오류코드 및 오류메시지 내용 전역 변수 선언 */
    private MsgEnum msgEnum;

    /**
     * <p>메소드명      : searchDssm01List - 발송내역(SMS) 조회</p>
     * <p>작성일자      : 2023. 05. 02.
     * <p>작성자(author): 70366 / KangMinhyeok
     * <p>설명          : 발송내역(SMS) 목록을 조회한다.</p>
     * <p>메소드인수    : RDMDLM04S01InVO </p>
     * <p>메소드리턴값  : RDMDLM04S01OutVO</p>
     * <p>예외처리      : Exception</p>
     */

    @Override
    public RDMDLM04S01OutVO searchDssm01List(RDMDLM04S01InVO inVo) throws Exception{
        LOGGER.info("&&&&& RDMDLM04SERVICE searchDssm01List  START &&&&&");

        /**발송내역(SMS) 조회 서비스 결과값 객체 생성*/
        RDMDLM04S01OutVO resultVO = new RDMDLM04S01OutVO();

        /**발송내역(SMS)에 대한 조회 조건 입력값 객체 생성 및 대입 수행 */
        DlvrDescReadSmsDSSM01DTO targetDto = new DlvrDescReadSmsDSSM01DTO();

        targetDto.setDlvrDtFr(inVo.getRDMDLM04DSSM01VO().getDlvrDtFr());        /**발송_일자_시작일자*/
        targetDto.setDlvrDtTo(inVo.getRDMDLM04DSSM01VO().getDlvrDtTo());      /**발송_일자_종료일자*/
        targetDto.setDueDtFr(inVo.getRDMDLM04DSSM01VO().getDueDtFr());      /** 납입_일자_시작일자 */
        targetDto.setDueDtTo(inVo.getRDMDLM04DSSM01VO().getDueDtTo());      /** 납입_일자_종료일자 */
        targetDto.setLoanNo(inVo.getRDMDLM04DSSM01VO().getLoanNo());        /** 대출_번호 */
        targetDto.setLoanSeq(inVo.getRDMDLM04DSSM01VO().getLoanSeq());      /** 대출_순서 */
        targetDto.setHpNo1(inVo.getRDMDLM04DSSM01VO().getHpNo1());      /** 휴대폰_번호1 */
        targetDto.setHpNo2(inVo.getRDMDLM04DSSM01VO().getHpNo2());      /** 휴대폰_번호2 */
        targetDto.setHpNo3(inVo.getRDMDLM04DSSM01VO().getHpNo3());      /** 휴대폰_번호3 */
        targetDto.setSendStat(inVo.getRDMDLM04DSSM01VO().getSendStat());        /** SMS_전송_상태 */

        List<DlvrDescReadSmsDSSD01DTO> queryResultList = dlvrDescReadSmsMapper.searchDssm01List(targetDto);

        for(DlvrDescReadSmsDSSD01DTO item : queryResultList) {
            RDMDLM04DSSD01VO  dssd01Vo =  new RDMDLM04DSSD01VO();

            dssd01Vo.setSlct(item.getSlct());
            dssd01Vo.setClsDt(item.getClsDt());       /** 마감_일자 */
            dssd01Vo.setClsSnum(item.getClsSnum());     /** 마감_일련번호  */
            dssd01Vo.setDlvrDt(item.getDlvrDt());       /** 발송_일자 */
            dssd01Vo.setDueDt(item.getDueDt());     /** 납입_일자 */
            dssd01Vo.setContMan(item.getContMan());      /** 계약자 */
            dssd01Vo.setContManNo(item.getContManNo());     /** 계약자_번호 */
            dssd01Vo.setRlDueMan(item.getRlDueMan());        /** 실_납입_자 */
            dssd01Vo.setIntgCnt(item.getIntgCnt());     /** 통합_건수 */
            dssd01Vo.setAskAmt(item.getAskAmt());       /** 청구_금액 */
            dssd01Vo.setAutoTranBankNm(item.getAutoTranBankNm());       /** 자동이체_은행_명 */
            dssd01Vo.setAcntNo(item.getAcntNo());       /** 계좌번호 */
            dssd01Vo.setHpNo1(item.getHpNo1());     /** 휴대폰_번호1 */
            dssd01Vo.setHpNo2(item.getHpNo2());     /** 휴대폰_번호2 */
            dssd01Vo.setHpNo3(item.getHpNo3());      /** 휴대폰_번호3 */
            dssd01Vo.setSmsSendRsltCd(item.getSmsSendRsltCd());      /** SMS_전송_결과_코드 */
            dssd01Vo.setSmsSendRsltNm(item.getSmsSendRsltNm());     /** SMS_전송_결과_명 */
            dssd01Vo.setSmsCntn(item.getSmsCntn());     /** SMS_내용 */
            dssd01Vo.setDlvrExclCd(item.getDlvrExclCd());   /** 발송_제외_코드 */
            dssd01Vo.setDlvrExclNm(item.getDlvrExclNm());       /** 발송_제외_명 */
            dssd01Vo.setAcntStatCd(item.getAcntStatCd());       /** 계좌_상태_코드 */
            dssd01Vo.setAcntStatNm(item.getAcntStatNm());       /** 계좌_상태_명 */
            dssd01Vo.setLoanNo(item.getLoanNo());       /** 대출_번호 */
            dssd01Vo.setLoanSeq(item.getLoanSeq());     /** 대출_순서 */

            resultVO.getListRDMDLM04DSSD01VO().add(dssd01Vo);
        }
        return resultVO;
    }

}
