package hanalife.r.dm.dl.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.dm.dl.service.RDMDLM01Service;
import hanalife.r.dm.dl.vo.RDMDLM01DSSM2VO;
import hanalife.r.dm.dl.vo.RDMDLM01DSSM3VO;
import hanalife.r.dm.dl.vo.RDMDLM01DSSMVO;
import hanalife.r.dm.dl.vo.RDMDLM01S01InVO;
import hanalife.r.dm.dl.vo.RDMDLM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RDMDLM01Controller.java Class
 * 클래스설명   : 발송관리 (RDMDLM01) Controller
 * 작성일자     : 2023. 3. 9.
 * 작성자명     : 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 9.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/dm/dl")
@Controller
public class RDMDLM01Controller {

	@Resource(name = "RDMDLM01Service")
	private RDMDLM01Service RDMDLM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(RDMDLM01Controller.class);

	/**
	 * <p>메소드명      : 발송관리_대출내역조회 /RDMDLM01S01.do </p>
	 * <p>작성일자      : 2023. 3. 09
	 * <p>작성자(author): 70319
	 * <p>설명          : 발송관리_대출내역조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/searchLoanDescList.do")
	public String RDMDLM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RDMDLM01Controller RDMDLM01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** RDMDLM01S01 내역조회 업무 서비스 호출 입력값 대입 */
			RDMDLM01DSSMVO targetVo = new RDMDLM01DSSMVO();
			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RDMDLM01S01InVO InVO = new RDMDLM01S01InVO();
            InVO.setRDMDLM01DSSMVO(targetVo);    /** 발송관리조회 DS_SMDO 입력값 VO 객체 대입 */

			/** RDMDLM01S01 내역조회 업무 서비스 호출 수행 */
			RDMDLM01S01OutVO resulS01List = RDMDLM01.getRDMDLM01S01(InVO);

			XFrame5Util.setOutputData("DS_SD01", resulS01List.getRDMDLM01DSSDDO01VO(), model); /** 대출정보조회 */

			LOGGER.info("##### RDMDLM01Controller RDMDLM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RDMDLM01Controller RDMDLM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 발송관리_대출내역조회 /RDMDLM01S02.do </p>
	 * <p>작성일자      : 2023. 3. 09
	 * <p>작성자(author): 70319
	 * <p>설명          : 발송관리_대출내역조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/searchLoanRelManList.do")
	public String RDMDLM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RDMDLM01Controller RDMDLM01S02 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM2", request, response, model);

			/** RDMDLM01S01 내역조회 업무 서비스 호출 입력값 대입 */
			RDMDLM01DSSM2VO targetVo = new RDMDLM01DSSM2VO();
			targetVo.setLoanNo( sourceMap.get("loanNo").toString()); /** 대출번호 */
			targetVo.setLoanSeq( sourceMap.get("loanSeq").toString()); /** 대출순번 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RDMDLM01S01InVO InVO = new RDMDLM01S01InVO();
            InVO.setRDMDLM01DSSM2VO(targetVo);    /** 발송관리_대출관계자 조회 DS_SMDO 입력값 VO 객체 대입 */

			/** RDMDLM01S01 내역조회 업무 서비스 호출 수행 */
			RDMDLM01S01OutVO resulS01List = RDMDLM01.getRDMDLM01S02(InVO);

			XFrame5Util.setOutputData("DS_SD02", resulS01List.getRDMDLM01DSSDDO02VO(), model); /** 대출관계자조회 */

			LOGGER.info("##### RDMDLM01Controller RDMDLM01S02 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RDMDLM01Controller RDMDLM01S02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 발송관리_고객주소조회 /RDMDLM01S03.do </p>
	 * <p>작성일자      : 2023. 3. 09
	 * <p>작성자(author): 70319
	 * <p>설명          : 발송관리_고객주소조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/searchCustAddrList.do")
	public String RDMDLM01S03(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RDMDLM01Controller RDMDLM01S02 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM2", request, response, model);

			/** RDMDLM01S01 내역조회 업무 서비스 호출 입력값 대입 */
			RDMDLM01DSSM3VO targetVo = new RDMDLM01DSSM3VO();
			targetVo.setCustNo(sourceMap.get("custNo").toString()); /** 고객번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RDMDLM01S01InVO InVO = new RDMDLM01S01InVO();
            InVO.setRDMDLM01DSSM3VO(targetVo);    /** 발송관리_고객주소 조회 DS_SMDO 입력값 VO 객체 대입 */

			/** RDMDLM01S01 내역조회 업무 서비스 호출 수행 */
			RDMDLM01S01OutVO resulS01List = RDMDLM01.getRDMDLM01S03(InVO);

			XFrame5Util.setOutputData("DS_SD03", resulS01List.getRDMDLM01DSSDDO03VO(), model); /** 고객주소조회 */

			LOGGER.info("##### RDMDLM01Controller RDMDLM01S03 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RDMDLM01Controller RDMDLM01S03 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : todo1등록 /todo0I01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : todo1등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
//	@RequestMapping("/todo0I01.do")
//	public String todo0I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
//
//		LOGGER.info("##### todo0Controller todo0I01 Start #####");
//
//		try {
//			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
//			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
//
//			/** todo1내역조회 업무 서비스 호출 입력값 대입 */
//			todo0S01InVO targetVo = new todo0S01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */
//
//			/** todo1내역조회 업무 서비스 호출 수행 */
//			todo0S01OutVO resulttodo0I01 = todo0.registertodo0I01(targetVo);
//
//			XFrame5Util.setOutputData("DS_SD01", resulttodo0I01.gettodo0I0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resulttodo0I01.gettodo0I0102VO(), model); /** 수납목록조회 */
//
//			LOGGER.info("##### todo0Controller todo0I01 Normal End #####");
//		} catch (Exception e) {
//			LOGGER.error("Error >>> " + e.getMessage());
//			// 오류 메시지 정보 설정
//			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
//			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
//
//			LOGGER.info("##### todo0Controller todo0I01 Exception End #####");
//		}
//
//		return XFrame5View.XFRAME5_VIEW;
//	}

	/**
	 * <p>메소드명      : todo1수정 /todo0U01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : todo1수정 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
//	@RequestMapping("/todo0U01.do")
//	public String todo0U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
//
//		LOGGER.info("##### todo0Controller todo0U01 Start #####");
//
//		try {
//			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
//			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
//
//			/** todo1내역조회 업무 서비스 호출 입력값 대입 */
//			todo0U01InVO targetVo = new todo0U01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */
//
//			/** todo1내역조회 업무 서비스 호출 수행 */
//			todo0S01OutVO resulttodo0U01 = todo0.modifytodo0U01(targetVo);
//
//			XFrame5Util.setOutputData("DS_SD01", resulttodo0U01.gettodo0U0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resulttodo0U01.gettodo0U0102VO(), model); /** 수납목록조회 */
//
//			LOGGER.info("##### todo0Controller todo0U01 Normal End #####");
//		} catch (Exception e) {
//			LOGGER.error("Error >>> " + e.getMessage());
//			// 오류 메시지 정보 설정
//			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
//			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
//
//			LOGGER.info("##### todo0Controller todo0U01 Exception End #####");
//		}
//
//		return XFrame5View.XFRAME5_VIEW;
//	}

	/**
	 * <p>메소드명      : todo1삭제 /todo0D01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : todo1삭제 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
//	@RequestMapping("/todo0D01.do")
//	public String todo0D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
//
//		LOGGER.info("##### todo0Controller todo0D01 Start #####");
//
//		try {
//			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
//			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
//
//			/** todo1내역조회 업무 서비스 호출 입력값 대입 */
//			todo0D01InVO targetVo = new todo0D01InVO();
//			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
//			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
//			targetVo.setSetDiv((String) sourceMap.get("setDiv")); /** 결제구분 */
//			targetVo.setAcctDtFr((String) sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
//			targetVo.setAcctDtTo((String) sourceMap.get("acctDtTo")); /** 회계조회종료일자 */
//
//			/** todo1내역조회 업무 서비스 호출 수행 */
//			todo0S01OutVO resulttodo0D01 = todo0.removetodo0D01(targetVo);
//
//			XFrame5Util.setOutputData("DS_SD01", resulttodo0D01.gettodo0D0101VO(), model); /** 대출정보조회 */
//			XFrame5Util.setOutputData("DS_SD02", resulttodo0D01.gettodo0D0102VO(), model); /** 수납목록조회 */
//
//			LOGGER.info("##### todo0Controller todo0D01 Normal End #####");
//		} catch (Exception e) {
//			LOGGER.error("Error >>> " + e.getMessage());
//			// 오류 메시지 정보 설정
//			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
//			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
//
//			LOGGER.info("##### todo0Controller todo0D01 Exception End #####");
//		}
//
//		return XFrame5View.XFRAME5_VIEW;
//	}

}
