package hanalife.r.dm.dl.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.dm.dl.service.RDMDLM02Service;
import hanalife.r.dm.dl.vo.RDMDLM02DSSMVO;
import hanalife.r.dm.dl.vo.RDMDLM02S01InVO;
import hanalife.r.dm.dl.vo.RDMDLM02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RDMDLM02Controller.java Class
 * 클래스설명   : 발송내역 (RDMDLM02) Controller
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/dm/dl")
@Controller
public class RDMDLM02Controller {

	@Resource(name = "RDMDLM02Service")
	private RDMDLM02Service RDMDLM02;

	private static final Logger LOGGER = LoggerFactory.getLogger(RDMDLM02Controller.class);

	/**
	 * <p>
	 * 메소드명 : 발송내역조회 /RDMDLM02S01.do
	 * </p>
	 * <p>
	 * 작성일자 : 2023. 2. 27.
	 * <p>
	 * 작성자(author): 70317
	 * <p>
	 * 설명 : 발송내역조회 한다.
	 * </p>
	 * <p>
	 * 예외처리 : Exception
	 * </p>
	 */
	@RequestMapping("/RDMDLM02S01.do")
	public String RDMDLM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model)
			throws Exception {

		LOGGER.info("##### RDMDLM02Controller RDMDLM02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceDSSMMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
			//로그인사용자정보 - 업데이트를 위한 사원번호 필요
			//Map<String, Object> sourceDSSQLINFOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SQL_INFO", request, response, model);

			/** 발송내역조회 업무 서비스 호출 입력값 대입 */
			RDMDLM02DSSMVO targetVo = new RDMDLM02DSSMVO();
			targetVo.setDueDtFr((String)sourceDSSMMap.get("dueDtFr")); /** 발송일자 */
			targetVo.setDueDtTo((String)sourceDSSMMap.get("dueDtTo")); /** 발송일자 */
			targetVo.setDlvrThngCd((String)sourceDSSMMap.get("dlvrThngCd")); /** 발송종류 */
			targetVo.setMngDeptCd((String)sourceDSSMMap.get("mngDeptCd")); /** 관리부서코드 */
			targetVo.setMngDeptNm((String)sourceDSSMMap.get("mngDeptNm")); /** 관리부서명 */
			targetVo.setDlvrDtTo((String)sourceDSSMMap.get("dlvrDtTo")); /** 납입일자 */
			targetVo.setPrdtMidClasCd((String)sourceDSSMMap.get("prdtMidClasCd")); /** 상품코드 */
			targetVo.setLoanNo((String)sourceDSSMMap.get("loanNo")); /** 대출번호 */
			targetVo.setLoanSeq((String)sourceDSSMMap.get("loanSeq")); /** 대출일련번호 */
			targetVo.setDlvrDtFr((String)sourceDSSMMap.get("dlvrDtFr")); /** 납입일자 */
			targetVo.setClsSnum((String)sourceDSSMMap.get("clsSnum")); /** 일련번호 */
			targetVo.setClsDt((String)sourceDSSMMap.get("clsDt")); /** 마감일자 */
			targetVo.setDlvrKind((String)sourceDSSMMap.get("dlvrKind")); /** 발송방법 */
			targetVo.setAcctUnitCd((String)sourceDSSMMap.get("acctUnitCd")); /** 회계번호코드 */
			targetVo.setAcctUnitNm((String)sourceDSSMMap.get("acctUnitNm")); /** 회계번호명 */
			targetVo.setRecvManNo((String)sourceDSSMMap.get("recvManNo")); /** 수신자번호 */
			targetVo.setRecvMan((String)sourceDSSMMap.get("recvMan")); /** 수신자번호 */
			targetVo.setHpNo1((String)sourceDSSMMap.get("hpNo1")); /** 핸드폰번호1 */
			targetVo.setHpNo2((String)sourceDSSMMap.get("hpNo2")); /** 핸드폰번호2 */
			targetVo.setHpNo3((String)sourceDSSMMap.get("hpNo3")); /** 핸드폰번호3 */
			targetVo.setRecvFax1((String)sourceDSSMMap.get("recvFax1")); /** 팩스번호1 */
			targetVo.setRecvFax2((String)sourceDSSMMap.get("recvFax2")); /** 팩스번호2 */
			targetVo.setRecvFax3((String)sourceDSSMMap.get("recvFax3")); /** 팩스번호3 */
			targetVo.setDlvrExclFg((String)sourceDSSMMap.get("dlvrExclFg")); /** 발송물제외 */
			//targetVo.setEmpNo((String)sourceDSSQLINFOMap.get("loginEmpNo")); /** 사원번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RDMDLM02S01InVO InVO = new RDMDLM02S01InVO();
            InVO.setRDMDLM02DSSMVO(targetVo); /** 발송내역조회 DS_SM 입력값 VO 객체 대입 */

			/** 발송내역조회 업무 서비스 호출 수행 */
            RDMDLM02S01OutVO resultRDMDLM02S01 = RDMDLM02.searchSdList(InVO);

			XFrame5Util.setOutputData("DS_SD01", resultRDMDLM02S01.getListRDMDLM02DSSD01VO(), model); /** 발송내역조회 */

			LOGGER.info("##### RDMDLM02Controller RDMDLM02S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RDMDLM02Controller RDMDLM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>
	 * 메소드명 : 발송내역삭제 /RDMDLM02D01.do
	 * </p>
	 * <p>
	 * 작성일자 : 2023. 2. 27.
	 * <p>
	 * 작성자(author): 70317
	 * <p>
	 * 설명 : 발송내역삭제 한다.
	 * </p>
	 * <p>
	 * 예외처리 : Exception
	 * </p>
	 */
	@RequestMapping("/RDMDLM02D01.do")
	public String RDMDLM02D01(HttpServletRequest request, HttpServletResponse response, ModelMap model)
			throws Exception {

		LOGGER.info("##### RDMDLM02Controller RDMDLM02D01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceDSSMMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);
			//로그인사용자정보 - 현재 작업 완료되지 않아 Map이 null로 떨어져 주석 처리 및 후에 사원번호를 위해 주석 제거 바람
			//Map<String, Object> sourceDSSQLINFOMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SQL_INFO", request, response, model);

			/** 발송내역삭제 업무 서비스 호출 입력값 대입 */
			RDMDLM02DSSMVO targetVo = new RDMDLM02DSSMVO();
			targetVo.setDueDtFr((String)sourceDSSMMap.get("dueDtFr")); /** 발송일자 */
			targetVo.setDueDtTo((String)sourceDSSMMap.get("dueDtTo")); /** 발송일자 */
			targetVo.setDlvrThngCd((String)sourceDSSMMap.get("dlvrThngCd")); /** 발송종류 */
			targetVo.setMngDeptCd((String)sourceDSSMMap.get("mngDeptCd")); /** 관리부서코드 */
			targetVo.setMngDeptNm((String)sourceDSSMMap.get("mngDeptNm")); /** 관리부서명 */
			targetVo.setDlvrDtTo((String)sourceDSSMMap.get("dlvrDtTo")); /** 납입일자 */
			targetVo.setPrdtMidClasCd((String)sourceDSSMMap.get("prdtMidClasCd")); /** 상품코드 */
			targetVo.setLoanNo((String)sourceDSSMMap.get("loanNo")); /** 대출번호 */
			targetVo.setLoanSeq((String)sourceDSSMMap.get("loanSeq")); /** 대출일련번호 */
			targetVo.setDlvrDtFr((String)sourceDSSMMap.get("dlvrDtFr")); /** 납입일자 */
			targetVo.setClsSnum((String)sourceDSSMMap.get("clsSnum")); /** 일련번호 */
			targetVo.setClsDt((String)sourceDSSMMap.get("clsDt")); /** 마감일자 */
			targetVo.setDlvrKind((String)sourceDSSMMap.get("dlvrKind")); /** 발송방법 */
			targetVo.setAcctUnitCd((String)sourceDSSMMap.get("acctUnitCd")); /** 회계번호코드 */
			targetVo.setAcctUnitNm((String)sourceDSSMMap.get("acctUnitNm")); /** 회계번호명 */
			targetVo.setRecvManNo((String)sourceDSSMMap.get("recvManNo")); /** 수신자번호 */
			targetVo.setRecvMan((String)sourceDSSMMap.get("recvMan")); /** 수신자번호 */
			targetVo.setHpNo1((String)sourceDSSMMap.get("hpNo1")); /** 핸드폰번호1 */
			targetVo.setHpNo2((String)sourceDSSMMap.get("hpNo2")); /** 핸드폰번호2 */
			targetVo.setHpNo3((String)sourceDSSMMap.get("hpNo3")); /** 핸드폰번호3 */
			targetVo.setRecvFax1((String)sourceDSSMMap.get("recvFax1")); /** 팩스번호1 */
			targetVo.setRecvFax2((String)sourceDSSMMap.get("recvFax2")); /** 팩스번호2 */
			targetVo.setRecvFax3((String)sourceDSSMMap.get("recvFax3")); /** 팩스번호3 */
			targetVo.setDlvrExclFg((String)sourceDSSMMap.get("dlvrExclFg")); /** 발송물제외 */
			//targetVo.setEmpNo((String)sourceDSSQLINFOMap.get("loginEmpNo")); /** 사원번호 */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RDMDLM02S01InVO InVO = new RDMDLM02S01InVO();
            InVO.setRDMDLM02DSSMVO(targetVo); /** 발송내역삭제 DS_SM 입력값 VO 객체 대입 */

			/** 발송내역삭제 업무 서비스 호출 수행 */
			RDMDLM02S01OutVO resultRDMDLM02D01 = RDMDLM02.deleteDlvr(InVO);

			XFrame5Util.setOutputData("DS_SD02", resultRDMDLM02D01.getListRDMDLM02DSSD02VO(), model); /** 발송내역삭제 */

			LOGGER.info("##### RDMDLM02Controller RDMDLM02D01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RDMDLM02Controller RDMDLM02D01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
