package hanalife.r.rc.cl.web;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.co.la.service.LoanInfoProcMngService;
import hanalife.r.rc.cl.service.RRCCLM01Service;
import hanalife.r.rc.cl.vo.RRCCLM01DSSD1VO;
import hanalife.r.rc.cl.vo.RRCCLM01DSSD2VO;
import hanalife.r.rc.cl.vo.RRCCLM01DSSM1VO;
import hanalife.r.rc.cl.vo.RRCCLM01DSSMVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

@RequestMapping("/r/rc/cl")
@Controller
public class RRCCLM01Controller {

    @Resource(name = "RRCCLM01Service")
    private RRCCLM01Service RRCCLM01;

    @Resource(name = "LoanInfoProcMngService")
    private LoanInfoProcMngService LoanInfoProcMngService;

    private static final Logger LOGGER = LoggerFactory.getLogger(RRCCLM01Controller.class);

    /**
     * <p>메소드명       : 수납거래내역조회 /RRCCLM01S01.do </p>
     * <p>작성일자       : 2023. 4. 20.
     * <p>작성자(author): 70317
     * <p>설명          : 수납거래내역을 조회한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/RRCCLM01S01.do")
    public String RRCCLM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RRCRCM03Controller RRCRCM03S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);

            /** 수납내역상세조회 업무 서비스 호출 입력값 대입 */
            RRCCLM01DSSMVO targetVo = new RRCCLM01DSSMVO();
            targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */
            targetVo.setAcctDtFr((String)sourceMap.get("acctDtFr")); /** 회계일자From */
            targetVo.setAcctDtTo((String)sourceMap.get("acctDtTo")); /** 회계일자To */
            targetVo.setIsrtDeptCd((String)sourceMap.get("isrtDeptCd")); /** 입력부서코드 */
            targetVo.setIsrtDtFr((String)sourceMap.get("isrtDtFr")); /** 입력일자From */
            targetVo.setIsrtDtTo((String)sourceMap.get("isrtDtTo")); /** 입력일자To */

            targetVo.setPrdtClasCd((String)sourceMap.get("prdtClasCd")); /** 상품코드 */
            targetVo.setTrTpCd((String)sourceMap.get("trTpCd")); /** 거래유형코드 */
            targetVo.setFrstRegEmpNo((String)sourceMap.get("frstRegEmpNo")); /** 입력자 */
            targetVo.setSetlDivCd((String)sourceMap.get("setlDivCd")); /** 결제구분코드 */

            /** 수납내역상세조회 업무 서비스 호출 수행 */
            List<RRCCLM01DSSD1VO> resultS01 = RRCCLM01.searchDescList(targetVo);


                XFrame5Util.setOutputData("DS_SD_01", resultS01, model); /** 대출정보조회 */
//                XFrame5Util.setOutputData("DS_RCPT_DESC_SD01", resultRRCRCM03S01.getListRRCRCM03DSRCPTDESCSD01VO(), model); /** 대출정보조회 */
//                XFrame5Util.setOutputData("DS_RCPT_DESC_SD02", resultRRCRCM03S01.getListRRCRCM03DSRCPTDESCSD02VO(), model); /** 대출정보조회 */

                LOGGER.info("##### RRCCLM01Controller RRCCLM01S01 Normal End #####");


        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RRCCLM01Controller RRCCLM01S01 Exception End #####");
        }


        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p>메소드명       : 수납거래내역 sub 조회 /RRCCLM01S02.do </p>
     * <p>작성일자       : 2023. 4. 20.
     * <p>작성자(author): 70317
     * <p>설명          : 수납거래내역의 건별 전표내역을 조회한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/RRCCLM01S02.do")
    public String RRCCLM01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RRCCLM01Controller RRCCLM01S02 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH_CLS_SUB", request, response, model);
            LOGGER.info("##### 입력세팅... #####");
            /** 수납내역상세조회 업무 서비스 호출 입력값 대입 */
            RRCCLM01DSSM1VO targetVo = new RRCCLM01DSSM1VO();
            targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */
            targetVo.setAcctDt((String)sourceMap.get("acctDt")); /** 대출순번 */
            targetVo.setTrDescNo((String)sourceMap.get("trDescNo")); /** 대출순번 */

            LOGGER.info("##### RRCCLM01.searchClsDescSub #####");
            /** 수납내역상세조회 업무 서비스 호출 수행 */
            List<RRCCLM01DSSD2VO> resultS01 = RRCCLM01.searchClsDescSub(targetVo);


                XFrame5Util.setOutputData("DS_SD_02", resultS01, model); /** 대출정보조회 */
//                XFrame5Util.setOutputData("DS_RCPT_DESC_SD01", resultRRCRCM03S01.getListRRCRCM03DSRCPTDESCSD01VO(), model); /** 대출정보조회 */
//                XFrame5Util.setOutputData("DS_RCPT_DESC_SD02", resultRRCRCM03S01.getListRRCRCM03DSRCPTDESCSD02VO(), model); /** 대출정보조회 */

                LOGGER.info("##### RRCCLM01Controller RRCCLM01S02 Normal End #####");


        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RRCCLM01Controller RRCCLM01S01 Exception End #####");
        }


        return XFrame5View.XFRAME5_VIEW;
    }

}
