package hanalife.r.rc.mn.service.impl;

import java.sql.SQLException;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.DateUtil;
import hanalife.r.rc.mn.mapper.CprtContMngMdulMapper;
import hanalife.r.rc.mn.mapper.dto.CprtContMngMdulObjDTO;
import hanalife.r.rc.mn.service.CprtContMngMdulService;
import hanalife.r.rc.mn.vo.CprtContMngMdulObjVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCMN0101ServiceImpl.java Class
 * 클래스설명   : 제휴약정 한도잔액 수정 (RRCMN0101) Service Implements
 * 작성일자     : 2023. 3. 14.
 * 작성자명     : 70322 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 14.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRRCMN0101S01 : 제휴약정 한도잔액 수정목록조회
 *              registerRRCMN0101I01 : 제휴약정 한도잔액 수정등록
 *              modifyRRCMN0101U01 : 제휴약정 한도잔액 수정수정
 *              removeRRCMN0101U01 : 제휴약정 한도잔액 수정삭제
 * </pre>
 */
@Service("CprtContMngService")
public class CprtContMngMdulServiceImpl implements CprtContMngMdulService {

	private static final Logger LOGGER = LoggerFactory.getLogger(CprtContMngMdulServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

	@Autowired
	private CprtContMngMdulMapper cprtContMngMdulMapper;

	/**
	 * <p>메소드명			: searchCprtLim</p>
	 * <p>작성일자			: 2023. 3. 16.
	 * <p>작성자(author)	: 70322 / sungjin.park
	 * <p>설명          	: 제휴약정 한도잔액 조회</p>
	 * <p>메소드인수    	: CprtContMngMdulObjVO </p>
	 * <p>메소드리턴값  		: CprtContMngMdulObjVO</p>
	 * <p>예외처리      	: Exception</p>
	 */
	@Override
	public CprtContMngMdulObjVO searchCprtLim(CprtContMngMdulObjVO contMngMdulObj) throws Exception {

		if(contMngMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMngMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMngMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMngMdulObj;
		}

		contMngMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		contMngMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			//필수데이타 체크
			contMngMdulObj = this.checkObjBlank("SEARCH", contMngMdulObj);

		    //대출 상품 조회
		    contMngMdulObj = this.chkPrdtCd(contMngMdulObj);
		    if (!contMngMdulObj.getPrdtLrgeClasCd().equals("1")) {
	    		contMngMdulObj.setLoanAblFg("1");
	    		return contMngMdulObj;
		    }

		    //중고차 약정제외 2018-08-01 두비스
		    if (contMngMdulObj.getPrdtMidClasCd().equals("02")) {
		    	contMngMdulObj.setLoanAblFg("1");
		    	return contMngMdulObj;
		    }

		    //대출제휴점의 제휴약정 조회
		    contMngMdulObj = this.searchCprtCont(contMngMdulObj);
		    if (contMngMdulObj.getLimCnt() == 0) {
		    	contMngMdulObj.setCprtBranCd("0");
		    	contMngMdulObj = this.searchCprtCont(contMngMdulObj);
		    }

		    if (contMngMdulObj.getLimCnt() == 0) {
		    	contMngMdulObj.setLimAmt(0);
		    	contMngMdulObj.setLimRamt(0);
		    	contMngMdulObj.setLoanAblFg("0");
		    	contMngMdulObj.setIpssRsnCd("02");
		    	return contMngMdulObj;
		    }

		    //약정해지여부가 '1'
		    if (contMngMdulObj.getContClosFg().equals("1")) {
		    	contMngMdulObj.setLimAmt(0);
		    	contMngMdulObj.setLimRamt(0);
		    	contMngMdulObj.setLoanAblFg("0");
		    	contMngMdulObj.setIpssRsnCd("03");
		    	return contMngMdulObj;
		    }

		    //한도관리여부가 '0'
		    if (contMngMdulObj.getLimMngFg().equals("0")) {
		    	contMngMdulObj.setLimAmt(0);
		    	contMngMdulObj.setLimRamt(0);
		    	contMngMdulObj.setLoanAblFg("1");
		    	contMngMdulObj.setIpssRsnCd("00");
		    	return contMngMdulObj;
		    }

		    //한도잔액과 대출금 차액 계산
		    long rAmt = contMngMdulObj.getLimRamt() - contMngMdulObj.getLoanPamt();
		    contMngMdulObj.setLimCnt(0);
		    //System.out.println("한도잔액: " + contMngMdulObj.limRamt);
		    //System.out.println("대출금액: " + contMngMdulObj.loanPamt);
		    //System.out.println("rAmt: " + rAmt);

		    if (rAmt >= 0) {
		    	contMngMdulObj.setLimRamt(rAmt);
		    	contMngMdulObj.setLoanAblFg("1");
		    	contMngMdulObj.setIpssRsnCd("00");
		    	return contMngMdulObj;
		    } else {
		    	contMngMdulObj.setLimRamt(rAmt);
		    	contMngMdulObj.setLoanAblFg("0");
		    	contMngMdulObj.setIpssRsnCd("04");
		    	return contMngMdulObj;
		    }

		} catch (Exception e) {
			/** CPRT_CONT_ERR_SYSTEM_SEARCH_CPRT_LIM("E003", "시스템 오류", "제휴약정 한도잔액 조회 처리 중 에러가 발생했습니다") */
			contMngMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM_SEARCH_CPRT_LIM.getErrorCd());
			contMngMdulObj.setRsltCntn(e.getMessage());
			return contMngMdulObj;
		}

	}

	/**
	 * <p>메소드명			: chkPrdtCd</p>
	 * <p>작성일자			: 2023. 3. 16.
	 * <p>작성자(author)	: 70322 / sungjin.park
	 * <p>설명          	: 대출상품 코드 조회</p>
	 * <p>메소드인수    	: CprtContMngMdulObjVO </p>
	 * <p>메소드리턴값  		: CprtContMngMdulObjVO</p>
	 * <p>예외처리      	: Exception</p>
	 */
	@Override
	public CprtContMngMdulObjVO chkPrdtCd(CprtContMngMdulObjVO contMdulObj) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

	    try {

	    	/** 수납내역상세조회 조회 조건 입력값 객체 생성 및 대입 수행 */
			CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setPrdtCd(contMdulObj.getPrdtCd());		/**  */

	    	List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchPrdtCdSQL(i01Dto);

	    	if(resultCprtContMngMdulObjDTO == null) {
				/** CPRT_CONT_ERR_CHK_PRDT_CD_FAIL("E005", "시스템 오류", "대출상품 코드 조회 처리 실패하였습니다") */
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHK_PRDT_CD_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHK_PRDT_CD_FAIL.getDescription());
				return contMdulObj;
			}

	    	for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
	    		contMdulObj.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());
	    		contMdulObj.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd());
	    	}

	    	contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se) {
			/** CPRT_CONT_ERR_SYSTEM_CHK_PRDT_CD("E004", "시스템 오류", "대출상품 코드 조회 중 에러가 발생했습니다") */
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM_CHK_PRDT_CD.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
			/** CPRT_CONT_ERR_SYSTEM_CHK_PRDT_CD("E004", "시스템 오류", "대출상품 코드 조회 중 에러가 발생했습니다") */
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM_CHK_PRDT_CD.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명			: updateCprtLim</p>
	 * <p>작성일자			: 2023. 3. 16.
	 * <p>작성자(author)	: 70322 / sungjin.park
	 * <p>설명          	: 제휴약정 한도잔액 수정</p>
	 * <p>메소드인수    	: CprtContMngMdulObjVO </p>
	 * <p>메소드리턴값  		: CprtContMngMdulObjVO</p>
	 * <p>예외처리      	: Exception</p>
	 */
	@Override
	public CprtContMngMdulObjVO updateCprtLim(CprtContMngMdulObjVO contMngMdulObj) throws Exception {

		if(contMngMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMngMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMngMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMngMdulObj;
		}

		contMngMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		contMngMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			String incrFg = "0";	/**증가여부*/
			long rAmt = 0;			/**한도잔액*/

			//필수데이타 체크
			contMngMdulObj = this.checkObjBlank("UPDATE", contMngMdulObj);

			//대출상품 검색
			contMngMdulObj = this.searchLoanPrdtCd(contMngMdulObj);

			if (contMngMdulObj.getLimCnt() == 0){	/**  */
				contMngMdulObj.setLimAmt(0);		/**한도금액*/
				contMngMdulObj.setLimRamt(0);		/**한도잔액*/
				contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
				contMngMdulObj.setIpssRsnCd("05");	/**불능사유코드*/
				return contMngMdulObj;
		    } else {
		    	if (!contMngMdulObj.getPrdtLrgeClasCd().equals("1")){	/**상품_대분류_코드*/
					contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
					return contMngMdulObj;
		    	}
		    	//중고차 약정제외 2018-08-01 두비스
		    	if (contMngMdulObj.getPrdtMidClasCd().equals("02")){	/**상품_중분류_코드*/
	    			contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
					return contMngMdulObj;
		    	}
		    }

			//대출제휴점 검색
			contMngMdulObj = this.searchLoanCprtBran(contMngMdulObj);
		    if (contMngMdulObj.getLimCnt() == 0){	/**  */
		    	contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    	contMngMdulObj.setLimRamt(0);		/**한도잔액*/
		    	contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
		    	contMngMdulObj.setIpssRsnCd("06");	/**불능사유코드*/
		    	return contMngMdulObj;
		    }

		    contMngMdulObj = this.searchCprtCont(contMngMdulObj);
		    if (contMngMdulObj.getLimCnt() == 0){	/**  */
		    	contMngMdulObj.setCprtBranCd("0");	/**제휴점코드*/
		    	contMngMdulObj = this.searchCprtCont(contMngMdulObj);
		    }

		    if (contMngMdulObj.getLimCnt() == 0){	/**  */
		    	contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    	contMngMdulObj.setLimRamt(0);		/**한도잔액*/
		    	contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
		    	contMngMdulObj.setIpssRsnCd("02");	/**불능사유코드*/
		    	return contMngMdulObj;
		    }

		    //승인처리 및 대출확정
		    if (contMngMdulObj.getBizDivCd().equals("1")){	/**업무구분코드*/
		    	if (contMngMdulObj.getContManNo().equals(contMngMdulObj.getCprtComNo())){	/**주계약자_번호==제휴사번호*/
		    		incrFg = "0";
		    	} else {	/**주계약자_번호!=제휴사번호*/
		    		contMngMdulObj = this.searchRegLdgr(contMngMdulObj);
		    		if (contMngMdulObj.getLimCnt() == 0){	/**  */
		    			incrFg = "0";
		    		} else {
		    			if (contMngMdulObj.getRegLdgrFg().equals("1")){	/**등록원부_여부*/
		    				contMngMdulObj.setLoanAblFg("1");			/**대출가능여부*/
		    				return contMngMdulObj;
		    			} else if (contMngMdulObj.getRegLdgrFg().equals("0")) {	/**등록원부_여부*/
	    					incrFg = "0";
		    			}
		    		}
		    	}
		    } else if (contMngMdulObj.getBizDivCd().equals("2")) {	/**업무구분코드*/
		    	//승인취소 및 대출취소
		    	if (contMngMdulObj.getContManNo().equals(contMngMdulObj.getCprtComNo())) {	/**주계약자_번호==제휴사번호*/
		    		incrFg = "1";
		    	} else {	/**주계약자_번호!=제휴사번호*/
		    		contMngMdulObj = this.searchRegLdgr(contMngMdulObj);
		    		if (contMngMdulObj.getLimCnt() == 0) {	/**  */
		    			incrFg = "1";
		    		} else {
		    			if (contMngMdulObj.getRegLdgrFg().equals("1")){	/**등록원부_여부*/
	    					contMngMdulObj.setLoanAblFg("1");			/**대출가능여부*/
	    					return contMngMdulObj;
		    			} else if (contMngMdulObj.getRegLdgrFg().equals("0")) {	/**등록원부_여부*/
		    				incrFg = "1";
		    			}
		    		}
		    	}
		    } else if (contMngMdulObj.getBizDivCd().equals("3")) {	/**업무구분코드*/
		    	//등록원부 등록
		    	contMngMdulObj = this.searchLoanAprvDt(contMngMdulObj);
		    	if (contMngMdulObj.getLimCnt() == 0) {	/**  */
		    		contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    		contMngMdulObj.setLimRamt(0);       /**한도잔액*/
		    		contMngMdulObj.setLoanAblFg("0");   /**대출가능여부*/
		    		contMngMdulObj.setIpssRsnCd("05");  /**불능사유코드*/
		    		return contMngMdulObj;
		    	} else {
		    		if (contMngMdulObj.getAprvDt() == null || contMngMdulObj.getAprvDt().equals("")) {	/**대출_승인일*/
		    			contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
		    			return contMngMdulObj;
		    		} else {
		    			if (!contMngMdulObj.getContManNo().equals(contMngMdulObj.getCprtComNo())) {	/**주계약자_번호==제휴사번호*/
		    				incrFg = "1";
		    			}
		    		}
		    	}
		    } else if (contMngMdulObj.getBizDivCd().equals("4")) {	/**업무구분코드*/
		    	//등록원부 등록 취소
		    	contMngMdulObj = this.searchLoanAprvDt(contMngMdulObj);
		    	if (contMngMdulObj.getLimCnt() == 0) {	/**  */
		    		contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    		contMngMdulObj.setLimRamt(0);		/**한도잔액*/
		    		contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
		    		contMngMdulObj.setIpssRsnCd("05");	/**불능사유코드*/
		    		return contMngMdulObj;
		    	} else {
		    		if (contMngMdulObj.getAprvDt() == null || contMngMdulObj.getAprvDt().equals("")) {	/**대출_승인일*/
		    			contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
		    			return contMngMdulObj;
		    		} else {
		    			if (!contMngMdulObj.getContManNo().equals(contMngMdulObj.getCprtComNo()))	/**주계약자_번호==제휴사번호*/
		    				incrFg = "0";
		    		}
		    	}
		    } else if (contMngMdulObj.getBizDivCd().equals("5")) {	/**업무구분코드*/
		    	//수납처리
		    	if (contMngMdulObj.getContManNo().equals(contMngMdulObj.getCprtComNo())) {	/**주계약자_번호==제휴사번호*/
		    		incrFg = "1";
		    	} else {
		    		contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
		    		return contMngMdulObj;
		    	}
		    } else if (contMngMdulObj.getBizDivCd().equals("6")) {	/**업무구분코드*/
		    	//수납취소
		    	if (contMngMdulObj.getContManNo().equals(contMngMdulObj.getCprtComNo())) {	/**주계약자_번호==제휴사번호*/
		    		incrFg = "0";
		    	} else {
		    		contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
		    		return contMngMdulObj;
		    	}
		    } else {
		    	contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
		    	contMngMdulObj.setIpssRsnCd("06");	/**불능사유코드*/
		    	return contMngMdulObj;
		    }

		    //업무구분이 '1', 약정해지여부가 '1'
		    if (contMngMdulObj.getBizDivCd().equals("1") && contMngMdulObj.getContClosFg().equals("1")) {	/**업무구분코드, 약정_해지_여부*/
		    	contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    	contMngMdulObj.setLimRamt(0);		/**한도잔액*/
		    	contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
		    	contMngMdulObj.setIpssRsnCd("08");	/**불능사유코드*/
		    	return contMngMdulObj;
		    }

		    //한도관리여부가 '0'
		    if (contMngMdulObj.getLimMngFg().equals("0")) {	/**한도_관리_여부*/
		    	contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    	contMngMdulObj.setLimRamt(0);		/**한도잔액*/
		    	contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
		    	contMngMdulObj.setIpssRsnCd("00");	/**불능사유코드*/
		    	return contMngMdulObj;
		    }

		    //증가여부 '1'-> 한도잔액=한도잔액 + 금액 / '0'-> 한도잔액=한도잔액-금액
		    if (incrFg.equals("1")) {
		    	rAmt = contMngMdulObj.getLimRamt() + contMngMdulObj.getLoanPamt();	/**한도잔액=한도잔액+대출금액*/
		    } else if (incrFg.equals("0")) {
		    	rAmt = contMngMdulObj.getLimRamt() - contMngMdulObj.getLoanPamt();	/**한도잔액=한도잔액-대출금액*/
		    }

		    if (rAmt < 0 || contMngMdulObj.getLimAmt() < contMngMdulObj.getLimRamt()) {
		    	contMngMdulObj.setLimAmt(0);		/**한도금액*/
		    	contMngMdulObj.setLimRamt(0);		/**한도잔액*/
		    	contMngMdulObj.setLoanAblFg("0");	/**대출가능여부*/
		    	contMngMdulObj.setIpssRsnCd("09");	/**불능사유코드*/
		    	return contMngMdulObj;
		    }

		    contMngMdulObj.setLimRamt(rAmt);	/**한도잔액*/

		    //한도 수정 처리
		    contMngMdulObj = this.updateCprtCont(contMngMdulObj);

		    //한도증감이력 처리
		    //int maxSnum = this.searchMaxSnum(contMngMdulObj);
		    contMngMdulObj = this.searchMaxSnum(contMngMdulObj);
		    //this.insertLimChngHist(contMngMdulObj, maxSnum + 1, incrFg);
		    contMngMdulObj = this.insertLimChngHist(contMngMdulObj, contMngMdulObj.getLimCnt() + 1, incrFg);

		    contMngMdulObj.setLoanAblFg("1");	/**대출가능여부*/
		    contMngMdulObj.setIpssRsnCd("00");	/**불능사유코드*/

		    return contMngMdulObj;

		} catch (Exception e) {
			/** CPRT_CONT_ERR_SYSTEM_UPDATE_CPRT_LIM("E005", "시스템 오류", "제휴약정 한도잔액 수정 처리 중 에러가 발생했습니다!") */
			contMngMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM_UPDATE_CPRT_LIM.getErrorCd());
			contMngMdulObj.setRsltCntn(e.getMessage());
			return contMngMdulObj;
		}

	}

	/**
	 * <p>메소드명		: checkObjBlank</p>
	 * <p>설명		: 한도약정체크에서 필요한 필수데이타를 체크 한다.</p>
	 * <p>메소드인수1	: DfeeRtObj dfeeRtObj</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private static CprtContMngMdulObjVO checkObjBlank(String procDiv, CprtContMngMdulObjVO contMdulObj) throws Exception {
		// 데이터 필수입력 체크

		try {

			if (procDiv.equals("UPDATE")){
		    	if (contMdulObj.getBizDivCd() == null || contMdulObj.getBizDivCd().equals("")){
		    		//throw new Exception("[제휴약정한도수정] 업무구분을 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_BIZ_DIV_CD.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_BIZ_DIV_CD.getDescription());
					return contMdulObj;
		    	}
	    		if (contMdulObj.getLoanNo() == null || contMdulObj.getLoanNo().equals("")){
	    			//throw new Exception("[제휴약정한도수정] 대출번호를 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_NO.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_NO.getDescription());
					return contMdulObj;
	    		}
	    		if (contMdulObj.getLoanSeq() == null || contMdulObj.getLoanSeq().equals("")){
	    			//throw new Exception("[제휴약정한도수정] 대출순번을 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_SEQ.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_SEQ.getDescription());
					return contMdulObj;
	    		}

	    		if (! (contMdulObj.getBizDivCd().equals("3") || contMdulObj.getBizDivCd().equals("4"))){
	    			if (contMdulObj.getLoanPamt() == 0){
	    				//throw new Exception("[제휴약정한도수정] 대출금액을 찾을 수 없습니다.");
			    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_PAMT.getErrorCd());
						contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_PAMT.getDescription());
						return contMdulObj;
	    			}
	    		}
		    } else {
		    	if (contMdulObj.getCprtComNo() == null || contMdulObj.getCprtComNo().equals("")){
		    		//throw new Exception("[제휴약정한도조회] 제휴사번호를 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_CPRT_COM_NO.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_CPRT_COM_NO.getDescription());
					return contMdulObj;
		    	}
		    	if (contMdulObj.getCprtBranCd() == null || contMdulObj.getCprtBranCd().equals("")){
		    		//throw new Exception("[제휴약정한도조회] 제휴점코드를 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_CPRT_BRAN_CD.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_CPRT_BRAN_CD.getDescription());
					return contMdulObj;
		    	}
		    	if (contMdulObj.getPrdtCd() == null || contMdulObj.getPrdtCd().equals("")){
		    		//throw new Exception("[제휴약정한도조회] 상품코드를 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_PRDT_CD.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_PRDT_CD.getDescription());
					return contMdulObj;
		    	}
		    	if (contMdulObj.getLoanPamt() == 0){
		    		//throw new Exception("[제휴약정한도조회] 대출금액을 찾을 수 없습니다.");
		    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_PAMT.getErrorCd());
					contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_CHECK_LOAN_PAMT.getDescription());
					return contMdulObj;
		    	}
		    }

	    	contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

		} catch (Exception e) {
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
		}

	}

	/**
	 * <p>메소드명		: searchLoanPrdtCd</p>
	 * <p>설명		: 대출 상품 조회</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO searchLoanPrdtCd(CprtContMngMdulObjVO contMdulObj) throws Exception{

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

		int limCnt = 0;

	    try {

			/** 수납내역상세조회 조회 조건 입력값 객체 생성 및 대입 수행 */
			CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setLoanNo(contMdulObj.getLoanNo());		/** 대출번호 */
			i01Dto.setLoanSeq(contMdulObj.getLoanSeq());	/** 대출순번 */

	    	List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchLoanPrdtCdSQL(i01Dto);

	    	if(resultCprtContMngMdulObjDTO == null) {
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getDescription());
				return contMdulObj;
			}

	    	contMdulObj.setLimCnt(limCnt);

	    	for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
	    		contMdulObj.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());
	    		contMdulObj.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd());
	    		contMdulObj.setPrdtCd(sourceIO.getPrdtCd());
	    		contMdulObj.setContManNo(sourceIO.getContManNo());
	    		limCnt += 1;
		        contMdulObj.setLimCnt(limCnt);
	    	}

	    	contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se){
	    	//throw new Exception("대출상품 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e){
			//throw new Exception("대출상품 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명		: searchLoanCprtBran</p>
	 * <p>설명		: 대출 제휴점 조회</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO searchLoanCprtBran(CprtContMngMdulObjVO contMdulObj) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

	    int limCnt = 0;

	    try {

			CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setLoanNo(contMdulObj.getLoanNo());		/** 대출번호 */
			i01Dto.setLoanSeq(contMdulObj.getLoanSeq());	/** 대출순번 */

			List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchLoanCprtBranSQL(i01Dto);

			if(resultCprtContMngMdulObjDTO == null) {
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getDescription());
				return contMdulObj;
			}

	    	contMdulObj.setLimCnt(limCnt);

	    	for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
	    		contMdulObj.setCprtComNo(sourceIO.getCprtComNo());
	    		contMdulObj.setCprtBranCd(sourceIO.getCprtBranCd());
	    		limCnt += 1;
		        contMdulObj.setLimCnt(limCnt);
	    	}

	    	contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se) {
	    	//throw new Exception("대출제휴점 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
	    	//throw new Exception("대출제휴점 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명	: searchCprtCont</p>
	 * <p>설명		: 제휴약정 조회</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO searchCprtCont(CprtContMngMdulObjVO contMdulObj) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

	    int limCnt = 0;

	    try {

	    	CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setCprtComNo(contMdulObj.getCprtComNo());	/**제휴사번호*/
			i01Dto.setPrdtCd(contMdulObj.getPrdtCd());			/**상품코드*/
			i01Dto.setCprtBranCd(contMdulObj.getCprtBranCd());	/**제휴점코드*/

			List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchCprtLimSQL(i01Dto);

			if(resultCprtContMngMdulObjDTO == null) {
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getDescription());
				return contMdulObj;
			}

			contMdulObj.setLimCnt(limCnt);

			for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
	    		contMdulObj.setLimMngFg(sourceIO.getLimMngFg());
	    		contMdulObj.setLimAmt(sourceIO.getLimAmt());
	    		contMdulObj.setLimRamt(sourceIO.getLimRamt());
	    		contMdulObj.setPrdtClasCd(sourceIO.getPrdtClasCd());
	    		contMdulObj.setContClosFg(sourceIO.getContClosFg());
	    		limCnt += 1;
		        contMdulObj.setLimCnt(limCnt);
	    	}

			contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se) {
	    	//throw new Exception("제휴약정 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
	    	//throw new Exception("제휴약정 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명		: searchRegLdgr</p>
	 * <p>설명		: 대출 제휴점 조회</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO searchRegLdgr(CprtContMngMdulObjVO contMdulObj) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

		int limCnt = 0;

	    try {

	    	CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setLoanNo(contMdulObj.getLoanNo());			/**대출번호*/
			i01Dto.setLoanSeq(contMdulObj.getLoanSeq());		/**대출순번*/
			i01Dto.setContManNo(contMdulObj.getContManNo());	/**주계약자_번호*/

			List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchRegLdgrSQL(i01Dto);

			if(resultCprtContMngMdulObjDTO == null) {
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_REG_LDGR_FAIL.getDescription());
				return contMdulObj;
			}

			contMdulObj.setLimCnt(limCnt);

			for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
		        contMdulObj.setRegLdgrFg(sourceIO.getRegLdgrFg());
		        limCnt += 1;
		        contMdulObj.setLimCnt(limCnt);
	    	}

			contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se) {
	    	//throw new Exception("등록원부 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
	    	//throw new Exception("등록원부 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명	: searchLoanAprvDt</p>
	 * <p>설명		: 대출 승인일 조회</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO searchLoanAprvDt(CprtContMngMdulObjVO contMdulObj) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

		int limCnt = 0;

	    try {

	    	CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setLoanNo(contMdulObj.getLoanNo());			/**대출번호*/
			i01Dto.setLoanSeq(contMdulObj.getLoanSeq());		/**대출순번*/

			List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchLoanAprvDtSQL(i01Dto);

			if(resultCprtContMngMdulObjDTO == null) {
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_LOAN_APRV_DT_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_LOAN_APRV_DT_FAIL.getDescription());
				return contMdulObj;
			}

			contMdulObj.setLimCnt(limCnt);

			for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
	    		contMdulObj.setLoanPamt(sourceIO.getLoanPamt());
	    		contMdulObj.setAprvDt(sourceIO.getAprvDt());
	    		limCnt += 1;
		        contMdulObj.setLimCnt(limCnt);
	    	}

			contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se) {
	    	//throw new Exception("대출승인일 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
	    	//throw new Exception("대출승인일 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명	    : updateCprtCont</p>
	 * <p>설명		: 제휴한도 수정</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO updateCprtCont(CprtContMngMdulObjVO contMdulObj) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

		int limCnt = 0;

	    try {

	    	CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setLimRamt(contMdulObj.getLimRamt());				/**대출번호*/
	    	i01Dto.setLastProcDt(DateUtil.getCurrentDateString("YYYYMMDD"));			/**대출번호*/ // DateFormatUtil.format(ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD))
	    	i01Dto.setLastProcTm(DateUtil.getCurrentDateString("HHMMSS"));			/**대출번호*/ // ServerSysDate.getServerDate(ServerSysDate.HHMMSS)
			i01Dto.setEmpNo(contMdulObj.getEmpNo());					/**대출순번*/
			i01Dto.setCprtComNo(contMdulObj.getCprtComNo());			/**대출순번*/
			i01Dto.setCprtBranCd(contMdulObj.getCprtBranCd());			/**대출순번*/
			i01Dto.setPrdtLrgeClasCd(contMdulObj.getPrdtLrgeClasCd());	/**대출순번*/

			int resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.updateCprtLimSQL(i01Dto);

			if(resultCprtContMngMdulObjDTO != 1) {
				contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_UPDATE_FAIL.getErrorCd());
				contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_UPDATE_FAIL.getDescription());
				return contMdulObj;
			}

			contMdulObj.setLimCnt(limCnt);

			contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
			return contMdulObj;

	    } catch (SQLException se) {
	    	//throw new Exception("제휴약정 한도 수정 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
	    	//throw new Exception("제휴약정 한도 수정 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	}

	/**
	 * <p>메소드명	: searchMaxSnum</p>
	 * <p>설명		: 한도증감이력 MAX Snum 조회</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO searchMaxSnum(CprtContMngMdulObjVO contMdulObj) throws Exception {

		//int maxSnum = 0;

	    try {

	    	CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setCprtComNo(contMdulObj.getCprtComNo());	/**  */
	    	i01Dto.setCprtBranCd(contMdulObj.getCprtBranCd());	/**  */
	    	i01Dto.setPrdtClasCd(contMdulObj.getPrdtClasCd());	/**  */

	    	List<CprtContMngMdulObjDTO> resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.searchMaxSnumSQL(i01Dto);

	    	if(resultCprtContMngMdulObjDTO == null) {
	    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_MAX_SNUM_FAIL.getErrorCd());
	    		contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_MAX_SNUM_FAIL.getDescription());
				return contMdulObj;
			}

	    	for(CprtContMngMdulObjDTO sourceIO : resultCprtContMngMdulObjDTO) {
	    		//maxSnum = sourceIO.getLimCnt();
	    		contMdulObj.setLimCnt(sourceIO.getLimCnt());
	    	}

	    	contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
	    	contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
	    	return contMdulObj;

	    } catch (SQLException se) {
	    	//throw new Exception("한도증감이력 일련번호 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(se.getMessage());
			return contMdulObj;
	    } catch (Exception e) {
	    	//throw new Exception("한도증감이력 일련번호 조회 중 오류");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

	    //return maxSnum;
	}

	/**
	 * <p>메소드명	: insertLimChngHist</p>
	 * <p>설명		: 한도증감이력 등록</p>
	 * <p>메소드인수1	: CprtContMngMdulObj contMdulObj</p>
	 * <p>메소드인수2	: Connection con</p>
	 * <p>메소드리턴값	: N/A</p>
	 */
	private CprtContMngMdulObjVO insertLimChngHist(CprtContMngMdulObjVO contMdulObj, int snum, String incrFg) throws Exception {

		if(contMdulObj == null) {
			/** CPRT_CONT_DATA_ZERO("E001", "요청 데이터 없슴", "제휴약정 한도잔액 수정 요청 객체가 NULL입니다") */
			contMdulObj.setRsltCd(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCd());
			contMdulObj.setRsltCntn(msgEnum.CPRT_CONT_DATA_ZERO.getErrorCn());
			return contMdulObj;
		}

	    try {

	    	CprtContMngMdulObjDTO i01Dto = new CprtContMngMdulObjDTO();

	    	i01Dto.setCprtComNo(contMdulObj.getCprtComNo());		/** 제휴사번호 */
	    	i01Dto.setCprtBranCd(contMdulObj.getCprtBranCd());		/** 제휴점코드 */
	    	i01Dto.setPrdtClasCd(contMdulObj.getPrdtClasCd());		/** 상품분류코드 */
	    	i01Dto.setLimAmt(contMdulObj.getLimAmt());				/** 한도금액 */
	    	i01Dto.setLimRamt(contMdulObj.getLimRamt());			/** 한도잔액 */
	    	i01Dto.setSnum(snum);									/** 일련번호 */
	    	i01Dto.setIncrAmtFg(incrFg);							/** 한도증감여부 */
	    	i01Dto.setFirstProcDt(DateUtil.getCurrentDateString("YYYYMMDD"));	/** 최초등록일자 */ 
	    	i01Dto.setFirstProcTm(DateUtil.getCurrentDateString("HHMMSS"));	/** 최초등록시간 */ 
	    	i01Dto.setEmpNo(contMdulObj.getEmpNo());				/** 최초등록사원번호 */

	    	int resultCprtContMngMdulObjDTO = cprtContMngMdulMapper.insertCprtLimChngSQL(i01Dto);

	    	if(resultCprtContMngMdulObjDTO != 1) {
	    		contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_LIM_CHNG_FAIL.getErrorCd());
	    		contMdulObj.setRsltCntn(MsgEnum.CPRT_CONT_ERR_LIM_CHNG_FAIL.getDescription());
				return contMdulObj;
			}

	    	contMdulObj.setRsltCd(msgEnum.SUCCESS.getErrorCd());
	    	contMdulObj.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
	    	return contMdulObj;

	    } catch (Exception e) {
	    	//throw new Exception("제휴약정한도증감이력 등록중 오류!!");
	    	contMdulObj.setRsltCd(MsgEnum.CPRT_CONT_ERR_SYSTEM.getErrorCd());
	    	contMdulObj.setRsltCntn(e.getMessage());
			return contMdulObj;
	    }

    }



}
