package hanalife.r.rc.rc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.rc.rc.mapper.RmbrPlanReadMapper;
import hanalife.r.rc.rc.mapper.dto.RmbrPlanReadDSRMBRPLANSD01DTO;
import hanalife.r.rc.rc.mapper.dto.RmbrPlanReadDSRMBRPLANSD02DTO;
import hanalife.r.rc.rc.mapper.dto.RmbrPlanReadDSRMBRPLANSMDTO;
import hanalife.r.rc.rc.service.RRCRCP02Service;
import hanalife.r.rc.rc.vo.RRCRCP02DSRMBRPLANSD01VO;
import hanalife.r.rc.rc.vo.RRCRCP02DSRMBRPLANSD02VO;
import hanalife.r.rc.rc.vo.RRCRCP02DSRMBRPLANSMVO;
import hanalife.r.rc.rc.vo.RRCRCP02S01InVO;
import hanalife.r.rc.rc.vo.RRCRCP02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RRCRCP02ServiceImpl.java Class
 * 클래스설명   : 상환스케줄 (RRCRCP02) Service Implements
 * 작성일자     : 2023. 3. 6.
 * 작성자명     : 70320 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 6.][70320 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRRCRCP02S01 : 상환스케줄목록조회
 *              registerRRCRCP02I01 : 상환스케줄등록
 *              modifyRRCRCP02U01 : 상환스케줄수정
 *              removeRRCRCP02U01 : 상환스케줄삭제
 * </pre>
 */
@Service("RRCRCP02Service")
public class RRCRCP02ServiceImpl implements RRCRCP02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RRCRCP02ServiceImpl.class);

	@Autowired
	private RmbrPlanReadMapper rmbrPlanReadMapper;

//	@Autowired
//	private SearchLoanSeqService searchLoanSeqService;

	/**
	 * <p>메소드명      : getRRCRCP02S01 : 상환스케줄목록조회</p>
	 * <p>작성일자      : 2023. 3. 6.
	 * <p>작성자(author): 70320 / jaeho.jang
	 * <p>설명          : 상환스케줄목록을 조회 한다.</p>
	 * <p>메소드인수    : RRCRCP02S01InVo </p>
	 * <p>메소드리턴값  : RRCRCP02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RRCRCP02S01OutVO getRRCRCP02S01(RRCRCP02S01InVO inVO) throws Exception {

		RRCRCP02S01OutVO outVo = new RRCRCP02S01OutVO();
		RRCRCP02DSRMBRPLANSMVO sourceIO = inVO.getRRCRCP02DSRMBRPLANSM();
		RmbrPlanReadDSRMBRPLANSMDTO targetIO = new RmbrPlanReadDSRMBRPLANSMDTO();
		targetIO.setLoanNo(sourceIO.getLoanNo());
		targetIO.setLoanSeq(sourceIO.getLoanSeq());
		targetIO.setMngNo(sourceIO.getMngNo());

		//TODO >> searchLoan checkExistLoan 호출하는 부분 추가
		//SearchLoanSeqSearch01VO searchLoanVO = new SearchLoanSeqSearch01VO();
		//searchLoanVO = searchLoanSeqService.checkExistLoan(searchLoanVO);

		List<RmbrPlanReadDSRMBRPLANSD01DTO> list1 =	rmbrPlanReadMapper.searchRmbrPlan(targetIO);
		List<RRCRCP02DSRMBRPLANSD01VO> returnList1 = new ArrayList<RRCRCP02DSRMBRPLANSD01VO>();
		for(RmbrPlanReadDSRMBRPLANSD01DTO dto : list1) {
			RRCRCP02DSRMBRPLANSD01VO vo = new RRCRCP02DSRMBRPLANSD01VO();
			vo.setLoanNo(dto.getLoanNo()); /*  */
			vo.setLoanSeq(dto.getLoanSeq()); /*  */
			vo.setMngNo(dto.getMngNo()); /*  */
			vo.setContManNo(dto.getContManNo()); /*  */
			vo.setCustNm(dto.getCustNm()); /*  */
			vo.setPrdtCd(dto.getPrdtCd()); /*  */
			vo.setPrdtNm(dto.getPrdtNm()); /*  */
			vo.setStrtTims(dto.getStrtTims()); /*  */
			vo.setEndTims(dto.getEndTims()); /*  */
			returnList1.add(vo);
		}
		outVo.setListRATMNM01DSRMBRPLANSD01VO(returnList1);

		List<RmbrPlanReadDSRMBRPLANSD02DTO> list2 = rmbrPlanReadMapper.searchRmbrPlanPiAmt(targetIO);
		List<RRCRCP02DSRMBRPLANSD02VO> returnList2 = new ArrayList<RRCRCP02DSRMBRPLANSD02VO>();
		for(RmbrPlanReadDSRMBRPLANSD02DTO dto : list2) {
			RRCRCP02DSRMBRPLANSD02VO vo = new RRCRCP02DSRMBRPLANSD02VO();
			vo.setTims(dto.getTims()); /*  */
			vo.setDueDt(dto.getDueDt()); /*  */
			vo.setMmPamt(dto.getMmPamt()); /*  */
			vo.setMmInt(dto.getMmInt()); /*  */
			vo.setMmPiamt(dto.getMmPiamt()); /*  */
			vo.setTimsAfPamtRamt(dto.getTimsAfPamtRamt()); /*  */
			vo.setMmTrtFee(dto.getMmTrtFee()); /*  */
			returnList2.add(vo);
		}
		outVo.setListRATMNM01DSRMBRPLANSD02VO(returnList2);

		return outVo;

	}
}
