package hanalife.r.rc.rc.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.mapper.dto.RtRcptBaseDTO;
import hanalife.c.co.mapper.dto.SetlInfoDTO;
import hanalife.c.co.mapper.dto.StLoanBaseDTO;
import hanalife.c.co.vo.SetlInfoVO;
import hanalife.r.rc.rc.mapper.RcptDAOMapper;
import hanalife.r.rc.rc.mapper.dto.RcptDAODSLOANINFODTO;
import hanalife.r.rc.rc.mapper.dto.RcptDAODSRMBRSMDTO;
import hanalife.r.rc.rc.service.RcptDAOService;
import hanalife.r.rc.rc.vo.RcptDAODSLOANINFOVO;
import hanalife.r.rc.rc.vo.RcptDAOS01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RcptDAOServiceImpl.java Class
 * 클래스설명   : 수납관리 DAO  (RcptDAO) Service Implements
 * 작성일자     : 2023. 3. 23.
 * 작성자명     : 70322 / jaeho.jang / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 23.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRcptDAOS01 : 수납관리 DAO 목록조회
 *              registerRcptDAOI01 : 수납관리 DAO 등록
 *              modifyRcptDAOU01 : 수납관리 DAO 수정
 *              removeRcptDAOU01 : 수납관리 DAO 삭제
 * </pre>
 */
@Service("RcptDAOService")
public class RcptDAOServiceImpl implements RcptDAOService {

	private static final Logger LOGGER = LoggerFactory.getLogger(RcptDAOServiceImpl.class);

	@Autowired
	private RcptDAOMapper rcptDAOMapper;

	/**
	 * <p>메소드명      : searchLoanInfo : 대출정보 목록조회</p>
	 * <p>작성일자      : 2023. 3. 23.
	 * <p>작성자(author): 70322 / younghwe.kim
	 * <p>설명          : 대출정보 목록을 조회 한다.</p>
	 * <p>메소드인수    : LoanInfoProcMngInVO </p>
	 * <p>메소드리턴값  : LoanInfoProcMngOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RcptDAOS01OutVO searchLoanInfo(StLoanBaseDTO inVo) throws Exception {

		/** 대출정보 조회 서비스 결과값 객체 생성 */
		RcptDAOS01OutVO resultVo = new RcptDAOS01OutVO();

		/** 대출정보 조회 조건 입력값 객체 생성 및 대입 수행 */
		RcptDAODSRMBRSMDTO i01Dto = new RcptDAODSRMBRSMDTO();

		i01Dto.setLoanNo(inVo.getLoanNo());		/**대출_번호*/
		i01Dto.setLoanSeq(inVo.getLoanSeq());	/**대출_순번*/
		i01Dto.setLoanLastFg(inVo.getLoanLastFg());	/**  */

		// DSLOANINFO - 대출정보
		/**  조회 쿼리 Mapper 호출 수행 */
        List<RcptDAODSLOANINFODTO> resultLoanInfoDTO = rcptDAOMapper.searchLoanInfo(i01Dto);
        LOGGER.debug("resultLoanInfoDTO size : " + resultLoanInfoDTO.size());
        /**  화면 출력을 위한 결과값 List VO 객체 생성 */
        List<RcptDAODSLOANINFOVO> resultLoanInfoList = new ArrayList<RcptDAODSLOANINFOVO>();

        for(RcptDAODSLOANINFODTO sourceIO : resultLoanInfoDTO) {
        	/**  VO에 조회된 Mapper DTO 값을 대입 */
        	RcptDAODSLOANINFOVO targetIO = new RcptDAODSLOANINFOVO();
        	targetIO.setLoanNo(sourceIO.getLoanNo()); /*  */
        	targetIO.setLoanSeq(sourceIO.getLoanSeq()); /*  */
        	targetIO.setContManNo(sourceIO.getContManNo()); /*  */
        	targetIO.setAddr(sourceIO.getAddr()); /*  */
        	targetIO.setCustNm(sourceIO.getCustNm()); /*  */
        	targetIO.setRlDueManNo(sourceIO.getRlDueManNo()); /*  */
        	targetIO.setRlDueManNm(sourceIO.getRlDueManNm()); /*  */
        	targetIO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd()); /*  */
        	targetIO.setPrdtLrgeClasNm(sourceIO.getPrdtLrgeClasNm()); /*  */
        	targetIO.setPrdtMidClasCd(sourceIO.getPrdtMidClasCd()); /*  */
        	targetIO.setPrdtMidClasNm(sourceIO.getPrdtMidClasNm()); /*  */
        	targetIO.setPrdtSmClasCd(sourceIO.getPrdtSmClasCd()); /*  */
        	targetIO.setPrdtSmClasNm(sourceIO.getPrdtSmClasNm()); /*  */
        	targetIO.setDueMethNm(sourceIO.getDueMethNm());
        	targetIO.setRmbrFrmlNm(sourceIO.getRmbrFrmlNm()); /*  */
        	targetIO.setAcctUnitCd(sourceIO.getAcctUnitCd()); /*  */
        	targetIO.setAcctUnitNm(sourceIO.getAcctUnitNm()); /*  */
        	targetIO.setMngDeptCd(sourceIO.getMngDeptCd()); /*  */
        	targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /*  */
        	targetIO.setLoanIntRt(sourceIO.getLoanIntRt()); /*  */
        	targetIO.setSetlNo(sourceIO.getSetlNo()); /*  */

        	targetIO.setLoanTerm(sourceIO.getLoanTerm()); /*  */
        	targetIO.setLoanPamt(sourceIO.getLoanPamt()); /*  */

        	targetIO.setLoanRamt(sourceIO.getLoanRamt()); /*  */
        	targetIO.setLoanPamtRamt(sourceIO.getLoanPamtRamt()); /*  */
        	targetIO.setLoanIntRamt(sourceIO.getLoanIntRamt()); /*  */

        	targetIO.setDfeeRt(sourceIO.getDfeeRt()); /*  */
        	targetIO.setTrtFeeRt(sourceIO.getTrtFeeRt()); /*  */
        	targetIO.setLoanStatCd(sourceIO.getLoanStatCd()); /*  */
        	targetIO.setLoanStatNm(sourceIO.getLoanStatNm()); /*  */
        	targetIO.setBndStatCd(sourceIO.getBndStatCd()); /*  */
        	targetIO.setBndStatNm(sourceIO.getBndStatNm()); /*  */
        	targetIO.setDeliDt(sourceIO.getDeliDt()); /*  */
        	targetIO.setLoanDt(sourceIO.getLoanDt()); /*  */
        	targetIO.setMidRmbrFeeRt(sourceIO.getMidRmbrFeeRt()); /*  */
        	targetIO.setMrtgSmClasNm(sourceIO.getMrtgSmClasNm()); /*  */
        	targetIO.setFcntDueDt(sourceIO.getFcntDueDt()); /*  */
        	targetIO.setEprtDt(sourceIO.getEprtDt()); /*  */
        	targetIO.setContCnt(sourceIO.getContCnt()); /*  */
        	targetIO.setGuarCnt(sourceIO.getGuarCnt()); /*  */
        	targetIO.setTrtFee(sourceIO.getTrtFee()); /*  */

        	targetIO.setRmbrTrtFee(sourceIO.getRmbrTrtFee()); /*  */
        	targetIO.setTrtFeeIstpFg(sourceIO.getTrtFeeIstpFg()); /*  */
        	targetIO.setAskMethNm(sourceIO.getAskMethNm());
        	targetIO.setImgAcntBankNm(sourceIO.getImgAcntBankNm());
        	targetIO.setImgAcntNo(sourceIO.getImgAcntNo());
        	targetIO.setAcntStatNm(sourceIO.getAcntStatNm());
        	targetIO.setSetlDd(sourceIO.getSetlDd());
        	targetIO.setCntcTel1(sourceIO.getCntcTel1());	    /** 휴대폰번호1 */
        	targetIO.setCntcTel2(sourceIO.getCntcTel2());	    /** 휴대폰번호2 */
        	targetIO.setCntcTel3(sourceIO.getCntcTel3());	    /** 휴대폰번호3 */
        	targetIO.setSetlBankCd(sourceIO.getSetlBankCd());	/** 자동이체은행코드 */
        	targetIO.setSetlBankNm(sourceIO.getSetlBankNm());	/** 자동이체은행명 */
        	targetIO.setSetlAcntNo(sourceIO.getSetlAcntNo());   /** 자동이체계좌번호 */
        	targetIO.setSetlAcntDisp(sourceIO.getSetlAcntDisp());
        	targetIO.setDepoOwnNo(sourceIO.getDepoOwnNo());		/** 소유자번호 */
        	targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm());		/** 소유자명 */
        	targetIO.setFcntDueDt(sourceIO.getFcntDueDt());     /** 초회일자 */
        	targetIO.setEndDt(sourceIO.getEndDt());             /** 종료일자 */
        	targetIO.setRcntSetlDt(sourceIO.getRcntSetlDt());   /** 최근결제일 */
        	targetIO.setOffcNm(sourceIO.getOffcNm());           /** 직장명 */



        	/** 대출정보 List 객체에 추가하도록 수행 */
        	resultLoanInfoList.add(targetIO);
        }

        /** 연체현황목록조회(부서별) 화면 출력 결과값 대입 */
        resultVo.setListRcptDAODSLOANINFOVO(resultLoanInfoList);

		return resultVo;

	}

	/**
	 * <p>메소드명      : search : 결제정보 목록조회</p>
	 * <p>작성일자      : 2023. 4. 18.
	 * <p>작성자(author): 70326 / hyunsik.You
	 * <p>설명          : 결제정보 목록을 조회 한다.</p>
	 * <p>메소드인수    : RtRcptBaseDTO </p>
	 * <p>메소드리턴값  : RcptDAOS01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RcptDAOS01OutVO search(RtRcptBaseDTO searchDO) throws Exception {

		/** 대출정보 조회 서비스 결과값 객체 생성 */
		RcptDAOS01OutVO resultVo = new RcptDAOS01OutVO();

		/** 대출정보 조회 조건 입력값 객체 생성 및 대입 수행 */

		/**  조회 쿼리 Mapper 호출 수행 */
        List<SetlInfoDTO> resultSetlInfo = rcptDAOMapper.search(searchDO);
        LOGGER.info("serviceImpl : " + resultSetlInfo);
        /**  화면 출력을 위한 결과값 List VO 객체 생성 */
        List<SetlInfoVO> resultSetlInfoList = new ArrayList<SetlInfoVO>();
        LOGGER.info("boolean 1 : " + resultSetlInfo.isEmpty());
        if(!resultSetlInfo.isEmpty()) {
        	LOGGER.info("serviceImpl 2 : " + !resultSetlInfo.isEmpty());
        	for(SetlInfoDTO sourceIO : resultSetlInfo) {
            	/**  VO에 조회된 Mapper DTO 값을 대입 */
            	SetlInfoVO targetIO = new SetlInfoVO();
            	targetIO.setAcctDt(sourceIO.getAcctDt());
            	targetIO.setRcptTpCd(sourceIO.getRcptTpCd());
            	targetIO.setDsrcOccrCd(sourceIO.getDsrcOccrCd());
            	targetIO.setSetlFrstRank(sourceIO.getSetlFrstRank());
            	targetIO.setDsrcNo(sourceIO.getDsrcNo());
            	targetIO.setDsrcAdjAmt(sourceIO.getDsrcAdjAmt());
            	targetIO.setRcptAmt(sourceIO.getRcptAmt());
            	targetIO.setCashAmt(sourceIO.getCashAmt());
            	targetIO.setChkAmt(sourceIO.getChkAmt());
            	targetIO.setSetlAmt(sourceIO.getSetlAmt());
            	targetIO.setChkNo(sourceIO.getChkNo());
            	targetIO.setExmpConsNo(sourceIO.getExmpConsNo());
            	targetIO.setExmpPassFg(sourceIO.getExmpPassFg());
            	targetIO.setExmpAmt(sourceIO.getExmpAmt());
            	targetIO.setExmpPamt(sourceIO.getExmpPamt());
            	targetIO.setExmpInt(sourceIO.getExmpInt());
            	targetIO.setExmpDfee(sourceIO.getExmpDfee());
            	targetIO.setExmpLeglActnCost(sourceIO.getExmpLeglActnCost());
            	targetIO.setExmpMidRmbrFee(sourceIO.getExmpMidRmbrFee());
            	targetIO.setPreRcptTpCd(sourceIO.getPreRcptTpCd());
            	targetIO.setLeglUnCalcFg(sourceIO.getLeglUnCalcFg());
            	targetIO.setPreIsrtDeptCd(sourceIO.getPreIsrtDeptCd());
            	targetIO.setPreBankCd(sourceIO.getPreBankCd());
            	targetIO.setPreAcntNo(sourceIO.getPreAcntNo());
            	targetIO.setSeltDivCd(sourceIO.getSeltDivCd());
            	targetIO.setCortMaxAmt(sourceIO.getCortMaxAmt());
            	targetIO.setCalcPsgInt(sourceIO.getCalcPsgInt());
            	targetIO.setCalcMidRmbrFee(sourceIO.getCalcMidRmbrFee());
            	targetIO.setMidRmbrPamt(sourceIO.getMidRmbrPamt());
            	targetIO.setMidRmbrInt(sourceIO.getMidRmbrInt());
            	targetIO.setMidRmbrFee(sourceIO.getMidRmbrFee());
            	targetIO.setBankCd(sourceIO.getBankCd());
            	targetIO.setAcntNo(sourceIO.getAcntNo());
            	targetIO.setRcptAcntCd(sourceIO.getRcptAcntCd());

            	/** 대출정보 List 객체에 추가하도록 수행 */
            	resultSetlInfoList.add(targetIO);
            }
        }

        /** 연체현황목록조회(부서별) 화면 출력 결과값 대입 */
        resultVo.setListRRCRCM01DSSETLINFOVO(resultSetlInfoList);

		return resultVo;
	}
}
