package hanalife.r.rc.rd.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.rc.rd.service.RRCRCM02Service;
import hanalife.r.rc.rd.vo.RRCRCM02DSSMDOVO;
import hanalife.r.rc.rd.vo.RRCRCM02S01InVO;
import hanalife.r.rc.rd.vo.RRCRCM02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 클래스명    : RRCRCM02Controller
 * 클래스설명  : 수납결제내역조회 (RRCRCM02) Controller
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023.02.24
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.02.24][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 수납결제내역조회 : /RRCRCM02S01.do
 * </pre>
 */
@RequestMapping("r/rc/rd")
@Controller
public class RRCRCM02Controller {

    @Resource(name = "RRCRCM02Service")
    private RRCRCM02Service RRCRCM02;

    private static final Logger LOGGER = LoggerFactory.getLogger(RRCRCM02Controller.class);

    /**
     * <p>메소드명      : 수납내역조회 /RRCRCM02S01.do </p>
     * <p>작성일자      : 2023. 2. 27.
     * <p>작성자(author): 70317
     * <p>설명          : 수납상세 목록을 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/selectRcptList.do")
    public String RRCRCM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RRCRCM02Controller RRCRCM02S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

            /** 수납결제내역조회 업무 서비스 호출 입력값 대입 */
            RRCRCM02DSSMDOVO targetVo = new RRCRCM02DSSMDOVO();
            targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */
            targetVo.setSetlDiv((String)sourceMap.get("setlDiv")); /** 결제구분 */
            targetVo.setAcctDtFr((String)sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
            targetVo.setAcctDtTo((String)sourceMap.get("acctDtTo")); /** 회계조회종료일자 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            RRCRCM02S01InVO InVO = new RRCRCM02S01InVO();
            InVO.setRRCRCM02DSSMDOVO(targetVo);    /** 수납결제내역조회 DS_SMDO 입력값 VO 객체 대입 */

            LOGGER.info("##### InVO = " + InVO.getRRCRCM02DSSMDOVO().getLoanNo() );

            /** 수납결제내역조회 업무 서비스 호출 수행 */
            RRCRCM02S01OutVO resultRRCRCM02S01 = RRCRCM02.getRRCRCM02S01(InVO);

            XFrame5Util.setOutputData("DS_SD01", resultRRCRCM02S01.getRRCRCM02DSSDDO01VO(), model); /** 대출정보조회 */
            XFrame5Util.setOutputData("DS_SD02", resultRRCRCM02S01.getRRCRCM02DSSDDO02VO(), model); /** 수납목록조회 */

            LOGGER.info("##### RRCRCM02Controller RRCRCM02S01 Normal End #####");
        }
        catch (Exception e) {
            LOGGER.error("Error >>> "+e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RRCRCM02Controller RRCRCM02S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
