package hanalife.r.rc.rd.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.rc.rd.service.RRCRD0101Service;
import hanalife.r.rc.rd.vo.RRCRD0101S01InVO;
import hanalife.r.rc.rd.vo.RRCRD0101S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 클래스명    : RRCRD0101Controller
 * 클래스설명  : 수납결제내역조회 (RRCRD0101) Controller
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023.02.24
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.02.24][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : 수납결제내역조회 : /RRCRD0101S01.do
 * </pre>
 */
@RequestMapping("/r/rc/rd")
@Controller
public class RRCRD0101Controller {

    @Resource(name = "RRCRD0101Service")
    private RRCRD0101Service RRCRD0101;

    private static final Logger LOGGER = LoggerFactory.getLogger(RRCRD0101Controller.class);

    /**
	 * <p>메소드명      : 수납내역조회 /RRCRD0101S01.do </p>
	 * <p>작성일자      : 2023. 2. 27.
	 * <p>작성자(author): 70317
	 * <p>설명          : 수납상세 목록을 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
    @RequestMapping("/RRCRD0101S01.do")
    public String RRCRD0101S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

    	LOGGER.info("##### RRCRD0101Controller RRCRD0101S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

            /** 수납결제내역조회 업무 서비스 호출 입력값 대입 */
            RRCRD0101S01InVO targetVo = new RRCRD0101S01InVO();
            targetVo.setLoanNo((String)sourceMap.get("loanNo")); /** 대출번호 */
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq")); /** 대출순번 */
            targetVo.setSetDiv((String)sourceMap.get("setDiv")); /** 결제구분 */
            targetVo.setAcctDtFr((String)sourceMap.get("acctDtFr")); /** 회계조회시작일자 */
            targetVo.setAcctDtTo((String)sourceMap.get("acctDtTo")); /** 회계조회종료일자 */

            /** 수납결제내역조회 업무 서비스 호출 수행 */
            RRCRD0101S01OutVO resultRRCRD0101S01 = RRCRD0101.getRRCRD0101S01(targetVo);

            XFrame5Util.setOutputData("DS_SD01", resultRRCRD0101S01.getRRCRD0101S0101VO(), model); /** 대출정보조회 */
            XFrame5Util.setOutputData("DS_SD02", resultRRCRD0101S01.getRRCRD0101S0102VO(), model); /** 수납목록조회 */

            LOGGER.info("##### RRCRD0101Controller RRCRD0101S01 Normal End #####");
        }
        catch (Exception e) {
        	LOGGER.error("Error >>> "+e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

        	LOGGER.info("##### RRCRD0101Controller RRCRD0101S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
