package hanalife.r.sr.sr.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.RtDsrcChngHistDTO;
import hanalife.c.co.mapper.dto.RtRcptDsrcBaseDTO;
import hanalife.r.sr.sr.mapper.dto.DsrcDSSD01DTO;
import hanalife.r.sr.sr.mapper.dto.DsrcDSSD02DTO;
import hanalife.r.sr.sr.mapper.dto.DsrcDSSDDODTO; /* 예가수 정산정보 내역조회 출력 DTO */
import hanalife.r.sr.sr.mapper.dto.DsrcDSSM01DTO; /* 예가수 발생정보 내역조회 입력 DTO */
import hanalife.r.sr.sr.mapper.dto.DsrcDSSMDODTO; /* 예가수 발생정보 내역조회 출력 DTO */
import hanalife.r.sr.sr.mapper.dto.DsrcDSSMDTO;   /* 예/가수환불현황 조회 입력 DTO */
import hanalife.r.sr.sr.mapper.dto.DsrcSearchDTO; /* 예/가수금 처리 서비스 호출 예/가수내역조회 입출력DTO */

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : DsrcMapper.java Class
 * 클래스설명   : 예/가수금 관리(Mapper)를(을) 위한 Interface Mapper
 * 작성일자     : 2023. 3. 16.
 * 작성자명     : 70317 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 16.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Mapper("dsrcMapper")
public interface DsrcMapper {

	 /**
     * <pre>
     * 메소드명      : searchRfndReptForSpclBnd
     * 작성일자      : 2023. 3. 7.
     * 작성자(author): 70323 HeoHyemi
     * 설명          : 예/가수환불현황조회_환불현황을(를) 조회 한다.
     * 메소드인수1   : 예/가수환불현황조회_환불현황 입력
     * 메소드리턴값  : 예/가수환불현황조회_환불현황 출력
     * 예외처리      : Exception
     * </pre>
     */
	public List<RtRcptDsrcBaseDTO> search(RtRcptDsrcBaseDTO inDto) throws Exception;



    /**
     * <pre>
     * 메소드명      : searchRfndReptForSpclBnd
     * 작성일자      : 2023. 3. 7.
     * 작성자(author): 70323 HeoHyemi
     * 설명          : 예/가수환불현황조회_환불현황을(를) 조회 한다.
     * 메소드인수1   : 예/가수환불현황조회_환불현황 입력
     * 메소드리턴값  : 예/가수환불현황조회_환불현황 출력
     * 예외처리      : Exception
     * </pre>
     */
	public List<DsrcDSSD01DTO> searchRfndReptForSpclBnd(DsrcDSSMDTO inDto) throws Exception;

	/**
	 * <pre>
	 * 메소드명      : searchRfndDescForSpclBnd
	 * 작성일자      : 2023. 3. 7.
	 * 작성자(author): 70323 HeoHyemi
	 * 설명          : 예/가수환불현황조회_환불내역을(를) 조회 한다.
	 * 메소드인수1   : 예/가수환불현황조회_환불내역 입력
	 * 메소드리턴값  : 예/가수환불현황조회_환불내역 출력
	 * 예외처리      : Exception
	 * </pre>
	 */
	public List<DsrcDSSD02DTO> searchRfndDescForSpclBnd(DsrcDSSMDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchDsrcBaseForSpclBnd
     * 작성일자      : 2023. 3. 7.
     * 작성자(author): 70317 / younghwe.kim
     * 설명          : 예가수 발생정보 내역조회 특수채권에러처리을(를) 조회 한다. ( RSRSR_DSRCMNGBC / RT_RCPT_DSRC_BASE_SEARCH_FOR_SPCL_BND(9001))
     * 메소드인수1   : 예가수 발생정보 내역조회 특수채권에러처리
     * 메소드리턴값  : 예가수 발생정보 내역조회 특수채권에러처리
     * 예외처리      : Exception
     * </pre>
     */
    public List<DsrcDSSMDODTO> searchDsrcBaseForSpclBnd(DsrcDSSM01DTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : searchDsrcAdj
     * 작성일자      : 2023. 3. 7.
     * 작성자(author): 70317 / younghwe.kim
     * 설명          : 예가수 정산정보 내역조회 특수채권에러처리을(를) 조회 한다. ( RSRSR_DSRCMNGBC / RT_RCPT_DSRC_BASE_SEARCH_2(12))
     * 메소드인수1   : 예가수 정산정보 내역조회 특수채권에러처리
     * 메소드리턴값  : 예가수 정산정보 내역조회 특수채권에러처리
     * 예외처리      : Exception
     * </pre>
     */
    public List<DsrcDSSDDODTO> searchDsrcAdj(DsrcDSSM01DTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : dsrcSearch
     * 작성일자      : 2023. 3. 7.
     * 작성자(author): 70317 / younghwe.kim
     * 설명          : 예가수금처리 - 예가수내역을(를) 조회 한다. ( AskUnrcvProcQuery.DSRC_SEARCH )
     * 메소드인수1   : 결제일자, 대출번호, 대출순번
     * 메소드리턴값  : 예가수금처리 - 예가수내역조회
     * 예외처리      : Exception
     * </pre>
     */
    public DsrcSearchDTO dsrcSearch(DsrcSearchDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      : dsrcSearchByDsrcNo
     * 작성일자      : 2023. 3. 7.
     * 작성자(author): 70317 / younghwe.kim
     * 설명          : 예가수금처리 - 예가수내역을(를) 조회 한다. ( AskUnrcvProcQuery.DSRC_SEARCH_BY_DSRCNO )
     * 메소드인수1   : 결제일자, 예가수번호
     * 메소드리턴값  : 예가수금처리 - 예가수내역조회
     * 예외처리      : Exception
     * </pre>
     */
    public DsrcSearchDTO dsrcSearchByDsrcNo(DsrcSearchDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      	: update
     * 작성일자      	: 2023. 5. 26.
     * 작성자(author)	: 70326 / YHS
     * 설명         	: RT_RCPT_DSRC_BASE 수정
     * 메소드인수1   	: RMK(적요), LastEmpNo
     * 메소드리턴값  	: int
     * 예외처리      	: Exception
     * </pre>
     */
    public int update(RtRcptDsrcBaseDTO inDto) throws Exception;

    /**
     * <pre>
     * 메소드명      	: update
     * 작성일자      	: 2023. 5. 26.
     * 작성자(author)	: 70326 / YHS
     * 설명         	: RT_RCPT_DSRC_BASE 수정
     * 메소드인수1   	: RMK(적요), LastEmpNo
     * 메소드리턴값  	: int
     * 예외처리      	: Exception
     * </pre>
     */
    public int createDsrcChngHist(RtDsrcChngHistDTO inDto) throws Exception;

}
