package hanalife.r.sr.sr.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.r.sr.sr.mapper.DsrcAdjDescReadMapper;
import hanalife.r.sr.sr.mapper.dto.DsrcAdjDescReadDSDESCSDDTO;
import hanalife.r.sr.sr.mapper.dto.DsrcAdjDescReadDSDSRCADJDESCSMDTO;
import hanalife.r.sr.sr.mapper.dto.DsrcAdjDescReadDSDSRCADJDESCSUMSDDTO;
import hanalife.r.sr.sr.service.RSRSRM02Service;
import hanalife.r.sr.sr.vo.RSRSRM02DSDESCSDVO;
import hanalife.r.sr.sr.vo.RSRSRM02DSDSRCADJDESCSUMSDVO;
import hanalife.r.sr.sr.vo.RSRSRM02S01InVO;
import hanalife.r.sr.sr.vo.RSRSRM02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RSRSRM02ServiceImpl.java Class
 * 클래스설명   : 예/가수내역 및 합계 조회 (RSRSRM02) Service Implements
 * 작성일자     : 2023. 3. 8.
 * 작성자명     : 70321 / KimMinSeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 8.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : searchRcptDesc : 예/가수내역 조회
 * </pre>
 */
@Service("RSRSRM02Service")
public class RSRSRM02ServiceImpl implements RSRSRM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RSRSRM02ServiceImpl.class);

	@Autowired
	private DsrcAdjDescReadMapper dsrcAdjDescReadMapper;

	/**
	 * <p>메소드명      : searchRcptDesc : 예/가수내역 조회</p>
	 * <p>작성일자      : 2023. 3. 8.
	 * <p>작성자(author): 70321 / KimMinSeok
	 * <p>설명          : 예/가수내역 및 합계를 조회 한다.</p>
	 * <p>메소드인수    : RSRSRM02S01InVo </p>
	 * <p>메소드리턴값  : RSRSRM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RSRSRM02S01OutVO searchRcptDesc(RSRSRM02S01InVO inVo) throws Exception {

		/** 예/가수내역 조회 서비스 결과값 객체 생성 */
		RSRSRM02S01OutVO resultVo = new RSRSRM02S01OutVO();

		/** 예/가수내역에 대한 조회 조건 입력값 객체 생성 및 대입 수행 */
		DsrcAdjDescReadDSDSRCADJDESCSMDTO targetDto = new DsrcAdjDescReadDSDSRCADJDESCSMDTO();

		targetDto.setSumKind(inVo.getRSRSRM02DSDSRCADJDESCSM().getSumKind()); /**  */
		targetDto.setAcctDtFr(inVo.getRSRSRM02DSDSRCADJDESCSM().getAcctDtFr()); /**  */
		targetDto.setAcctDtTo(inVo.getRSRSRM02DSDSRCADJDESCSM().getAcctDtTo()); /**  */
		targetDto.setDsrcRamt(inVo.getRSRSRM02DSDSRCADJDESCSM().getDsrcRamt()); /**  */
		targetDto.setMmDlyFg(inVo.getRSRSRM02DSDSRCADJDESCSM().getMmDlyFg()); /**  */
		targetDto.setMngPlcDivCd(inVo.getRSRSRM02DSDSRCADJDESCSM().getMngPlcDivCd()); /**  */
		targetDto.setLoanNo(inVo.getRSRSRM02DSDSRCADJDESCSM().getLoanNo()); /**  */
		targetDto.setLoanSeq(inVo.getRSRSRM02DSDSRCADJDESCSM().getLoanSeq()); /**  */
		targetDto.setDsrcNo(inVo.getRSRSRM02DSDSRCADJDESCSM().getDsrcNo()); /**  */
		targetDto.setMngDeptCd(inVo.getRSRSRM02DSDSRCADJDESCSM().getMngDeptCd()); /**  */
		targetDto.setDsrcAdjCd(inVo.getRSRSRM02DSDSRCADJDESCSM().getDsrcAdjCd()); /**  */
		targetDto.setSetlDtFr(inVo.getRSRSRM02DSDSRCADJDESCSM().getSetlDtFr()); /**  */
		targetDto.setSetlDtTo(inVo.getRSRSRM02DSDSRCADJDESCSM().getSetlDtTo()); /**  */
		targetDto.setAcctUnitCd(inVo.getRSRSRM02DSDSRCADJDESCSM().getAcctUnitCd()); /**  */

		/** 예/가수내역에 대한 조회 쿼리 Mapper 호출 수행 */
		List<DsrcAdjDescReadDSDESCSDDTO> resultDTO = new ArrayList<DsrcAdjDescReadDSDESCSDDTO>();

		/** 전체(0)와 잔액(1) 기준 구분 */
		if( "0".equals(targetDto.getSumKind()) ){
			resultDTO = dsrcAdjDescReadMapper.searchRcptDescList0(targetDto);
		}else {
			resultDTO = dsrcAdjDescReadMapper.searchRcptDescList1(targetDto);
		}

		/** 예/가수내역 조회 화면 출력을 위한 결과값 List VO 객체 생성 */
		List<RSRSRM02DSDESCSDVO> resultList = new ArrayList<RSRSRM02DSDESCSDVO>();

		for (DsrcAdjDescReadDSDESCSDDTO sourceIO : resultDTO) {
			/** 예/가수내역 VO에 조회된 Mapper DTO 값을 대입 */
			RSRSRM02DSDESCSDVO targetIO = new RSRSRM02DSDESCSDVO();

			targetIO.setDsrcNo(sourceIO.getDsrcNo()); /**  */
			targetIO.setDsrcSnum(sourceIO.getDsrcSnum()); /**  */
			targetIO.setLoanNo(sourceIO.getLoanNo()); /**  */
			targetIO.setLoanSeq(sourceIO.getLoanSeq()); /**  */
			targetIO.setCustNm(sourceIO.getCustNm()); /**  */
			targetIO.setSetlNo(sourceIO.getSetlNo()); /**  */
			targetIO.setOccrDeptNm(sourceIO.getOccrDeptNm()); /**  */
			targetIO.setAdjDeptNm(sourceIO.getAdjDeptNm()); /**  */
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm()); /**  */
			targetIO.setAcctDt(sourceIO.getAcctDt()); /**  */
			targetIO.setSetlDt(sourceIO.getSetlDt()); /**  */
			targetIO.setRcptTpCd(sourceIO.getRcptTpCd()); /**  */
			targetIO.setRcptTpNm(sourceIO.getRcptTpNm()); /**  */
			targetIO.setDsrcAdjNm(sourceIO.getDsrcAdjNm()); /**  */
			targetIO.setDsrcOccrNm(sourceIO.getDsrcOccrNm()); /**  */
			targetIO.setDsrcOccrAmt(sourceIO.getDsrcOccrAmt()); /**  */
			targetIO.setDsrcAdjAmt(sourceIO.getDsrcAdjAmt()); /**  */
			targetIO.setDsrcRamt(sourceIO.getDsrcRamt()); /**  */
			targetIO.setRmk(sourceIO.getRmk()); /**  */
			targetIO.setIsrtEmpNo(sourceIO.getIsrtEmpNo()); /**  */
			targetIO.setIsrtEmpNm(sourceIO.getIsrtEmpNm()); /**  */
			targetIO.setAcctUnitCd(sourceIO.getAcctUnitCd()); /**  */
			targetIO.setAcctUnitNm(sourceIO.getAcctUnitNm()); /**  */
			targetIO.setDlyTcnt(sourceIO.getDlyTcnt()); /**  */
			targetIO.setDlyYn(sourceIO.getDlyYn()); /**  */
			targetIO.setDlyAmt(sourceIO.getDlyAmt()); /**  */
			targetIO.setUnArngRsn(sourceIO.getUnArngRsn()); /**  */
			targetIO.setMngPlcDivNm(sourceIO.getMngPlcDivNm()); /**  */

			/** 상단의 예/가수내역 조회 결과 List 객체에 추가하도록 수행 */
            resultList.add(targetIO);

		}

		/** 예/가수내역 조회 서비스 결과값 객체에 조회 결과 List 추가 */
		resultVo.setListRSRSRM02DSDESCSDVO(resultList);

		/** 예/가수내역 합계에 대한 조회 쿼리 Mapper 호출 수행 */
		List<DsrcAdjDescReadDSDSRCADJDESCSUMSDDTO> resultSumDTO = new ArrayList<DsrcAdjDescReadDSDSRCADJDESCSUMSDDTO>();

		/** 전체(0)와 잔액(1) 기준 구분 */
		if( "0".equals(targetDto.getSumKind()) ){
			resultSumDTO = dsrcAdjDescReadMapper.searchRcptDescSum0(targetDto);
		}else {
			resultSumDTO = dsrcAdjDescReadMapper.searchRcptDescSum1(targetDto);
		}

		/** 예/가수내역 합계 조회 화면 출력을 위한 결과값 List VO 객체 생성 */
		List<RSRSRM02DSDSRCADJDESCSUMSDVO> resultSumList = new ArrayList<RSRSRM02DSDSRCADJDESCSUMSDVO>();

		for (DsrcAdjDescReadDSDSRCADJDESCSUMSDDTO sourceIO : resultSumDTO) {
			/** 상단의 예/가수 내역 합계 VO에 조회된 Mapper DTO 값을 대입 */
			RSRSRM02DSDSRCADJDESCSUMSDVO targetIO = new RSRSRM02DSDSRCADJDESCSUMSDVO();

			targetIO.setCnt(sourceIO.getCnt()); /**  */
			targetIO.setDsrcOccrAmt(sourceIO.getDsrcOccrAmt()); /**  */
			targetIO.setDsrcAdjAmt(sourceIO.getDsrcAdjAmt()); /**  */
			targetIO.setDsrcRamt(sourceIO.getDsrcRamt()); /**  */

			/** 상단의 예/가수 내역 합계 결과 List 객체에 추가하도록 수행 */
            resultSumList.add(targetIO);

		}

		/** 예/가수내역 합계 조회 서비스 결과값 객체에 조회 결과 List 추가 */
		resultVo.setListRSRSRM02DSDSRCADJDESCSUMSDVO(resultSumList);

		/** 예/가수내역 조회 서비스 결과값 리턴 */
		return resultVo;

	}

}
