package hanalife.r.sr.sr.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.StringUtil;
import hanalife.r.sr.sr.mapper.DsrcChngHistMapper;
import hanalife.r.sr.sr.mapper.dto.DsrcChngHistDSSDDTO;
import hanalife.r.sr.sr.mapper.dto.DsrcChngHistDSSMDTO;
import hanalife.r.sr.sr.service.RSRSRP02Service;
import hanalife.r.sr.sr.vo.RSRSRP02DSRMRKHISTVO;
import hanalife.r.sr.sr.vo.RSRSRP02DSSETLHISTVO;
import hanalife.r.sr.sr.vo.RSRSRP02DSUNARNGHISTVO;
import hanalife.r.sr.sr.vo.RSRSRP02S01InVO;
import hanalife.r.sr.sr.vo.RSRSRP02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RSRSRP02ServiceImpl.java Class
 * 클래스설명   : 예가수변경이력팝업 (RSRSRP02) Service Implements
 * 작성일자     : 2023. 5. 9.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 9.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRSRSRP02S01 : 예가수변경이력팝업조회
 * </pre>
 */
@Service("RSRSRP02Service")
public class RSRSRP02ServiceImpl implements RSRSRP02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(RSRSRP02ServiceImpl.class);

    private MsgEnum msgEnum;
	private Constants consts;

	@Autowired
	private DsrcChngHistMapper dsrcChngHistMapper;

	/**
	 * <p>메소드명      : getRSRSRP02S01 : 예가수변경이력팝업조회</p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 예가수변경이력팝업 조회한다.</p>
	 * <p>메소드인수    : RSRSRP02S01InVo </p>
	 * <p>메소드리턴값  : RSRSRP02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RSRSRP02S01OutVO getRSRSRP02S01(RSRSRP02S01InVO inVo) throws Exception {

		RSRSRP02S01OutVO resultVo = new RSRSRP02S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		DsrcChngHistDSSMDTO inDto = new DsrcChngHistDSSMDTO();

		inDto.setDsrcNo(inVo.getRSRSRP02DSSMVO().getDsrcNo()); 			/** 예가수번호 */

		// 미정리변경내역 기본 목록 조회
		inDto.setChngDiv(consts.CHNG_DIV_UN_ARNG); 						/** 변경구분 */
		List<DsrcChngHistDSSDDTO> resultUnarngHist = dsrcChngHistMapper.searchDsrcChngHist(inDto);	/** 미정리변경내역*/

		List<RSRSRP02DSUNARNGHISTVO> resultUnarngHistList = new ArrayList<RSRSRP02DSUNARNGHISTVO>();

		for (DsrcChngHistDSSDDTO sourceIO : resultUnarngHist) {
			RSRSRP02DSUNARNGHISTVO targetIO = new RSRSRP02DSUNARNGHISTVO();

			targetIO.setDsrcNo(sourceIO.getDsrcNo()); 											/** 예가수번호 */
			targetIO.setHistSnum(sourceIO.getHistSnum()); 										/** 이력일련번호 */
			targetIO.setChngDiv(sourceIO.getChngDiv()); 										/** 변경구분 */
			targetIO.setChngDivNm(sourceIO.getChngDivNm()); 									/** 변경구분명 */
			targetIO.setChngBf(sourceIO.getChngBf()); 											/** 변경전 */
			targetIO.setChngAf(sourceIO.getChngAf()); 											/** 변경후 */
			targetIO.setRmrk(sourceIO.getRmrk()); 												/** 비고 */
			targetIO.setFrstRegDt(sourceIO.getFrstRegDt()); 									/** 최초등록일자 */
			targetIO.setFrstRegTm(sourceIO.getFrstRegTm()); 									/** 최초등록시간 */
			targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo()); 								/** 최초등록사원번호 */
			targetIO.setFrstRegEmpNm(StringUtil.nameMasking(sourceIO.getFrstRegEmpNm())); 		/** 최초등록사원명 */
			targetIO.setLastRegDt(sourceIO.getLastRegDt()); 									/** 최종처리일자 */
			targetIO.setLastRegTm(sourceIO.getLastRegTm()); 									/** 최종처리시간 */
			targetIO.setLastRegEmpNo(sourceIO.getLastRegEmpNo()); 								/** 최종처리사원번호 */
			targetIO.setLastRegEmpNm(StringUtil.nameMasking(sourceIO.getLastRegEmpNm())); 		/** 최종처리사원명 */

			resultUnarngHistList.add(targetIO);
		}

		resultVo.setRSRSRP02DSUNARNGHISTVO(resultUnarngHistList);		/** 미정리변경내역 */

		// 적요변경내역 기본 목록 조회
		inDto.setChngDiv(consts.CHNG_DIV_RMRK); 						/** 변경구분 */
		List<DsrcChngHistDSSDDTO> resultRmrkHist = dsrcChngHistMapper.searchDsrcChngHist(inDto);	/** 적요변경내역*/

		List<RSRSRP02DSRMRKHISTVO> resultRmrkHistList = new ArrayList<RSRSRP02DSRMRKHISTVO>();

		for (DsrcChngHistDSSDDTO sourceIO : resultRmrkHist) {
			RSRSRP02DSRMRKHISTVO targetIO = new RSRSRP02DSRMRKHISTVO();

			targetIO.setDsrcNo(sourceIO.getDsrcNo()); 											/** 예가수번호 */
			targetIO.setHistSnum(sourceIO.getHistSnum()); 										/** 이력일련번호 */
			targetIO.setChngDiv(sourceIO.getChngDiv()); 										/** 변경구분 */
			targetIO.setChngDivNm(sourceIO.getChngDivNm()); 									/** 변경구분명 */
			targetIO.setChngBf(sourceIO.getChngBf()); 											/** 변경전 */
			targetIO.setChngAf(sourceIO.getChngAf()); 											/** 변경후 */
			targetIO.setRmrk(sourceIO.getRmrk()); 												/** 비고 */
			targetIO.setFrstRegDt(sourceIO.getFrstRegDt()); 									/** 최초등록일자 */
			targetIO.setFrstRegTm(sourceIO.getFrstRegTm()); 									/** 최초등록시간 */
			targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo()); 								/** 최초등록사원번호 */
			targetIO.setFrstRegEmpNm(StringUtil.nameMasking(sourceIO.getFrstRegEmpNm())); 		/** 최초등록사원명 */
			targetIO.setLastRegDt(sourceIO.getLastRegDt()); 									/** 최종처리일자 */
			targetIO.setLastRegTm(sourceIO.getLastRegTm()); 									/** 최종처리시간 */
			targetIO.setLastRegEmpNo(sourceIO.getLastRegEmpNo()); 								/** 최종처리사원번호 */
			targetIO.setLastRegEmpNm(StringUtil.nameMasking(sourceIO.getLastRegEmpNm())); 		/** 최종처리사원명 */

			resultRmrkHistList.add(targetIO);
		}

		resultVo.setRSRSRP02DSRMRKHISTVO(resultRmrkHistList);		/** 적요변경내역 */

		// 예가수결제일자변경내역 기본 목록 조회
		inDto.setChngDiv(consts.CHNG_DIV_SETL); 						/** 변경구분 */
		List<DsrcChngHistDSSDDTO> resultSetlHist = dsrcChngHistMapper.searchDsrcChngHist(inDto);	/** 예가수결제일자변경내역*/

		List<RSRSRP02DSSETLHISTVO> resultSetlHistList = new ArrayList<RSRSRP02DSSETLHISTVO>();

		for (DsrcChngHistDSSDDTO sourceIO : resultSetlHist) {
			RSRSRP02DSSETLHISTVO targetIO = new RSRSRP02DSSETLHISTVO();

			targetIO.setDsrcNo(sourceIO.getDsrcNo()); 											/** 예가수번호 */
			targetIO.setHistSnum(sourceIO.getHistSnum()); 										/** 이력일련번호 */
			targetIO.setChngDiv(sourceIO.getChngDiv()); 										/** 변경구분 */
			targetIO.setChngDivNm(sourceIO.getChngDivNm()); 									/** 변경구분명 */
			targetIO.setChngBf(sourceIO.getChngBf()); 											/** 변경전 */
			targetIO.setChngAf(sourceIO.getChngAf()); 											/** 변경후 */
			targetIO.setRmrk(sourceIO.getRmrk()); 												/** 비고 */
			targetIO.setFrstRegDt(sourceIO.getFrstRegDt()); 									/** 최초등록일자 */
			targetIO.setFrstRegTm(sourceIO.getFrstRegTm()); 									/** 최초등록시간 */
			targetIO.setFrstRegEmpNo(sourceIO.getFrstRegEmpNo()); 								/** 최초등록사원번호 */
			targetIO.setFrstRegEmpNm(StringUtil.nameMasking(sourceIO.getFrstRegEmpNm())); 		/** 최초등록사원명 */
			targetIO.setLastRegDt(sourceIO.getLastRegDt()); 									/** 최종처리일자 */
			targetIO.setLastRegTm(sourceIO.getLastRegTm()); 									/** 최종처리시간 */
			targetIO.setLastRegEmpNo(sourceIO.getLastRegEmpNo()); 								/** 최종처리사원번호 */
			targetIO.setLastRegEmpNm(StringUtil.nameMasking(sourceIO.getLastRegEmpNm())); 		/** 최종처리사원명 */

			resultSetlHistList.add(targetIO);
		}

		resultVo.setRSRSRP02DSSETLHISTVO(resultSetlHistList);		/** 예가수결제일자변경내역 */

		return resultVo;
	}

}