package hanalife.r.sr.sr.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.sr.sr.service.RSRSRM02Service;
import hanalife.r.sr.sr.vo.RSRSRM02DSDSRCADJDESCSMVO;
import hanalife.r.sr.sr.vo.RSRSRM02S01InVO;
import hanalife.r.sr.sr.vo.RSRSRM02S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RSRSRM02Controller.java Class
 * 클래스설명   : 예/가수내역조회 (RSRSRM02) Controller
 * 작성일자     : 2023. 04. 24.
 * 작성자명     : 70366 / KangMinhyeok / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 8.][70321 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/sr/sr")
@Controller
public class RSRSRM02Controller {

	@Resource(name = "RSRSRM02Service")
	private RSRSRM02Service RSRSRM02;

	private static final Logger LOGGER = LoggerFactory.getLogger(RSRSRM02Controller.class);

	/**
	 * <p>메소드명      : RSRSRM02S01조회 /RSRSRM02S01.do </p>
	 * <p>작성일자      : 2023. 04. 24.
	 * <p>작성자(author): 70366
	 * <p>설명          : 예/가수내역을 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RSRSRM02S01.do")
	public String RSRSRM02S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RSRSRM02Controller RSRSRM02S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceDSDSRCADJDESCSMMap = XFrame5DataSetUtil.getXFrameDataSet("DS_DSRC_ADJ_DESC_SM", request, response, model);

			/** 예/가수내역조회내역조회 업무 서비스 호출 입력값 대입 */
			RSRSRM02DSDSRCADJDESCSMVO targetVo = new RSRSRM02DSDSRCADJDESCSMVO();

			targetVo.setSumKind((String)sourceDSDSRCADJDESCSMMap.get("sumKind"));        /** 합계 구분 ['전체'|'잔액'] */
			targetVo.setAcctDtFr((String)sourceDSDSRCADJDESCSMMap.get("acctDtFr"));      /** 회계일자_시작일자 */
			targetVo.setAcctDtTo((String)sourceDSDSRCADJDESCSMMap.get("acctDtTo"));      /** 회계일자_종료일자*/
			targetVo.setDsrcRamt((String)sourceDSDSRCADJDESCSMMap.get("dsrcRamt"));       /** 예가수_잔액 */
			targetVo.setMmDlyFg((String)sourceDSDSRCADJDESCSMMap.get("mmDlyFg"));        /** 월_연체_여부 */
			targetVo.setMngPlcDivCd((String)sourceDSDSRCADJDESCSMMap.get("mngPlcDivCd"));        /** 관리처_구분_코드 */
			targetVo.setLoanNo((String)sourceDSDSRCADJDESCSMMap.get("loanNo"));      /** 대출_번호 */
			targetVo.setLoanSeq((String)sourceDSDSRCADJDESCSMMap.get("loanSeq"));        /** 대출_순서 */
			targetVo.setDsrcNo((String)sourceDSDSRCADJDESCSMMap.get("dsrcNo"));      /** 예가수_번호 */
			targetVo.setMngDeptCd((String)sourceDSDSRCADJDESCSMMap.get("mngDeptCd"));        /** 관리부서_코드 */
			targetVo.setDsrcAdjCd((String)sourceDSDSRCADJDESCSMMap.get("dsrcAdjCd"));         /** 예가수_정산_코드 */
			targetVo.setSetlDtFr((String)sourceDSDSRCADJDESCSMMap.get("setlDtFr"));      /** 결제일자_시작일자 */
			targetVo.setSetlDtTo((String)sourceDSDSRCADJDESCSMMap.get("setlDtTo"));      /** 결제일자_종료일자 */
			targetVo.setAcctUnitCd((String)sourceDSDSRCADJDESCSMMap.get("acctUnitCd"));      /**회계_단위  */



			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RSRSRM02S01InVO InVO = new RSRSRM02S01InVO();
            InVO.setRSRSRM02DSDSRCADJDESCSM(targetVo); /** 예/가수내역조회 DS_SMDO 입력값 VO 객체 대입 */

			/** 예/가수내역조회 업무 서비스 호출 수행 */
			RSRSRM02S01OutVO resultRSRSRM02S01 = RSRSRM02.searchRcptDesc(InVO);

			XFrame5Util.setOutputData("DS_DESC_SD", resultRSRSRM02S01.getListRSRSRM02DSDESCSDVO(), model); /** 내역조회 */
			XFrame5Util.setOutputData("DS_DSRC_ADJ_DESC_SUM_SD", resultRSRSRM02S01.getListRSRSRM02DSDSRCADJDESCSUMSDVO(), model); /** 내역합계조회 */

			LOGGER.info("##### RSRSRM02Controller RSRSRM02S01 Normal End #####");  

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RSRSRM02Controller RSRSRM02S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}