package hanalife.r.va.va.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.r.va.va.mapper.ImgAcntTrDescReadMapper;
import hanalife.r.va.va.mapper.dto.ImgAcntTrDescReadDSSDDODTO;
import hanalife.r.va.va.mapper.dto.ImgAcntTrDescReadDSSMDODTO;
import hanalife.r.va.va.service.RVAVAM01Service;
import hanalife.r.va.va.vo.RVAVAM01DSSD01VO;
import hanalife.r.va.va.vo.RVAVAM01DSSEARCHVO;
import hanalife.r.va.va.vo.RVAVAM01S01InVO;
import hanalife.r.va.va.vo.RVAVAM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RVAVAM01S01ServiceImpl.java Class
 * 클래스설명   : 가상계좌거래내역조회 (RVAVAM01S01) Service Implements
 * 작성일자     : 2023. 3. 14.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 21.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getRVAVAM01S01 : 가상계좌거래내역조회
 * </pre>
 */
@Service("RVAVAM01Service")
public class RVAVAM01ServiceImpl implements RVAVAM01Service{

	private static final Logger LOGGER = LoggerFactory.getLogger(RVAVAM01ServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

	@Autowired
	private ImgAcntTrDescReadMapper imgAcntTrDescReadMapper;


	/**
	 * <p>메소드명      : searchImgAcnt : 수납내역상세조회</p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70322 / sungjin.park
	 * <p>설명          : 가상계좌거래내역을 조회 한다.</p>
	 * <p>메소드인수    : RVAVAM01S01InVO </p>
	 * <p>메소드리턴값  : RVAVAM01S01OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RVAVAM01S01OutVO searchImgAcnt(RVAVAM01S01InVO inVo) throws Exception {

		LOGGER.info("##### RVAVAM01ServiceImpl getRVAVAM01S01 Start #####");

		/** 가상계좌거래내역 서비스 결과값 객체 생성 */
		RVAVAM01S01OutVO resultVo = new RVAVAM01S01OutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		if("".equals(inVo.getRVAVAM01DSSEARCHVO().getTrDtFr()) || inVo.getRVAVAM01DSSEARCHVO().getTrDtFr()==null || "".equals(inVo.getRVAVAM01DSSEARCHVO().getTrDtTo()) || inVo.getRVAVAM01DSSEARCHVO().getTrDtTo()==null) {
			resultVo.setRsltCd("E000");
			resultVo.setRsltCntn("거래일자는 필수 조건입니다.");
			LOGGER.info("##### RVAVAM01ServiceImpl DSSEARCH Exception End #####");
			return resultVo;
		}

        try {
        	LOGGER.info("##### RVAVAM01ServiceImpl searchImgAcnt Start #####");

    		resultVo = searchDesc(inVo.getRVAVAM01DSSEARCHVO());

        } catch (Exception e) {
        	LOGGER.error("[대출정보 조회 오류] : 대출 정보 조회 중 오류  " + e.getMessage());
            resultVo.setRsltCd("E001");
            resultVo.setRsltCntn("대출정보 조회 오류");
        	LOGGER.info("##### RVAVAM01ServiceImpl searchImgAcnt Exception End #####");
        }

		return resultVo;
	}

	private RVAVAM01DSSD01VO searchCombo(RVAVAM01DSSEARCHVO inVo) throws Exception {
		RVAVAM01DSSD01VO result = new RVAVAM01DSSD01VO();
		//공통코드 미정의로 인해 주석처리 후 남겨둠 mapper.xml 에 쿼리는 등록해놓은 상태
		//result.put(DS_SEARCH_TR_ORG, RComboBoxUtil.selectTrOrgImgAcnt(DS_SEARCH_TR_ORG, tx));
		//result.put(DS_SEARCH_PRDT_CLAS, RComboBoxUtil.selectPrdtClas(DS_SEARCH_PRDT_CLAS,tx));
		//result.setErrorCode("0");
		//result.setErrorMessage("SSC0001");
		return result;
	}

	private RVAVAM01S01OutVO searchDesc(RVAVAM01DSSEARCHVO searchVo) throws Exception {

		RVAVAM01S01OutVO resultVo = new RVAVAM01S01OutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {

			List<RVAVAM01DSSD01VO> descList = searchDescList(searchVo);

			if(descList == null) {
				resultVo.setRsltCd("E003");
				resultVo.setRsltCntn("가상계좌거래내역 정보없음");
			}

			resultVo.setListRVAVAM01DSSD01VO(descList);

		} catch (Exception e) {
			resultVo.setRsltCd("E002");
			resultVo.setRsltCntn("가상계좌거래내역 조회실패");
		}

		return resultVo;
	}

	private List<RVAVAM01DSSD01VO> searchDescList(RVAVAM01DSSEARCHVO searchVo) throws Exception {

		ImgAcntTrDescReadDSSMDODTO inDto = new ImgAcntTrDescReadDSSMDODTO();

		List<RVAVAM01DSSD01VO> resultImgAcntList = new ArrayList<RVAVAM01DSSD01VO>();

		inDto.setLoanNo(searchVo.getLoanNo());
		inDto.setLoanSeq(searchVo.getLoanSeq());
		inDto.setTrDtFr(searchVo.getTrDtFr());
		inDto.setTrDtTo(searchVo.getTrDtTo());
		inDto.setAcntNo(searchVo.getAcntNo());
		inDto.setDepoOwnnm(searchVo.getDepoOwnnm());
		inDto.setTrOrgCd(searchVo.getTrOrgCd());
		inDto.setMngDeptCd(searchVo.getMngDeptCd());
		inDto.setPrdtClasCd(searchVo.getPrdtClasCd());
		inDto.setBndDivsEmpNo(searchVo.getBndDivsEmpNo());
		inDto.setCnclFg(searchVo.getCnclFg());
		inDto.setSetlFg(searchVo.getSetlFg());

		List<ImgAcntTrDescReadDSSDDODTO> resultImgAcntDto = imgAcntTrDescReadMapper.searchDescList(inDto);

		for(ImgAcntTrDescReadDSSDDODTO sourceIO : resultImgAcntDto) {

			RVAVAM01DSSD01VO targetIO = new RVAVAM01DSSD01VO();
			targetIO.setTrDt(sourceIO.getTrDt());
			targetIO.setTrOrgNm(sourceIO.getTrOrgNm());
			targetIO.setBankNm(sourceIO.getBankNm());
			targetIO.setLoanNo(sourceIO.getLoanNo());
			targetIO.setLoanSeq(sourceIO.getLoanSeq());
			targetIO.setCustNo(sourceIO.getCustNo());
			targetIO.setCustNm(sourceIO.getCustNm());
			targetIO.setDepoOwnnm(sourceIO.getDepoOwnnm());
			targetIO.setAcntNo(sourceIO.getAcntNo());
			targetIO.setTrAmt(sourceIO.getTrAmt());
			targetIO.setMngDeptNm(sourceIO.getMngDeptNm());
			targetIO.setBndDivsEmpNo(sourceIO.getBndDivsEmpNo());
			targetIO.setBndDivsEmpNm(sourceIO.getBndDivsEmpNm());
			targetIO.setPrdtClasNm(sourceIO.getPrdtClasNm());
			targetIO.setPrdtLrgeClasCd(sourceIO.getPrdtLrgeClasCd());
			targetIO.setRecvTm(sourceIO.getRecvTm());
			targetIO.setCnclFg(sourceIO.getCnclFg());
			targetIO.setSetlFg(sourceIO.getSetlFg());
			targetIO.setSetlNo(sourceIO.getSetlNo());
			targetIO.setRcptPamt(sourceIO.getRcptPamt());
			targetIO.setRcptInt(sourceIO.getRcptInt());
			targetIO.setRcptDfee(sourceIO.getRcptDfee());
			targetIO.setLeglActnCost(sourceIO.getLeglActnCost());
			targetIO.setMidRmbrFee(sourceIO.getMidRmbrFee());
			targetIO.setTrtFeeDisc(sourceIO.getTrtFeeDisc());
			targetIO.setDsrcOccrAmt(sourceIO.getDsrcOccrAmt());
			targetIO.setRcptAmt(sourceIO.getRcptAmt());
			targetIO.setPdueAmt(sourceIO.getPdueAmt());
			targetIO.setDsrcNo(sourceIO.getDsrcNo());
			targetIO.setDsrcAdjYn(sourceIO.getDsrcAdjYn());
			targetIO.setBankBrnchCd(sourceIO.getBankBrnchCd());
			targetIO.setTrmnCd(sourceIO.getTrmnCd());
			targetIO.setIamtTm(sourceIO.getIamtTm());

			resultImgAcntList.add(targetIO);
		}

		return resultImgAcntList;

	}

}
