package hanalife.r.va.va.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.va.va.service.RVAVAM01Service;
import hanalife.r.va.va.vo.RVAVAM01DSSEARCHVO;
import hanalife.r.va.va.vo.RVAVAM01S01InVO;
import hanalife.r.va.va.vo.RVAVAM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RVAVAM01Controller.java Class
 * 클래스설명   : 가상계좌 거래내역 조회 (RVAVAM01) Controller
 * 작성일자     : 2023. 3. 30.
 * 작성자명     : 70322 / sungjin.park / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 30.][70322 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/va/va")
@Controller
public class RVAVAM01Controller {

	@Resource(name = "RVAVAM01Service")
	private RVAVAM01Service RVAVAM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(RVAVAM01Controller.class);

	/**
	 * <p>메소드명      : 가상계좌 거래내역 조회 /RVAVAM01S01.do </p>
	 * <p>작성일자      : 2023. 3. 30.
	 * <p>작성자(author): 70322
	 * <p>설명          : 가상계좌 거래내역 조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RVAVAM01S01.do")
	public String RVAVAM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RVAVAM01Controller RVAVAM01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SEARCH", request, response, model);	/** 조회조건 */

			/** 가상계좌 거래내역 조회내역조회 업무 서비스 호출 입력값 대입 */
			RVAVAM01DSSEARCHVO targetVo = new RVAVAM01DSSEARCHVO();
			targetVo.setLoanNo((String) sourceMap.get("loanNo")); /** 대출번호 */
			targetVo.setLoanSeq((String) sourceMap.get("loanSeq")); /** 대출순번 */
			targetVo.setTrDtFr((String) sourceMap.get("trDtFr")); /**  */
			targetVo.setTrDtTo((String) sourceMap.get("trDtTo")); /**  */
			targetVo.setAcntNo((String) sourceMap.get("acntNo")); /**  */
			targetVo.setDepoOwnnm((String) sourceMap.get("depoOwnnm")); /**  */
			targetVo.setTrOrgCd((String) sourceMap.get("trOrgCd")); /**  */
			targetVo.setMngDeptCd((String) sourceMap.get("mngDeptCd")); /**  */
			targetVo.setPrdtClasCd((String) sourceMap.get("prdtClasCd")); /**  */
			targetVo.setBndDivsEmpNo((String) sourceMap.get("bndDivsEmpNo")); /**  */
			targetVo.setCnclFg((String) sourceMap.get("cnclFg")); /**  */
			targetVo.setSetlFg((String) sourceMap.get("setlFg")); /**  */

			/** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			RVAVAM01S01InVO InVO = new RVAVAM01S01InVO();
            InVO.setRVAVAM01DSSEARCHVO(targetVo); /** 연체현황조회 DS_SMDO 입력값 VO 객체 대입 */

			/** 가상계좌 거래내역 조회내역조회 업무 서비스 호출 수행 */
			RVAVAM01S01OutVO resultRVAVAM01S01 =  RVAVAM01.searchImgAcnt(InVO);

			XFrame5Util.setOutputData("DS_SD_01", resultRVAVAM01S01.getListRVAVAM01DSSD01VO(), model); /** 조회내역 */

			LOGGER.info("##### RVAVAM01Controller RVAVAM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### RVAVAM01Controller RVAVAM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
