package hanalife.r.va.va.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.va.va.service.RVAVAM03Service;
import hanalife.r.va.va.vo.RVAVAM03D01InVO;
import hanalife.r.va.va.vo.RVAVAM03DSSM01VO;
import hanalife.r.va.va.vo.RVAVAM03DSSM02VO;
import hanalife.r.va.va.vo.RVAVAM03S01InVO;
import hanalife.r.va.va.vo.RVAVAM03S01OutVO;
import hanalife.r.va.va.vo.RVAVAM03U01InVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RVAVAM03Controller.java Class
 *
 * 클래스설명   : 가상계좌변경관리 (RVAVAM03) Controller
 * 작성일자     : 2023. 3. 7.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/va/va")
@Controller
public class RVAVAM03Controller {

	@Resource(name = "RVAVAM03Service")
	private RVAVAM03Service RVAVAM03;

	private static final Logger LOGGER = LoggerFactory.getLogger(RVAVAM03Controller.class);

	/**
	 * <p>메소드명      : 가상계좌대출정보 /RVAVAM03S01.do </p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author): 70323
	 * <p>설명          : 가상계좌대출정보 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RVAVAM03S01.do")
	public String RVAVAM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RVAVAM03Controller RVAVAM03S01 Start #####");

		try {

			/*************************************************
			 * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			 *************************************************/
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM01", request, response, model);


			/*************************************************
			 * ■ 가상계좌대출정보조회 DataSet 항목값 VO객체 입력값 대입
			 *************************************************/
			RVAVAM03DSSM01VO targetVo = new RVAVAM03DSSM01VO();

			targetVo.setLoanNo((String)sourceMap.get("loanNo"));        // 대출번호
			targetVo.setLoanSeq((String)sourceMap.get("loanSeq"));      // 대출순번
			targetVo.setCustNo((String)sourceMap.get("custNo"));        // 고객번호
			targetVo.setImgAcntNo((String)sourceMap.get("imgAcntNo"));  // 가상계좌번호


			/*************************************************
			 * ■ VO객체에 DataSetVO 입력값 대입
			 *************************************************/
			RVAVAM03S01InVO InVO = new RVAVAM03S01InVO();
			InVO.setRVAVAM03DSSM01VO(targetVo);


			/*************************************************
			 * ■ 가상계좌대출정보조회 업무 서비스 호출 수행
			 *************************************************/
			RVAVAM03S01OutVO resultRVAVAM03S01 = RVAVAM03.getRVAVAM03S01(InVO);


			/*************************************************
			 * ■ 가상계좌대출정보조회 DataSet 결과값 설정
			 *************************************************/
			XFrame5Util.setOutputData("DS_SD01", resultRVAVAM03S01.getRVAVAM03DSSD01VO(), model);
			LOGGER.info("##### RVAVAM03Controller RVAVAM03S01 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
			LOGGER.info("##### RVAVAM03Controller RVAVAM03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;

	}


	/**
	 * <p>메소드명      : 가상계좌변경이력 /RVAVAM03S02.do </p>
	 * <p>작성일자      : 2023. 3. 9.
	 * <p>작성자(author): 70323
	 * <p>설명          : 가상계좌변경이력 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/RVAVAM03S02.do")
	public String RVAVAM03S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### RVAVAM03Controller RVAVAM03S02 Start #####");

		try {

			/*************************************************
			 * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			 *************************************************/
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM02", request, response, model);


			/*************************************************
			 * ■ 가상계좌변경이력조회 DataSet 항목값 VO객체 입력값 대입
			 *************************************************/
			RVAVAM03DSSM02VO targetVo = new RVAVAM03DSSM02VO();

			targetVo.setLoanNo((String)sourceMap.get("loanNo"));           // 대출번호
			targetVo.setLoanSeq((String)sourceMap.get("loanSeq"));         // 대출순번

			LOGGER.info("##### (String)sourceMap.get(\"loanNo\") #####  : " + (String)sourceMap.get("loanNo"));
			LOGGER.info("##### (String)sourceMap.get(\"loanSeq\") ##### : " + (String)sourceMap.get("loanSeq"));


			/*************************************************
			 * ■ VO객체에 DataSetVO 입력값 대입
			 *************************************************/
			RVAVAM03S01InVO InVO = new RVAVAM03S01InVO();
			InVO.setRVAVAM03DSSM02VO(targetVo);


			/*************************************************
			 * ■ 가상계좌변경이력조회 업무 서비스 호출 수행
			 *************************************************/
			RVAVAM03S01OutVO resultRVAVAM03S01 = RVAVAM03.getRVAVAM03S02(InVO);


			/*************************************************
			 * ■ 가상계좌변경이력조회 DataSet 결과값 설정
			 *************************************************/
			XFrame5Util.setOutputData("DS_SD02", resultRVAVAM03S01.getRVAVAM03DSSD02VO(), model);
			LOGGER.info("##### RVAVAM03Controller RVAVAM03S02 Normal End #####");

		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
			LOGGER.info("##### RVAVAM03Controller RVAVAM03S02 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;

	}


	/**
     * <p>메소드명      : 가상계좌변경관리수정 /RVAVAM03U01.do </p>
     * <p>작성일자      : 2023. 3. 9.
     * <p>작성자(author): 70323
     * <p>설명          : 가상계좌변경관리수정 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/RVAVAM03U01.do")
    public String RVAVAM03U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RVAVAM03Controller RVAVAM03U01 Start #####");

        try {

        	/*************************************************
			 * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			 *************************************************/
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM02", request, response, model);


            /*************************************************
			 * ■ 가상계좌변경관리수정 DataSet 항목값 VO객체 입력값 대입
			 *************************************************/
            RVAVAM03DSSM02VO targetVo = new RVAVAM03DSSM02VO();

            targetVo.setLoanNo((String)sourceMap.get("loanNo"));                   // 대출번호
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq"));                 // 대출순번
            targetVo.setLoanStatCd((String)sourceMap.get("loanStatCd"));           // 대출상태코드
            targetVo.setLoanStatNm((String)sourceMap.get("loanStatNm"));           // 대출상태명
            targetVo.setBfBankCd((String)sourceMap.get("bfBankCd"));               // 변경전은행코드
            targetVo.setBfBankNm((String)sourceMap.get("bfBankNm"));               // 변경전은행명
            targetVo.setBfAcntNo((String)sourceMap.get("bfAcntNo"));               // 변경전계좌번호
            targetVo.setAfBankCd((String)sourceMap.get("afBankCd"));               // 변경후은행코드
            targetVo.setLogInEmpNo((String)sourceMap.get("logInEmpNo"));           // 로그인사원번호


            /*************************************************
			 * ■ VO객체에 DataSetVO 입력값 대입
			 *************************************************/
            RVAVAM03U01InVO InVO = new RVAVAM03U01InVO();
            InVO.setRVAVAM03DSSM02VO(targetVo);


            /*************************************************
			 * ■ 가상계좌변경관리수정 업무 서비스 호출 수행
			 *************************************************/
            RVAVAM03.modifyRVAVAM03U01(InVO);


            /*************************************************
			 * ■ 가상계좌변경관리수정 DataSet 결과값 설정
			 *************************************************/
            LOGGER.info("##### RVAVAM03Controller RVAVAM03U01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
            LOGGER.info("##### RVAVAM03Controller RVAVAM03U01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;

    }

    /**
     * <p>메소드명      : 가상계좌변경관리삭제 /RVAVAM03D01.do </p>
     * <p>작성일자      : 2023. 2. 27.
     * <p>작성자(author): 70317
     * <p>설명          : 가상계좌변경관리삭제 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/RVAVAM03D01.do")
    public String RVAVAM03D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RVAVAM03Controller RVAVAM03D01 Start #####");

        try {

        	/*************************************************
			 * ■ XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			 *************************************************/
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM02", request, response, model);


            /*************************************************
			 * ■ 가상계좌변경관리삭제 DataSet 항목값 VO객체 입력값 대입
			 *************************************************/
            RVAVAM03DSSM02VO targetVo = new RVAVAM03DSSM02VO();

            targetVo.setLoanNo((String)sourceMap.get("loanNo"));                   // 대출번호
            targetVo.setLoanSeq((String)sourceMap.get("loanSeq"));                 // 대출순번
            targetVo.setLoanStatCd((String)sourceMap.get("loanStatCd"));           // 대출상태코드
            targetVo.setLoanStatNm((String)sourceMap.get("loanStatNm"));           // 대출상태명
            targetVo.setBfBankCd((String)sourceMap.get("bfBankCd"));               // 변경전은행코드
            targetVo.setBfBankNm((String)sourceMap.get("bfBankNm"));               // 변경전은행명
            targetVo.setBfAcntNo((String)sourceMap.get("bfAcntNo"));               // 변경전계좌번호
            targetVo.setAfBankCd((String)sourceMap.get("afBankCd"));               // 변경후은행코드
            targetVo.setLogInEmpNo((String)sourceMap.get("logInEmpNo"));           // 로그인사원번호


            /*************************************************
			 * ■ VO객체에 DataSetVO 입력값 대입
			 *************************************************/
            RVAVAM03D01InVO InVO = new RVAVAM03D01InVO();
            InVO.setRVAVAM03DSSM02VO(targetVo);


            /*************************************************
			 * ■ 가상계좌변경관리삭제 업무 서비스 호출 수행
			 *************************************************/
            RVAVAM03.removeRVAVAM03D01(InVO);


            /*************************************************
			 * ■ 가상계좌변경관리수정 DataSet 결과값 설정
			 *************************************************/
            //XFrame5Util.setOutputData("DS_SD02", resultRVAVAM03D01.getRVAVAM03D0102VO(), model); /** 수납목록조회 */
            LOGGER.info("##### RVAVAM03Controller RVAVAM03D01 Normal End #####");

        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());
            LOGGER.info("##### RVAVAM03Controller RVAVAM03D01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;

    }

}