package hanalife.r.va.va.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.r.va.va.service.RVAVAP01Service;
import hanalife.r.va.va.vo.RVAVAP01DSPOPUPSMVO;
import hanalife.r.va.va.vo.RVAVAP01S01InVO;
import hanalife.r.va.va.vo.RVAVAP01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RATMNM03Controller.java Class
 * 클래스설명   : 자동이체거래내역조회 (RATMNM03) Controller
 * 작성일자     : 2023. 4. 18.
 * 작성자명     : 70367 / ByeonJunoh / 가계대출 시스템 구축
 * Copyrightⓒ2033 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2033. 4. 18.][70367 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/r/va/va")
@Controller
public class RVAVAP01Controller {

    @Resource(name = "RVAVAP01Service")
    private RVAVAP01Service RVAVAP01;

    private static final Logger LOGGER = LoggerFactory.getLogger(RVAVAP01Controller.class);

    /**
     * <p>메소드명      : 자동이체거래내역조회 /RATMNM03S01.do </p>
     * <p>작성일자      : 2023. 4. 18.
     * <p>작성자(author): 70367
     * <p>설명          : 자동이체거래내역조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/RVAVAP01S01.do")
    public String RVAVAP01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### RVAVAP01Controller RVAVAP01S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_POPUP_SM", request, response, model);

            /** 자동이체계좌신청조회내역조회 업무 서비스 호출 입력값 대입 */
            LOGGER.info("##### RVAVAP01Controller RVAVAP01 0 #####" );
            RVAVAP01DSPOPUPSMVO targetVo = new RVAVAP01DSPOPUPSMVO();
            LOGGER.info("##### RVAVAP01Controller RVAVAP01 1 #####" + sourceMap.get("stndDt"));
            targetVo.setStndDt((String)sourceMap.get("stndDt"));
            LOGGER.info("##### RVAVAP01Controller RVAVAP01  2 #####" + targetVo.getStndDt());


            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            RVAVAP01S01InVO InVO = new RVAVAP01S01InVO();

             /** 자동이체거래현황 조회 DS_SMDO 입력값 VO 객체 대입 */
             InVO.setRVAVAP01DSPOPUPSMVO(targetVo);

            /** 자동이체계좌신청조회내역조회 업무 서비스 호출 수행 */
            RVAVAP01S01OutVO resultRVAVAP01S01 = RVAVAP01.getRVAVAP01S01(InVO);

            XFrame5Util.setOutputData("DS_POPUP_SD", resultRVAVAP01S01.getListRVAVAP01DSPOPUPSDVO(), model);

            LOGGER.info("##### RVAVAP01Controller RVAVAP01 Exception End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RVAVAP01Controller RVAVAP01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }

}
