package hanalife.s.ag.bs.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.cm.sp.service.callSpService;
import hanalife.c.cm.sp.vo.chkAccNmVO;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.c.sc.sq.util.Util;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.ag.bs.service.SAGBSM01Service;
import hanalife.s.ag.bs.vo.SAGBSM01DSSDCVO;
import hanalife.s.ag.bs.vo.SAGBSM01I01InVO;
import hanalife.s.ag.bs.vo.SAGBSM01I01OutVO;
import hanalife.s.ag.bs.vo.SAGBSM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SAGBSM01Controller.java Class
 *
 * 클래스설명   : SR기관관리 (SAGBSM01) Controller
 * 작성일자     : 2023. 4. 12.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 12.][70323 ][최초작성]
 * [2023. 4. 14.][70323 ][조회 조건 입력 삭제]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/ag/bs")
@Controller
public class SAGBSM01Controller {

	@Resource(name = "SAGBSM01Service")
	private SAGBSM01Service SAGBSM01;

	@Resource(name = "callSpService")
	private callSpService callSp;

	private static final Logger LOGGER = LoggerFactory.getLogger(SAGBSM01Controller.class);

	/**
	 * <p>메소드명      : SR기관관리 /SAGBSM01S01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR기관관리 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM01S01.do")
	public String SAGBSM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM01Controller SAGBSM01S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			//Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** SR기관관리내역조회 업무 서비스 호출 입력값 대입 */
//			SAGBSM01S01InVO targetVo = new SAGBSM01S01InVO();
//			SAGBSM01DSSMVO smVo = new SAGBSM01DSSMVO();
//
//			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */
//
//			targetVo.setSAGBSM01DSSMVO(smVo);

			/** SR기관관리내역조회 업무 서비스 호출 수행 */
//			SAGBSM01S01OutVO resultSAGBSM01S01 = SAGBSM01.getSAGBSM01S01(targetVo);
			SAGBSM01S01OutVO resultSAGBSM01S01 = SAGBSM01.getSAGBSM01S01();

			XFrame5Util.setOutputData("DS_SD", resultSAGBSM01S01.getSAGBSM01DSSDVO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM01S01.getRsltCd());		/** 결과코드 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM01S01.getRsltCntn());	/** 결과메세지 */

			LOGGER.info("##### SAGBSM01Controller SAGBSM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM01Controller SAGBSM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SR기관관리등록 /SAGBSM01I01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR기관관리 등록 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM01I01.do")
	public String SAGBSM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM01Controller SAGBSM01I01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** SR기관관리내역조회 업무 서비스 호출 입력값 대입 */
			SAGBSM01I01InVO targetVo = new SAGBSM01I01InVO();
			SAGBSM01DSSDCVO sdcVo = new SAGBSM01DSSDCVO();

			BeanUtil.mapToBean(sourceMap, sdcVo);	/** Map을 VO로 변환 */

			targetVo.setSAGBSM01DSSDCVO(sdcVo);

			/** SR기관관리내역조회 업무 서비스 호출 수행 */
			SAGBSM01I01OutVO resultSAGBSM01I01 = SAGBSM01.registerSAGBSM01S01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM01I01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM01I01.getRsltCntn());

			LOGGER.info("##### SAGBSM01Controller SAGBSM01I01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM01Controller SAGBSM01I01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : SR기관관리수정 /SAGBSM01U01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR기관관리 수정 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM01U01.do")
	public String SAGBSM01U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM01Controller SAGBSM01U01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SD_C", request, response, model);

			/** SR기관관리내역조회 업무 서비스 호출 입력값 대입 */
			SAGBSM01I01InVO targetVo = new SAGBSM01I01InVO();
			SAGBSM01DSSDCVO sdcVo = new SAGBSM01DSSDCVO();

			BeanUtil.mapToBean(sourceMap, sdcVo);	/** Map을 VO로 변환 */

			targetVo.setSAGBSM01DSSDCVO(sdcVo);

			/** SR기관관리내역조회 업무 서비스 호출 수행 */
			SAGBSM01I01OutVO resultSAGBSM01U01 = SAGBSM01.modifySAGBSM01S01(targetVo);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSAGBSM01U01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSAGBSM01U01.getRsltCntn());

			LOGGER.info("##### SAGBSM01Controller SAGBSM01U01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM01Controller SAGBSM01U01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

	/**
	 * <p>메소드명      : 계좌번호확인 /SAGBSM01C01.do </p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323
	 * <p>설명          : SR기관관리 계좌번호 확인 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SAGBSM01C01.do")
	public String SAGBSM01C01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SAGBSM01Controller SAGBSM01C01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ACNT_CHK", request, response, model);

			/** SR기관관리내역조회 업무 서비스 호출 입력값 대입 */
			chkAccNmVO chkAccNmVO = new chkAccNmVO();

			chkAccNmVO.setLvvIgjbh(		(String)sourceMap.get("acntNo")		); 		/** 계좌번호 */
			chkAccNmVO.setLvvIbankcd(	(String)sourceMap.get("bankcd")		); 		/** 은행코드 */
			chkAccNmVO.setLvvIygjjmbh(	(String)sourceMap.get("corpNo")		); 		/** 주민번호앞자리(6자리) / 법인번호 */

			/** SR기관관리내역조회 업무 서비스 호출 수행 */
			chkAccNmVO resultSAGBSM01C01 = callSp.chkAccNm(chkAccNmVO);

			String revRecode = chkAccNmVO.getRevRecode();

			if(revRecode == null) {
				revRecode = "계좌번호 확인 오류입니다.";
			}

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, chkAccNmVO.getOutData());		/** 1:정상, 그외 에러 */
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, revRecode);	/** 정상인경우:실 예금주명, 에러인경우 에러내용 */

			LOGGER.info("##### SAGBSM01Controller SAGBSM01C01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SAGBSM01Controller SAGBSM01C01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
