package hanalife.s.as.as.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.as.as.service.SASASM01Service;
import hanalife.s.as.as.vo.SASASM01DSSMVO;
import hanalife.s.as.as.vo.SASASM01S01InVO;
import hanalife.s.as.as.vo.SASASM01S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SASASM01Controller.java Class
 *
 * 클래스설명   : 상담목록조회 (SASASM01) Controller
 * 작성일자     : 2023. 3. 21.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/as/as")
@Controller
public class SASASM01Controller {

	@Resource(name = "SASASM01Service")
	private SASASM01Service SASASM01;

	private static final Logger LOGGER = LoggerFactory.getLogger(SASASM01Controller.class);

	/**
	 * <p>메소드명      : 상담목록조회 /SASASM01S01.do </p>
	 * <p>작성일자      : 2023. 3. 21.
	 * <p>작성자(author): 70323
	 * <p>설명          : 상담목록조회 한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SASASM01S01.do")
	public String SASASM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SASASM01Controller SASASM01S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 상담목록조회내역조회 업무 서비스 호출 입력값 대입 */
			SASASM01S01InVO targetVo = new SASASM01S01InVO();
			SASASM01DSSMVO smVo = new SASASM01DSSMVO();

			smVo.setCnslDtFr((String)sourceMap.get("cnslDtFr")); /** 상담일자시작 */
			smVo.setCnslDtTo((String)sourceMap.get("cnslDtTo")); /** 상담일자종료 */
			smVo.setChnlPrgsStatCd((String)sourceMap.get("chnlPrgsStatCd")); /** 모바일진행상태코드 */
			smVo.setChnlPrgsStatNm((String)sourceMap.get("chnlPrgsStatNm")); /** 모바일진행상태명 */

			targetVo.setSASASM01DSSMVO(smVo);

			/** 상담목록조회내역조회 업무 서비스 호출 수행 */
			SASASM01S01OutVO resultSASASM01S01 = SASASM01.getSASASM01S01(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultSASASM01S01.getSASASM01DSSDVO(), model);

			LOGGER.info("##### SASASM01Controller SASASM01S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SASASM01Controller SASASM01S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
