package hanalife.s.ln.ch.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.s.ln.ch.mapper.dto.LoanBaseDTO;
import hanalife.s.ln.ch.mapper.dto.MidPartRmbrInVODTO;
import hanalife.s.ln.ch.mapper.dto.MidPartRmbrOutVODTO;
import hanalife.s.ln.ch.mapper.dto.PsgIntCalcDTO;
import hanalife.s.ln.ch.mapper.dto.RmbrPlanUpdtInVODTO;
import hanalife.s.ln.ch.mapper.dto.RmbrPlanUpdtOutVODTO;
import hanalife.s.ln.ch.mapper.dto.SetlDdChngDTO;
import hanalife.s.ln.lm.mapper.dto.LoanBaseOutVODTO;
import hanalife.s.ln.lm.mapper.dto.LoanPiamtDTO;
import hanalife.s.ln.lm.mapper.dto.LoanPiamtOutVODTO;

/**
 * <pre>
 * 클래스명    : RmbrPlanUpdtMapper.java Class
 * 클래스설명  : 연체리스트 관리 Mapper
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 10.
 * 작성자명    : 70326 / hyunsik.you / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */

@Mapper("RmbrPlanUpdtMapper")
public interface RmbrPlanUpdtMapper {

	/**
     * <p>메소드명      : dueDtRead</p>
     * <p>설명         : 납입일자 조회.</p>
     * <p>메소드인수1   : RmbrPlanUpdtInVO</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  :  String</p>
     * <p>예외처리      : Exception</p>
     */
    public String dueDtRead(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : intStrtDtRead</p>
     * <p>설명         : 이자시작일자 조회.</p>
     * <p>메소드인수1   : RmbrPlanUpdtInVO</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  :  String</p>
     * <p>예외처리      : Exception</p>
     */
    public String intStrtDtRead(RmbrPlanUpdtInVODTO inDto) throws Exception;
    /**
     * <p>메소드명      : intStrtDtRead</p>
     * <p>설명         : 이자시작일자 조회.</p>
     * <p>메소드인수1   : RmbrPlanUpdtInVO</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  :  String</p>
     * <p>예외처리      : Exception</p>
     */
    public String intStrtDtRead2(RmbrPlanUpdtInVODTO inDto) throws Exception;

	/**
     * <p>메소드명      : updateLoan</p>
     * <p>설명         : 납입일변경 이력 조회한다.</p>
     * <p>메소드인수1   : RmbrPlanUpdtInVO</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  :  RmbrPlanUpdtOutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<RmbrPlanUpdtOutVODTO> setlDdChngHistRead(RmbrPlanUpdtInVODTO inDto) throws Exception;

	/**
     * <p>메소드명      : searchMax</p>
     * <p>설명          : .</p>
     * <p>메소드인수1   : RmbrPlanUpdtInVO</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : RmbrPlanUpdtOutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<RmbrPlanUpdtOutVODTO> searchMax(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanIntRtRead</p>
     * <p>설명          : 대출원리금 이자율 조회</p>
     * <p>메소드인수1   : RmbrPlanUpdtInVO</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : RmbrPlanUpdtOutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<RmbrPlanUpdtOutVODTO> loanIntRtRead(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : psgIntCalc</p>
     * <p>설명          : 경과이자계산한다.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 경과이자계산 OUTVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<PsgIntCalcDTO> psgIntCalcQry(PsgIntCalcDTO inDto) throws Exception;

    /**
     * <p>메소드명      : setlDdChngRead1</p>
     * <p>설명          : 결제일변경 조회쿼리1.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : SetlDdChngDTO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<SetlDdChngDTO> setlDdChngRead1(SetlDdChngDTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanPiamtRead1</p>
     * <p>설명          : 대출원리금 조회.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : RmbrPlanUpdtOutVO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<LoanPiamtOutVODTO> loanPiamtRead1(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanBaseRead1</p>
     * <p>설명          : 대출기본조회 1 - 중도부분상환</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : LoanBaseDTO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<LoanBaseDTO> loanBaseRead1(LoanBaseDTO inDto) throws Exception;

    /**
     * <p>메소드명     : loanPiamtCrte2</p>
     * <p>설명        : 결제일변경 대출원리금 거래일련번호 증가 저장.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int loanPiamtCrte2(SetlDdChngDTO inDto) throws Exception;

    /**
     * <p>메소드명      : rmbrPlanTrSeqUdpt1</p>
     * <p>설명          : MAX 거래일련번호 + 1 수정</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int rmbrPlanTrSeqUdpt1(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : rmbrPlanHistCrte1</p>
     * <p>설명          : 상환계획이력 등록.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int rmbrPlanHistCrte1(RmbrPlanUpdtInVODTO inDto) throws Exception;

	/**
     * <p>메소드명      : updateLoan</p>
     * <p>설명          : 대출기본원장을 변경한다.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int updateLoan(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : </p>
     * <p>설명          : 결제일변경이력 수정쿼리.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int setlDdChngHistUpdt(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : setlDdChngUpdt1</p>
     * <p>설명          : 결제일변경 수정쿼리.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int setlDdChngUpdt1(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : setlDdChngUpdt2</p>
     * <p>설명          : 결제일변경 수정쿼리2.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : 응답코드/응답메시지</p>
     * <p>예외처리      : Exception</p>
     */
    public int setlDdChngUpdt2(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanPiamtUpdt1</p>
     * <p>설명          : 결제일변경 후 대출원리금 변경.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : int</p>
     * <p>예외처리      : Exception</p>
     */
    public int loanPiamtUpdt1(SetlDdChngDTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanBaseUpdt1</p>
     * <p>설명          : 결제일변경 후 대출기본 변경.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : int</p>
     * <p>예외처리      : Exception</p>
     */
    public int loanBaseUpdt1(SetlDdChngDTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanPiamtCrte1</p>
     * <p>설명          : 대출원리금 저장.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : int</p>
     * <p>예외처리      : Exception</p>
     */
    public int loanPiamtCrte1(LoanPiamtDTO inDto) throws Exception;

    /**
     * <p>메소드명      : trtFeeRamtRead</p>
     * <p>설명          : 취급수수료 잔액 조회.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : RmbrPlanUpdtOutVODTO</p>
     * <p>예외처리      : Exception</p>
     */
    public RmbrPlanUpdtOutVODTO trtFeeRamtRead(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : rmbrPlanDescDel1</p>
     * <p>설명          : 대출번호, 대출순번,회차를 조건으로 상환계획내역 삭제</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public LoanBaseOutVODTO rmbrPlanDescDel1(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : rmbrPlanDescDel2</p>
     * <p>설명          : 대출번호, 대출순번, 우선순위를 조건으로 상환계획내역 삭제</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public LoanBaseOutVODTO rmbrPlanDescDel2(RmbrPlanUpdtInVODTO inDto) throws Exception;


    /**
     * <p>메소드명      : rmbrPlanDescCrte</p>
     * <p>설명          : 상환계획내역을 저장하기 위한 쿼리</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : </p>
     * <p>예외처리      : Exception</p>
     */
    public RmbrPlanUpdtOutVODTO rmbrPlanDescCrte(RmbrPlanUpdtInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : cnclTrSnumRead</p>
     * <p>설명          : 취소 거래 일련번호 검색</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : MidPartRmbrOutVODTO</p>
     * <p>예외처리      : Exception</p>
     */
    public List<MidPartRmbrOutVODTO> cnclTrSnumRead(MidPartRmbrInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : loanPiamtRcvr</p>
     * <p>설명          : 중도상환 취소시 대출원리금 복구.</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : int</p>
     * <p>예외처리      : Exception</p>
     */
    public int loanPiamtRcvr(MidPartRmbrInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : rmbrPlanDescDel</p>
     * <p>설명          : 대출번호,대출순번을 조건으로 상환계획내역을 삭제하기 위한 쿼리</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : int</p>
     * <p>예외처리      : Exception</p>
     */
    public int rmbrPlanDescDel(MidPartRmbrInVODTO inDto) throws Exception;

    /**
     * <p>메소드명      : rmbrPlanDescDel</p>
     * <p>설명          : 상환계획이력을 조회하여 상환계획내역에 저장하기 위한 쿼리</p>
     * <p>메소드인수1   : List args</p>
     * <p>메소드인수2   : ITransaction tx 트랜잭션객체</p>
     * <p>메소드리턴값  : int</p>
     * <p>예외처리      : Exception</p>
     */
    public int rmbrPlanDescRcvr(MidPartRmbrInVODTO inDto) throws Exception;

}
