package hanalife.s.ln.ch.service;

import hanalife.s.ln.ch.vo.MidPartRmbrObj;
import hanalife.s.ln.ch.vo.MidPartRmbrOutVO;
import hanalife.s.ln.ch.vo.PsgIntCalcObj;
import hanalife.s.ln.ch.vo.RmbrPlanUpdtOutVO;
import hanalife.s.ln.ch.vo.SetlDdChngObj;
import hanalife.s.ln.lm.vo.LoanBaseObj;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RmbrPlanUpdtService.java Class
 * 클래스설명   : 상환계획변경
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70326 / HyunSik.You / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : updateLoan : 대출 원장 업데이트
 * </pre>
 */
public interface RmbrPlanUpdtService {

	/**
	 * <p>메소드명      : psgIntCalc</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 경과이자 계산</p>
	 * <p>메소드인수    : PsgIntCalcObj </p>
	 * <p>메소드리턴값  : PsgIntCalcObj</p>
	 * <p>예외처리      : Exception</p>
	 */
	public PsgIntCalcObj psgIntCalc(PsgIntCalcObj obj) throws Exception;

	/**
	 * <p>메소드명      : setlDdChng</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 결제일 변경</p>
	 * <p>메소드인수    : SetlDdChngObj </p>
	 * <p>메소드리턴값  : SetlDdChngObj</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SetlDdChngObj setlDdChng(SetlDdChngObj inVo) throws Exception;

	/**
	 * <p>메소드명      : midPartRmbrAfSetlDdChng - 중도부분상환 이후 납입일 변경사항 반영</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상환 이후 납입일 변경사항 반영</p>
	 * <p>메소드인수    : MidPartRmbrObj obj, int div </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public RmbrPlanUpdtOutVO midPartRmbrAfSetlDdChng(MidPartRmbrObj obj, int div) throws Exception;

	/**
	 * <p>메소드명      : rmbrPlanTrSnumUpdt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : MAX 거래일련번호 + 1 수정</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public RmbrPlanUpdtOutVO rmbrPlanTrSnumUpdt(String loanNo, String loanSeq, String empNo) throws Exception;

	/**
	 * <p>메소드명      : loanBaseRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출기본 조회</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, String userEmpNo </p>
	 * <p>메소드리턴값  : LoanBaseOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public LoanBaseObj loanBaseRead(String loanNo, String loanSeq, String userEmpNo) throws Exception;

	/**
	 * <p>메소드명      : updateLoan - 대출기본변경</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출기본변경</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, String userEmpNo </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public RmbrPlanUpdtOutVO updateLoan(String loanNo, String loanSeq, String userEmpNo) throws Exception;

	/**
	 * <p>메소드명      : midPartRmbr</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상환</p>
	 * <p>메소드인수    : MidPartRmbrObj obj, char crteFg </p>
	 * <p>메소드리턴값  : LoanBaseObj</p>
	 * <p>예외처리      : Exception</p>
	 */
	public LoanBaseObj midPartRmbr(MidPartRmbrObj obj, char crteFg) throws Exception;

	/**
	 * <p>메소드명      : loanPiamtCrte</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출원리금 저장</p>
	 * <p>메소드인수    : LoanBaseObj </p>
	 * <p>메소드리턴값  : LoanBaseObj</p>
	 * <p>예외처리      : Exception</p>
	 */
	public LoanBaseObj loanPiamtCrte(LoanBaseObj obj) throws Exception;

	/**
	 * <p>메소드명      : midPartRmbrCncl</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상환 취소</p>
	 * <p>메소드인수    : MidPartRmbrInVO </p>
	 * <p>메소드리턴값  : MidPartRmbrOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public MidPartRmbrOutVO midPartRmbrCncl(MidPartRmbrObj obj) throws Exception;

}
