package hanalife.s.ln.ch.service.impl;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.s.ln.ch.mapper.RmbrPlanUpdtMapper;
import hanalife.s.ln.ch.mapper.dto.LoanBaseDTO;
import hanalife.s.ln.ch.mapper.dto.MidPartRmbrInVODTO;
import hanalife.s.ln.ch.mapper.dto.MidPartRmbrOutVODTO;
import hanalife.s.ln.ch.mapper.dto.PsgIntCalcDTO;
import hanalife.s.ln.ch.mapper.dto.RmbrPlanUpdtInVODTO;
import hanalife.s.ln.ch.mapper.dto.RmbrPlanUpdtOutVODTO;
import hanalife.s.ln.ch.mapper.dto.SetlDdChngDTO;
import hanalife.s.ln.ch.service.RmbrPlanUpdtService;
import hanalife.s.ln.ch.vo.MidPartRmbrObj;
import hanalife.s.ln.ch.vo.MidPartRmbrOutVO;
import hanalife.s.ln.ch.vo.PsgIntCalcObj;
import hanalife.s.ln.ch.vo.RmbrPlanUpdtOutVO;
import hanalife.s.ln.ch.vo.SetlDdChngObj;
import hanalife.s.ln.lm.mapper.dto.LoanPiamtDTO;
import hanalife.s.ln.lm.mapper.dto.LoanPiamtOutVODTO;
import hanalife.s.ln.lm.vo.LoanBaseObj;
import hanalife.s.ln.lm.vo.LoanBaseOutVO;
import hanalife.s.ln.lm.vo.LoanPiamtObj;
import hanalife.s.ln.lm.vo.RmbrPlanObj;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RmbrPlanUpdtServiceImpl.java Class
 * 클래스설명   : 상환계획변경 Service Implements
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70326 / HyunSik.You / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70326 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : updateLoan : 대출기본변경
 * </pre>
 */
@Resource
@Service("RmbrPlanUpdtService")
public class RmbrPlanUpdtServiceImpl implements RmbrPlanUpdtService {

	private static final Logger LOGGER = LoggerFactory.getLogger(RmbrPlanUpdtServiceImpl.class);

	public RmbrPlanUpdtServiceImpl() {
	}

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private MsgEnum msgEnum;

	@Autowired
	private RmbrPlanUpdtMapper rmbrPlanUpdtMapper;

	/**
	 * <p>메소드명      : psgIntCalc</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 경과이자 계산</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@SuppressWarnings("unchecked")
	@Override
	public PsgIntCalcObj psgIntCalc(PsgIntCalcObj obj) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		obj.rsltCd   = msgEnum.SUCCESS.getErrorCd();	/** 응답코드 */
		obj.rsltCntn = msgEnum.SUCCESS.getErrorCn();	/** 응답메시지 */

        try {

			PsgIntCalcDTO psgIntCalcDTO = new PsgIntCalcDTO();

			psgIntCalcDTO.loanNo = obj.loanNo;      /** 대출번호 */
			psgIntCalcDTO.loanSeq = obj.loanSeq;    /** 대출순번 */
			psgIntCalcDTO.chngTims = obj.chngTims;  /** 변경회차 */
        	// 경과이자계산
    		List<PsgIntCalcDTO> resultDTO = rmbrPlanUpdtMapper.psgIntCalcQry(psgIntCalcDTO);
    		int index = 0;
    		if(resultDTO != null) {
	    		for(PsgIntCalcDTO rs : resultDTO) {

	    			long timsBfPamtRamt = rs.timsBfPamtRamt;  	        /** 회차전원금잔액 */
	    			String dueDt = rs.dueDt;   /** 변경전 납입일자 */
	    			double loanIntRt = rs.loanIntRt;			 	    /** 대출이자율 */
	    			int psgDdCnt = 0;

	    			long[] psgIntArr = new long[2];
	    			psgIntArr[0] = rs.frstRank;						    /** 우선순위 */

	    			String chngBfDueDt = dueDt;							/** 변경전 납입일자 */
					String chngAfDueDt = obj.chngDueDt;				    /** 변경후 납입일자 */

					// 취소의 경우 역 계산
					if ("1".equals(obj.cnclFg)) {
						chngBfDueDt = obj.chngDueDt;
						chngAfDueDt = dueDt;
					}

					if(DateUtil.daysBetween(chngBfDueDt, chngAfDueDt) > 0) {

						psgDdCnt = DateUtil.daysBetween(chngBfDueDt, chngAfDueDt);
						psgIntArr[1] = (long) (timsBfPamtRamt * psgDdCnt * loanIntRt / 36500);

					} else {

						psgDdCnt = DateUtil.daysBetween(chngAfDueDt, chngBfDueDt);
						psgIntArr[1] = (long) (timsBfPamtRamt * psgDdCnt * loanIntRt / 36500 * -1);

						if (loanIntRt < 0) {
							psgIntArr[1] = 0;
							loanIntRt = 0;
						}
					}

					// 적용이자 및 경과일수
					if (loanIntRt >= obj.aplyIntRt) {
						obj.aplyIntRt = loanIntRt;
						obj.psgDdCnt  = psgDdCnt;
					}
					// 취소의 경우 이전 경과이자 * -1
					if ("1".equals(obj.cnclFg)) {
						psgIntArr[1] = psgIntArr[1] * -1;
					}
					obj.psgInt += psgIntArr[1];
					obj.psgIntList.add(psgIntArr);
					index++;
	    		}
    		}

    		if (obj.psgInt < 0) {
				obj.psgDdCnt = obj.psgDdCnt * -1;
			}

			if (index == 0) {
				LOGGER.debug("변경회차의 상환계획 정보를 찾을 수 없습니다.");
				obj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
				obj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
			}

        }catch (Exception e) {
        	LOGGER.debug("(상환계획변경)경과이자계산중 오류!");
        	obj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
			obj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
		}
        return obj;
	}


	/**
	 * <p>메소드명      : setlDdChng</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 결제일 변경</p>
	 * <p>메소드인수    : SetlDdChngObj </p>
	 * <p>메소드리턴값  : SetlDdChngObj</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SetlDdChngObj setlDdChng(SetlDdChngObj obj) throws Exception {

		LOGGER.debug("상환계획 변경. 결제일 변경 시작");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
        obj.rsltCd   = msgEnum.SUCCESS.getErrorCd();
		obj.rsltCntn = msgEnum.SUCCESS.getErrorCn();

		try {

			SetlDdChngDTO setlDdDto = new SetlDdChngDTO();

			setlDdDto.loanNo  = obj.loanNo;	  /** 대출번호 */
			setlDdDto.loanSeq = obj.loanSeq;  /** 대출순번 */
			setlDdDto.empNo   = obj.empNo;    /** 사원번호 */

			// 원리금 거래일련번호 증가
			rmbrPlanUpdtMapper.loanPiamtCrte2(setlDdDto);

			// 상환계획 거래일련번호 증가
			this.rmbrPlanTrSnumUpdt(obj.loanNo, obj.loanSeq, obj.empNo);

			// 경과이자계산 호출
			PsgIntCalcObj psgIntCalcObj = new PsgIntCalcObj();
			psgIntCalcObj.loanNo = obj.loanNo;					 /** 대출번호 */
			psgIntCalcObj.loanSeq = obj.loanSeq;				 /** 대출순번 */
			psgIntCalcObj.chngTims = obj.chngTims;				 /** 변경회차 */
			psgIntCalcObj.chngDueDt = obj.chngDueDt;			 /** 변경납입일자 */
			psgIntCalcObj.cnclFg = obj.cnclFg;					 /** 대출번호 */

			psgIntCalcObj = psgIntCalc(psgIntCalcObj);
			obj.psgInt = psgIntCalcObj.psgInt;                   /** 경과이자 */
			obj.aplyIntRt = psgIntCalcObj.aplyIntRt;             /** 적용이자율 */
			obj.psgDdCnt = psgIntCalcObj.psgDdCnt;               /** 경과일수 */

			// 상환계획 내역 조회
			setlDdDto.loanNo   = obj.loanNo;                     /** 대출번호 */
			setlDdDto.loanSeq  = obj.loanSeq;                    /** 대출순번 */
			setlDdDto.chngTims = obj.chngTims;                   /** 변경회차 */

			List<SetlDdChngDTO> resultDTO = rmbrPlanUpdtMapper.setlDdChngRead1(setlDdDto);

			if(resultDTO != null) {
				for (SetlDdChngDTO rs : resultDTO) {

					RmbrPlanUpdtInVODTO rmbrPlanDto1 = new RmbrPlanUpdtInVODTO();
					RmbrPlanUpdtInVODTO rmbrPlanDto2 = new RmbrPlanUpdtInVODTO();

					try {
						// 납입일자
						String dueDt = DateUtil.addMonth(obj.chngDueDt, rs.tims - obj.chngTims);

						// 이자시작일자
						String intStrtDt = null;
						if (rs.tims == obj.chngTims) {
							intStrtDt = rs.intStrtDt; // 이자시작일자
						} else {
							intStrtDt = DateUtil.addMonth(obj.chngDueDt, rs.tims - obj.chngTims - 1); // 이자시작일자
						}

						rmbrPlanDto1.setDueDt(dueDt);               /** 납입일자 */
						rmbrPlanDto1.setIntStrtDt(intStrtDt);       /** 이자시작일자 */
						rmbrPlanDto1.setLoanNo(obj.loanNo);	        /** 대출번호 */
			    		rmbrPlanDto1.setLoanSeq(obj.loanSeq);	    /** 대출순번 */
			    		rmbrPlanDto1.setEmpNo(obj.empNo);      	    /** 직원번호 */
						rmbrPlanDto1.setTims(rs.tims);	            /** 회차 */
			    		rmbrPlanDto1.setTrSnum(rs.trSnum);	        /** 거래일련번호 */
			    		rmbrPlanDto1.setFsrtRank(rs.frstRank);	    /** 우선순위 */

			    		// 결제일 변경 업데이트
			    		LOGGER.debug("결제일 변경 업데이트 시작");
						rmbrPlanUpdtMapper.setlDdChngUpdt1(rmbrPlanDto1);

					}catch (Exception e) {
						LOGGER.error("[상환계획변경] : 결제일 변경 중 오류  " + e.getMessage());
						obj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
						obj.rsltCntn = e.getMessage();
					}

					// 납입회차 == 변경회차
					if(rs.tims == obj.chngTims) {

						// 우선순위별 경과이자
						long psgInt = 0;
						int size = psgIntCalcObj.psgIntList.size();
						LOGGER.debug("사이즈 : "+size);

						for( int k = 0; k < size; k++) {
							// 0.경과이자,우선순위
							long[] psgIntArr = (long[]) psgIntCalcObj.psgIntList.get(k);

							if (rs.frstRank == psgIntArr[0]) {
								psgInt = psgIntArr[1];
							}
						}

						try {
							// 결제일변경 수정쿼리2
							rmbrPlanDto2.setPsgInt(psgInt);             /** 경과이자 */
							rmbrPlanDto2.setLoanNo(obj.loanNo);	        /** 대출번호 */
				    		rmbrPlanDto2.setLoanSeq(obj.loanSeq);	    /** 대출순번 */
				    		rmbrPlanDto2.setEmpNo(obj.empNo);     	    /** 직원번호 */
				    		rmbrPlanDto2.setTims(rs.tims);	            /** 회차 */
				    		rmbrPlanDto2.setTrSnum(rs.trSnum);	        /** 거래일련번호 */
				    		rmbrPlanDto2.setFsrtRank(rs.frstRank);	    /** 우선순위 */

							rmbrPlanUpdtMapper.setlDdChngUpdt2(rmbrPlanDto2);

						}catch (Exception e) {
							LOGGER.error("[상환계획변경] : 결제일 변경 중 오류  " + e.getMessage());
							obj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
							obj.rsltCntn = e.getMessage();
						}
					}
				}
			}

			// 상환계획이력 저장
			this.rmbrPlanHistCrte(obj.loanNo, obj.loanSeq);
			// 대출원리금 갱신
			this.setlDdChngLoanPiamtUpdt(obj);
			// 대출기본 갱신
			this.setlDdChngLoanBaseUpdt(obj);
			// 대출기본 조회
			LoanBaseObj loanBaseObj = this.loanBaseRead(obj.loanNo, obj.loanSeq, obj.empNo);

			if (loanBaseObj.prdtLrgeClasCd.equals("3") || loanBaseObj.prdtLrgeClasCd.equals("4")) {
				// 일단 주석
				//LeasRmbrPlanCrteCC.midSetDdChng(inVo);
				//LeasRmbrSchdRcknDdChngCC.setLeasEprtDt(inVo);
			}
		}catch (Exception e) {
			LOGGER.error("[상환계획변경] : 결제일 변경 중 오류  " + e.getMessage());
			obj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
			obj.rsltCntn = e.getMessage();
		}
		return obj;
	}

	/**
	 * <p>메소드명      : loanPiamtCrte</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출원리금 저장</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : void</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public LoanBaseObj loanPiamtCrte(LoanBaseObj obj) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseObj resultVo = new LoanBaseObj();

        resultVo.rsltCd   = msgEnum.SUCCESS.getErrorCd();
        resultVo.rsltCntn = msgEnum.SUCCESS.getErrorCn();

        try{
        	//LoanBaseInVODTO loanBaseDto = new LoanBaseInVODTO();
		   	LoanPiamtDTO loanPiamtDto = new LoanPiamtDTO();

        	List piamtList = obj.piamtObjList;
        	int size = piamtList.size();

        	if(size > 0) {
        		for(int i = 0; i < size; i++) {

        			LoanPiamtObj piamtObj = (LoanPiamtObj) piamtList.get(i);

        			loanPiamtDto.loanNo      = piamtObj.loanNo;
        			loanPiamtDto.loanSeq     = piamtObj.loanSeq;
        			loanPiamtDto.trSnum      = piamtObj.trSnum;
        			loanPiamtDto.frstRank    = piamtObj.frstRank;
        			loanPiamtDto.strtTims    = piamtObj.strtTims;
        			loanPiamtDto.strtDt      = piamtObj.strtDt;
        			loanPiamtDto.endDt       = piamtObj.endDt;
        			loanPiamtDto.rmbrFrmlCd  = piamtObj.rmbrFrmlCd;
        			loanPiamtDto.crteDivCd   = piamtObj.crteDivCd;
        			loanPiamtDto.dueCyclCd   = piamtObj.dueCyclCd;
        			loanPiamtDto.dueStrtTims = piamtObj.dueStrtTims;
        			loanPiamtDto.loanPamt    = piamtObj.loanPamt;
        			loanPiamtDto.intRt       = piamtObj.intRt;
        			loanPiamtDto.baseFg      = piamtObj.baseFg;
        			loanPiamtDto.cnclTrSnum  = piamtObj.cnclTrSnum;
        			loanPiamtDto.lendEmpNo   = obj.empNo;	//추후 empNo로 변경
        			loanPiamtDto.trtFee      = piamtObj.trtFee;

        			rmbrPlanUpdtMapper.loanPiamtCrte1(loanPiamtDto);
        		}
        	}
        }catch (Exception e) {
        	LOGGER.debug("[상환계획변경] : [대출원리금] 저장중 오류");
        	resultVo.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
            resultVo.rsltCntn = e.getMessage();
		}
        return resultVo;
	}

	/**
	 * <p>메소드명      : rmbrPlanTrSnumUpdt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : MAX 거래일련번호 + 1 수정</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, String empNo </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RmbrPlanUpdtOutVO rmbrPlanTrSnumUpdt(String loanNo, String loanSeq, String empNo) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		RmbrPlanUpdtOutVO resultVo = new RmbrPlanUpdtOutVO();

        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        try{
        	RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	/** 대출순번 */
    		rmbrPlanDto.setEmpNo(empNo);	    /** 직원번호 */

        	rmbrPlanUpdtMapper.rmbrPlanTrSeqUdpt1(rmbrPlanDto);

        }catch (Exception e) {
        	LOGGER.debug("[상환계획변경] : 거래일련번호 수정중 오류!");
        	resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
		}
		return resultVo;
	}

	/**
	 * <p>메소드명      : loanPiamtRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출원리금 조회</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : List</p>
	 * <p>예외처리      : Exception</p>
	 */

	private List loanPiamtRead(String loanNo, String loanSeq) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		List piamtList = new ArrayList();

        try {

        	RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	/** 대출순번 */

    		List<LoanPiamtOutVODTO> resultDTO = rmbrPlanUpdtMapper.loanPiamtRead1(rmbrPlanDto);

    		if(resultDTO != null) {
    			for (LoanPiamtOutVODTO rs : resultDTO) {
    				LoanPiamtObj obj = new LoanPiamtObj();

    				obj.loanNo      = rs.getLoanNo();
    				obj.loanSeq     = rs.getLoanSeq();
    				obj.trSnum      = rs.getTrSnum();
    				obj.frstRank    = rs.getFrstRank();
    				obj.strtTims    = rs.getStrtTims();
    				obj.endTims     = rs.getEndTims();
    				obj.strtDt      = rs.getStrtDt();
    				obj.endDt       = rs.getEndDt();
    				obj.rmbrFrmlCd  = rs.getRmbrFrmlCd();
    				obj.crteDivCd   = rs.getCrteDivCd();
    				obj.dueCyclCd   = rs.getDueCyclCd();
    				obj.dueStrtTims = rs.getDueStrtTims();
    				obj.loanPamt    = rs.getLoanPamt();
    				obj.intRt       = rs.getIntRt();
    				obj.baseFg      = rs.getBaseFg();
    				obj.cnclTrSnum  = rs.getCnclTrSnum();
    				// 원리금의 기간
    				obj.term = obj.endTims - obj.strtTims + 1;
    				// 납입주기
    				// 2018-08-01 두비스, 두비스
    				// 고객의요청으로 (박병욱) 납입주기코드 A를 12개월로 추가함.
    				if ("A".equals(obj.dueCyclCd.trim())) {
    					obj.dueCycl = Integer.parseInt("12");
    				} else {
    					obj.dueCycl = "".equals(obj.dueCyclCd.trim()) ? 1 : Integer.parseInt(obj.dueCyclCd);
    				}
    				piamtList.add(obj);
    			}
    		}
        }catch (Exception e) {
        	LOGGER.debug("[상환계획변경] : [대출원리금] 조회 오류! ");
		}
		return piamtList;
	}

	/**
	 * <p>메소드명      : dueDtRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 납입일자 조회</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */

	private String dueDtRead(String loanNo, String loanSeq, int tims) throws Exception {

		String dueDt = null;

		try {

			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	/** 대출순번 */
    		rmbrPlanDto.setTims(tims);	        /** 회차 */

    		dueDt = rmbrPlanUpdtMapper.dueDtRead(rmbrPlanDto);

		}catch (Exception e) {
			LOGGER.debug("[상환계획변경] : [납입일자] 조회 오류! ");
		}
		return dueDt;
	}

	/**
	 * <p>메소드명      : intStrtDtRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 이자시작일자 조회</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */

	private String intStrtDtRead(String loanNo, String loanSeq, int tims) throws Exception {

		String intStrtDt = null;

		try {

			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	/** 대출순번 */
    		rmbrPlanDto.setTims(tims);	        /** 회차 */

    		intStrtDt = rmbrPlanUpdtMapper.intStrtDtRead(rmbrPlanDto);

		}catch (Exception e) {
			LOGGER.debug("[상환계획변경] : [이자시작일자] 조회 오류! ");
		}

		return intStrtDt;
	}

	/**
	 * <p>메소드명      : intStrtDtRead2</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 이자시작일자 조회</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, int frstRank, int tims </p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */

	private String intStrtDtRead2(String loanNo, String loanSeq, int frstRank, int tims) throws Exception {

		String intStrtDt = null;

		try {

			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	     /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	 /** 대출순번 */
    		rmbrPlanDto.setTims(tims);	         /** 회차 */
    		rmbrPlanDto.setFsrtRank(frstRank);	 /** 우선순위 */

    		intStrtDt = rmbrPlanUpdtMapper.intStrtDtRead2(rmbrPlanDto);

		}catch (Exception e) {
			LOGGER.debug("[상환계획변경] : [이자시작일자] 조회 오류! ");
		}

		return intStrtDt;
	}


	/**
	 * <p>메소드명      : loanBaseRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출기본조회 - 상환계획생성.대출기본 객체 조회</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, String userEmpNo </p>
	 * <p>메소드리턴값  : LoanBaseObj</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public LoanBaseObj loanBaseRead(String loanNo, String loanSeq, String userEmpNo) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseObj result = new LoanBaseObj();

        result.rsltCd   = msgEnum.SUCCESS.getErrorCd();
        result.rsltCntn = msgEnum.SUCCESS.getErrorCn();
        LoanBaseObj loanObj = null;
        loanObj = new LoanBaseObj();
        try {

        	LoanBaseDTO loanBaseDto = new LoanBaseDTO();

        	loanBaseDto.loanNo  = loanNo;	    /** 대출번호 */
        	loanBaseDto.loanSeq = loanSeq;	    /** 대출순번 */

    		List<LoanBaseDTO> resultDTO = rmbrPlanUpdtMapper.loanBaseRead1(loanBaseDto);

    		if(resultDTO != null) {

	    		for(LoanBaseDTO rs : resultDTO) {

	    			loanObj.loanNo = loanNo;                                     /** 대출번호 */
					loanObj.loanSeq = loanSeq;                                   /** 대출순번 */
					loanObj.prdtCd = rs.prdtCd;                                  /** 상품코드 */
					loanObj.prdtLrgeClasCd = rs.prdtLrgeClasCd;                  /** 상품대분류 */
					loanObj.prdtMidClasCd = rs.prdtMidClasCd;                    /** 상품중분류 */
					loanObj.loanPamt = rs.loanPamtRamt;                          /** 대출원금 */
					loanObj.loanTerm = rs.loanTerm;                              /** 대출기간 */
					loanObj.setlDd = rs.setlDd;                                  /** 기산일 */
					loanObj.fcntDueDt = rs.fcntDueDt;   /** 초회납입일자 */
					loanObj.fcntMopaCalcFg = rs.fcntMopaCalcFg;                  /** 초회월할여부  */
					loanObj.loanDt = rs.loanDt;         /** 대출일자 = 이자계산시작일자 */
					loanObj.defrIntDistFg = rs.defrIntDistFg;                    /** 거치이자배분 여부 */
					loanObj.trtFeeIstpFg = rs.trtFeeIstpFg;                      /** 취급수수료분납여부 */
					loanObj.trtFeeIstpAmt = rs.trtFeeIstpAmt;                    /** 취급수수료분납금액 */
					loanObj.empNo = userEmpNo;                                   /** 사원번호 */
	    		}
    		}
        }catch (Exception e) {
        	LOGGER.debug("[상환계획변경] : 대출기본 조회중 오류발생");
        	loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
        	loanObj.rsltCntn = e.getMessage();
		}
        return loanObj;
	}

	/**
	 * <p>메소드명      : midPartRmbrAfSetlDdChng</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상환 이후 납입일변경사항 반영</p>
	 * <p>메소드인수    : MidPartRmbrObj obj, int div </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RmbrPlanUpdtOutVO midPartRmbrAfSetlDdChng(MidPartRmbrObj obj, int div) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		RmbrPlanUpdtOutVO resultVo = new RmbrPlanUpdtOutVO();

        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        try {
        	RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setDiv(div);	    								/** 1.중도상환, 2,중도상환취소 */
    		rmbrPlanDto.setLoanNo(obj.loanNo);	    						/** 대출번호 */
    		rmbrPlanDto.setLoanSeq(obj.loanSeq);	    					/** 대출순번 */
    		if(div == 1) {
    			rmbrPlanDto.setMidPartRmbrTims(obj.midPartRmbrTims);		/** 중도부분상환회차 */
    		}else {
    			rmbrPlanDto.setCnclTrSnum(obj.cnclTrSnum);	    			/** 취소시 거래일련번호 */
    		}

    		// 납입일 변경이력 조회
    		List<RmbrPlanUpdtOutVODTO> resultDTO = rmbrPlanUpdtMapper.setlDdChngHistRead(rmbrPlanDto);

    		if(resultDTO != null) {
    			for (RmbrPlanUpdtOutVODTO rs : resultDTO) {

    				SetlDdChngObj setlDdChngObj = new SetlDdChngObj();

    				setlDdChngObj.loanNo = obj.loanNo;
					setlDdChngObj.loanSeq = obj.loanSeq;
					setlDdChngObj.chngTims = rs.getChngTims();
					setlDdChngObj.chngDueDt = rs.getChngAfDueDt();
					setlDdChngObj.empNo = obj.empNo;
					//long oldPsgInt = rs.getLong(3);
					int setlDdChngSnum = rs.getSnum();

					// 납입일 변경 호출
					setlDdChng(setlDdChngObj);
					long newPsgInt = setlDdChngObj.psgInt;

    				try {

    					rmbrPlanDto.setPsgInt(newPsgInt);	/** 경과이자 */
    					rmbrPlanDto.setSnum(setlDdChngSnum);
    					rmbrPlanDto.setLoanNo(setlDdChngObj.loanNo);
    					rmbrPlanDto.setLoanSeq(setlDdChngObj.loanSeq);
    					rmbrPlanDto.setEmpNo(StringUtil.trimToStr(setlDdChngObj.empNo));

    					rmbrPlanUpdtMapper.setlDdChngHistUpdt(rmbrPlanDto);

					} catch (Exception e) {
			        	LOGGER.debug("[상환계획변경] : [결제일변경] 처리 중 오류!");
			        	resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			            resultVo.setRsltCntn(e.getMessage());
					}
    			}
    		}

        }catch (Exception e) {
        	LOGGER.debug("[상환계획변경] : [결제일변경] 처리 중 오류!");
        	resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
		}
        return resultVo;
	}

	/**
	 * <p>메소드명      : updateLoan - 대출기본변경</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출기본 업데이트</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, String userEmpNo </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public RmbrPlanUpdtOutVO updateLoan(String loanNo, String loanSeq, String userEmpNo) throws Exception {

		long loanIntSum = 0;
		int totTims    = 0;
		String eprtDt  = null;

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		RmbrPlanUpdtOutVO resultVo = new RmbrPlanUpdtOutVO();

        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        try {
        	RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	/** 대출순번 */
    		rmbrPlanDto.setEmpNo(userEmpNo);	/** 직원번호 */

            List<RmbrPlanUpdtOutVODTO> resultDTO = rmbrPlanUpdtMapper.searchMax(rmbrPlanDto);

            if(resultDTO.isEmpty() == false) {
            	loanIntSum = resultDTO.get(0).getLoanIntSum();
            	totTims    = resultDTO.get(0).getTotTims();
                eprtDt     = resultDTO.get(0).getEprtDt();

                rmbrPlanDto.setLoanIntSum(loanIntSum);
                rmbrPlanDto.setTotTims(totTims);
                rmbrPlanDto.setEprtDt(eprtDt);
            }else {
            	LOGGER.debug("[상환계획변경] : 상환계획내역 조회 데이터 없음");
                resultVo.setRsltCd(msgEnum.NOT_FOUND.getErrorCd());
                resultVo.setRsltCntn(msgEnum.NOT_FOUND.getErrorCn());
                return resultVo;
            }

            LOGGER.info("■ [ST_LOAN_BASE] 대출원장 UPDATE");
            if (rmbrPlanUpdtMapper.updateLoan(rmbrPlanDto) != 1) {
                LOGGER.info("[상환계획변경] : 대출기본 수정 중 오류");
                resultVo.setRsltCd("9999");
                resultVo.setRsltCntn("대출기본 수정 중 오류");
                return resultVo;
            }

        }catch(Exception e) {
        	LOGGER.error("[상환계획변경] : 대출기본 수정 중 오류 : " + e.getMessage());
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
        }
		return resultVo;
	}

	/**
	 * <p>메소드명      : rmbrPlanHistCrte</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 상환계획이력 등록</p>
	 * <p>메소드인수    : String loanNo, String loanSeq </p>
	 * <p>메소드리턴값  : void</p>
	 * <p>예외처리      : Exception</p>
	 */
	public RmbrPlanUpdtOutVO rmbrPlanHistCrte(String loanNo, String loanSeq) throws Exception {

		RmbrPlanUpdtOutVO result = new RmbrPlanUpdtOutVO();

		result.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        result.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {

			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);    /** 대출순번 */

    		rmbrPlanUpdtMapper.rmbrPlanHistCrte1(rmbrPlanDto);

		}catch (Exception e) {
			LOGGER.error("[상환계획변경] : [상환계획이력] 생성중 오류! " + e.getMessage());
            result.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            result.setRsltCntn(e.getMessage());
		}

		return result;
	}

	public void midPartRmbr(MidPartRmbrObj obj) throws Exception {
		midPartRmbr(obj, '1');
	}

	/**
	 * <p>메소드명      : updateLoan</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상화</p>
	 * <p>메소드인수    : MidPartRmbrInVO </p>
	 * <p>메소드리턴값  : LoanBaseOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public LoanBaseObj midPartRmbr(MidPartRmbrObj obj, char crteFg) throws Exception {

		LOGGER.debug("상환계획변경.중도부분상환 시작!");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseObj loanObj = new LoanBaseObj();

		loanObj.rsltCd   = msgEnum.SUCCESS.getErrorCd();
		loanObj.rsltCntn = msgEnum.SUCCESS.getErrorCn();

		try {

			// 대출기본객체 구성
			loanObj = makeLoanObjMidPartRmbr(obj);

			// 원리금구성 모듈 호출 - 생성구분입력(부분상환-2)
			// 주석 풀어야함
			//RmbrPlanCrteCC.makePiamt(loanObj);

			if (crteFg == '1') {
				// 대출원리금 저장
				loanPiamtCrte(loanObj);

				// 상환계획내역 거래일련번호 업데이트
				rmbrPlanTrSnumUpdt(loanObj.loanNo, loanObj.loanSeq, loanObj.empNo);

			}
			// 시작회차 이후의 회차별상환계획 생성
			List pniList = loanObj.piamtObjList;
			int size2 = pniList.size();
			for (int j = 0; j < size2; j++) {
				LoanPiamtObj piamtObj = (LoanPiamtObj) pniList.get(j);

				// 주석 풀어야함
				//List rmbrList = RmbrPlanCrteCC.makeRmbrPlanDesc(loanObj, piamtObj, 2, obj.midPartRmbrTims, con);
				List rmbrList = null;

				piamtObj.rmbrObjList = rmbrList;
			}

			if (crteFg == '1') {
				// 3.생성된 상환계획 저장
				rmbrPlanDescCrte(loanObj, obj.midPartRmbrTims);

				// 4.상환계획 이력 저장
				rmbrPlanHistCrte(obj.loanNo, obj.loanSeq);

				// 5.납입일변경이력 테이블 검색 중도부분상환 이후 회차의 결제일 변경을 반영
				midPartRmbrAfSetlDdChng(obj, 1);

				// 6.대출기본 변경
				updateLoan(obj.loanNo, obj.loanSeq, obj.empNo);
			}

			return loanObj;

		}catch (Exception e) {
			LOGGER.error("[중도상환 오류] :  ");
		}

		return loanObj;
	}

	/**
	 * <p>메소드명      : rmbrPlanDescCrte</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 상환계획내역 저장</p>
	 * <p>메소드인수    : LoanBaseInVO </p>
	 * <p>메소드리턴값  : void</p>
	 * <p>예외처리      : Exception</p>
	 */
	public LoanBaseOutVO rmbrPlanDescCrte(LoanBaseObj loanObj, int chngTims) throws Exception {
		LOGGER.debug("[rmbrPlanDescCrte] : 상환계획내역 저장");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseOutVO resultVo = new LoanBaseOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
        try {

			// 변경회차 이후 상환계획내역 삭제
			try {

				// 상환계획내역 삭제
				RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

	    		rmbrPlanDto.setLoanNo(loanObj.loanNo);	    /** 대출번호 */
	    		rmbrPlanDto.setLoanSeq(loanObj.loanSeq);	/** 대출순번 */
	    		rmbrPlanDto.setTims(chngTims);	            /** 회차 */

	    		rmbrPlanUpdtMapper.rmbrPlanDescDel1(rmbrPlanDto);

			} catch (Exception e) {

		        LOGGER.error("[상환계획변경] : 상환계획 저장중 오류! " + e.getMessage());
		        resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
		        resultVo.setRsltCntn(e.getMessage());
			}

			// 변경회차 이후 상환계획 저장
			int size = loanObj.piamtObjList.size();
			// 거치이자배분의 거치기간 중도상환시 변경회차 이전건 저장하기 위한 flag
			boolean passFlag = false;

			// 상환계획내역 등록
			for (int i = 0; i < size; i++) {
				LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(i);

				// 거치이자배분이고, 상환결제일자가 거치기간 내에 있으면 기존내역 삭제
				if ("1".equals(loanObj.defrIntDistFg.trim()) && "4".equals(piamtObj.rmbrFrmlCd.trim())
						&& loanObj.chngSetlDt != null && DateUtil.daysBetween(loanObj.chngSetlDt, piamtObj.endDt) > 0) {

					try {
						// 상환계획내역 삭제
						RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

			    		rmbrPlanDto.setLoanNo(loanObj.loanNo);	     /** 대출번호 */
			    		rmbrPlanDto.setLoanSeq(loanObj.loanSeq);	 /** 대출순번 */
			    		rmbrPlanDto.setFsrtRank(piamtObj.frstRank);  /** 회차 */

			    		rmbrPlanUpdtMapper.rmbrPlanDescDel2(rmbrPlanDto);

					}catch (Exception e) {
					     LOGGER.error("[상환계획변경] : 상환계획 저장중 오류! " + e.getMessage());
					     resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
					     resultVo.setRsltCntn(e.getMessage());
					}

					// 변경회차 이전건 저장
					passFlag = true;
				}

				int size2 = piamtObj.rmbrObjList.size();

				// 전체 이자합계
				double totIntSum = 0;

				for (int j = 0; j < size2; j++) {
					RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(j);
					if (rmbrObj.tims < chngTims && !passFlag) {
						continue;
					}
					// 전체이자합계를 먼저 구한다~
					totIntSum += rmbrObj.mmInt;
				}

				for (int k = 0; k < size2; k++) {
					RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);

					if (rmbrObj.tims < chngTims && !passFlag) {
						continue;
					}

					RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

		    		rmbrPlanDto.setLoanNo(rmbrObj.loanNo);	                    /** 대출번호 */
		    		rmbrPlanDto.setLoanSeq(rmbrObj.loanSeq);	                /** 대출순번 */
		    		rmbrPlanDto.setTrSnum(rmbrObj.trSnum);	                	/** 거래일련번호 */
		    		rmbrPlanDto.setFsrtRank(rmbrObj.frstRank);	                /** 우선순위 */
		    		rmbrPlanDto.setTims(rmbrObj.tims);	                /** 회차 */
		    		rmbrPlanDto.setDueDt(rmbrObj.dueDt);	            /** 납입일자 */
		    		rmbrPlanDto.setRmbrFrmlCd(StringUtil.trimToStr(rmbrObj.rmbrFrmlCd));	    /** 상환방식코드 */
		    		rmbrPlanDto.setCrteDivCd(StringUtil.trimToStr(piamtObj.crteDivCd));	    /** 생성구분코드 */
		    		rmbrPlanDto.setMmPamt(rmbrObj.mmPamt);	                            /** 월원금 */
		    		rmbrPlanDto.setMmInt(rmbrObj.mmInt);	                            /** 월이자 */
		    		rmbrPlanDto.setMmPiamt(rmbrObj.mmPiamt);	                        /** 월원리금 */

		    		rmbrPlanDto.setTimsBfPamtRamt(rmbrObj.timsBfPamtRamt);	/** 회차전잔여원금*/
		    		rmbrPlanDto.setTimsAfPamtRamt(rmbrObj.timsAfPamtRamt);	/** 회차후잔여원금*/

		    		// 회차전 잔여이자 = 전체이자합계 - 전회차이자
		    		rmbrPlanDto.setTotBfIntSum(totIntSum);
					// 회차후 잔여이자 = 전체이자합계 - 당회차이자합계
		    		totIntSum = totIntSum - rmbrObj.mmInt;
		    		rmbrPlanDto.setTotAfIntSum(totIntSum);
		    		rmbrPlanDto.setPdueFg(StringUtil.trimToStr(rmbrObj.pdueFg).equals("") ? "0" : StringUtil.trimToStr(rmbrObj.pdueFg)); // 선납여부
		    		rmbrPlanDto.setIntRt(rmbrObj.intRt);
		    		rmbrPlanDto.setIntCalcDay(rmbrObj.intCalcDay);
		    		rmbrPlanDto.setDueDt(rmbrObj.dueDt);
		    		rmbrPlanDto.setMmTrtFee(rmbrObj.mmTrtFee);
		    		rmbrPlanDto.setTimsBfTrtFeeRamt(rmbrObj.timsBfTrtFeeRamt);	        /** 회차전잔여원금 */
		    		rmbrPlanDto.setTimsAfTrtFeeRamt(rmbrObj.timsAfTrtFeeRamt);	        /** 회차후잔여원금 */
		    		rmbrPlanDto.setEmpNo(StringUtil.trimToStr(loanObj.empNo));     		/** 사번 */

		    		rmbrPlanUpdtMapper.rmbrPlanDescCrte(rmbrPlanDto);
				}

			}
        }catch (Exception e) {
        	LOGGER.debug("[상환계획변경] : 상환계획 저장중 오류!");
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : midPartRmbrCncl</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상환 취소</p>
	 * <p>메소드인수    : MidPartRmbrInVO </p>
	 * <p>메소드리턴값  : MidPartRmbrOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public MidPartRmbrOutVO midPartRmbrCncl(MidPartRmbrObj obj) throws Exception {

		LOGGER.debug("상환계획변경.midPartRmbrCncl 시작!");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		MidPartRmbrOutVO resultVo = new MidPartRmbrOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			// 1.중도부분상환 취소일련번호 조회
			obj.cnclTrSnum = cnclTrSnumRead(obj.loanNo, obj.loanSeq);

			if (obj.cnclTrSnum < 1) {
				LOGGER.debug("중도상환 취소 대상이 없습니다.");
				resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
		        resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
			}

			// 대출원리금 복구
			loanPiamtRcvr(obj.loanNo, obj.loanSeq, obj.cnclTrSnum, obj.empNo);
			// 상환계획내역 복구
			rmbrPlanDescRcvr(obj.loanNo, obj.loanSeq, obj.cnclTrSnum, obj.empNo);
			// 상환계획이력 저장
			rmbrPlanHistCrte(obj.loanNo, obj.loanSeq);

			// 취소된 중도상환 이후의 결제일변경을 반영
			midPartRmbrAfSetlDdChng(obj, 2);

			// 6.대출기본 변경
			updateLoan(obj.loanNo, obj.loanSeq, obj.empNo);

			// 7.수납기본에 TR_SNUM 반영을 위한 로직 추가
			List list = loanPiamtRead(obj.loanNo, obj.loanSeq);
			LoanPiamtObj piObj = (LoanPiamtObj) list.get(0);
			obj.trSnum = piObj.trSnum;

		} catch (Exception e) {
			LOGGER.debug("중도상환 취소 대상이 없습니다.");
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
	        resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : loanPiamtRcvr</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도상환 취소시 대출원리금 복구</p>
	 * <p>메소드인수    :  String loanNo, String loanSeq, int trSnum, String empNo</p>
	 * <p>메소드리턴값  : MidPartRmbrOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	private MidPartRmbrOutVO loanPiamtRcvr(String loanNo, String loanSeq, int trSnum, String empNo) throws Exception {

		LOGGER.debug("상환계획변경.loanPiamtRcvr 시작!");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		MidPartRmbrOutVO resultVo = new MidPartRmbrOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        try {
        	MidPartRmbrInVODTO midPartDto = new MidPartRmbrInVODTO();

			midPartDto.setLoanNo(loanNo);	    /** 대출번호 */
			midPartDto.setLoanSeq(loanSeq);		/** 대출순번 */
			midPartDto.setTrSnum(trSnum);	    /** 회차 */
			midPartDto.setEmpNo(empNo);	 	    /** 사번 */

			rmbrPlanUpdtMapper.loanPiamtRcvr(midPartDto);

		} catch (Exception e) {
			LOGGER.debug("[중도상환취소] : [대출원리금] 저장중 오류!");

			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
	        resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : rmbrPlanDescRcvr</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도상환 취소 시 상환계획내역 복구</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, int trSnum, String empNo </p>
	 * <p>메소드리턴값  : MidPartRmbrOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	private MidPartRmbrOutVO rmbrPlanDescRcvr(String loanNo, String loanSeq, int trSnum, String empNo) throws Exception {

		LOGGER.debug("상환계획변경.rmbrPlanDescRcvr 시작!");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		MidPartRmbrOutVO resultVo = new MidPartRmbrOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 상환계획내역 저장
        try {
        	MidPartRmbrInVODTO midPartDto = new MidPartRmbrInVODTO();

			midPartDto.setLoanNo(loanNo);	    /** 대출번호 */
			midPartDto.setLoanSeq(loanSeq);		/** 대출순번 */
			// 이전 상환계획내역 삭제
			rmbrPlanUpdtMapper.rmbrPlanDescDel(midPartDto);

			midPartDto.setTrSnum(trSnum);		/** 회차 */
			midPartDto.setEmpNo(empNo);			/** 사번 */
			// 이전 상환계획내역 삭제
			if(rmbrPlanUpdtMapper.rmbrPlanDescRcvr(midPartDto) != 1) {
				LOGGER.debug("[중도상환취소] : 복구할 상환계획이력을 찾을 수 없습니다.");

				resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
		        resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
			}

		} catch (Exception e) {
			LOGGER.debug("[중도상환취소] : [상환계획내역] 저장중 오류!");

			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
	        resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : midCondChng</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도조건변경</p>
	 * <p>메소드인수    : LoanBaseInVO </p>
	 * <p>메소드리턴값  : LoanBaseOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public LoanBaseOutVO midCondChng(String loanNo, String loanSeq, int chngTims, String chngDt, String userEmpNo) throws Exception {

		LOGGER.debug("상환계획변경.cnclTrSnumRead 조회 시작");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseOutVO resultVo = new LoanBaseOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        try {

        	// 1.변경된 원리금을 이용하여 상환계획 객체 생성(생성구분코드-3(중도조건변경))
        	LoanBaseObj loanObj = makeLoanObjMidCondChng(loanNo, loanSeq, chngTims, userEmpNo);

        	// 거치이자분납건 1회차 후의 중도조건변경 불가
        	if (loanObj.defrIntDistFg != null && loanObj.defrIntDistFg.equals("1") && chngTims > 1) {
        		LOGGER.debug("[거치이자할부분납] 상품은 중도변경이 불가능합니다.(1회차부터 변경시만 가능)!");
        		resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
                resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
        	}

        	// 변경회차의 이자 일할계산(초회부터 재생성인 경우는 제외)
        	if (!(chngTims == 1 && chngDt.equals(loanObj.loanDt))) {
        		chngTimsCalcInt(loanObj, chngTims, chngDt);
        	}

        	// 상환계획내역 거래일련번호 업데이트
        	rmbrPlanTrSnumUpdt(loanNo, loanSeq, userEmpNo);

        	// 3.생성된 상환계획 저장
        	rmbrPlanDescCrte(loanObj, chngTims);

        	// 4.상환계획 이력 저장
        	rmbrPlanHistCrte(loanNo, loanSeq);

        	// 5.대출기본 수정
        	updateLoan(loanNo, loanSeq, userEmpNo);

		} catch (Exception e) {
			LOGGER.debug("[중도변경]" + e.getMessage());
    		resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}
		return resultVo;
	}

	/**
	 * <p>메소드명      : chngTimsCalcInt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 변경회차의 이자 일할로 재계산~</p>
	 * <p>메소드인수    : LoanBaseObj loanObj, int chngTims, String chngDt </p>
	 * <p>메소드리턴값  : LoanBaseOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public LoanBaseOutVO chngTimsCalcInt(LoanBaseObj loanObj, int chngTims, String chngDt) throws Exception {

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseOutVO resultVo = new LoanBaseOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			int size1 = loanObj.piamtObjList.size();

			for (int i = 0; i < size1; i++) {
				LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(i);

				int size2 = piamtObj.rmbrObjList.size();

				// 거치이고 할부기간 이자분납인 경우는 이자계산 안하고 통과
				if ("4".equals(piamtObj.rmbrFrmlCd)) {
					if ("1".equals(loanObj.defrIntDistFg)) {
						continue;
					}
				}

				for (int j = 0; j < size2; j++) {
					RmbrPlanObj obj = (RmbrPlanObj) piamtObj.rmbrObjList.get(j);
					if (obj.tims == chngTims) {
						// 변경회차의 이자시작일자 조회
						String intStrtDt = intStrtDtRead(obj.loanNo, obj.loanSeq, chngTims);

						if (intStrtDt == null) {
							//throw new Exception("ESZ9999null^변경시작회차의 이자시작일을" + " 찾을 수 없습니다.");
						} else if (DateUtil.daysBetween(intStrtDt, chngDt) == 0) {
							continue;
						} else if (DateUtil.daysBetween(intStrtDt, chngDt) < 0
								|| DateUtil.daysBetween(chngDt, obj.dueDt) < 0) {
							//throw new Exception("ESZ9999null^변경시작일자는 변경시작회차의" + " 이자시작일과 납입일 사이여야 합니다.");
						}
						long oldInt = 0;
						long newInt = 0;

						// 변경전 원리금의 이자율 조회
						double oldIntRt = searchLoanIntRt(obj.loanNo, obj.loanSeq, obj.trSnum - 1, obj.frstRank);
						if (oldIntRt == piamtObj.intRt) {
							if (!intStrtDt.equals(obj.intCalcDay)) {

								// 주석 풀어야함
								/*
								 * obj.mmInt = RmbrPlanCrteCC.floorValue(piamtObj.loanPamt
								 * DateUtil.daysBetween(intStrtDt, obj.dueDt) * (oldIntRt * 0.01) / 365);
								 */
								obj.mmPiamt = obj.mmPamt + obj.mmInt;
								obj.intCalcDay = intStrtDt;
							}
							continue;
						}

						// 1.이자계산일수
						int frstDd = 0;
						// 변경전
						frstDd = DateUtil.daysBetween(intStrtDt, chngDt);
						// 주석 풀어야함
						//oldInt = RmbrPlanCrteCC.floorValue(piamtObj.loanPamt * frstDd * (oldIntRt * 0.01) / 365);

						// 변경후
						frstDd = DateUtil.daysBetween(chngDt, obj.dueDt);
						// 주석 풀어야함
						//newInt = RmbrPlanCrteCC.floorValue(piamtObj.loanPamt * frstDd * (piamtObj.intRt * 0.01) / 365);

						obj.mmInt = oldInt + newInt;
						obj.mmPiamt = obj.mmPamt + obj.mmInt;
						obj.intCalcDay = intStrtDt;
					}
				}
			}
		} catch (Exception e) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
	        resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}
		return resultVo;
	}

	/**
	 * <p>메소드명      : makeLoanObjMidCondChng</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 대출기본,대출원리금 조회하여 상환계획 생성(중도조건변경)</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, int chngTims, String userEmpNo </p>
	 * <p>메소드리턴값  : LoanBaseOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	private LoanBaseObj makeLoanObjMidCondChng(String loanNo, String loanSeq, int chngTims, String userEmpNo) throws Exception {

		LOGGER.debug("상환계획변경.cnclTrSnumRead 조회 시작");
		LoanBaseObj loanObj = new LoanBaseObj();
		try {
			// 대출기본 조회
			loanObj = loanBaseRead(loanNo, loanSeq, userEmpNo);

			if(loanObj == null) {
				LOGGER.debug("[상환계획변경] : [대출기본]에 데이터가 없습니다.");
	    		loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
	            loanObj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
			}

			// 중도변경인 경우 변경회차 이후의 취급수수료 잔액 조회
			if (chngTims > 1 && loanObj.trtFeeIstpFg != null && loanObj.trtFeeIstpFg.trim().equals("1")) {
				loanObj.trtFeeIstpAmt = trtFeeRamtRead(loanNo, loanSeq, chngTims);
			}

			// 대출원리금 조회
			List piamtList = loanPiamtRead(loanNo, loanSeq);
			if (piamtList == null || piamtList.size() == 0) {
				LOGGER.debug("[상환계획변경] : [대출원리금]에 데이터가 없습니다.");
	    		loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
	            loanObj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
			}
			loanObj.piamtObjList = piamtList;

			// 변경회차의 (납입일자 - 회차) 를 초회납입일자로 계산~
			String dueDt = dueDtRead(loanNo, loanSeq, chngTims);
			if (dueDt != null && chngTims > 1) {
				loanObj.fcntDueDt = DateUtil.addMonth(dueDt, (chngTims * -1) + 1);
				// loanObj.loanDt = DateUtil.addMonth(dueDt, -1);
			}

			// 원리금구성 모듈 호출  (주석 풀어야함)
			//RmbrPlanCrteCC.makePiamt(resultVo);

			// 시작회차 이후의 회차별상환계획 생성  (주석 풀어야함)
			//RmbrPlanCrteCC.makeRmbrPlan(resultVo);

		} catch (Exception e) {
    		LOGGER.debug("[상환계획변경] : [대출기본]에 데이터가 없습니다.");
    		loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
    		loanObj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
		}
		return loanObj;
	}
	/**
	 * <p>메소드명      : cnclTrSnumRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 취소일련번호 조회</p>
	 * <p>메소드인수    : String loanNo, String loanSeq </p>
	 * <p>메소드리턴값  : int</p>
	 * <p>예외처리      : Exception</p>
	 */
	private int cnclTrSnumRead(String loanNo, String loanSeq) throws Exception {

		LOGGER.debug("상환계획변경.cnclTrSnumRead 조회 시작");
		int canSeq = 0;
		try {

			MidPartRmbrInVODTO midPartDto = new MidPartRmbrInVODTO();

			midPartDto.setLoanNo(loanNo);	    /** 대출번호 */
			midPartDto.setLoanSeq(loanSeq);		/** 대출순번 */

			List<MidPartRmbrOutVODTO> midPartOutDTO = rmbrPlanUpdtMapper.cnclTrSnumRead(midPartDto);

			if(midPartOutDTO != null) {
    			for (MidPartRmbrOutVODTO sourceIO : midPartOutDTO) {
    				canSeq = sourceIO.getCnclTrSnum();		/** 변경회차 */
    			}
    		}

		} catch (Exception e) {
			LOGGER.debug("상환계획변경.cnclTrSnumRead 조회 시작");
		}

		return canSeq;
	}

	/**
	 * <p>메소드명      : makeLoanObjMidPartRmbr</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 중도부분상환에서 대출기본객체 구성</p>
	 * <p>메소드인수    : MidPartRmbrInVO </p>
	 * <p>메소드리턴값  : LoanBaseOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	private LoanBaseObj makeLoanObjMidPartRmbr(MidPartRmbrObj obj) throws Exception {
		LOGGER.debug("::: makeLoanObjMidPartRmbr :::!");

		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		LoanBaseObj loanObj = new LoanBaseObj();

		loanObj.rsltCd   = msgEnum.SUCCESS.getErrorCd();
		loanObj.rsltCntn = msgEnum.SUCCESS.getErrorCn();

        try {

        	// 대출기본 조회
    		loanObj = loanBaseRead(obj.loanNo, obj.loanSeq, obj.empNo);

        	if(loanObj == null) {
        		loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
        		loanObj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
        	}

    		loanObj.chngSetlDt = obj.midPartRmbrDt;
    		loanObj.chngIntStrtDt = obj.midPartRmbrDt; // 이자계산은 중도상환일자부터~
    		loanObj.loanPamt = obj.pamtRamt;           // 대출원금은 중도상환후 잔액~
    		loanObj.empNo = obj.empNo;

        	// 변경회차의 이자시작일자 조회
        	String intStrtDt = intStrtDtRead(obj.loanNo, obj.loanSeq, obj.midPartRmbrTims);

        	// 변경회차의 이자시작일자가 중도상환일자보다 크면 일자 변경
    		// 무이자거치기간의 경우 중도상환일자는 이자시작일자와 무관~
    		if (DateUtil.daysBetween(loanObj.chngSetlDt, intStrtDt) > 0) {
    			loanObj.chngIntStrtDt = intStrtDt;
    		}
    		// 변경회차의 (납입일자 - 회차) 를 초회납입일자로 계산~
    		String dueDt = dueDtRead(obj.loanNo, obj.loanSeq, obj.midPartRmbrTims);
    		if (dueDt != null && obj.midPartRmbrTims > 1) {
    			loanObj.fcntDueDt = DateUtil.addMonth(dueDt, (obj.midPartRmbrTims * -1) + 1);
    			loanObj.setlDd = loanObj.fcntDueDt.substring(6, 8);
    		}
    		// 변경회차 이후의 취급수수료 잔액 조회
    		if (loanObj.trtFeeIstpFg != null && loanObj.trtFeeIstpFg.trim().equals("1")) {
    			loanObj.trtFeeIstpAmt = trtFeeRamtRead(obj.loanNo, obj.loanSeq, obj.midPartRmbrTims);
    		}

    		// 대출원리금 조회
    		List piamtList = loanPiamtRead(obj.loanNo, obj.loanSeq);

    		// 중도상환회차가 현재 TR_SNUM에 포함되어 있지 않을때 에러처리한다.
    		boolean bMidRmbr = false;
    		int size = piamtList.size();
    		for (int i = 0; i < size; i++) {
    			LoanPiamtObj piamtObj = (LoanPiamtObj) piamtList.get(i);
    			obj.trSnum = piamtObj.trSnum+1;
    			LOGGER.error("obj.loanNo = " + obj.loanNo);
    			LOGGER.error("obj.midPartRmbrTims = " + obj.midPartRmbrTims);
    			LOGGER.error("opiamtObj.trSnum = " + piamtObj.trSnum);
    			LOGGER.error("piamtObj.strtTims = " + piamtObj.strtTims);
    			LOGGER.error("piamtObj.endTims = " + piamtObj.endTims);

    			if (obj.midPartRmbrTims >= piamtObj.strtTims && obj.midPartRmbrTims <= piamtObj.endTims) {

    				LOGGER.error("중도상환회차가 현재 TR_SNUM에 포함여부 체크.");
    				bMidRmbr = true;
    			}
    		}
    		// 중도상환회차가 현재 원리금에 포함안되면 에러처리한다. 2018-08-01
    		if (!bMidRmbr) {
    			LOGGER.error("[상환계획변경] : 부분상환을 처리할수 없습니다. 담당자에 문의하세요!");
        		loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
        		loanObj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
    		}

    		// 원리금 구성
    		reMakePiamt(obj, loanObj, piamtList);

        }catch (Exception e) {
        	loanObj.rsltCd   = msgEnum.ERR_SYSTEM.getErrorCd();
    		loanObj.rsltCntn = msgEnum.ERR_SYSTEM.getErrorCn();
		}
		return loanObj;
	}

	/**
	 * <p>메소드명      : reMakePiamt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 원리금 구성</p>
	 * <p>메소드인수    : MidPartRmbrInVO, LoanBaseOutVO , List </p>
	 * <p>메소드리턴값  : void</p>
	 * <p>예외처리      : Exception</p>
	 */
	public RmbrPlanUpdtOutVO reMakePiamt(MidPartRmbrObj obj, LoanBaseObj loanObj, List piamtList) throws Exception {

		LOGGER.info("::: loanPiamtRead :::");


		/** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
		RmbrPlanUpdtOutVO resultVo = new RmbrPlanUpdtOutVO();

		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
		try {

			// 이자배분상품 체크 추가 => 2018-08-01
			// RmbrPlanCrteCC.checkDefrIntDistFg(loanObj, con);
			// 원금잔액
			long pamtRamt = obj.pamtRamt;
			// 이전 잔여원금
			long bfPamtRamt = obj.pamtRamt;
			// 대출원리금 구성
			int size = piamtList.size();

			// 구성시작
			for (int i = 0; i < piamtList.size(); i++) {
				LoanPiamtObj piamtObj = null;
				// 우선순위 뒤에서 부터 구성한다.
				piamtObj = (LoanPiamtObj) piamtList.get(size - 1 - i);

				// 중도상환회차 이전 종료된 원리금은 포함하지 않는다.
				// 거치이자배분이면서 거치인경우는 종료회차 무관
				if (piamtObj.endTims < obj.midPartRmbrTims && !("1".equals(loanObj.defrIntDistFg.trim()) && "4".equals(piamtObj.rmbrFrmlCd.trim()))) {
					continue;
				}

				if (piamtObj.strtTims <= obj.midPartRmbrTims && piamtObj.endTims >= obj.midPartRmbrTims
						&& !("1".equals(loanObj.defrIntDistFg.trim()) && "4".equals(piamtObj.rmbrFrmlCd.trim()))) {

						piamtObj.strtTims = obj.midPartRmbrTims; // 시작회차(중도상환회차)

						if (DateUtil.isValid(loanObj.fcntDueDt.substring(0, 6) + loanObj.setlDd)) {
							piamtObj.strtDt = DateUtil.addMonth(loanObj.fcntDueDt.substring(0, 6) + loanObj.setlDd, piamtObj.strtTims - 1);
						} else {
							piamtObj.strtDt = DateUtil.addMonth(loanObj.fcntDueDt, piamtObj.strtTims - 1);
						}
						// 시작일자=변경회차의 납입일자
						/*
						 * piamtObj.strtDt = dueDtRead(obj.loanNo, obj.loanSeq,
						 * obj.midPartRmbrTims, con); if (piamtObj.strtDt == null) {
						 * piamtObj.strtDt =
						 * DateUtil.addMonth(loanObj.fcntDueDt.substring(0, 6) +
						 * loanObj.setlDd, piamtObj.strtTims - 1); }
						 */
				}

				piamtObj.term = piamtObj.endTims - piamtObj.strtTims + 1; // 원리금의 기간

				// 대출원금(잔여원금) 계산
				if (piamtObj.endTims >= obj.midPartRmbrTims || ("1".equals(loanObj.defrIntDistFg.trim()) && "4".equals(piamtObj.rmbrFrmlCd.trim()))) {

					if ("4".equals(piamtObj.rmbrFrmlCd.trim())) {
						piamtObj.loanPamt = bfPamtRamt;
					} else {

						if (piamtObj.loanPamt <= pamtRamt) {
							pamtRamt = pamtRamt - piamtObj.loanPamt;
						} else {
							piamtObj.loanPamt = pamtRamt;
							pamtRamt = 0;
						}

						bfPamtRamt = piamtObj.loanPamt;
					}
				} else {
					piamtObj.loanPamt = 0;
				}

				if (piamtObj.loanPamt == 0) {
					continue;
				}

				piamtObj.crteDivCd = "2"; // 생성구분코드 => 중도부분상환
				piamtObj.cnclTrSnum = piamtObj.trSnum; // 취소일련번호 셋팅
				piamtObj.trSnum = piamtObj.trSnum + 1; // 거래일련번호 증가

				// 이자배분금액 분배
				if (obj.intDistRamt > 0 && "1".equals(loanObj.defrIntDistFg.trim()) && "4".equals(piamtObj.rmbrFrmlCd.trim())) {

					if (pamtRamt == 0) {
						piamtObj.intDistAmt = obj.intDistRamt;
						obj.intDistRamt = 0;
					} else {
						// 주석풀어야함
						//piamtObj.intDistAmt = RmbrPlanCrteCC.floorValue(obj.intDistRamt * (piamtObj.loanPamt / loanObj.loanPamt));
						obj.intDistRamt = obj.intDistRamt - piamtObj.intDistAmt;
					}
				}

				if (loanObj.piamtObjList == null) {
					loanObj.piamtObjList = new ArrayList();
				}

				loanObj.piamtObjList.add(piamtObj);
			}
		}catch (Exception e) {

			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}
		return resultVo;
	}

	public void midAddLoanCrte(String loanNo, String loanSeq, int addTims, String addLoanDt, long addLoanPamt,
			String rmbrFrmlCd, String userEmpNo) throws Exception {

		try {

			// 대출기본 조회
			LoanBaseObj loanObj = loanBaseRead(loanNo, loanSeq, userEmpNo);
			if (loanObj == null) {
				//throw new Exception("[상환계획변경] : [대출기본]에 데이터가 없습니다.");
			}
			loanObj.chngIntStrtDt = addLoanDt;

			// 대출원리금 조회
			List piamtList = loanPiamtRead(loanNo, loanSeq);
			if (piamtList == null || piamtList.size() == 0) {
				//throw new Exception("[상환계획변경] : [대출원리금]에 데이터가 없습니다.");
			}
			loanObj.piamtObjList = piamtList;
			int size = loanObj.piamtObjList.size();
			for (int i = 0; i < size; i++) {
				LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(i);
				piamtObj.trSnum = piamtObj.trSnum + 1;
			}
			// 대출원리금 저장
			loanPiamtCrte(loanObj);
			// 상환계획 거래일련번호 증가
			rmbrPlanTrSnumUpdt(loanObj.loanNo, loanObj.loanSeq, loanObj.empNo);

			// 변경회차의 (납입일자 - 회차) 를 초회납입일자로 계산~
			String dueDt = dueDtRead(loanNo, loanSeq, addTims);
			if (dueDt != null && addTims > 1) {
				loanObj.fcntDueDt = DateUtil.addMonth(dueDt, (addTims * -1) + 1);
			}
			LoanPiamtObj bfPiamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(loanObj.piamtObjList.size() - 1);
			// 원리금 구성
			LoanPiamtObj piamtObj = new LoanPiamtObj();
			piamtObj.loanNo = loanObj.loanNo;
			piamtObj.loanSeq = loanObj.loanSeq;
			piamtObj.trSnum = bfPiamtObj.trSnum;
			piamtObj.frstRank = bfPiamtObj.frstRank + 1;// 우선순위 증가
			piamtObj.strtTims = addTims;
			piamtObj.endTims = loanObj.loanTerm;
			// 원리금의 기간
			piamtObj.term = piamtObj.endTims - piamtObj.strtTims + 1;
			piamtObj.endTerm = loanObj.loanTerm;
			piamtObj.strtDt = loanObj.fcntDueDt;
			piamtObj.endDt = DateUtil.addMonth(piamtObj.strtDt, piamtObj.endTims - piamtObj.strtTims + 1);
			piamtObj.rmbrFrmlCd = rmbrFrmlCd;
			piamtObj.crteDivCd = "2";
			piamtObj.dueCycl = bfPiamtObj.dueCycl;
			piamtObj.dueCyclCd = bfPiamtObj.dueCyclCd;
			piamtObj.dueStrtTims = bfPiamtObj.dueStrtTims;
			piamtObj.loanPamt = addLoanPamt;
			piamtObj.intRt = bfPiamtObj.intRt;
			piamtObj.baseFg = "0";
			piamtObj.cnclTrSnum = 0;

			loanObj.piamtObjList.clear();
			loanObj.piamtObjList.add(piamtObj);

			// 원리금 구성
			// 주석풀어야함
			//RmbrPlanCrteCC.makePiamt(loanObj, con);

			// 시작회차 이후의 회차별상환계획 생성
			// 주석 풀어야함
			//piamtObj.rmbrObjList = RmbrPlanCrteCC.makeRmbrPlanDesc(loanObj, piamtObj, 2, addTims, con);
			piamtObj.rmbrObjList = null;
			// 대출원리금 저장
			loanPiamtCrte(loanObj);
			// 생성된 상환계획 저장
			rmbrPlanDescCrte1(loanObj);
			// 상환계획 이력 저장
			rmbrPlanHistCrte(loanNo, loanSeq);
			// 대출기본 수정
			updateLoan(loanNo, loanSeq, userEmpNo);
		} catch (Exception se) {

		}
	}

	/**
	 * <p>메소드명      : trtFeeRamtRead</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 취급수수료 잔액 조회</p>
	 * <p>메소드인수    : RmbrPlanUpdtInVo </p>
	 * <p>메소드리턴값  : long</p>
	 * <p>예외처리      : Exception</p>
	 */
	private long trtFeeRamtRead(String loanNo, String loanSeq, int tims) throws Exception {

		long trtFeeRamt = 0;

		try {

			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

    		rmbrPlanDto.setLoanNo(loanNo);	    /** 대출번호 */
    		rmbrPlanDto.setLoanSeq(loanSeq);	/** 대출순번 */
    		rmbrPlanDto.setTims(tims);	        /** 회차 */

    		RmbrPlanUpdtOutVODTO rmbrPlanOutDTO = rmbrPlanUpdtMapper.trtFeeRamtRead(rmbrPlanDto);

    		if(rmbrPlanOutDTO != null) {
    			trtFeeRamt = rmbrPlanOutDTO.getTrtFeeRamt();
    		}

		}catch (Exception e) {
			LOGGER.error("[상환계획변경] : [취급수수료 잔액] 조회 오류! " + e.getMessage());
		}
		return trtFeeRamt;
	}

	/**
	 * <p>메소드명      : strtTimsCalcInt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 변경회차의 이자 일할로 재계산~</p>
	 * <p>메소드인수    : LoanBaseObj loanObj, int chngTims, String chngDt </p>
	 * <p>메소드리턴값  : long</p>
	 * <p>예외처리      : Exception</p>
	 */
	public RmbrPlanUpdtOutVO strtTimsCalcInt(LoanBaseObj loanObj, int chngTims, String chngDt) throws Exception {

		RmbrPlanUpdtOutVO resultVo = new RmbrPlanUpdtOutVO();

        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());
		try {

			int size1 = loanObj.piamtObjList.size();
			for (int i = 0; i < size1; i++) {
				LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(i);

				int size2 = piamtObj.rmbrObjList.size();

				// 거치이고 할부기간 이자분납인 경우는 이자계산 안하고 통과
				if ("4".equals(piamtObj.rmbrFrmlCd)) {
					if ("1".equals(loanObj.defrIntDistFg)) {
						continue;
					}
				}

				for (int j = 0; j < size2; j++) {
					RmbrPlanObj obj = (RmbrPlanObj) piamtObj.rmbrObjList.get(j);
					if (obj.tims == chngTims) {
						// 변경회차의 이자시작일자 조회
						String intStrtDt = intStrtDtRead2(obj.loanNo, obj.loanSeq, obj.frstRank, chngTims);

						if (intStrtDt == null) {
							intStrtDt = piamtObj.strtDt;
							if (DateUtil.daysBetween(intStrtDt, obj.dueDt) == 0) {
								intStrtDt = chngDt;
							}
						} else if (DateUtil.daysBetween(intStrtDt, chngDt) == 0) {
							continue;
						} else if (DateUtil.daysBetween(intStrtDt, chngDt) < 0
								|| DateUtil.daysBetween(chngDt, obj.dueDt) < 0) {
							//throw new Exception("ESZ9999null^변경시작일자는 변경시작회차의" + " 이자시작일과 납입일 사이여야 합니다.");
						}
						long oldInt = 0;
						long newInt = 0;

						// 변경전 원리금의 이자율 조회
						double oldIntRt = searchLoanIntRt(obj.loanNo, obj.loanSeq, obj.trSnum - 1, obj.frstRank);
						if (oldIntRt == piamtObj.intRt) {
							if (!intStrtDt.equals(obj.intCalcDay)) {
								// 주석 풀어야함
	//							obj.mmInt = RmbrPlanCrteCC.floorValue(piamtObj.loanPamt
	//									* DateUtil.daysBetween(intStrtDt, obj.dueDt) * (oldIntRt * 0.01) / 365);
								obj.mmPiamt = obj.mmPamt + obj.mmInt;
								obj.intCalcDay = intStrtDt;
							}
							continue;
						}

						// 1.이자계산일수
						int frstDd = 0;
						// 변경전
						frstDd = DateUtil.daysBetween(intStrtDt, chngDt);
						// 주석 풀어야함
						//oldInt = RmbrPlanCrteCC.floorValue(piamtObj.loanPamt * frstDd * (oldIntRt * 0.01) / 365);
						// 변경후
						frstDd = DateUtil.daysBetween(chngDt, obj.dueDt);
						// 주석풀어야함
						//newInt = RmbrPlanCrteCC.floorValue(piamtObj.loanPamt * frstDd * (piamtObj.intRt * 0.01) / 365);
						obj.mmInt = oldInt + newInt;
						obj.mmPiamt = obj.mmPamt + obj.mmInt;
						obj.intCalcDay = intStrtDt;
					}
				}
			}
		} catch (Exception e) {
			LOGGER.error("[상환계획변경] : [상환계획이력] 생성중 오류! " + e.getMessage());
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : rmbrPlanDescCrte1</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 상환계획내역 저장</p>
	 * <p>메소드인수    : LoanBaseObj loanObj </p>
	 * <p>메소드리턴값  : int</p>
	 * <p>예외처리      : Exception</p>
	 */
	public int rmbrPlanDescCrte1(LoanBaseObj loanObj) throws Exception {

		int rowCnt = 0;

		try {

			int size = loanObj.piamtObjList.size();
			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

			for (int j = 0; j < size; j++) {
				LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(j);
				int size2 = piamtObj.rmbrObjList.size();

				// 전체 이자합계
				double totIntSum  = 0;
				double totIntSum1 = 0;

				for (int k = 0; k < size2; k++) {
					RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);
					// 전체이자합계를 먼저 구한다~
					totIntSum += rmbrObj.mmInt;
				}

				for (int k = 0; k < size2; k++) {
					RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);

					rmbrPlanDto.setLoanNo(rmbrObj.loanNo);
					rmbrPlanDto.setLoanNo(rmbrObj.loanSeq);
					rmbrPlanDto.setTrSnum(rmbrObj.trSnum);
					rmbrPlanDto.setFsrtRank(rmbrObj.frstRank);
					rmbrPlanDto.setTims(rmbrObj.tims);
					rmbrPlanDto.setDueDt(rmbrObj.dueDt);
					rmbrPlanDto.setRmbrFrmlCd(StringUtil.trimToStr(rmbrObj.rmbrFrmlCd));
					rmbrPlanDto.setCrteDivCd(StringUtil.trimToStr(piamtObj.crteDivCd));
					rmbrPlanDto.setMmPamt(rmbrObj.mmPamt);
					rmbrPlanDto.setMmInt(rmbrObj.mmInt);
					rmbrPlanDto.setMmPiamt(rmbrObj.mmPiamt);
					rmbrPlanDto.setTimsBfPamtRamt(rmbrObj.timsBfPamtRamt);
					rmbrPlanDto.setTimsAfPamtRamt(rmbrObj.timsAfPamtRamt);
					rmbrPlanDto.setTotIntSum(totIntSum);
					// 회차후 잔여이자 = 전체이자합계 - 당회차이자합계
					totIntSum1 = totIntSum - rmbrObj.mmInt;
					rmbrPlanDto.setTotIntSum(totIntSum1);
					rmbrPlanDto.setPdueFg(StringUtil.trimToStr(rmbrObj.pdueFg).equals("") ? "0" : StringUtil.trimToStr(rmbrObj.pdueFg)); // 선납여부
		    		rmbrPlanDto.setIntRt(rmbrObj.intRt);
		    		rmbrPlanDto.setIntCalcDay(rmbrObj.intCalcDay);
		    		rmbrPlanDto.setDueDt(rmbrObj.dueDt);
		    		rmbrPlanDto.setMmTrtFee(rmbrObj.mmTrtFee);
		    		rmbrPlanDto.setTimsBfTrtFeeRamt(rmbrObj.timsBfTrtFeeRamt);	        /** 회차전잔여원금 */
		    		rmbrPlanDto.setTimsAfTrtFeeRamt(rmbrObj.timsAfTrtFeeRamt);	        /** 회차후잔여원금 */
		    		rmbrPlanDto.setEmpNo(StringUtil.trimToStr(loanObj.empNo));     		/** 사번 */

		    		rmbrPlanUpdtMapper.rmbrPlanDescCrte(rmbrPlanDto);
		    		rowCnt++;
				}
			}

		} catch (Exception e) {
			LOGGER.error("(상환계획생성)상환계획 저장중 오류발생!");
		}

		return rowCnt;
	}

	/**
	 * <p>메소드명      : setlDdChngLoanPiamtUpdt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 결제일 변경 후 대출원리금 변경</p>
	 * <p>메소드인수    : SetlDdChngObj </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	private RmbrPlanUpdtOutVO setlDdChngLoanPiamtUpdt(SetlDdChngObj obj) throws Exception {

		LOGGER.debug("상환계획변경.setlDdChngLoanPiamtUpdt 시작!");

		RmbrPlanUpdtOutVO result = new RmbrPlanUpdtOutVO();
		result.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        result.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			SetlDdChngDTO setlDdDto = new SetlDdChngDTO();

			setlDdDto.loanNo  = obj.loanNo;	        /** 대출번호 */
			setlDdDto.loanSeq = obj.loanSeq;	    /** 대출순번 */
			setlDdDto.empNo   = obj.empNo;	        /** 직원번호 */

    		rmbrPlanUpdtMapper.loanPiamtUpdt1(setlDdDto);
		}catch (Exception e) {
			LOGGER.error("[상환계획변경] : [상환계획이력] 생성중 오류! " + e.getMessage());
            result.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            result.setRsltCntn(e.getMessage());
		}
		return result;
	}

	/**
	 * <p>메소드명      : setlDdChngLoanBaseUpdt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 결제일 변경 후 대출기본 변경</p>
	 * <p>메소드인수    : SetlDdChngObj </p>
	 * <p>메소드리턴값  : RmbrPlanUpdtOutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	private RmbrPlanUpdtOutVO setlDdChngLoanBaseUpdt(SetlDdChngObj obj) throws Exception {

		LOGGER.debug("상환계획변경.setlDdChngLoanPiamtUpdt 시작!");
		RmbrPlanUpdtOutVO result = new RmbrPlanUpdtOutVO();
		result.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        result.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			// 대출기본 변경 - 만기일자, 대출이자, 대출이자잔액
			SetlDdChngDTO setlDdDto = new SetlDdChngDTO();

			setlDdDto.psgInt    = obj.psgInt;                       /** 경과이자 */
			setlDdDto.chngDueDt = obj.chngDueDt.substring(6, 8);    /** 변경납입일자 */
			setlDdDto.loanNo    = obj.loanNo;	                    /** 대출번호 */
			setlDdDto.loanSeq   = obj.loanSeq;	                    /** 대출순번 */
    		setlDdDto.empNo     = StringUtil.trimToStr(obj.empNo);	    /** 직원번호 */

    		rmbrPlanUpdtMapper.loanBaseUpdt1(setlDdDto);

		}catch (Exception e) {
			LOGGER.error("[상환계획변경] : [상환계획이력] 생성중 오류! " + e.getMessage());
            result.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            result.setRsltCntn(e.getMessage());
		}
		return result;
	}

	/**
	 * <p>메소드명      : searchLoanIntRt</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70326 / HyunSik.You
	 * <p>설명          : 해당 우선순위의 이자율 조회</p>
	 * <p>메소드인수    : String loanNo, String loanSeq, int trSnum, int frstRank </p>
	 * <p>메소드리턴값  : double</p>
	 * <p>예외처리      : Exception</p>
	 */
	private double searchLoanIntRt(String loanNo, String loanSeq, int trSnum, int frstRank)	throws Exception {

		double intRt = 0;

		try {

			RmbrPlanUpdtInVODTO rmbrPlanDto = new RmbrPlanUpdtInVODTO();

			rmbrPlanDto.setLoanNo(loanNo);
			rmbrPlanDto.setLoanSeq(loanSeq);
			rmbrPlanDto.setTrSnum(trSnum);
			rmbrPlanDto.setFsrtRank(frstRank);

			List<RmbrPlanUpdtOutVODTO> rmbrPlanOutDTO = rmbrPlanUpdtMapper.loanIntRtRead(rmbrPlanDto);

			if(rmbrPlanOutDTO != null) {

				for (RmbrPlanUpdtOutVODTO rs : rmbrPlanOutDTO) {
					intRt = rs.getLoanIntRt();
				}
			}

		} catch (Exception e) {
			LOGGER.error("[상환계획변경] :대출원리금 이자율 조회중 오류발생!");
		}

		return intRt;
	}


	/**
	 * 주어진 날짜 DATE(from, to) 의 기간 구하기
	 * @param from yyyyMMdd 형식
	 * @param to yyyyMMdd 형식
	 * @return 입력일자의 기간일수
	 */
	public static int daysBetween(String from, String to) {
		return daysBetween(from, to, "yyyyMMdd");
	}

	/**
	 * <p>주어진 날짜 DATE(from, to) 의 기간(일) 구하기 to - from
	 * <p>from, to 일자의 포맷은 일치해야한다.
	 * @param from 시작일자
	 * @param to 종료일자
	 * @param format 날짜포맷 ( yyyy-MM-dd, yyyyMMdd)
	 * @return
	 */
	private static int daysBetween(String from, String to, String format) {

		SimpleDateFormat formatter = new SimpleDateFormat(format, java.util.Locale.KOREA);
		Date d1 = null;
		Date d2 = null;

		try {
			d1 = formatter.parse(from);
			d2 = formatter.parse(to);
		}
		catch (ParseException e) {
			return -1;
		}

		if (!formatter.format(d1).equals(from)) {
			return -1;
		}

		if (!formatter.format(d2).equals(to)) {
			return -1;
		}

		long duration = d2.getTime() - d1.getTime();

		if (duration < 0) {
			return -1;
		}

		return (int) (duration / (1000 * 60 * 60 * 24));
	}

	// 필수 입력값 체크
	private static void checkNull(String value, String name) throws Exception {
		if (value == null || value.trim().equals("")) {
			//throw new Exception("[상환계획변경] : " + name + " 을(를) 찾을 수 없습니다.");
		}
	}

	private static void checkNull(double value, String name) throws Exception {
		if (value == 0) {
			//throw new Exception("[상환계획변경] : " + name + " 을(를) 찾을 수 없습니다.");
		}
	}

	public static long floorValue(double value) {
		if (value >= 0) {
			return (long) Math.floor(value);
		} else {
			return (long) Math.ceil(value);
		}
	}

}