package hanalife.s.ln.lm.service;

import hanalife.s.ln.lm.vo.UnrcvProcInVO;
import hanalife.s.ln.lm.vo.UnrcvProcOutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : UnrcvProcService.java Class
 * 클래스설명   : todo1 (UnrcvProc) Service Interface
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : create : 미수금 생성
 *           rcptUnrcvAmtCancel : 미수금 수납취소처리
 * </pre>
 */
public interface UnrcvProcService {

	/**
	 * <p>메소드명      : create : 미수금 생성</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 인지세 미수금 생성</p>
	 * <p>메소드인수    : UnrcvProcInVo </p>
	 * <p>메소드리턴값  : UnrcvProcOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public UnrcvProcOutVO create(UnrcvProcInVO inVo) throws Exception;

	/**
	 * <p>메소드명      : cancel : 취소처리</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 인지세 미수금 생성 취소</p>
	 * <p>메소드인수    : UnrcvProcInVo </p>
	 * <p>메소드리턴값  : UnrcvProcOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public UnrcvProcOutVO cancel(UnrcvProcInVO inVo) throws Exception;

	/**
	 * <p>메소드명      : rcptUnrcvAmt : 미수금 수납처리</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 인지세 미수금 수납</p>
	 * <p>메소드인수    : UnrcvProcInVo </p>
	 * <p>메소드리턴값  : UnrcvProcOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public UnrcvProcOutVO rcptUnrcvAmt(UnrcvProcInVO inVo) throws Exception;

	/**
	 * <p>메소드명      : procKcarUnrcvAdj : 미수금 정산처리</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 미수금 정산처리</p>
	 * <p>메소드인수    : UnrcvProcInVo </p>
	 * <p>메소드리턴값  : UnrcvProcOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public UnrcvProcOutVO procKcarUnrcvAdj(UnrcvProcInVO inVo) throws Exception;

	/**
	 * <p>메소드명      : rcptUnrcvAmtCancel : 미수금 수납취소처리</p>
	 * <p>작성일자      : 2023. 3. 13.
	 * <p>작성자(author): 70324 / WoongHee.Lee
	 * <p>설명          : 미수금 수납취소처리</p>
	 * <p>메소드인수    : UnrcvProcInVo </p>
	 * <p>메소드리턴값  : UnrcvProcOutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public UnrcvProcOutVO rcptUnrcvAmtCancel(UnrcvProcInVO inVo) throws Exception;


}
