package hanalife.s.ln.lm.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.s.ln.lm.mapper.RmbrPlanCrteMapper;
import hanalife.s.ln.lm.mapper.dto.RmbrPlanCrteCCInVODTO;
import hanalife.s.ln.lm.service.RmbrPlanCrteService;
import hanalife.s.ln.lm.vo.IntnPrftRtObj;
import hanalife.s.ln.lm.vo.LoanBaseObj;
import hanalife.s.ln.lm.vo.LoanPiamtObj;
import hanalife.s.ln.lm.vo.RmbrPlanObj;
import hanalife.util.format.ServerSysDate;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : RmbrPlanCrteServiceImpl.java Class
 * 클래스설명   : todo1 (RmbrPlanCrteCC) Service Implements
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70324 / younghwe.kim / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :    RmbrPlanCrteServiceImpl : 상환계획 생성
 * </pre>
 */
@Service("RmbrPlanCrteService")
public class RmbrPlanCrteServiceImpl implements RmbrPlanCrteService {

	private static final Logger LOGGER = LoggerFactory.getLogger(RmbrPlanCrteServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 **/
    @SuppressWarnings("unused")
	private MsgEnum msgEnum;

	@Autowired
	private RmbrPlanCrteMapper rmbrPlanCrteMapper;

	public RmbrPlanCrteServiceImpl() {
	}

    /**
     * <p>메소드명	: createRmblPlan</p>
     * <p>설　　명	: 상환계획내역을 생성한다.</p>
     * <p>메소드인수	: LoanBaseObj, Connection</p>
     * <p>리　턴　값	: LoanBaseObj</p>
     */
	// 대출기본 객체에 해당 대출에 대한 대출원리금 객체 리스트가 존재
	// 대출원리금 객체에 해당 원리금에 대한 상환계획 객체 리스트가 존재
	@Override
	public LoanBaseObj createRmblPlan(LoanBaseObj loanObj) throws Exception {
		List<LoanBaseObj> loanList = new ArrayList<LoanBaseObj>();
		loanList.add(loanObj);
//		if(!"71".equals(loanObj.prdtMidClasCd)) {
//			loanList = this.createRmblPlan(loanList);
//		}else {
//			//[hanalife] 2023-04-05 사용하지 않음
//			loanList = this.createRmblPlanIvst(loanList);
//		}

		loanList = this.createRmblPlan(loanList);

		return loanList.get(0);
	}

	/**
	 * <p>메소드명	: createRmblPlan</p>
	 * <p>설　　명	: 상환계획내역을 생성한다.</p>
	 * <p>메소드인수	: List(LoanBaseObj), Connection</p>
	 * <p>리　턴　값	: List(LoanBaseObj)</p>
	 */
	// 대출기본 객체에 해당 대출에 대한 대출원리금 객체 리스트가 존재
	// 대출원리금 객체에 해당 원리금에 대한 상환계획 객체 리스트가 존재
	public List<LoanBaseObj> createRmblPlan(List<LoanBaseObj> loanObjList) throws Exception {

		LOGGER.info(" 입력항목체크 START");
		// 입력항목체크
		this.validCheck(loanObjList);
		LOGGER.info(" 입력항목체크 END");
		// 원리금구성
		loanObjList = this.callMakePiamt(loanObjList);
		LOGGER.info(" 원리금구성 END");
		// 회차별 상환계획 구성
		loanObjList = this.callMakeRmbrPlan(loanObjList);
		LOGGER.info(" 회차별 상환계획 구성 END");
		// 내부수익률 계산
		loanObjList = this.callIntnPrftRt(loanObjList);
		LOGGER.info(" 내부수익률 END");
		// 상환계획내역 저장
		int cnt = this.rmbrPlanDescCrte(loanObjList);
		LOGGER.info(" 상환계획내역 저장 건수     >>>>>     " + cnt);

		return loanObjList;
	}

	/**
	 * <p>메소드명	: callMakePiamt</p>
	 * <p>설　　명	: 대출원리금 객체를 구성한다.</p>
	 * <p>메소드인수	: List(LoanBaseObj)</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	public List<LoanBaseObj> callMakePiamt(List<LoanBaseObj> loanObjList) throws Exception {
		//LOGGER.debug("makePni 시작!");
		int size1 = loanObjList.size();
		for (int i = 0; i < size1; i++) {
			LoanBaseObj loanObj = loanObjList.get(i);
			//<대출원리금> 객체 항목을 구성한다.
			loanObj = this.makePiamt(loanObj);

			loanObjList.set(i, loanObj);
		}

		return loanObjList;
	}

	/**
	 * <p>메소드명	: makePiamt</p>
	 * <p>설　　명	: 할부,리스의 경우의 대출원리금 객체를 구성한다.</p>
	 * <p>메소드인수	: LoanBaseObj</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	public LoanBaseObj makePiamt(LoanBaseObj loanObj) throws Exception {
		//이자배분상품 체크 추가 => 2018-08-01
		//checkDefrIntDistFg(loanObj);

		//기산일 추가 (Null이면 초회납입일의 일자를 SET)
		if (StringUtil.isNull(loanObj.setlDd)) {
			// [20190320_SHC] 초회납입일 체크 추가
			if (StringUtil.isNull(loanObj.fcntDueDt)) {
				throw new Exception("초회납입일이 존재하지 않습니다.");
			}
			loanObj.setlDd = loanObj.fcntDueDt.substring(6, 8);
		}

		//[렌터카공제조합] 윤년체크 추가 => 2018-08-01
		String leafYearFg = "";
		String leafYear = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD).toString();
		LOGGER.info("윤년(leafYear) ====> " + StringUtil.isLeapYr(leafYear));
		if (StringUtil.isLeapYr(leafYear)) {
			leafYearFg = "1";
		} else {
			leafYearFg = "0";
		}


		@SuppressWarnings("unchecked")
		List<LoanPiamtObj> piamtList = loanObj.piamtObjList;

		int size2 = piamtList.size();
		for (int j = 0; j < size2; j++) {

			LoanPiamtObj piamtObj = piamtList.get(j);
			LOGGER.info("■ 원리금구성(우선순위"+(j+1)+") 상환방식코드 = "+piamtObj.rmbrFrmlCd);

			//1.초회일수 = 대출기본.초회납입일자 - 대출기본.대출일자
			piamtObj.fcntDd = DateUtil.daysBetween(loanObj.loanDt, loanObj.fcntDueDt);
			//LOGGER.info("[ 초회일수 : " + piamtObj.fcntDd + "]");

			//2.납입횟수 = (대출원리금.기간 - 대출원리금.납입시작회차 + 납입주기) / 납입주기
			piamtObj.dueCnt = (int) Math.ceil((piamtObj.term - piamtObj.dueStrtTims + piamtObj.dueCycl) / piamtObj.dueCycl);

			//3.원금납입기간 = (대출원리금.기간-(대출원리금.납입주기-대출원리금.납입시작회차)
			piamtObj.pamtDueTerm = piamtObj.term - (piamtObj.dueCycl - piamtObj.dueStrtTims);
			LOGGER.info("[ 납입횟수 : " + piamtObj.dueCnt + "]");
			LOGGER.info("[ 원금납입기간 : " + piamtObj.pamtDueTerm + "]");

			//4.이자율 = 대출원리금.기준이자율
			//piamtObj.intRt = piamtObj.intRt;
			//LOGGER.info("[ 이자율 : " + piamtObj.intRt + "]");

			//5.거치여부
			if (piamtObj.frstRank == 1 && piamtObj.rmbrFrmlCd.equals("4")) {
				loanObj.deferFg = "1";
			}
			else {
				loanObj.deferFg = "0";
			}
			//6.만기여부
			if (piamtObj.rmbrFrmlCd.equals("3")) {
				piamtObj.mtrtYn = "1";
			}
			else {
				piamtObj.mtrtYn = "0";
			}

			//5.계산원리금 = 원단위절사(((대출기본.배가*((1+대출원리금.이자율/12)^대출원리금.납입주기) - 1) *
			//              (1+대출원리금.이자율/12)^대출원리금.원금납입기간 /
			//              ((1+대출원리금.이자율/12)^대출원리금.기간-1)+0.9) *
			//              대출원리금.잔여원금 / 대출기본.배가
			//원리금균등에서 납입주기가 3,6 일때 기간은 납입주기의 배수 가능
			if ("1".equals(piamtObj.rmbrFrmlCd) && piamtObj.term % piamtObj.dueCycl > 0) {
				throw new Exception("우선순위 " + piamtObj.frstRank + " 의 기간(" + piamtObj.term + ")으로 [원리금균등]의 상환계획을 구성할 수 없습니다. 우선순위별 기간은 납입주기의 배수만 가능합니다.");
			}

			/**
			 * [DOBSCAP] 두비스 : 2018-08-01
			 * 변경내역 : 대출원리금.계산원리금 , 대출원리금.계산원금, 대출원리금.계산원금나머지 부분을 아래 메소드에서 모두 처리하도록 변경
			 */
			piamtObj = this.calcMmPiamt(piamtObj);

			//8.계산이자(원단위단수)=셋째반올림(배가*대출원리금.이자율/12)*대출원리금.잔여원금/배가
			piamtObj.calcInt = this.floorValue(this.oddRoundThree(loanObj.veaga * (piamtObj.intRt * 0.01) / 12) * piamtObj.loanPamt / loanObj.veaga);
			LOGGER.info("[ 계산이자 : " + new BigDecimal(piamtObj.calcInt) + "]");

			//9.계산초회이자=원단위단수(대출원리금.잔여원금*대출원리금.초회일수*대출원리금.이자율/365)
			//if (leafYearFg.equals("1")) {
			//	piamtObj.calcFcntInt = floorValue(piamtObj.loanPamt * piamtObj.fcntDd * (piamtObj.intRt * 0.01) / 366);

			//String leafdd =  "0229";
			//String leftdt = ServerSysDate.getServerDate(ServerSysDate.YYYY) +  leafdd;

			//LOGGER.info(" leftdt :" + leftdt ); //2018-08-01 수정
			//LOGGER.info(" loanObj.loanDt :" + loanObj.loanDt ); //2018-08-01 수정
			//LOGGER.info(" loanObj.fcntDueDt :" + loanObj.fcntDueDt ); //2018-08-01 수정
			//LOGGER.info("[ DateUtil.daysBetween(loanObj.loanDt, leftdt) : " + DateUtil.daysBetween(loanObj.loanDt, leftdt) + "]");
			//LOGGER.info("[ DateUtil.daysBetween(leftdt , loanObj.fcntDueDt) : " + DateUtil.daysBetween(leftdt , loanObj.fcntDueDt) + "]");

			if (leafYearFg.equals("1")) { //2018-08-01 수정
			//if (leafYearFg.equals("1") && DateUtil.daysBetween(loanObj.loanDt, leftdt) >= 0 && DateUtil.daysBetween(leftdt , loanObj.fcntDueDt) >= 0 ) {
				piamtObj.calcFcntInt = this.floorValue(piamtObj.loanPamt * piamtObj.fcntDd * (piamtObj.intRt * 0.01) / 366);
			} else {
				piamtObj.calcFcntInt = this.floorValue(piamtObj.loanPamt * piamtObj.fcntDd * (piamtObj.intRt * 0.01) / 365);
			}
			//10.납입시작기간=대출원리금.시작회차+대출원리금.납입시작회차-1
			piamtObj.dueStrtTerm = piamtObj.strtTims + piamtObj.dueStrtTims - 1;
			//LOGGER.info("[ 납입시작기간 : " + piamtObj.dueStrtTerm + "]");

			//11.마지막기간 = 대출원리금.기간+대출원리금.시작회차 - 1 - (대출원리금.납입주기-대출원리금.납입시작회차)
			piamtObj.endTerm = piamtObj.term + piamtObj.strtTims - 1 - (piamtObj.dueCycl - piamtObj.dueStrtTims);
			//LOGGER.info("[ 마지막기간 : " + piamtObj.endTerm + "]");

			//취급수수료 분납
			if (loanObj.trtFeeIstpAmt > 0 && loanObj.trtFeeIstpFg != null && loanObj.trtFeeIstpFg.trim().equals("1")
					&& StringUtil.in(piamtObj.rmbrFrmlCd, new String[]{"1","2","3"}) ) {

				piamtObj.trtFee = loanObj.trtFeeIstpAmt;
				piamtObj.calcMmTrtFee = this.floorValue(piamtObj.trtFee / piamtObj.dueCnt);
				piamtObj.calcTrtFeeRamt = piamtObj.trtFee - (piamtObj.calcMmTrtFee * piamtObj.dueCnt);
				loanObj.trtFeeIstpAmt = 0;
			}
			//거치이자배분금액*****************************************
			if (StringUtil.trim(loanObj.defrIntDistFg).equals("1") && "4".equals(piamtObj.rmbrFrmlCd) && piamtObj.intDistAmt == 0) {

				//거치일수 =((초회납입일+기간(월)) - 초회납입일)(일수)
				if ("1".equals(loanObj.fcntMopaCalcFg)) {
					//이자배분금액=기본.대출원금*원리금.이자율*거치기간/12
					piamtObj.intDistAmt = this.floorValue(piamtObj.loanPamt * (piamtObj.intRt * 0.01) * piamtObj.term / 12);
				} else {
					int deferDd = DateUtil.daysBetween(loanObj.loanDt, DateUtil.addMonth(loanObj.fcntDueDt, piamtObj.term - 1));
					//이자배분금액=기본.대출원금*원리금.이자율*거치일수/365/(대출기간-거치기간)
					if (leafYearFg.equals("1")) {
						piamtObj.intDistAmt = this.floorValue(piamtObj.loanPamt * (piamtObj.intRt * 0.01) * deferDd / 366);
					} else {
						piamtObj.intDistAmt = this.floorValue(piamtObj.loanPamt * (piamtObj.intRt * 0.01) * deferDd / 365);
					}
				}
				//LOGGER.info("[ 거치일수 : " + deferDd + "]");
			}
			//LOGGER.info("[ 이자배분금액 : " + piamtObj.intDistAmt + "]");
			piamtList.set(j, piamtObj);
		}

		loanObj.piamtObjList = piamtList;

		return loanObj;
	}

	//원리금 계산
	@SuppressWarnings("deprecation")
	private LoanPiamtObj calcMmPiamt(LoanPiamtObj piamtObj) {

		if (piamtObj.intRt == 0) {
			/**
			 * [DOBSCAP] 두비스 : 2018-08-01
			 * 변경내역 : 대출원리금.이자율이 0인경우 아래와 같이 처리
			 *          1) 대출원리금.계산원리금 = 대출원리금.대출원금/대출원리금.납입횟수 (십원미만 절사)
			 *          2) 대출원리금.계산원금 = 대출원리금.계산원리금
			 *          3) 대출원리금.계산원금나머지 = 대출원리금.대출원금 - (대출원리금.계산원금 * 대출원리금.납입횟수)
			 */
			//계산원리금(십원미만 절사)
			piamtObj.calcPiamt = new BigDecimal((piamtObj.loanPamt / piamtObj.dueCnt)).divide(new BigDecimal(10), 0, BigDecimal.ROUND_DOWN).multiply(new BigDecimal(10)).longValue();
			//계산원금 = 계산원리금
			piamtObj.calcPamt = piamtObj.calcPiamt ;
			//계산원금나머지 = 대출원리금.잔여원금-(대출원리금.계산원금*대출원리금.납입횟수)
			piamtObj.calcPamtRamt = piamtObj.loanPamt - (piamtObj.calcPamt * piamtObj.dueCnt);
		}
		else {
			/**
			 * [DOBSCAP] 두비스 : 2018-08-01
			 * 변경내역 : 대출원리금.이자율이 0인 아닌경우 아래와 같이 처리
			 *          1) 대출원리금.계산원리금 = ((1+(대출원리금.이자율*0.01/12))^대출원리금.납입주기 - 1 )
			                                  * ((1+(대출원리금.이자율*0.01/12))^대출원리금.원금납입기간 )
			                                  / ((1+(대출원리금.이자율*0.01/12))^대출원리금.기간 - 1 )
			                                  * 대출원리금.대출원금 (십원미만 절상)
			 *          2) 대출원리금.계산원금 = 대출원리금.대출원금 * 대출원리금.납입회수 ( 원미만 절사)
			 *          3) 대출원리금.계산원금나머지 = 대출원리금.대출원금 - (대출원리금.계산원금 * 대출원리금.납입횟수)
			 */
			piamtObj.calcPiamt = new BigDecimal(( (Math.pow(1 + (piamtObj.intRt * 0.01) / 12, piamtObj.dueCycl) - 1)
							* Math.pow(1 + (piamtObj.intRt * 0.01) / 12, piamtObj.pamtDueTerm)
							/ (Math.pow(1 + (piamtObj.intRt * 0.01) / 12, piamtObj.term) - 1)
								* piamtObj.loanPamt))
							.divide(new BigDecimal(10), 0, BigDecimal.ROUND_UP).multiply(new BigDecimal(10)).longValue();;

			//계산원금 = 대출원리금.잔여원금 / 대출원리금.납입횟수(100원 단수처리)
			piamtObj.calcPamt = this.floorValue(piamtObj.loanPamt / piamtObj.dueCnt);
			//계산원금나머지 = 대출원리금.잔여원금-(대출원리금.계산원금*대출원리금.납입횟수)
			piamtObj.calcPamtRamt = piamtObj.loanPamt - (piamtObj.calcPamt * piamtObj.dueCnt);
		}
		/*
		piamtObj.calcPiamt = floorValue(floorValue(loanObj.veaga
				* (Math.pow(1 + (piamtObj.intRt * 0.01) / 12, piamtObj.dueCycl) - 1)
				* Math.pow(1 + (piamtObj.intRt * 0.01) / 12, pamtDueTerm)
				/ (Math.pow(1 + (piamtObj.intRt * 0.01) / 12, piamtObj.term) - 1) + 0.9)
				* piamtObj.loanPamt / loanObj.veaga);
		*/
		return piamtObj;
	}

	/**
	 * <p>메소드명	: callMakeRmbrPlan</p>
	 * <p>설　　명	: 회차별 상환계획 객체를 구성한다.</p>
	 * <p>메소드인수	: List(LoanBaseObj)</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	public List<LoanBaseObj> callMakeRmbrPlan(List<LoanBaseObj> loanList) throws Exception {
		int size1 = loanList.size();
		for (int i=0; i<size1; i++) {
			LoanBaseObj loanObj = loanList.get(i);
			loanObj = this.makeRmbrPlan(loanObj);

			loanList.set(i, loanObj);
		}

		return loanList;
	}





	/**
	 * <p>메소드명	: makeRmbrPlan</p>
	 * <p>설　　명	: 할부, 리스인 경우의 회차별 상환계획 객체를 구성한다.</p>
	 * <p>메소드인수	: LoanBaseObj</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	public LoanBaseObj makeRmbrPlan(LoanBaseObj loanObj) throws Exception {

		@SuppressWarnings("unchecked")
		List<LoanPiamtObj> pniList = loanObj.piamtObjList;
		int size2 = pniList.size();

		for (int j = 0; j < size2; j++) {
			LoanPiamtObj piamtObj = pniList.get(j);
			List<RmbrPlanObj> rmbrList = this.makeRmbrPlanDesc(loanObj, piamtObj);
			piamtObj.rmbrObjList = rmbrList;
		}

		//만기일자 구하기 위한 변수 추가
		int maxTurn = 0; //마지막회차
		String eprtDt = ""; //만기일자

		for (int i = 0; i < size2; i++) {
			LoanPiamtObj piamtObj = pniList.get(i);

			for (int k = 0; k < piamtObj.rmbrObjList.size(); k++) {
				RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);
				//*****************************************2018-08-01 추가
				if (rmbrObj.tims > maxTurn) {
					maxTurn = rmbrObj.tims;
					eprtDt = rmbrObj.dueDt;
				}
			}
		}
		loanObj.eprtDt = eprtDt;
		loanObj.lastTims = maxTurn;

		return loanObj;
	}



	//원리금별 상환계획 내역 생성
	public List<RmbrPlanObj> makeRmbrPlanDesc(LoanBaseObj loanObj, LoanPiamtObj piamtObj) throws Exception {
		return this.makeRmbrPlanDesc(loanObj, piamtObj, 0, 0);
	}

//	public static List makeRmbrPlanDesc(LoanBaseObj loanObj, LoanPiamtObj piamtObj , int div, int chngTurn) throws Exception {
//		return makeRmbrPlanDesc(loanObj, piamtObj, div, chngTurn, null);
//	}

	public List<RmbrPlanObj> makeRmbrPlanDesc(LoanBaseObj loanObj, LoanPiamtObj piamtObj, int div, int chngTurn) throws Exception {
		LOGGER.info("■ makeRmbrPlanDesc");
		List<RmbrPlanObj> rmbrList = new ArrayList<RmbrPlanObj>();

		//[렌터카공제조합] 윤년체크 추가 => 2018-08-01
		String leafYearFg = "";
		String leafYear = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD).toString();
		LOGGER.info("윤년(leafYear) ====> " + StringUtil.isLeapYr(leafYear));
		if (StringUtil.isLeapYr(leafYear)) {
			leafYearFg = "1";
		} else {
			leafYearFg = "0";
		}
		//쌍용차 다이어트 할부의 경우 이자율 정보 조회 (2018-08-01)
		//[hanalife] 2023-04-05 사용안함
		//checkVarMnrtPrdt(loanObj);

		//B.대출원리금.상환방식코드가 리볼빙이 아닌경우
		//대출원리금별 상환계획총회차 = 대출원리금.기간 + 대출원리금.시작회차 - 1
		int termCnt = piamtObj.term + piamtObj.strtTims - 1;

		//상환계획 내역의 갯수 정의
		//대출원리금.기간의 크기만큼 loop => 시작회차 부터 기간까지 loop 변경 2018-08-01
		for (int idx = piamtObj.strtTims; idx <= termCnt; idx++) {
			RmbrPlanObj rmbrObj = new RmbrPlanObj();

			RmbrPlanObj bfRmbrObj = null;
			if (idx > piamtObj.strtTims) {
				//전회차 상환계획 구함*************
				bfRmbrObj = rmbrList.get(idx - piamtObj.strtTims - 1);
			}
			//대출번호,대출순번
			rmbrObj.loanNo = loanObj.loanNo;
			rmbrObj.loanSeq = loanObj.loanSeq;
			//거래일련번호,우선순위
			rmbrObj.trSnum = piamtObj.trSnum;
			rmbrObj.frstRank = piamtObj.frstRank;
			rmbrObj.rmbrFrmlCd = piamtObj.rmbrFrmlCd;

			//1.회차 = (바로전)회차별상환계획.회차 + 1
			if (idx == piamtObj.strtTims) {
				rmbrObj.tims = piamtObj.strtTims;
			}
			else {
				rmbrObj.tims = bfRmbrObj.tims + 1;
			}

			//쌍용차 다이어트 할부의 경우 값 변경작업 (2018-08-01)
			//[hanalife] 2023-04-05 사용안함
//			chngVarMnrtPrdt(loanObj, piamtObj, bfRmbrObj, idx);

			//2.납입일자 = 대출기본.초회납입일자의 월에 (회차-1)를 더한다.
			String bfDueDt = DateUtil.addMonth(loanObj.fcntDueDt.substring(0, 6), rmbrObj.tims - 2) + loanObj.setlDd;
			rmbrObj.dueDt = DateUtil.addMonth(loanObj.fcntDueDt.substring(0, 6), rmbrObj.tims - 1) + loanObj.setlDd;

			rmbrObj.timsDdcnt = (int)StringUtil.dateDiff(bfDueDt, rmbrObj.dueDt);
			//LOGGER.info("전회차납입일 = "+bfDueDt+" / 당회차납입일 = "+rmbrObj.dueDt+" / 회차일수 = "+rmbrObj.timsDdcnt);

			if (!DateUtil.isValid(rmbrObj.dueDt)) {
				rmbrObj.dueDt = DateUtil.lastDayOfMonth(rmbrObj.dueDt.substring(0, 6) + "01");
			}
			//2-1.이자계산일자
			if (idx == piamtObj.strtTims) {
				if (div == 2) { //중도상환

					//변경회차의 이자시작일자 조회 결제일자가 이자시작일자보다 작으면 무이자거치기간
					if (piamtObj.strtTims == chngTurn) {
						rmbrObj.intCalcDay = loanObj.chngIntStrtDt;
					}
					else {
						rmbrObj.intCalcDay = DateUtil.addMonth(rmbrObj.dueDt, -1);
					}
				}
				else {
					//2018-08-01 1회차 아닌 원리금 시작회차 상환계획 이자시작일자 수정
					if (rmbrObj.tims == piamtObj.dueStrtTims) {
						rmbrObj.intCalcDay = loanObj.loanDt;
					}
					else {
						rmbrObj.intCalcDay = DateUtil.addMonth(rmbrObj.dueDt, -1);
					}
				}
			}
			else {
				rmbrObj.intCalcDay = bfRmbrObj.dueDt;
			}

			//3.납입회차여부 = MOD(회차-시작회차+1,납입주기) - MOD(납입시작회차,납입주기)
			// 결과가 0 이면 "Y" 0이 아니면 "N"
			int yn = (rmbrObj.tims - piamtObj.strtTims + 1) % piamtObj.dueCycl - (piamtObj.dueStrtTims % piamtObj.dueCycl);
			rmbrObj.dueTimsYn = (yn != 0) ? "0" : "1";

			//4.회차전_잔여원금,잔여취급수수료
			if (rmbrObj.tims < piamtObj.strtTims) {
				//회차 < 대출원리금.시작회차 => 회차전잔여원금=0
				rmbrObj.timsBfPamtRamt = 0;
				rmbrObj.timsBfTrtFeeRamt = 0;
			}
			else if (rmbrObj.tims == piamtObj.strtTims) {
				//회차 == 대출원리금.시작회차 => 회차전잔여원금=잔여원금
				rmbrObj.timsBfPamtRamt = piamtObj.loanPamt;
				rmbrObj.timsBfTrtFeeRamt = piamtObj.trtFee;
			}
			else {
				//회차전잔여원금 = (회차-1)회차의 회차전잔여원금 - (회차-1)회차의 원금
				rmbrObj.timsBfPamtRamt = bfRmbrObj.timsBfPamtRamt - bfRmbrObj.mmPamt;
				rmbrObj.timsBfTrtFeeRamt = bfRmbrObj.timsBfTrtFeeRamt - bfRmbrObj.mmTrtFee;
			}

			//5.월 이자
			rmbrObj.mmInt = this.calcIntOfMM(loanObj, piamtObj, rmbrObj);
			//6.월 원금
			rmbrObj.mmPamt = this.calcPamtOfMM(loanObj, piamtObj, rmbrObj);
			//7.월 취급수수료
			rmbrObj.mmTrtFee = this.calcTrtFeeOfMM(loanObj, piamtObj, rmbrObj);

			//중도상환의 경우 변경회차 이자는 일할계산이자~ => 2018-08-01
			if (div == 2 && rmbrObj.tims == chngTurn) { //중도상환
				if (rmbrObj.tims == 1 || !DateUtil.addMonth(loanObj.chngIntStrtDt, 1).equals(rmbrObj.dueDt)) {
					if (leafYearFg.equals("1")) {
						rmbrObj.mmInt = this.floorValue(piamtObj.loanPamt * DateUtil.daysBetween(loanObj.chngIntStrtDt, rmbrObj.dueDt)
								* (piamtObj.intRt * 0.01) / 366);
					} else {
						rmbrObj.mmInt = this.floorValue(piamtObj.loanPamt * DateUtil.daysBetween(loanObj.chngIntStrtDt, rmbrObj.dueDt)
								* (piamtObj.intRt * 0.01) / 365);
					}
				}
			}

			//이자배분금액
			if (piamtObj.intDistAmt > 0) {
				rmbrObj.mmInt = 0;
				rmbrObj.mmPamt = 0;
			}

			//7.월불입금
			rmbrObj.mmPiamt = rmbrObj.mmPamt + rmbrObj.mmInt + rmbrObj.mmTrtFee;

			//8.회차후_잔여원금,잔여취급수수료
			rmbrObj.timsAfPamtRamt = rmbrObj.timsBfPamtRamt - rmbrObj.mmPamt;
			rmbrObj.timsAfTrtFeeRamt = rmbrObj.timsBfTrtFeeRamt - rmbrObj.mmTrtFee;

			rmbrList.add(rmbrObj);
		}
		LOGGER.info("■ rmbrList.size = "+StringUtil.size(rmbrList));

		//거치이자 할부기간 분납상품의 경우 처리 추가 2018-08-01
		if (piamtObj.intDistAmt > 0) {
			//거치 다음 우선순위의 시작회차,종료회차 를 찾는다.
			@SuppressWarnings("unchecked")
			List<LoanPiamtObj> pniList = loanObj.piamtObjList;
			int strtTims = piamtObj.term + 1;
			int endTims = loanObj.loanTerm;
			for (int i = 0; i < pniList.size(); i++) {
				LoanPiamtObj afPiamtObj = pniList.get(i);
				if (afPiamtObj.frstRank == piamtObj.frstRank + 1 && !"4".equals(afPiamtObj.rmbrFrmlCd)) {
					strtTims = afPiamtObj.strtTims;
					endTims = afPiamtObj.term + afPiamtObj.strtTims - 1;
					break;
				}
			}

			//배분이자 금액
			long mmIntDistAmt = this.floorValue(piamtObj.intDistAmt / (endTims - strtTims + 1));
			//배분이자 나머지
			long intDistRamt = piamtObj.intDistAmt - (mmIntDistAmt * (endTims - strtTims + 1));

			for (int idx = strtTims; idx <= endTims; idx++) {

				RmbrPlanObj rmbrObj = new RmbrPlanObj();
				//대출번호,대출순번
				rmbrObj.loanNo = loanObj.loanNo;
				rmbrObj.loanSeq = loanObj.loanSeq;
				//거래일련번호,우선순위
				rmbrObj.trSnum = piamtObj.trSnum;
				rmbrObj.frstRank = piamtObj.frstRank;
				rmbrObj.rmbrFrmlCd = "7";

				rmbrObj.tims = idx;

				//2.납입일자 = 대출기본.초회납입일자의 월에 (회차-1)를 더한다.
				rmbrObj.dueDt = DateUtil.addMonth(loanObj.fcntDueDt.substring(0, 6), rmbrObj.tims - 1) + loanObj.setlDd;

				//2-1.이자계산일자
				rmbrObj.intCalcDay = DateUtil.addMonth(rmbrObj.dueDt, -1);

				//4.회차전_잔여원금
				rmbrObj.timsBfPamtRamt = 0;
				//5.회차후_잔여원금
				rmbrObj.timsAfPamtRamt = 0;

				//이자배분금액(배분후나머지는 첫도래회차에 합산) 2018.01.24
				if (rmbrObj.tims == strtTims) {
					rmbrObj.mmInt = mmIntDistAmt + intDistRamt;
				}
				else {
					rmbrObj.mmInt = mmIntDistAmt;
				}
				rmbrObj.mmPiamt = rmbrObj.mmPamt + rmbrObj.mmInt;

				rmbrList.add(rmbrObj);
			}
		}

		//대출금액.할인금액합계 += 대출원리금.현가할인이자합계
		piamtObj.nprDiscIntSum = this.floorValue(piamtObj.nprDiscIntSum); //일원미만절사~
		loanObj.discSum = loanObj.discSum + piamtObj.nprDiscIntSum;

		return rmbrList;
	}



	/**
	 * <p>메소드명	: calcIntOfMM</p>
	 * <p>설　　명	: 월이자를 계산한다.</p>
	 * <p>메소드인수	: LoanBaseObj, LoanPiamtObj, RmbrPlanObj</p>
	 * <p>리　턴　값	: 월이자</p>
	 */
	public long calcIntOfMM(LoanBaseObj loanObj, LoanPiamtObj piamtObj, RmbrPlanObj rmbrObj) {
		//LOGGER.info("calcIntOfMM 시작!");
		//[WOORICARD] 윤년체크 추가 => 2018-08-01
		String leafYear = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD).toString();
		boolean isLeapYr = StringUtil.isLeapYr(leafYear);

		if (rmbrObj.tims < piamtObj.dueStrtTerm) {
			//회차 < 대출원리금.시작회차 => 이자=0
			rmbrObj.mmInt = 0;
		}
		else if (loanObj.adueFg != null && loanObj.adueFg.equals("1") && rmbrObj.tims == piamtObj.dueStrtTerm) {
			//선불여부=="Y && 회차 == 대출원리금.시작회차 => 이자=0
			rmbrObj.mmInt = 0;
		}
		else {
			//납입회차여부 = 'Y'(1) 이면
			if (rmbrObj.dueTimsYn != null && rmbrObj.dueTimsYn.equals("1") && piamtObj.intRt != 0) {
				if (rmbrObj.tims == piamtObj.endTerm && (piamtObj.rmbrFrmlCd != null && piamtObj.rmbrFrmlCd.equals("1"))) {
					/**
					 * [DOBSCAP] 두비스 : 2018-08-01
					 * 변경내역 : 원리금균등시 마지막회차의 이자처리 방식 변경
					 *          1) 상환계획상세.월이자 = 대출원리금.계산원리금 - 상환계획상세.회차전잔여원금
					 */
					rmbrObj.mmInt = piamtObj.calcPiamt - rmbrObj.timsBfPamtRamt;
					//LOGGER.info("마지막이자 ("+rmbrObj.mmInt+"): piamtObj.calcPiamt("+piamtObj.calcPiamt+") -  rmbrObj.timsBfPamtRamt("+rmbrObj.timsBfPamtRamt+")");
				}
				else if (rmbrObj.tims == piamtObj.dueStrtTims && !"1".equals(StringUtil.trim(loanObj.fcntMopaCalcFg))) {
					//회차 == 대출원리금.납입시작회차 //초회월할여부 != '1' => 이자 = 대출원리금.계산초회이자
					rmbrObj.mmInt = piamtObj.calcFcntInt;
					//납입주기가 1보다 크면... 초회이자 + (납입시작회차-1)개월의 이자
					if (piamtObj.dueCycl > 1) {
						rmbrObj.mmInt += this.floorValue(rmbrObj.timsBfPamtRamt * (piamtObj.dueStrtTims - 1) * (piamtObj.intRt * 0.01) / 12);
					}
				} else if (rmbrObj.tims == piamtObj.dueStrtTims) {
					//이자 = 회차전잔여원금 * 대출원리금.납입시작회차 * 대출원리금.이자율 / 12
					rmbrObj.mmInt = this.floorValue(rmbrObj.timsBfPamtRamt * piamtObj.dueStrtTims * (piamtObj.intRt * 0.01) / 12);
				}
				else {
					// 원리금균등 회차이자 : 월할계산
					if (rmbrObj.rmbrFrmlCd.equals("1")) {
						//이자 = 회차전잔여원금 * 대출원리금.납입주기 * 대출원리금.이자율 / 12
						rmbrObj.mmInt = this.floorValue(rmbrObj.timsBfPamtRamt * piamtObj.dueCycl * (piamtObj.intRt * 0.01) / 12);
						//LOGGER.info("월할이자 ("+rmbrObj.mmInt+"): floorValue("+new BigDecimal(rmbrObj.timsBfPamtRamt)+" * "+piamtObj.dueCycl+" * "+piamtObj.intRt+" / 12)");
					}
					// 원리금균등 제외 회차이자 : 일할계산
					else {
						//이자 = 회차전 잔여원금 * 회차일수 * 이자율 / 365
						if (isLeapYr) {
							rmbrObj.mmInt = this.floorValue(rmbrObj.timsBfPamtRamt * rmbrObj.timsDdcnt * (piamtObj.intRt * 0.01) / 366);
						} else {
							rmbrObj.mmInt = this.floorValue(rmbrObj.timsBfPamtRamt * rmbrObj.timsDdcnt * (piamtObj.intRt * 0.01) / 365);
						}
						//LOGGER.info("일할이자("+rmbrObj.timsDdcnt+")="+rmbrObj.mmInt);
					}
				}
			}
			else {
				rmbrObj.mmInt = 0;
			}
		}
		LOGGER.info(StringUtil.lpad(rmbrObj.tims, 2, "0")+"회차 이자 : " + StringUtil.numFmt(rmbrObj.mmInt,"INT") + (isLeapYr?" (윤년)":""));
		//이자 반환
		return rmbrObj.mmInt;
	}

	/**
	 * <p>메소드명	: calcPamtOfMM</p>
	 * <p>설　　명	: 월원금을 계산한다.</p>
	 * <p>메소드인수	: LoanBaseObj, LoanPiamtObj, RmbrPlanObj</p>
	 * <p>리　턴　값	: 월원금</p>
	 */
	public long calcPamtOfMM(LoanBaseObj loanObj, LoanPiamtObj piamtObj, RmbrPlanObj rmbrObj) {
		//LOGGER.info("calcPamtOfMM 시작!");
		//원금균등
		if (piamtObj.rmbrFrmlCd != null && piamtObj.rmbrFrmlCd.equals("2")) {
			if (rmbrObj.tims < piamtObj.dueStrtTerm) {
				//회차 < 대출원리금.시작회차 => 원금=0
				rmbrObj.mmPamt = 0;
			}
			else if (rmbrObj.dueTimsYn != null && rmbrObj.dueTimsYn.equals("1")) {
				//회차
				if (rmbrObj.tims == piamtObj.dueStrtTerm) {
					//if (회차 == 대출원리금.시작회차)
					//=> 원금 = 대출원리금.계산원금 + 대출원리금.계산원금나머지
					rmbrObj.mmPamt = piamtObj.calcPamt + piamtObj.calcPamtRamt;
				}
				//if (회차==대출원리금.마지막기간)
				else if (rmbrObj.tims == piamtObj.endTerm) {
					//원금 = 회차전 잔여원금
					rmbrObj.mmPamt = rmbrObj.timsBfPamtRamt;
				}
				else {
					rmbrObj.mmPamt = piamtObj.calcPamt;
				}
			}
			else {
				rmbrObj.mmPamt = 0;
			}
		}
		//원금만기
		else if (piamtObj.rmbrFrmlCd != null && piamtObj.rmbrFrmlCd.equals("3")) {
			//if (회차==대출원리금.마지막기간)
			if (rmbrObj.tims == piamtObj.endTerm && piamtObj.mtrtYn != null && piamtObj.mtrtYn.equals("1")) {
				//원금 = 대출원리금.잔여원금
				rmbrObj.mmPamt = piamtObj.loanPamt;
			}
			else {
				rmbrObj.mmPamt = 0;
			}
		}
		//원리금균등 or 주기별원리금균등
		else if (piamtObj.rmbrFrmlCd != null && piamtObj.rmbrFrmlCd.equals("1")) {
			if (rmbrObj.tims < piamtObj.dueStrtTerm) {
				//회차 < 대출원리금.시작회차 => 원금=0
				rmbrObj.mmPamt = 0;
			}
			else if (piamtObj.intRt == 0 && rmbrObj.dueTimsYn != null && rmbrObj.dueTimsYn.equals("1")) {
				//이자율이 0인 경우 원금균등과 동일하게 처리
				if (rmbrObj.tims == piamtObj.dueStrtTerm) {
					//if (회차 == 대출원리금.시작회차)
					//원금 = 대출원리금.계산원금 + 대출원리금.계산원금나머지
					rmbrObj.mmPamt = piamtObj.calcPamt + piamtObj.calcPamtRamt;
				}
				//if (회차==대출원리금.마지막기간)
				else if (rmbrObj.tims == piamtObj.endTerm) {
					//원금 = 회차전 잔여원금
					rmbrObj.mmPamt = rmbrObj.timsBfPamtRamt;
				}
				else {
					rmbrObj.mmPamt = piamtObj.calcPamt;
				}
			}
			else if (loanObj.adueFg != null && loanObj.adueFg.equals("1") && rmbrObj.tims == piamtObj.dueStrtTerm) {
				//월원금 = 계산원리금 - 월이자
				rmbrObj.mmPamt = piamtObj.calcPiamt - rmbrObj.mmInt;
			}
			else if (rmbrObj.dueTimsYn != null && rmbrObj.dueTimsYn.equals("1")) {
				//if (회차==대출원리금.마지막기간)
				if (rmbrObj.tims == piamtObj.endTerm) {
					//원금 = 회차전 잔여원금
					rmbrObj.mmPamt = rmbrObj.timsBfPamtRamt;
				}
				else if (rmbrObj.tims == piamtObj.dueStrtTims && (loanObj.fcntMopaCalcFg == null || !loanObj.fcntMopaCalcFg.equals("1"))) {
					//초회차인경우 원금 = 대출원리금.계산원리금-원단위단수(회차전잔여원금*이자율/12)
					rmbrObj.mmPamt = piamtObj.calcPiamt - this.floorValue(rmbrObj.timsBfPamtRamt * (piamtObj.intRt * 0.01) / 12);
				}
				else {
					//원금 = 계산원리금 - 이자
					rmbrObj.mmPamt = piamtObj.calcPiamt - rmbrObj.mmInt;
				}
			}
			else {
				rmbrObj.mmPamt = 0;
			}
		}
		//원금반환~
		return rmbrObj.mmPamt;
	}

	/**
	 * <p>메소드명	: calcTrtFeeOfMM</p>
	 * <p>설　　명	: 월취급수수료를 계산한다.</p>
	 * <p>메소드인수	: LoanBaseObj, LoanPiamtObj, RmbrPlanObj</p>
	 * <p>리　턴　값	: long - 계산된 월원금</p>
	 */
	public long calcTrtFeeOfMM(LoanBaseObj loanObj, LoanPiamtObj piamtObj, RmbrPlanObj rmbrObj) {
		if (piamtObj.trtFee == 0) {
			return 0;
		}
		if (rmbrObj.tims < piamtObj.dueStrtTerm) {
			//회차 < 대출원리금.시작회차 => 취급수수료=0
			rmbrObj.mmTrtFee = 0;
		}
		else if (rmbrObj.dueTimsYn != null && rmbrObj.dueTimsYn.equals("1")) {
			//회차
			if (rmbrObj.tims == piamtObj.dueStrtTerm) {
			//if (회차 == 대출원리금.시작회차)
				rmbrObj.mmTrtFee = piamtObj.calcMmTrtFee + piamtObj.calcTrtFeeRamt;
			}
			else {
				rmbrObj.mmTrtFee = piamtObj.calcMmTrtFee;
			}
		}
		else {
			rmbrObj.mmTrtFee = 0;
		}
		return rmbrObj.mmTrtFee;
	}

	/**
	 * <p>메소드명	: validCheck</p>
	 * <p>설　　명	: 대출기본 객체의 Validation 체크</p>
	 * <p>메소드인수	: List(LoanBaseObj)</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	private void validCheck(List<LoanBaseObj> loanList) throws Exception {
		//LOGGER.debug("validCheck 시작!");
		int size1 = loanList.size();
		for (int i = 0; i < size1; i++) {
			LoanBaseObj loanObj = loanList.get(i);

			//2.대출원금
			if (loanObj.loanPamt < 0) {
				throw new Exception("(상환계획생성-" + loanObj.loanNo + ") 대출원금이 0 보다 작습니다.");
			}
			//3.기간
			if (loanObj.loanTerm <= 0) {
				throw new Exception("(상환계획생성-" + loanObj.loanNo + ") 대출기간이 0 보다 작습니다.");
			}
			//5.대출일자=이자계산일자
			if (loanObj.loanDt == null || loanObj.loanDt.equals("")) {
				throw new Exception("(상환계획생성-" + loanObj.loanNo + ") 대출일자(이자시작일자)를 찾을 수 없습니다.");
			}
			//6.초회납입일자
			if (loanObj.fcntDueDt == null || loanObj.fcntDueDt.equals("")) {
				throw new Exception("(상환계획생성-" + loanObj.loanNo + ") 초회납입일자를 찾을 수 없습니다.");
			}
			//8.초회월할여부 체크
			if (loanObj.fcntMopaCalcFg == null || loanObj.fcntMopaCalcFg.equals("")) {
				throw new Exception("(상환계획생성-" + loanObj.loanNo + ") 초회월할계산여부 를 찾을 수 없습니다.");
			}
		}
	}

	/**
	 * <p>메소드명	: oddRoundThree</p>
	 * <p>설　　명	: 실수값을 입력받아 소수 3째자리에서 반올림한 값을 리턴한다.</p>
	 * <p>메소드인수	: double - 실수값</p>
	 * <p>리　턴　값	: 소수 3째자리에서 반올림한 값</p>
	 */
	@SuppressWarnings("deprecation")
	public double oddRoundThree(double value) {
		BigDecimal result = new BigDecimal(value);
		return result.setScale(2, BigDecimal.ROUND_UP).doubleValue();
	}
	/**
	 * <p>메소드명	: oddFloorHundred</p>
	 * <p>설　　명	: 100원단위 절사한 값을 리턴한다.</p>
	 * <p>메소드인수	: double value - 실수값</p>
	 * <p>리　턴　값	: 100원단위 절사한 값</p>
	 */
	@SuppressWarnings("deprecation")
	public long oddFloorHundred(double value) {
		BigDecimal result = new BigDecimal(value);
		return result.multiply(new BigDecimal(0.01)).setScale(0, BigDecimal.ROUND_FLOOR).multiply(new BigDecimal(100)).longValue();
	}

	public long floorValue(double value) {
		if (value >= 0) {
			return (long) Math.floor(value);
		} else {
			return (long) Math.ceil(value);
		}
	}
	public long roundValue(double value) {
		if (value >= 0) {
			return Math.round(value);
		} else {
			return (long) Math.ceil(value);
		}
	}

	/**
	 * <p>메소드명	: rmbrPlanDescCrte</p>
	 * <p>설　　명	: 상환계획내역 저장</p>
	 * <p>메소드인수	: List(LoanBaseObj), Connection</p>
	 * <p>리　턴　값	: cnt</p>
	 */
	public int rmbrPlanDescCrte(List<LoanBaseObj> loanObjList) throws Exception {

		int rowCnt = 0;
		try {
			//상환계획내역 삭제
			RmbrPlanCrteCCInVODTO descDelInvo = new RmbrPlanCrteCCInVODTO();
//			pstmt1 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanDescDel());
			//상환계획이력 삭제
			RmbrPlanCrteCCInVODTO histDelInvo = new RmbrPlanCrteCCInVODTO();
//			pstmt2 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanHistDel());
			//상환계획내역 등록
			RmbrPlanCrteCCInVODTO descCrteInvo = new RmbrPlanCrteCCInVODTO();
//			pstmt3 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanDescCrte());
			//상환계획이력 등록
			RmbrPlanCrteCCInVODTO histCrteInvo = new RmbrPlanCrteCCInVODTO();
//			pstmt4 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanHistCrte());
			//상환계획내역 삭제(주택,부동산)
//			RmbrPlanCrteCCInVODTO descDelInvo2 = new RmbrPlanCrteCCInVODTO();
//			pstmt5 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanDescDel2());
			//상환계획이력 삭제(주택,부동산)
//			RmbrPlanCrteCCInVODTO histDelInvo2 = new RmbrPlanCrteCCInVODTO();
//			pstmt6 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanHistDel2());

			String yyyymmdd = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);	//시스템일자
			String hhmmss = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);		//시스템시간

			int size1 = loanObjList.size();
			for (int i = 0; i < size1; i++) {
				LoanBaseObj loanObj = loanObjList.get(i);

				//시뮬레이션일 경우 저장처리 없이 리턴~
				if ("2".equals(loanObj.rmbrPlanTypeDivCd)) {
					return 0;
				}

				//이전 상환계획내역,이력 삭제(주택,부동산 제외)*******************
				//if (!"10".equals(loanObj.prdtMidClasCd) && !"11".equals(loanObj.prdtMidClasCd)) {
				descDelInvo.setLoanNo(loanObj.loanNo);
				descDelInvo.setLoanSeq(loanObj.loanSeq);
				//1.상환계획내역 삭제 실행
				try {
					rmbrPlanCrteMapper.rmbrPlanDescDel(descDelInvo);
				} catch (Exception e) {
					e.printStackTrace();
					//LOGGER.debug("상환계획내역 삭제 데이터 없음");
				}

				//이전 상환계획이력 삭제*********************************
				if ("1".equals(loanObj.histCreateFg)) {
					histDelInvo.setLoanNo(loanObj.loanNo);
					histDelInvo.setLoanSeq(loanObj.loanSeq);
					//2.상환계획이력 삭제~
					try {
						rmbrPlanCrteMapper.rmbrPlanHistDel(histDelInvo);
					} catch (Exception e) {
						e.printStackTrace();
						//LOGGER.debug("상환계획이력 삭제 데이터 없음");
					}
				}
				//}

				int size2 = loanObj.piamtObjList.size();

				for (int j = 0; j < size2; j++) {
					LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(j);

					/*//이전 상환계획내역 삭제(주택,부동산)*******************
					if ("10".equals(loanObj.prdtMidClasCd) || "11".equals(loanObj.prdtMidClasCd)) {
						pstmt5.setString(1, loanObj.loanNo);
						pstmt5.setString(2, loanObj.loanSeq);
						pstmt5.setInt(3, piamtObj.trSnum);
						pstmt5.setInt(4, piamtObj.frstRank);
						pstmt5.addBatch();

						//이전 상환계획이력 삭제*****************************
						if ("1".equals(loanObj.histCreateFg) && j == 0) {
							pstmt6.setString(1, loanObj.loanNo);
							pstmt6.setString(2, loanObj.loanSeq);
							pstmt6.setInt(3, piamtObj.trSnum);
							pstmt6.addBatch();
						}
					}

					//4.상환계획내역 삭제(주택,부동산)
					try {
						pstmt5.executeBatch();
					} catch (BatchUpdateException bue) {
						//LOGGER.debug("상환계획내역 삭제 데이터 없음");
					}

					try {
						//5.상환계획이력 삭제(주택,부동산)
						pstmt6.executeBatch();
					} catch (BatchUpdateException bue) {
						//LOGGER.debug("상환계획이력 삭제 데이터 없음");
					}
					 */
					int size3 = piamtObj.rmbrObjList.size();

					//전체 이자합계
					long totIntSum = 0;

					for (int k = 0; k < size3; k++) {
						RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);
						//전체이자합계를 먼저 구한다~
						totIntSum += rmbrObj.mmInt;
					}

					for (int k = 0; k < size3; k++) {
						RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);
						descCrteInvo = new RmbrPlanCrteCCInVODTO();
						descCrteInvo.setLoanNo(rmbrObj.loanNo);																//대출번호
						descCrteInvo.setLoanSeq(rmbrObj.loanSeq);															//대출순번
						descCrteInvo.setTrSnum(rmbrObj.trSnum);																//거래일련번호
						descCrteInvo.setFrstRank(rmbrObj.frstRank);															//우선순위
						descCrteInvo.setTims(rmbrObj.tims);																	//회차
						descCrteInvo.setDueDt(rmbrObj.dueDt);																//납입일자
						descCrteInvo.setRmbrFrmlCd(rmbrObj.rmbrFrmlCd);														//상환방식코드
						descCrteInvo.setCrteDivCd(piamtObj.crteDivCd);														//생성구분코드
						descCrteInvo.setMmPamt(rmbrObj.mmPamt);																//월원금
						descCrteInvo.setMmInt(rmbrObj.mmInt);																//월이자
						descCrteInvo.setMmPiamt(rmbrObj.mmPiamt);															//월원리금
						descCrteInvo.setTimsBfPamtRamt(rmbrObj.timsBfPamtRamt);												//회차전잔여원금
						descCrteInvo.setTimsAfPamtRamt(rmbrObj.timsAfPamtRamt);												//회차후잔여원금
						//회차전 잔여이자 = 전체이자합계 - 전회차이자
						descCrteInvo.setTimsBfIntRamt(totIntSum);															//회차전잔여이자
						//회차후 잔여이자 = 전체이자합계 - 당회차이자합계 
						totIntSum = totIntSum - rmbrObj.mmInt;
						descCrteInvo.setTimsAfIntRamt(totIntSum);															//회차후잔여이자
						descCrteInvo.setPsgInt(0);																			//경과이자
						descCrteInvo.setPdueFg(StringUtil.trim(rmbrObj.pdueFg).equals("") ? "0" : StringUtil.trim(rmbrObj.pdueFg));	//선납여부
						descCrteInvo.setIntRt(rmbrObj.intRt);																//이자율
						descCrteInvo.setIntCalcStartDay(rmbrObj.intCalcDay);							//이자시작일자
						descCrteInvo.setIntCalcEndDay(rmbrObj.dueDt);								//이자종료일자
						descCrteInvo.setMmTrtFee(rmbrObj.mmTrtFee);															//월취급수수료
						descCrteInvo.setTimsBfTrtFeeRamt(rmbrObj.timsBfTrtFeeRamt);											//회차전잔여취급수수료
						descCrteInvo.setTimsAfTrtFeeRamt(rmbrObj.timsAfTrtFeeRamt);											//회차후잔여취급수수료
						descCrteInvo.setFrstRegDt(yyyymmdd);											//최초등록일자
						descCrteInvo.setFrstRegTm(hhmmss);																	//최초등록시간
						descCrteInvo.setFrstRegEmpNo(StringUtil.trim(loanObj.empNo));											//최초등록자사번
						descCrteInvo.setLastProcDt(yyyymmdd);										//최종처리일자
						descCrteInvo.setLastProcTm(hhmmss);																	//최종처리시간
						descCrteInvo.setLastProcEmpNo(StringUtil.trim(loanObj.empNo));											//최종처리자사번

//						pstmt3.setString(1, rmbrObj.loanNo); //대출번호
//						pstmt3.setString(2, rmbrObj.loanSeq); //대출순번
//						pstmt3.setInt(3, rmbrObj.trSnum); //거래일련번호
//						pstmt3.setInt(4, rmbrObj.frstRank); //우선순위
//						pstmt3.setInt(5, rmbrObj.tims); //회차
//						pstmt3.setString(6, rmbrObj.dueDt)); //납입일자
//						pstmt3.setString(7, Util.trimToStr(rmbrObj.rmbrFrmlCd)); //상환방식코드
//						pstmt3.setString(8, Util.trimToStr(piamtObj.crteDivCd)); //생성구분코드
//						pstmt3.setDouble(9, rmbrObj.mmPamt); //월원금
//						pstmt3.setDouble(10, rmbrObj.mmInt); //월이자
//						pstmt3.setDouble(11, rmbrObj.mmPiamt); //월원리금
//						pstmt3.setDouble(12, rmbrObj.timsBfPamtRamt); //회차전잔여원금
//						pstmt3.setDouble(13, rmbrObj.timsAfPamtRamt); //회차후잔여원금
//						//회차전 잔여이자 = 전체이자합계 - 전회차이자
//						pstmt3.setDouble(14, totIntSum);
//						//회차후 잔여이자 = 전체이자합계 - 당회차이자합계
//						totIntSum = totIntSum - rmbrObj.mmInt;
//						pstmt3.setDouble(15, totIntSum);
//						pstmt3.setDouble(16, 0); //경과이자
//						pstmt3.setString(17, Util.trimToStr(rmbrObj.pdueFg).equals("") ? "0" : Util.trimToStr(rmbrObj.pdueFg)); //선납여부
//						pstmt3.setDouble(18, piamtObj.intRt); //이자율
//						pstmt3.setString(19, rmbrObj.intCalcDay)); //이자시작일자
//						pstmt3.setString(20, rmbrObj.dueDt)); //이자종료일자
//						//2018-08-01
//						pstmt3.setDouble(21, rmbrObj.mmTrtFee); //월취급수수료
//						pstmt3.setDouble(22, rmbrObj.timsBfTrtFeeRamt); //회차전잔여취급수수료
//						pstmt3.setDouble(23, rmbrObj.timsAfTrtFeeRamt); //회차후잔여취급수수료
//
//						pstmt3.setString(24, yyyymmdd)); //최초등록일자
//						pstmt3.setString(25, hhmmss); //최초등록시간
//						pstmt3.setString(26, Util.trimToStr(loanObj.empNo)); //최초등록자사번
//						pstmt3.setString(27, yyyymmdd)); //최종처리일자
//						pstmt3.setString(28, hhmmss); //최종처리시간
//						pstmt3.setString(29, Util.trimToStr(loanObj.empNo)); //최종처리자사번
//
//						pstmt3.addBatch(); //상환계획내역
						rowCnt++;

						//4.상환계획내역 저장
						try {
							rmbrPlanCrteMapper.rmbrPlanDescCrte(descCrteInvo);
						} catch (Exception e) {
							e.printStackTrace();
							//LOGGER.debug("상환계획내역 저장 데이터 없음");
						}
					}
				}

				//상환계획 이력 저장**************************
				if ("1".equals(loanObj.histCreateFg)) {
					histCrteInvo.setLoanNo(loanObj.loanNo);
					histCrteInvo.setLoanSeq(loanObj.loanSeq);
					try {
						//5.상환계획이력 저장
						rmbrPlanCrteMapper.rmbrPlanHistCrte(histCrteInvo);
					} catch (Exception e) {
						e.printStackTrace();
						//LOGGER.debug("상환계획이력 저장 데이터 없음");
					}
				}
				//******************************************
			}
		}
		catch (Exception se) {
			se.printStackTrace();
			LOGGER.error(se.getMessage());
			throw new Exception("(상환계획생성)상환계획 저장중 오류발생! : " + se.getMessage());
		}
		return rowCnt;
	}


	/**
	 * <p>메소드명	: updateLoan</p>
	 * <p>설　　명	: 생성된 상환생성내역으로 대출기본 갱신</p>
	 * <p>메소드인수	: List loanList - 대출기본 리스트 객체</p>
	 * <p>메소드인수2	: Connection con - Connection 객체</p>
	 * <p>메소드리턴값      : N/A</p>
	 */
	@Override
	public void updateLoan(LoanBaseObj loanObj) throws Exception {
		@SuppressWarnings({ "unchecked", "rawtypes" })
		List<LoanBaseObj> loanList = new ArrayList();
		loanList.add(loanObj);
		updateLoan(loanList);
	}

	public void updateLoan(List<LoanBaseObj> loanList) throws Exception {

		try {

			String nowDate = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
			String nowTime = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);

			int baseSize = loanList.size();
			for (int i = 0; i < baseSize; i++) {
				LoanBaseObj loanObj = loanList.get(i);

				//대출이자 총액,초회불입금,총회차
				long loanIntSum = 0;
				int totTims = 0;

				int piAmtSize = loanObj.piamtObjList.size();
				for (int j = 0; j < piAmtSize; j++) {
					LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(j);
					//대출이자,월불입금
					long loanInt = 0;
					int rmbrSize = piamtObj.rmbrObjList.size();
					for (int k = 0; k < rmbrSize; k++) {
						RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(k);
						loanInt += rmbrObj.mmInt;

						//총회차=> MAX 회차
						if (rmbrObj.tims > totTims) {
							totTims = rmbrObj.tims;
						}
					}
					//대출이자 총액
					loanIntSum += loanInt;
				}

				RmbrPlanCrteCCInVODTO updateDTO = new RmbrPlanCrteCCInVODTO();

				updateDTO.setLoanInt(loanIntSum);
				updateDTO.setLoanIntRamt(loanIntSum);
				updateDTO.setTotTims(totTims);
				updateDTO.setEprtDt(loanObj.eprtDt);
				updateDTO.setIntnPrftRt(loanObj.intnPrftRt);
				updateDTO.setFactIntRt(loanObj.factIntRt);
				updateDTO.setLastProcDt(nowDate);
				updateDTO.setLastProcTm(nowTime);
				updateDTO.setLastProcEmpNo(StringUtil.trim(loanObj.empNo));
				updateDTO.setLoanNo(loanObj.loanNo);
				updateDTO.setLoanSeq(loanObj.loanSeq);

				rmbrPlanCrteMapper.loanBaseUpdt1(updateDTO);


			}
		}
		catch (Exception se) {
			se.printStackTrace();
			throw new Exception("(상환계획생성)대출기본 수정 중 오류 : " + se.getMessage());
		}
	}

	/**
	 * <p>메소드명	: callIntnPrftRt</p>
	 * <p>설　　명	: 내부수익률 계산 모듈을 호출한다.</p>
	 * <p>메소드인수	: List(LoanBaseObj)</p>
	 * <p>리　턴　값	: N/A</p>
	 */
	public List<LoanBaseObj> callIntnPrftRt(List<LoanBaseObj> loanObjList) throws Exception {
		int size = loanObjList.size();

    	for (int i = 0; i < size; i++) {
            LoanBaseObj loanObj = loanObjList.get(i);
            loanObj = this.callIntnPrftRt(loanObj);

            loanObjList.set(i, loanObj);
        }

    	return loanObjList;
    }

    @SuppressWarnings("deprecation")
	public LoanBaseObj callIntnPrftRt(LoanBaseObj loanObj) throws Exception {
    	//LOGGER.debug("calcIntnPrftRt 시작!");

        // 1.객체 SET
        IntnPrftRtObj intnPrftObj = new IntnPrftRtObj();
        //내부수익률.거치여부 = 대출기본.거치여부
        //intnPrftObj.deferFg = loanObj.deferFg;
        //내부수익률.기간 = 대출기본.기간

        intnPrftObj.term = new BigDecimal(loanObj.loanTerm);
        //내부수익율.납입주기 = 1
        intnPrftObj.dueCycl = new BigDecimal(1);
        //내부수익율.반복횟수 = 2000
        intnPrftObj.repeatCnt = new BigDecimal(2000);
        //내부수익율.최초내부수익율 = 0.1
        intnPrftObj.frstIntnPrftRt = new BigDecimal(0.1);
        // 내부수익율.허용오차 = 0.000001
        intnPrftObj.allowErr = new BigDecimal(0.000001);

        //회차별 합계
        BigDecimal[] mmDueAmt = new BigDecimal[intnPrftObj.term.intValue()]; //월원금+월이자

        @SuppressWarnings("unchecked")
		List<LoanPiamtObj> piamtList = loanObj.piamtObjList;

        int size = piamtList.size();
        for (int i = 0; i < size; i++) {
        	LoanPiamtObj piamtObj = piamtList.get(i);

        	int size2 = piamtObj.rmbrObjList.size();
        	for (int j = 0; j < size2; j++) {
        		RmbrPlanObj rmbrObj = (RmbrPlanObj) piamtObj.rmbrObjList.get(j);
        		int idx = rmbrObj.tims - 1;

        		if (mmDueAmt[idx] == null) {
        			mmDueAmt[idx] = new BigDecimal(0);
        		}

				//초회일할계산의 경우 초회차 이자는 월할로 적용=>2018-08-01 필드운영(백팀장님)요청
				if (!"1".equals(loanObj.fcntMopaCalcFg) && rmbrObj.tims == piamtObj.dueStrtTims && rmbrObj.mmInt != 0) {
					//long mmInt = floorValue(rmbrObj.timsBfPamtRamt * piamtObj.dueStrtTims * (piamtObj.intRt * 0.01) / 12);
					//mmDueAmt[idx] = mmDueAmt[idx].add(new BigDecimal(rmbrObj.mmPamt + mmInt + rmbrObj.mmTrtFee));

					mmDueAmt[idx] = mmDueAmt[idx].add(new BigDecimal(rmbrObj.mmPamt + rmbrObj.mmInt + rmbrObj.mmTrtFee));
				} else {
					mmDueAmt[idx] = mmDueAmt[idx].add(new BigDecimal(rmbrObj.mmPamt + rmbrObj.mmInt + rmbrObj.mmTrtFee));
				}
        	}
        }
        //내부수익율.월불입금 = 상환계획.월원금 + 상환계획.월이자
        intnPrftObj.mmDueAmt = mmDueAmt;
        //intnPrftObj.adueFg = loanObj.adueFg;
        //실제이자율 계산
        //초기유출금액 (대출기본.대출원금-취급수수료고객)
        double frstLoanPrin = loanObj.loanPamt - loanObj.custTrtFee;
        //실제이자율.초기유출금액 = 초기유출금액
        intnPrftObj.frstOutAmt = new BigDecimal(frstLoanPrin);
        //실제이자율 계산
        intnPrftObj = calcIntnPrftRt(intnPrftObj);
        loanObj.factIntRt = intnPrftObj.intnPrftRt.setScale(4, BigDecimal.ROUND_FLOOR).doubleValue() * 100;

        //초기유출금액 (대출기본.대출원금-취급수수료고객-취급수수료제휴사-보전수수료+판촉수수료-지급수수료-설정료-인지대_회사부담)
        //frstLoanPrin = loanObj.loanPamt - loanObj.custTrtFee - loanObj.cprtComTrtFee - loanObj.cprtFee + loanObj.prFee - loanObj.frstStndPrFee - loanObj.setFee - loanObj.comStmpFee;

		//렌터카공제조합 수정 2018-08-01
		frstLoanPrin = loanObj.loanPamt - loanObj.custTrtFee
				- loanObj.cprtComTrtFee - loanObj.cprtFee
				+ loanObj.prFee - loanObj.frstStndPrFee + loanObj.setFee + loanObj.comStmpFee
				+ loanObj.bsnAgntFeePay + loanObj.salePayAmt;

		//내부수익율.초기유출금액 = 초기유출금액
		intnPrftObj.frstOutAmt = new BigDecimal(frstLoanPrin);
		//내부수익율 계산
		intnPrftObj = calcIntnPrftRt(intnPrftObj);
		loanObj.intnPrftRt = intnPrftObj.intnPrftRt.setScale(4, BigDecimal.ROUND_FLOOR).doubleValue() * 100;
//		LOGGER.debug("<<<<>>>>실제이자율 : " + loanObj.factIntRt);
//		LOGGER.debug("<<<<>>>>내부수익율 : " + loanObj.intnPrftRt);
//		LOGGER.debug("loanObj.loanPamt       :"+     loanObj.loanPamt        );
//		LOGGER.debug("loanObj.custTrtFee     :"+     loanObj.custTrtFee      );
//		LOGGER.debug("loanObj.cprtComTrtFee  :"+     loanObj.cprtComTrtFee   );
//		LOGGER.debug("loanObj.cprtFee        :"+     loanObj.cprtFee         );
//		LOGGER.debug("loanObj.prFee          :"+     loanObj.prFee           );
//		LOGGER.debug("loanObj.frstStndPrFee  :"+     loanObj.frstStndPrFee   );
//		LOGGER.debug("loanObj.setFee         :"+     loanObj.setFee          );
//		LOGGER.debug("loanObj.comStmpFee     :"+     loanObj.comStmpFee      );
//		LOGGER.debug("loanObj.bsnAgntFeePay  :"+     loanObj.bsnAgntFeePay   );

		return loanObj;
	}

	/**
	 * <p>메소드명	: calcIntnPrftRt</p>
	 * <p>설　　명	: 내부수익율 을 계산한다.</p>
	 * <p>메소드인수	: IntnPrftRtObj intnPrftObj - 내부수익율 객체</p>
	 * <p>리　턴　값	: 내부수익율이 계산된 내부수익율 객체</p>
	 */
	@SuppressWarnings("deprecation")
	public IntnPrftRtObj calcIntnPrftRt(IntnPrftRtObj intnPrftObj) {
		//LOGGER.info("calcIntnPrftRt 시작!");
		/*내부수익률(internal rate of return; IRR)은 특정자산으로부터 미래에 얻게 될
		현금유입의 현재가치와 그 자산에 대한 투자원금(현금유출의 현재가치)을 일치시켜 주는 할인율 */

//		LOGGER.debug("//초기유출금액   : " + intnPrftObj.frstOutAmt);
//		LOGGER.debug("//잔존가치금액   : " + intnPrftObj.salgValAmt);
//		LOGGER.debug("//보증금         : " + intnPrftObj.guarAmt);
//		LOGGER.debug("//월불입금       : " + intnPrftObj.mmPayAmt);
//		LOGGER.debug("//선납여부       : " + intnPrftObj.ppayYn);
//		LOGGER.debug("//선불여부       : " + intnPrftObj.apayYn);
//		LOGGER.debug("//거치여부       : " + intnPrftObj.deferYn);
//		LOGGER.debug("//기간           : " + intnPrftObj.trm);
//		LOGGER.debug("//납입주기       : " + intnPrftObj.payCycl);
//		LOGGER.debug("//반복횟수       : " + intnPrftObj.repeatCnt);
//		LOGGER.debug("//최초내부수익률 : " + intnPrftObj.frstIntnPrftRt);
//		LOGGER.debug("//허용오차       : " + intnPrftObj.allowErr);
//		LOGGER.debug("//내부수익률     : " + intnPrftObj.insPrftRt);

		BigDecimal plusOne = new BigDecimal(1);
		BigDecimal minusOne = new BigDecimal( -1);

		//LOGGER.debug("calcIntnPrftRt 반복 계산 시작! >>> "+intnPrftObj.trm.intValue());
		//3)반복횟수만큼 LOOP 초기유출금액 초기유입금액 계산
		for (int i = 0; i < intnPrftObj.repeatCnt.intValue(); i++) {
		//for (int k = 0; k < 2; k++) {
			//유출, 유입 선언
			BigDecimal OutAmt = new BigDecimal(0); //유출
			BigDecimal inAmt = new BigDecimal(0); //유입

			//유출=(-1*초기유출금액)*(1+최초내부수익율)^기간
			OutAmt = intnPrftObj.frstOutAmt.multiply(minusOne)
					.multiply(new BigDecimal(Math.pow(intnPrftObj.frstIntnPrftRt.add(plusOne).doubleValue()
												, intnPrftObj.term.doubleValue())))
					.setScale(100, BigDecimal.ROUND_FLOOR);

			//유입=기간*(-1*초기유출금액)*(1+최초내부수익율)^(기간-1)
			inAmt = intnPrftObj.term.multiply(intnPrftObj.frstOutAmt.multiply(minusOne))
					.multiply(new BigDecimal(Math.pow(intnPrftObj.frstIntnPrftRt.add(plusOne).doubleValue()
												, intnPrftObj.term.subtract(plusOne).doubleValue())))
					.setScale(100, BigDecimal.ROUND_FLOOR);

			//4)반복횟수에 대하여 기간만큼 LOOP 실행 내부수익률 계산
			for (int j = 0; j < intnPrftObj.term.intValue(); j++) {
				//회차
				int turn = j + 1;
				/*
				if ("1".equals(intnPrftObj.adueFg)) {
					turn = j;
				}*/

				//계산월불입금
				BigDecimal calcPayAmt = new BigDecimal(0);
				if (intnPrftObj.mmDueAmt[j] != null) {
					calcPayAmt = intnPrftObj.mmDueAmt[j];
				}
				//유출=유출+월불입금*(1+최초내부수익율)^(기간-회차)
				OutAmt = OutAmt.add(
						calcPayAmt
						.multiply(new BigDecimal(Math.pow((intnPrftObj.frstIntnPrftRt.add(plusOne)).doubleValue()
														, intnPrftObj.term.subtract(new BigDecimal(turn)).doubleValue()))))
						.setScale(100, BigDecimal.ROUND_FLOOR);

				//if (기간-(회차+1)) > 0
				if ((intnPrftObj.term.intValue() - (turn + 1)) > 0) {
					//유입=유입+(기간-회차) * 월불입금 * (1+최초내부수익율)^(기간-(회차+1))
					inAmt = inAmt.add(
							intnPrftObj.term.subtract(new BigDecimal(turn))
							.multiply(calcPayAmt)
							.multiply(new BigDecimal(Math.pow((intnPrftObj.frstIntnPrftRt.add(plusOne)).doubleValue()
														, intnPrftObj.term.subtract(new BigDecimal(turn + 1)).doubleValue()))))
							.setScale(100, BigDecimal.ROUND_FLOOR);
				}

				//System.out.println("계산월불입금 : "+calcPayAmt);
				//System.out.println("유출 : " + OutAmt);
				//System.out.println("유입 : " + inAmt);
			}
			//내부수익률 계산(BigDecimal 형 나누기 인수 => 소수 10째짜리까지 계산)
			//계산내부수익율 = 최초내부수익율 - 유출/유입
			BigDecimal calPrftRt = intnPrftObj.frstIntnPrftRt
					.subtract(OutAmt.divide(inAmt, 10, BigDecimal.ROUND_FLOOR))
					.setScale(100, BigDecimal.ROUND_FLOOR);
			//System.out.println("최초내부수익율 : " + intnPrftObj.frstIntnPrftRt);

			//if (절대값((내부수익률-최초내부수익률)/최초내부수익율)<허용오차)
			//=> 내부수익율 = 내부수익율*(12/납입주기)
			double abs = (calPrftRt.subtract(intnPrftObj.frstIntnPrftRt))
					.divide(intnPrftObj.frstIntnPrftRt, 20, BigDecimal.ROUND_FLOOR).abs().doubleValue();

			////System.out.println("절대값 : " + (long) abs);
			if (abs < intnPrftObj.allowErr.doubleValue()) {
				intnPrftObj.intnPrftRt = calPrftRt.multiply(new BigDecimal(12).divide(intnPrftObj.dueCycl, 2, BigDecimal.ROUND_HALF_UP));
				//LOGGER.debug("반복횟수 : " + (k + 1));
				break;
			}
			//최초내부수익율 = 계산된 내부수익율
			intnPrftObj.frstIntnPrftRt = calPrftRt;
		}
		//intnPrftObj.insPrftRt = intnPrftObj.insPrftRt.setScale(4, BigDecimal.ROUND_FLOOR);

		//long endTime = System.currentTimeMillis();
		//LOGGER.debug("calcIntnPrftRt 반복 계산 종료! >>> " + (endTime - start));
		return intnPrftObj;
	}

	//실제 DB의 데이터를 조회하여 내부수익률을 계산한다.
	//[hanalife] 2023-04-05 사용안함
//	public static double callIntnPrftRtDB(String loanNo, String loanSeq, String userEmpNo) throws Exception {
//		return callIntnPrftRtDB(loanNo, loanSeq, 0, userEmpNo);
//	}
//
//	public static double callIntnPrftRtDB(String loanNo, String loanSeq, double frstLoanPrin, String userEmpNo) throws Exception {
//		double[] intnPrftRt = callFactIntRtDB(loanNo, loanSeq, frstLoanPrin, userEmpNo);
//		return intnPrftRt[0];
//	}
//
//	public static double[] callFactIntRtDB(String loanNo, String loanSeq, String userEmpNo) throws Exception {
//		return callFactIntRtDB(loanNo, loanSeq, 0, userEmpNo);
//	}
//
//	public static double[] callFactIntRtDB(String loanNo, String loanSeq, double frstLoanPrin, String userEmpNo) throws Exception {
//		//LOGGER.debug("calcIntnPrftRt 시작!");
//		ResultSet rs1 = null;
//		ResultSet rs2 = null;
//		PreparedStatement pstmt1 = null;
//		PreparedStatement pstmt2 = null;
//
//		//1.객체 SET
//		IntnPrftRtObj intnPrftObj = new IntnPrftRtObj();
//		double[] intnPrftRt = new double[2];
//		double factFrstLoanPrin = 0;
//
//		try {
//			//대출기본 조회(대출기간, 초기유출금액)
//			pstmt1 = con.prepareStatement(RmbrPlanCrteQuery.loanBaseRead());
//				pstmt1.setString(1, loanNo);
//				pstmt1.setString(2, loanSeq);
//			rs1 = pstmt1.executeQuery();
//			if (rs1.next()) {
//				//내부수익률.기간 = 대출기본.기간
//				intnPrftObj.term = new BigDecimal(rs1.getInt(1));
//				//내부수익율.납입주기 = 1
//				intnPrftObj.dueCycl = new BigDecimal(1);
//				//내부수익율.반복횟수 = 2000
//				intnPrftObj.repeatCnt = new BigDecimal(2000);
//				//내부수익율.최초내부수익율 = 0.1
//				intnPrftObj.frstIntnPrftRt = new BigDecimal(0.1);
//				//내부수익율.허용오차 = 0.000001
//				intnPrftObj.allowErr = new BigDecimal(0.000001);
//
//				//초기유출금액 (대출기본.대출원금-취급수수료고객-취급수수료제휴사-보전수수료+판촉수수료)
//				if (frstLoanPrin == 0) {
//					frstLoanPrin = rs1.getDouble(2);
//					factFrstLoanPrin = rs1.getDouble(3);
//				}
//			}
//			else {
//				return new double[] {0, 0};
//			}
//
//			//상환계획 내역(회차별 합계) 조회
//			List mmList = new ArrayList();
//			pstmt2 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanDescRead());
//				pstmt2.setString(1, loanNo);
//				pstmt2.setString(2, loanSeq);
//			rs2 = pstmt2.executeQuery();
//
//			while (rs2.next()) {
//				mmList.add(String.valueOf(rs2.getLong(1)));
//			}
//			int size = mmList.size();
//			if (size == 0) {
//				return new double[]{0, 0};
//			}
//
//			BigDecimal[] mmDueAmt = new BigDecimal[size];
//			for (int i=0; i<size; i++) {
//				mmDueAmt[i] = new BigDecimal( (String) mmList.get(i));
//			}
//			//내부수익율.월불입금
//			intnPrftObj.mmDueAmt = mmDueAmt;
//
//			//내부수익율 계산
//			//내부수익율.초기유출금액 = 초기유출금액
//			intnPrftObj.frstOutAmt = new BigDecimal(frstLoanPrin);
//			intnPrftObj = calcIntnPrftRt(intnPrftObj);
//			intnPrftRt[0] = intnPrftObj.intnPrftRt.setScale(4, BigDecimal.ROUND_FLOOR).doubleValue() * 100;
//			//LOGGER.debug("<<<<>>>>내부수익율 : " + intnPrftRt);
//
//			//실제이자율 계산
//			//실제이자율.초기유출금액 = 초기유출금액
//			intnPrftObj.frstOutAmt = new BigDecimal(factFrstLoanPrin);
//			intnPrftObj = calcIntnPrftRt(intnPrftObj);
//			intnPrftRt[1] = intnPrftObj.intnPrftRt.setScale(4, BigDecimal.ROUND_FLOOR).doubleValue() * 100;
//			//LOGGER.debug("<<<<>>>>실제이자율 : " + intnPrftRt);
//		}
//		catch (Exception se) {
//			se.printStackTrace();
//			throw new Exception("[내부수익률 계산] : " + se.getMessage());
//		}
//		finally {
//			QUtil.closeRsStmt(rs1, pstmt1);
//			QUtil.closeRsStmt(rs2, pstmt2);
//		}
//		return intnPrftRt;
//	}

//	public void updateIntnPrftRt(String loanNo, String loanSeq, double intnPrftRt, String userEmpNo) throws Exception {
//		//LOGGER.debug("updateIntnPrftRt 시작!");
//		PreparedStatement pstmt = null;
//
//		try {
//			//대출기본 수정
//			String nowDate = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
//			String nowTime = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);
//
//			pstmt = con.prepareStatement(RmbrPlanCrteQuery.loanBaseUpdt2());
//				pstmt.setDouble(1, intnPrftRt);
//				pstmt.setString(2, nowDate));
//				pstmt.setString(3, nowTime);
//				pstmt.setString(4, Util.trimToStr(userEmpNo));
//				pstmt.setString(5, loanNo);
//				pstmt.setString(6, loanSeq);
//			pstmt.executeUpdate();
//		}
//		catch (Exception se) {
//			se.printStackTrace();
//			throw new Exception("[내부수익률 수정] : " + se.getMessage());
//		}
//		finally {
//			QUtil.closeStmt(pstmt);
//		}
//	}

	public void updateFactIntRt(String loanNo, String loanSeq, double[] intnPrftRt, String userEmpNo) throws Exception {
		//LOGGER.debug("updateIntnPrftRt 시작!");
		RmbrPlanCrteCCInVODTO descCrteInvo = new RmbrPlanCrteCCInVODTO();
		try {
			//대출기본 수정
			String nowDate = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
			String nowTime = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);
			descCrteInvo.setIntnPrftRt(intnPrftRt[0]);
			descCrteInvo.setFactIntRt(intnPrftRt[1]);
			descCrteInvo.setLastProcDt(nowDate);
			descCrteInvo.setLastProcTm(nowTime);
			descCrteInvo.setLastProcEmpNo(StringUtil.trim(userEmpNo));
			descCrteInvo.setLoanNo(loanNo);
			descCrteInvo.setLoanSeq(loanSeq);

			rmbrPlanCrteMapper.loanBaseUpdt3(descCrteInvo);
		}
		catch (Exception se) {
			se.printStackTrace();
			throw new Exception("[내부수익률,실제이자율 수정] : " + se.getMessage());
		}
	}



	/**
	 * <p>메소드명	: checkDefrIntDistFg</p>
	 * <p>설　　명	: 이자배분여부 체크( "S00132" 공통코드 조회 )</p>
	 * <p>메소드인수	: LoanBaseObj</p>
	 * <p>리　턴　값	: N/A</p>
	 *//*
	public static void checkDefrIntDistFg(LoanBaseObj obj, Connection con) throws Exception {
		if (StringUtil.isNullT(obj.prdtCd)) {
			obj.defrIntDistFg = "0";
		}
		else {
			PreparedStatement pstmt = null;
			ResultSet rs = null;

			try {
				pstmt = con.prepareStatement(RmbrPlanCrteQuery.defrIntDistFgRead());
					pstmt.setString(1, obj.prdtCd);
				rs = pstmt.executeQuery();

				//값이 존재하면 거치이자배분 상품임
				if (rs.next()) {
					obj.defrIntDistFg = "1";
				}
				else {
					obj.defrIntDistFg = "0";
				}
			}
			catch (Exception e) {
				e.printStackTrace();
				throw new Exception("[상환계획생성] : [거치이자배분상품] 조회 오류!");
			}
			finally {
				QUtil.closeRsStmt(rs, pstmt);
			}
		}
	}
	*/


	/*========================================================================== 금융투자 =====================================================================================*/
	//[hanalife] 2023-04-05 사용하지 않음
	/**
     * <p>메소드명  : createRmblPlanIvst</p>
     * <p>설　　명  : 상환계획내역을 생성한다.(금융투자)</p>
     * <p>메소드인수 : List(LoanBaseObj), Connection</p>
     * <p>리　턴　값 : List(LoanBaseObj)</p>
     */
    // 대출기본 객체에 해당 대출에 대한 대출원리금 객체 리스트가 존재
    // 대출원리금 객체에 해당 원리금에 대한 상환계획 객체 리스트가 존재
//    public List createRmblPlanIvst(List loanObjList) throws Exception {
//
//        // 입력항목체크
//        this.validCheck(loanObjList);
//
//        // 원리금구성
//        //callMakePiamt(loanObjList);
//
//        // 회차별 상환계획 구성 (만기일자 넣어주기 위해서 추가)
//        callMakeRmbrPlanIvst(loanObjList);
//
//        // 내부수익률 계산
//        //callIntnPrftRt(loanObjList);
//
//        // 상환계획내역 저장
//        rmbrPlanDescCrteIvst(loanObjList);
//
//        return loanObjList;
//    }
//
//    /**
//     * <p>메소드명  : callMakeRmbrPlanIvst</p>
//     * <p>설　　명  : 회차별 상환계획 객체를 구성한다.</p>
//     * <p>메소드인수 : List(LoanBaseObj)</p>
//     * <p>리　턴　값 : N/A</p>
//     */
//    public static void callMakeRmbrPlanIvst(List loanList) throws Exception {
//        int size1 = loanList.size();
//        for (int i=0; i<size1; i++) {
//            LoanBaseObj loanObj = (LoanBaseObj) loanList.get(i);
//            makeRmbrPlanIvst(loanObj);
//        }
//    }
//
//    /**
//     * <p>메소드명  : makeRmbrPlanIvst</p>
//     * <p>설　　명  : 할부, 리스인 경우의 회차별 상환계획 객체를 구성한다.</p>
//     * <p>메소드인수 : LoanBaseObj</p>
//     * <p>리　턴　값 : N/A</p>
//     */
//    public static void makeRmbrPlanIvst(LoanBaseObj loanObj) throws Exception {
//        makeRmbrPlanIvst(loanObj, null);
//    }
//
//    /**
//     * <p>메소드명  : makeRmbrPlanIvst</p>
//     * <p>설　　명  : 할부, 리스인 경우의 회차별 상환계획 객체를 구성한다.</p>
//     * <p>메소드인수 : LoanBaseObj</p>
//     * <p>리　턴　값 : N/A</p>
//     */
//    public static void makeRmbrPlanIvst(LoanBaseObj loanObj) throws Exception {
//        List pniList = loanObj.piamtObjList;
//        int size2 = pniList.size();
//
//        //만기일자 구하기 위한 변수 추가
//        int maxTurn = 0; //마지막회차
//        String eprtDt = ""; //만기일자
//
//        for (int i = 0; i < size2; i++) {
//            LoanPiamtObj piamtObj = (LoanPiamtObj) pniList.get(i);
//
//            for (int k = 0; k < loanObj.rmbrPlanList.size(); k++) {
//                RmbrPlanObj rmbrObj = (RmbrPlanObj) loanObj.rmbrPlanList.get(k);
//                //*****************************************2018-08-01 추가
//                if (rmbrObj.tims > maxTurn) {
//                    maxTurn = rmbrObj.tims;
//                    eprtDt = rmbrObj.dueDt;
//                }
//            }
//        }
//        loanObj.eprtDt = eprtDt;
//        loanObj.lastTims = maxTurn;
//    }
//
//    /**
//     * <p>메소드명  : rmbrPlanDescCrteIvst</p>
//     * <p>설　　명  : 상환계획내역 저장(투자금융)</p>
//     * <p>메소드인수 : List(LoanBaseObj), Connection</p>
//     * <p>리　턴　값 : cnt</p>
//     */
//    public static int rmbrPlanDescCrteIvst(List loanObjList, Connection con) throws Exception {
//        PreparedStatement pstmt1 = null;
//        PreparedStatement pstmt2 = null;
//        PreparedStatement pstmt3 = null;
//        PreparedStatement pstmt4 = null;
//
//        int rowCnt = 0;
//        try {
//            //상환계획내역 삭제
//            pstmt1 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanDescDel());
//            //상환계획이력 삭제
//            pstmt2 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanHistDel());
//            //상환계획내역 등록
//            pstmt3 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanDescCrte());
//            //상환계획이력 등록
//            pstmt4 = con.prepareStatement(RmbrPlanCrteQuery.rmbrPlanHistCrte());
//
//            String yyyymmdd = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);  //시스템일자
//            String hhmmss = ServerSysDate.getServerDate(ServerSysDate.HHMMSS);      //시스템시간
//
//            int size1 = loanObjList.size();
//
//            LoanBaseObj loanObj = (LoanBaseObj) loanObjList.get(0);
//            LoanPiamtObj piamtObj = (LoanPiamtObj) loanObj.piamtObjList.get(0);
//            //시뮬레이션일 경우 저장처리 없이 리턴~
//            if ("2".equals(loanObj.rmbrPlanTypeDivCd)) {
//                return 0;
//            }
//
//            pstmt1.setString(1, loanObj.loanNo);
//            pstmt1.setString(2, loanObj.loanSeq);
//            pstmt1.addBatch();
//
//            //이전 상환계획이력 삭제*********************************
//            if ("1".equals(loanObj.histCreateFg)) {
//                pstmt2.setString(1, loanObj.loanNo);
//                pstmt2.setString(2, loanObj.loanSeq);
//                pstmt2.addBatch();
//            }
//
//            int rmbrSize = loanObj.rmbrPlanList.size();
//
//            //전체 이자합계
//            double totIntSum = 0;
//            for (int j = 0; j < rmbrSize; j++) {
//                RmbrPlanObj rmbrObj = (RmbrPlanObj) loanObj.rmbrPlanList.get(j);
//                //전체이자합계를 먼저 구한다~
//                totIntSum += rmbrObj.mmInt;
//
//            }
//
//            for (int k = 0; k < rmbrSize; k++) {
//                RmbrPlanObj rmbrObj = (RmbrPlanObj) loanObj.rmbrPlanList.get(k);
//
//                pstmt3.setString(1, piamtObj.loanNo); //대출번호
//                pstmt3.setString(2, piamtObj.loanSeq); //대출순번
//                pstmt3.setInt(3, piamtObj.trSnum); //거래일련번호
//                pstmt3.setInt(4, piamtObj.frstRank); //우선순위
//                pstmt3.setInt(5, rmbrObj.tims); //회차
//                pstmt3.setString(6, StringUtil.unformat(rmbrObj.dueDt))); //납입일자
//                pstmt3.setString(7, Util.trimToStr(piamtObj.rmbrFrmlCd)); //상환방식코드
//                pstmt3.setString(8, Util.trimToStr(piamtObj.crteDivCd)); //생성구분코드
//                pstmt3.setDouble(9, rmbrObj.mmPamt); //월원금
//                pstmt3.setDouble(10, rmbrObj.mmInt); //월이자
//                pstmt3.setDouble(11, rmbrObj.mmPiamt); //월원리금
//                pstmt3.setDouble(12, rmbrObj.mmPamt + rmbrObj.timsAfPamtRamt); //회차전잔여원금
//                pstmt3.setDouble(13, rmbrObj.timsAfPamtRamt); //회차후잔여원금
//                //회차전 잔여이자 = 전체이자합계 - 전회차이자
//                pstmt3.setDouble(14, totIntSum);
//                //회차후 잔여이자 = 전체이자합계 - 당회차이자합계
//                totIntSum = totIntSum - rmbrObj.mmInt;
//                pstmt3.setDouble(15, totIntSum);
//                pstmt3.setDouble(16, 0); //경과이자
//                pstmt3.setString(17, Util.trimToStr(rmbrObj.pdueFg).equals("") ? "0" : Util.trimToStr(rmbrObj.pdueFg)); //선납여부
//                pstmt3.setDouble(18, piamtObj.intRt); //이자율
//                if (rmbrObj.tims == piamtObj.dueStrtTims) {
//                    pstmt3.setString(19, loanObj.loanDt)); //이자시작일자
//                }else {
//                    pstmt3.setString(19, DateUtil.addMonth(StringUtil.unformat(rmbrObj.dueDt), -1))); //이자시작일자
//                }
//                pstmt3.setString(20, StringUtil.unformat(rmbrObj.dueDt))); //이자종료일자]
//                //2018-08-01
//               // pstmt3.setDouble(21, rmbrObj.mmTrtFee); //월취급수수료
//               // pstmt3.setDouble(22, rmbrObj.timsBfTrtFeeRamt); //회차전잔여취급수수료
//               // pstmt3.setDouble(23, rmbrObj.timsAfTrtFeeRamt); //회차후잔여취급수수료
//                pstmt3.setDouble(21, 0); //월취급수수료
//                pstmt3.setDouble(22, 0); //회차전잔여취급수수료
//                pstmt3.setDouble(23, 0); //회차후잔여취급수수료
//
//                pstmt3.setString(24, yyyymmdd)); //최초등록일자
//                pstmt3.setString(25, hhmmss); //최초등록시간
//                pstmt3.setString(26, Util.trimToStr(loanObj.empNo)); //최초등록자사번
//                pstmt3.setString(27, yyyymmdd)); //최종처리일자
//                pstmt3.setString(28, hhmmss); //최종처리시간
//                pstmt3.setString(29, Util.trimToStr(loanObj.empNo)); //최종처리자사번
//
//                pstmt3.addBatch(); //상환계획내역
//                rowCnt++;
//            }
//
//            //상환계획 이력 저장**************************
//            if ("1".equals(loanObj.histCreateFg)) {
//                pstmt4.setString(1, loanObj.loanNo);
//                pstmt4.setString(2, loanObj.loanSeq);
//                pstmt4.addBatch();
//            }
//            //******************************************
//
//            //1.상환계획내역 삭제 실행
//            try {
//                pstmt1.executeBatch();
//            } catch (BatchUpdateException bue) {
//                //LOGGER.debug("상환계획내역 삭제 데이터 없음");
//            }
//
//            //2.상환계획이력 삭제~
//            try {
//                pstmt2.executeBatch();
//            } catch (BatchUpdateException bue) {
//                //LOGGER.debug("상환계획이력 삭제 데이터 없음");
//            }
//
//
//            //4.상환계획내역 저장
//            try {
//                pstmt3.executeBatch();
//            } catch (BatchUpdateException bue) {
//                bue.printStackTrace();
//                //LOGGER.debug("상환계획내역 저장 데이터 없음");
//            }
//
//            try {
//                //5.상환계획이력 저장
//                pstmt4.executeBatch();
//            } catch (BatchUpdateException bue) {
//                bue.printStackTrace();
//                //LOGGER.debug("상환계획이력 저장 데이터 없음");
//            }
//        }
//        catch (Exception se) {
//            se.printStackTrace();
//            LOGGER.error(se.getMessage());
//            throw new Exception("(상환계획생성)상환계획 저장중 오류발생! : " + se.getMessage());
//        }
//        finally {
//            QUtil.closeStmt(pstmt1);
//            QUtil.closeStmt(pstmt2);
//            QUtil.closeStmt(pstmt3);
//            QUtil.closeStmt(pstmt4);
//        }
//        return rowCnt;
//    }

	/*  ====================================================  쌍차 관련 소스 ====================================================  */
//	private static void chngVarMnrtPrdt(LoanBaseObj loanObj, LoanPiamtObj piamtObj, RmbrPlanObj bfRmbrObj, int idx) {
//		//해당 상품이 아니면 통과
//		if (!loanObj.varMnrtPrdtFg) {
//			return;
//		}
//		boolean chngFg = false;
//		if (piamtObj.strtTims > 1 && idx == piamtObj.strtTims) {
//			if (idx < 13) {
//				piamtObj.intRt = loanObj.yyindInt1;
//			}
//			else if (idx < 25) {
//				piamtObj.intRt = loanObj.yyindInt2;
//			}
//			else if (idx < 37) {
//				piamtObj.intRt = loanObj.yyindInt3;
//			}
//			else if (idx < 49) {
//				piamtObj.intRt = loanObj.yyindInt4;
//			}
//			else {
//				piamtObj.intRt = loanObj.yyindInt5;
//			}
//			chngFg = true;
//		}
//		else if (idx == 13) {
//			piamtObj.intRt = loanObj.yyindInt2;
//			chngFg = true;
//		}
//		else if (idx == 25) {
//			piamtObj.intRt = loanObj.yyindInt3;
//			chngFg = true;
//		}
//		else if (idx == 37) {
//			piamtObj.intRt = loanObj.yyindInt4;
//			chngFg = true;
//		}
//		else if (idx == 49) {
//			piamtObj.intRt = loanObj.yyindInt5;
//			chngFg = true;
//		}
//
//		if (chngFg) {
//			if (bfRmbrObj != null) {
//				piamtObj.loanPamt = bfRmbrObj.timsAfPamtRamt;
//			}
//			piamtObj.term = piamtObj.endTerm - idx + 1;
//
//			//2.납입횟수 = (대출원리금.기간 - 대출원리금.납입시작회차 + 납입주기) / 납입주기
//			piamtObj.dueCnt = (int) Math.ceil((piamtObj.term - piamtObj.dueStrtTims + piamtObj.dueCycl) / piamtObj.dueCycl);
//			//3.원금납입기간 = (대출원리금.기간-(대출원리금.납입주기-대출원리금.납입시작회차)
//			piamtObj.pamtDueTerm = piamtObj.term - (piamtObj.dueCycl - piamtObj.dueStrtTims);
//
//			calcMmPiamt(piamtObj);
//			/*
//			//2.납입횟수 = (대출원리금.기간 - 대출원리금.납입시작회차 + 납입주기) / 납입주기
//			piamtObj.dueCnt = (int) Math.ceil((piamtObj.term - piamtObj.dueStrtTims + piamtObj.dueCycl) / piamtObj.dueCycl);
//			//3.원금납입기간 = (대출원리금.기간-(대출원리금.납입주기-대출원리금.납입시작회차)
//			piamtObj.pamtDueTerm = piamtObj.term - (piamtObj.dueCycl - piamtObj.dueStrtTims);
//			*/
//		}
//	}
//
//	/**
//	 * <p>메소드명	: checkVarMnrtPrdt</p>
//	 * <p>설　　명	: 변동금리(다이어트할부) 체크</p>
//	 * <p>메소드인수	: LoanBaseObj</p>
//	 * <p>리　턴　값	: N/A</p>
//	 */
//	private static void checkVarMnrtPrdt(LoanBaseObj obj) throws Exception {
//		if (StringUtil.in(obj.prdtCd, "SY00H9", "SY00V3", "SY00SE")) {
//			obj.varMnrtPrdtFg = true;
//		}
//
//		if (obj.varMnrtPrdtFg) {
//			PreparedStatement pstmt = null;
//			ResultSet rs = null;
//
//			try {
//				pstmt = con.prepareStatement(RmbrPlanCrteQuery.varMnrtPrdtRead());
//					pstmt.setString(1, obj.prdtCd);
//					pstmt.setString(2, obj.loanDt));
//				rs = pstmt.executeQuery();
//
//				LOGGER.error("RmbrPlanCrteQuery.varMnrtPrdtRead()"+RmbrPlanCrteQuery.varMnrtPrdtRead());
//				LOGGER.error("obj.prdtCd"+obj.prdtCd);
//				LOGGER.error("obj.loanDt"+obj.loanDt);
//
//				//값이 존재하지 않으면 에러
//				if (rs.next()) {
//					obj.yyindInt1 = rs.getDouble(1);
//					obj.yyindInt2 = rs.getDouble(2);
//					obj.yyindInt3 = rs.getDouble(3);
//					obj.yyindInt4 = rs.getDouble(4);
//					obj.yyindInt5 = rs.getDouble(5);
//				}
//				else {
//					throw new Exception("[상환계획생성-변동금리상품] 조회 오류 : " + "해당 상품의 변동금리정보가 존재하지 않습니다.");
//				}
//			}
//			catch (Exception e) {
//				e.printStackTrace();
//				throw new Exception("[상환계획생성-변동금리상품] 조회 오류 : " + e.getMessage());
//			}
//			finally {
//				QUtil.closeRsStmt(rs, pstmt);
//
//			}
//		}
//	}
}
