package hanalife.s.ln.pm.mapper;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import hanalife.c.co.mapper.dto.StDferIncdPrftBaseDTO;
import hanalife.c.co.mapper.dto.StDferIncdPrftDescDTO;
import hanalife.c.co.mapper.dto.StDferIncdPrftDistDescDTO;
import hanalife.c.co.mapper.dto.StRmbrPlanDescDTO;
import hanalife.s.ln.pm.mapper.dto.LoanBaseReadINDTO;
import hanalife.s.ln.pm.mapper.dto.LoanBaseReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.LoanChngConsReadINDTO;
import hanalife.s.ln.pm.mapper.dto.LoanChngConsReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.LoanPayDescReadINDTO;
import hanalife.s.ln.pm.mapper.dto.LoanPayDescReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.PrFeePayDescReadINDTO;
import hanalife.s.ln.pm.mapper.dto.PrFeePayDescReadOUTDTO;
import hanalife.s.ln.pm.mapper.dto.SelectTrtDescReadINDTO;
import hanalife.s.ln.pm.mapper.dto.SelectTrtDescReadOUTDTO;



/**
 * <pre>
 * 클래스명    : DferIncdPrftMapper.java
 * 클래스설명  : 이연부대수익스케줄 생성처 Mapper
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 29.
 * 작성자명    : 70279
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 29.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Mapper("DferIncdPrftMapper")
public interface DferIncdPrftMapper {

	/**
     * <pre>
     * 메소드명      : loanBaseRead
     * 설명         : 대출기본 조회
	 * @param LoanBaseReadINDTO
	 * @return LoanBaseReadOUTDTO
	 * @exception Exception
     * </pre>
     */
	public LoanBaseReadOUTDTO loanBaseRead(LoanBaseReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : maxSumRead
     * 설명         : 일련번호 max+1 조회
	 * @param MaxSumReadINDTO
	 * @return int
	 * @exception Exception
     * </pre>
     */
	public int maxSumRead(StDferIncdPrftBaseDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : dferIncdPrftBaseCrte
     * 설명         : 이연부대수익기본 저장
	 * @param StDferIncdPrftBaseDTO
	 * @return int
	 * @exception Exception
     * </pre>
     */
	public int dferIncdPrftBaseCrte(StDferIncdPrftBaseDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : dferIncdPrftDescCrte
     * 설명         : 이연부대수익내역 저장
	 * @param dferIncdPrftDescCrte
	 * @return int
	 * @exception Exception
     * </pre>
     */
	public int dferIncdPrftDescCrte(StDferIncdPrftDescDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : dferIncdPrftDistDescCrte
     * 설명         : 이연부대수익배분내역 저장
	 * @param StDferIncdPrftDistDescDTO
	 * @return int
	 * @exception Exception
     * </pre>
     */
	public int dferIncdPrftDistDescCrte(StDferIncdPrftDistDescDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : rmbrPlanDescRead
     * 설명         : 상환계획내역 조회
	 * @param StRmbrPlanDescDTO
	 * @return List<StRmbrPlanDescDTO>
	 * @exception Exception
     * </pre>
     */
	public List<StRmbrPlanDescDTO> rmbrPlanDescRead(StRmbrPlanDescDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : dferIncdPrftBaseUpdt
     * 설명         : 이연부대수익 기본 수정
	 * @param StDferIncdPrftBaseDTO
	 * @return int
	 * @exception Exception
     * </pre>
     */
	public int dferIncdPrftBaseUpdt(StDferIncdPrftBaseDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : prFeePayDescRead
     * 설명         : 판촉수수료 지급내역 조회
	 * @param PrFeePayDescReadOUTDTO
	 * @return PrFeePayDescReadINDTO
	 * @exception Exception
     * </pre>
     */
	public PrFeePayDescReadOUTDTO prFeePayDescRead(PrFeePayDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : loanPayDescRead
     * 설명         : 대출지급내역 조회
	 * @param LoanPayDescReadOUTDTO
	 * @return LoanPayDescReadINDTO
	 * @exception Exception
     * </pre>
     */
	public LoanPayDescReadOUTDTO loanPayDescRead(LoanPayDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : moggRcrpManTrtDescRead
     * 설명         : 모기지 모집인 취급 내역 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<MoggRcrpManTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> moggRcrpManTrtDescRead(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : ucarMmTrtDescRead
     * 설명         : 중고차 월별 취급 내역 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> ucarMmTrtDescRead(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : plMmTrtDescRead
     * 설명         : PL 월별 취급 내역 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> plMmTrtDescRead(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : plMmTrtDescRead2
     * 설명         : PL 월별 취급 내역 조회 - 전월 취급이 없을경우
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> plMmTrtDescRead2(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : plMmTrtDescRead3
     * 설명         : PL 월별 취급 내역 조회 - 전월 취급이 없을경우
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> plMmTrtDescRead3(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : moggLtrmContFeeTrtDescRead
     * 설명         : 모기지 장기근속수수료 취급 내역 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> moggLtrmContFeeTrtDescRead(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : loanChngConsRead
     * 설명         : 대출변경품의 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public LoanChngConsReadOUTDTO loanChngConsRead(LoanChngConsReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : acMmTrtDescRead
     * 설명         : AC 월별 취급 내역 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> acMmTrtDescRead(SelectTrtDescReadINDTO inDTO) throws Exception;

	/**
     * <pre>
     * 메소드명      : acMmTrtDescRead2
     * 설명         : AC 월별 취급 내역 조회
	 * @param SelectTrtDescReadINDTO
	 * @return List<SelectTrtDescReadOUTDTO>
	 * @exception Exception
     * </pre>
     */
	public List<SelectTrtDescReadOUTDTO> acMmTrtDescRead2(SelectTrtDescReadINDTO inDTO) throws Exception;
}


