package hanalife.s.mo.in.service;

import hanalife.s.mo.in.vo.SMOINM02InVO;
import hanalife.s.mo.in.vo.SMOINM02OutVO;
import hanalife.s.mo.in.vo.SMOINM02S01InVO;
import hanalife.s.mo.in.vo.SMOINM02S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM02Service.java Class
 * 클래스설명   : 권원보험관리 (SMOINM02) Service Interface
 * 작성일자     : 2023. 4. 10.
 * 작성자명     : 70319 / ShinJeongSeon / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 10.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSMOINM02S01 : 권원보험관리목록조회

 * </pre>
 */
public interface SMOINM02Service {

	/**
	 * <p>메소드명      : getSMOINM02S01 : 권원보험관리</p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리를 조회 한다.</p>
	 * <p>메소드인수     : SMOINM02S01InVo </p>
	 * <p>메소드리턴값   : SMOINM02S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SMOINM02S01OutVO getSMOINM02S01(SMOINM02S01InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : askSMOINM02I01 : 권원보험관리 조사의뢰 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 조사의뢰를 한다.</p>
	 * <p>메소드인수     : SMOINM02InVO </p>
	 * <p>메소드리턴값   : SMOINM02OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SMOINM02OutVO askSMOINM02I01(SMOINM02InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : cnclSMOINM02I02 : 권원보험관리 조사의뢰 취소 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 조사의뢰 취소를 한다.</p>
	 * <p>메소드인수     : SMOINM02InVO </p>
	 * <p>메소드리턴값   : SMOINM02OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SMOINM02OutVO cnclSMOINM02I02(SMOINM02InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : setSMOINM02I03 : 권원보험관리 권리보험확인 확인</p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 권리보험확인 확인을 한다.</p>
	 * <p>메소드인수     : SMOINM02InVO </p>
	 * <p>메소드리턴값   : SMOINM02OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SMOINM02OutVO setSMOINM02I03(SMOINM02InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : askSMOINM02I04 : 권원보험관리 실행재통보 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 실행재통보를 한다.</p>
	 * <p>메소드인수     : SMOINM02InVO </p>
	 * <p>메소드리턴값   : SMOINM02OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SMOINM02OutVO askSMOINM02I04(SMOINM02InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : askSMOINM02I05 : 권원보험관리 완제재통보 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 완제재통보를 한다.</p>
	 * <p>메소드인수     : SMOINM02InVO </p>
	 * <p>메소드리턴값   : SMOINM02OutVO</p>
	 * <p>예외처리      : Exception</p>
	 */
	public SMOINM02OutVO askSMOINM02I05(SMOINM02InVO inVo) throws Exception;

	/**
	 * <p>메소드명      : recvSMOINM02_N400100 : 권원보험관리 권리조사보고서 수신 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 권리조사보고서(N400-100) 수신 시 데이터를 수정 한다.</p>
	 * <p>메소드인수     : TIFHION003VO </p>
	 * <p>메소드리턴값   : TIFHION003VO</p>
	 * <p>예외처리      : Exception</p>
	 */
	//public TIFHION003VO recvSMOINM02_N400100(TIFHION003VO inVo) throws Exception;

	/**
	 * <p>메소드명      : recvSMOINM02_N400400 : 권원보험관리 권리조사확인서 수신 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 권리조사확인서(N400-400) 수신 시 데이터를 수정 한다.</p>
	 * <p>메소드인수     : TIFHION003VO </p>
	 * <p>메소드리턴값   : TIFHION003VO</p>
	 * <p>예외처리      : Exception</p>
	 */
	//public TIFHION004VO recvSMOINM02_N400400(TIFHION004VO inVo) throws Exception;

	/**
	 * <p>메소드명      : recvSMOINM02_N400500 : 권원보험관리 권리보험가입승인 수신 </p>
	 * <p>작성일자      : 2023. 4. 10.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명         : 권원보험관리 권리보험가입승인(N400-500) 수신 시 데이터를 수정 한다.</p>
	 * <p>메소드인수     : TIFHION003VO </p>
	 * <p>메소드리턴값   : TIFHION003VO</p>
	 * <p>예외처리      : Exception</p>
	 */
	//public TIFHION005VO recvSMOINM02_N400500(TIFHION005VO inVo) throws Exception;

}