package hanalife.s.mo.in.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.mo.in.mapper.TitleInsuReadMapper;
import hanalife.s.mo.in.mapper.dto.TitleInsuReadDSSDDODTO;
import hanalife.s.mo.in.mapper.dto.TitleInsuReadDSSMDTO;
import hanalife.s.mo.in.service.SMOINM01Service;
import hanalife.s.mo.in.vo.SMOINM01DSSDDO01VO;
import hanalife.s.mo.in.vo.SMOINM01S01InVO;
import hanalife.s.mo.in.vo.SMOINM01S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM01ServiceImpl.java Class
 * 클래스설명   : 권원보험현황조회 (SMOINM01) Service Implements
 * 작성일자     : 2023. 4. 03.
 * 작성자명     : 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 03.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSMOINM01S01 : 권원보험현황조회목록조회

 * </pre>
 */
@Service("SMOINM01Service")
public class SMOINM01ServiceImpl implements SMOINM01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOINM01ServiceImpl.class);

	/** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

	@Autowired
	private TitleInsuReadMapper titleInsuReadMapper;

	/**
	 * <p>메소드명      : getSMOINM01S01 : 권원보험현황조회</p>
	 * <p>작성일자      : 2023. 4. 03.
	 * <p>작성자(author): 70319 / ShinJeongSeon
	 * <p>설명          : 권원보험현황조회 한다.</p>
	 * <p>메소드인수    : SMOINM01S01InVo </p>
	 * <p>메소드리턴값  : SMOINM01S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@SuppressWarnings("static-access")
	@Override
	public SMOINM01S01OutVO getSMOINM01S01(SMOINM01S01InVO inVo) throws Exception {

		/*************************************************
         * ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
         *************************************************/
		SMOINM01S01OutVO     resultVo = new SMOINM01S01OutVO();
		TitleInsuReadDSSMDTO inDto    = new TitleInsuReadDSSMDTO();

        resultVo.setRsltCd  (msgEnum.SUCCESS.getErrorCd()    );
        resultVo.setRsltCntn(msgEnum.SUCCESS.getDescription());

        /*************************************************
         * ■ 검색조건 셋팅
         *************************************************/
		inDto.setReadDtFr(inVo.getSMOINM01DSSMVO().getReadDtFr());    /** 조회일자시작 */
		inDto.setReadDtTo(inVo.getSMOINM01DSSMVO().getReadDtTo());    /** 조회일자종료 */

		/*************************************************
         * ■ 권원보험현황 조회
         *************************************************/
		List<SMOINM01DSSDDO01VO> resultList = new ArrayList<SMOINM01DSSDDO01VO>();
		List<TitleInsuReadDSSDDODTO> resultDTO = titleInsuReadMapper.searchTitleInsuReadList(inDto);

		try {

			for (TitleInsuReadDSSDDODTO sourceIO : resultDTO) {
				SMOINM01DSSDDO01VO targetIO = new SMOINM01DSSDDO01VO();

				targetIO.setApplDt      (sourceIO.getApplDt()                  );    /* 신청일자 */
				targetIO.setLoanApplNo  (sourceIO.getLoanApplNo()              );    /* 신청번호 */
				targetIO.setCustNm      (this.nameMasking(sourceIO.getCustNm()));    /* 고객명 */
				targetIO.setCustResiNo  (sourceIO.getCustResiNo()              );    /* 생년월일 */
				targetIO.setCustNo      (sourceIO.getCustNo()                  );    /* 고객번호 */
				targetIO.setCollTypeGbCd(sourceIO.getCollTypeGbCd()            );    /* 담보종류 */
				targetIO.setLonApplAmt  (sourceIO.getLonApplAmt()              );    /* 대출신청금액 */
				targetIO.setHiStockNo   (sourceIO.getHiStockNo()               );    /* 보험증권번호 */
				targetIO.setHiIngStsCd  (sourceIO.getHiIngStsCd()              );    /* 권원진행상태 */

				/*************************************************
	             * ■ 권원보험현황조회 List 객체에 추가하도록 수행
	             *************************************************/
				resultList.add(targetIO);
			}

			resultVo.setSMOINM01DSSDDO01VO(resultList);

		} catch (Exception e) {
            LOGGER.error("[권원보험현황조회오류] : 권원보험현황조회 중 오류  " + e.getMessage() + " > " + e.toString() );
            resultVo.setRsltCd( msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );
        }

		return resultVo;
	}

	/**
	 * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 성명 마스킹 처리 한다.</p>
	 * <p>메소드인수    : String</p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */
	private String nameMasking(String name) {

		String maskName = "";

		if(name.length() <= 0) {
			return maskName;
		}

		String fstName = name.substring(0, 1);					// 성
		String midName = name.substring(1, name.length() -1);	// 가운데 이름
		String lstName = name.substring(name.length() -1);		// 마지막 글자

		String midMask = "";	// 중간 마스킹 처리

		for(int i = 0; i < midName.length(); i++) {
			midMask += "*";
		}

		if(midName.equals("")) {	// 외자일 경우
			maskName = fstName + "*";
		}else {
			maskName = fstName + midMask + lstName;
		}

		return maskName;

	}

}