package hanalife.s.mo.in.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.DateUtil;
import hanalife.s.mo.in.mapper.MciMngMapper;
import hanalife.s.mo.in.mapper.dto.mciMngDSSDDTO;
import hanalife.s.mo.in.mapper.dto.mciMngDSSMDTO;
import hanalife.s.mo.in.mapper.dto.stSgiInsuTrDescDTO;
import hanalife.s.mo.in.service.SMOINM04Service;
import hanalife.s.mo.in.vo.SMOINM04DSSDVO;
import hanalife.s.mo.in.vo.SMOINM04I01InVO;
import hanalife.s.mo.in.vo.SMOINM04I01OutVO;
import hanalife.s.mo.in.vo.SMOINM04S01InVO;
import hanalife.s.mo.in.vo.SMOINM04S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SMOINM04ServiceImpl.java Class
 * 클래스설명   : MCI관리 (SMOINM04) Service Implements
 * 작성일자     : 2023. 4. 3.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 3.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSMOINM04S01 : MCI관리목록조회

 * </pre>
 */
@Service("SMOINM04Service")
public class SMOINM04ServiceImpl implements SMOINM04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SMOINM04ServiceImpl.class);

	private MsgEnum msgEnum;

	@Autowired
	private MciMngMapper mciMngMapper;

	/**
	 * <p>메소드명      : getSMOINM04S01 : MCI관리</p>
	 * <p>작성일자      : 2023. 4. 3.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : MCI관리 조회 한다.</p>
	 * <p>메소드인수    : SMOINM04S01InVo </p>
	 * <p>메소드리턴값  : SMOINM04S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SMOINM04S01OutVO getSMOINM04S01(SMOINM04S01InVO inVo) throws Exception {

		SMOINM04S01OutVO resultVo = new SMOINM04S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		mciMngDSSMDTO inDto = new mciMngDSSMDTO();

		//inDto.setBsnDivCd(inVo.getSMOINM04DSSMVO().getBsnDivCd()); /** 업무구분코드 */
		inDto.setLoanApplNo(inVo.getSMOINM04DSSMVO().getLoanApplNo()); /** 대출신청번호 */

		//List<mciMngDSSDDTO> resultDTO =  mciMngMapper.searchMciMngStat(inDto);
		List<mciMngDSSDDTO> resultDTO1 = mciMngMapper.searchMciMngList(inDto);
		List<mciMngDSSDDTO> resultDTO2 = mciMngMapper.searchMciMrtgList(inDto);
		List<mciMngDSSDDTO> resultDTO3 = mciMngMapper.searchMciGramList(inDto);

//		Set<mciMngDSSDDTO> resultDTO = new LinkedHashSet<>(resultDTO1);
//		resultDTO.addAll(resultDTO2);
//		resultDTO.addAll(resultDTO3);

//		resultDTO.addAll(resultDTO1);
//		resultDTO.addAll(resultDTO2);
//		resultDTO.addAll(resultDTO3);
//		resultDTO.addAll(mciMngMapper.searchMciMngList(inDto));			/** MCI관리리스트*/
//		resultDTO.addAll(mciMngMapper.searchMciMrtgList(inDto));		/** MCI부동산담보리스트*/
//		resultDTO.addAll(mciMngMapper.searchMciGramList(inDto));		/** MCI전문용리스트*/

		List<SMOINM04DSSDVO> resultList = new ArrayList<SMOINM04DSSDVO>();
//		List<SMOINM04DSSDVO> resultList1 = new ArrayList<SMOINM04DSSDVO>();
//		List<SMOINM04DSSDVO> resultList2 = new ArrayList<SMOINM04DSSDVO>();
//		List<SMOINM04DSSDVO> resultList3 = new ArrayList<SMOINM04DSSDVO>();

		for (mciMngDSSDDTO sourceIO : resultDTO1) {
			SMOINM04DSSDVO targetIO = new SMOINM04DSSDVO();
			for (mciMngDSSDDTO sourceIO1 : resultDTO1) {
				targetIO.setLoanApplNo(sourceIO1.getLoanApplNo()); 						/** 대출신청번호 */
				targetIO.setLoanCnslNo(sourceIO1.getLoanCnslNo()); 						/** 대출상담번호 */
				targetIO.setCustNo(sourceIO1.getCustNo()); 								/** 고객번호 */
				targetIO.setBsdcd(sourceIO1.getBsdcd()); 								/** 보증서발행상태(업무구분코드) */
				targetIO.setBndno(sourceIO1.getBndno()); 								/** 보증보험증권번호 */
				targetIO.setRslcd(sourceIO1.getRslcd()); 								/** 결과코드 */

				/**  주민등록번호 마스킹 처리 : 230421-2******  */
				String mzdbRsrno = sourceIO1.getMzdbRsrno();
				String maskMzdbRsrno = "";
				String repMzdbRsrno = "";

				if(mzdbRsrno.length() > 8) {
					repMzdbRsrno = mzdbRsrno.replace("-", "");		//전문 송신용 하이픈 제거
					maskMzdbRsrno = mzdbRsrno.substring(0, 8);
				}

				targetIO.setMzdbRsrno(repMzdbRsrno); 									/** 주채무자주민등록번호 */
				targetIO.setMaskMzdbRsrno(maskMzdbRsrno + "******"); 					/** 주채무자주민등록번호_마스킹 */
				targetIO.setMzdbName(sourceIO1.getMzdbName()); 							/** 주채무자명 */
				targetIO.setMaskMzdbName(this.nameMasking(sourceIO1.getMzdbName())); 	/** 주채무자명 */
				targetIO.setLoanRqstAmnt(sourceIO1.getLoanRqstAmnt()); 					/** 대출신청금액 */
				targetIO.setLoanIntrt(sourceIO1.getLoanIntrt()); 						/** 대출산출금리 */
				targetIO.setRpmcd(sourceIO1.getRpmcd()); 								/** 상환방식구분코드 */
				targetIO.setRpyunMntcn(sourceIO1.getRpyunMntcn()); 						/** 상환주기구분코드 */
				targetIO.setT1hRpyam(sourceIO1.getT1hRpyam()); 							/** 최초상환금액 */
				targetIO.setLnprStrdt(sourceIO1.getLnprStrdt()); 						/** 대출희망일자 */
				targetIO.setLnprEnddt(sourceIO1.getLnprEnddt()); 						/** 대출만기일자 */
				targetIO.setFrscnRpedt(sourceIO1.getFrscnRpedt()); 						/** 최초상환일자 */
				targetIO.setLoanPssam(sourceIO1.getLoanPssam()); 						/** 최종승인금액(총대출가능금액) */
				targetIO.setIncmAmnt(sourceIO1.getIncmAmnt()); 							/** 연소득금액 */
				targetIO.setInsprStrdt(sourceIO1.getInsprStrdt()); 						/** 보험기간개시일자 */
				targetIO.setApplcDate(sourceIO1.getApplcDate()); 						/** 보험청약일자 */
				targetIO.setInsprEnddt(sourceIO1.getInsprEnddt()); 						/** 보험기간종료일자 */
				targetIO.setInsrnEniam(sourceIO1.getInsrnEniam()); 						/** 보험가입금액 */
				targetIO.setInsuFee(sourceIO1.getInsuFee()); 							/** 보험료 */
				targetIO.setInsuFeert(sourceIO1.getInsuFeert()); 						/** 보험료율 */
			}

			for (mciMngDSSDDTO sourceIO2 : resultDTO2) {
				long rlesEsvam = sourceIO2.getRlesEsvam();								/** 적용감정가액(부동산평가금액) */
				double lntvLmtrt = sourceIO2.getLntvLmtrt();							/** 신청(산출)LTV */
				long orofpStupAmnt = sourceIO2.getOrofpStupAmnt();						/** 선순위설정금액 */
				long smlamTnncyGrnam = sourceIO2.getSmlamTnncyGrnam();					/** 소액임대차금액 */
				long vldtyClltrAmnt = 0;												/** 유효(가용)담보가 */

				/** 유효담보가액 = (적용감정가 X LTV - 선순위설정금액 - 소액임대차금액) */
				if(rlesEsvam > 0 && lntvLmtrt > 0 && orofpStupAmnt > 0 && smlamTnncyGrnam > 0) {
					vldtyClltrAmnt = (long) (rlesEsvam * lntvLmtrt - orofpStupAmnt - smlamTnncyGrnam);
				}

				/** 부동산담보정보 */
				targetIO.setClltrRlesKndcd(sourceIO2.getClltrRlesKndcd()); 				/** 담보유형구분코드 */
				targetIO.setRlesEsvam(rlesEsvam); 										/** 적용감정가액(부동산평가금액) */
				targetIO.setOrofpStupAmnt(orofpStupAmnt); 								/** 선순위설정금액 */
				targetIO.setSmlamTnncyGrnam(smlamTnncyGrnam); 							/** 소액임대차금액 */
				targetIO.setLntvLmtrt(lntvLmtrt); 										/** 신청(산출)LTV */
				targetIO.setVldtyClltrAmnt(vldtyClltrAmnt); 							/** 유효(가용)담보가 */
				targetIO.setMciRlesVztnMthcd(sourceIO2.getMciRlesVztnMthcd()); 			/** 감정평가구분코드 */
				targetIO.setMciRlesVztnOrgcd(sourceIO2.getMciRlesVztnOrgcd()); 			/** 담보평가기관구분코드 */

				/** 담보소재지 우편번호 null 처리 */
				String clltrLctnZpcd = sourceIO2.getClltrLctnZpcd();
				String clltrLctnZpcdSeq = sourceIO2.getClltrLctnZpcdSeq();

				if(clltrLctnZpcdSeq != null && !"".equals(clltrLctnZpcdSeq)) {
					clltrLctnZpcd = clltrLctnZpcd + " " + clltrLctnZpcdSeq;
				}

				targetIO.setClltrLctnZpcd(clltrLctnZpcd); /** 담보소재지우편번호 */

				/** 담보소재지 주소 null 및 마스킹 처리 */
				String clltrLctnLodnmPrmad = sourceIO2.getClltrLctnLodnmPrmad();
				String clltrLctnLodnmEtcad = sourceIO2.getClltrLctnLodnmEtcad();
				String maskAddr = "";

				if(clltrLctnLodnmEtcad != null && !"".equals(clltrLctnLodnmEtcad)) {
					clltrLctnLodnmPrmad = clltrLctnLodnmPrmad + " " + clltrLctnLodnmEtcad;

					for(int i = 0; i < clltrLctnLodnmEtcad.length(); i++) {
						maskAddr += "*";
					}
				}

				targetIO.setClltrLctnLodnmPrmad(clltrLctnLodnmPrmad); /** 담보소재지도로명주소 */
				targetIO.setMaskClltrLctnLodnmPrmad(sourceIO2.getClltrLctnLodnmPrmad() + " " + maskAddr); /** 담보소재지도로명주소_마스킹 */
				targetIO.setTotalVllgCount(sourceIO2.getTotalVllgCount()); 				/** 총동수 */
				targetIO.setTotalGnrtnCount(sourceIO2.getTotalGnrtnCount()); 			/** 총세대수 */
				targetIO.setPrvusAreaSqrmt(sourceIO2.getPrvusAreaSqrmt()); 				/** 건물전용면적 */
				targetIO.setRoomCount(sourceIO2.getRoomCount()); 						/** 총방수 */
				targetIO.setClltrregno(sourceIO2.getClltrregno()); 						/** 등기필증일련번호(부동산고유번호) */
			}

			for (mciMngDSSDDTO sourceIO3 : resultDTO3) {
				/** 전문송신용정보 */

				targetIO.setMzdbQlfctCode(sourceIO3.getMzdbQlfctCode()); 		/** 소득유형코드 */

				/** 주채무자주민등록주소우편번호 null 처리 */
				String mzdbAddrsZpcd = sourceIO3.getMzdbAddrsZpcd();
				String mzdbAddrsZpcdSeq = sourceIO3.getMzdbAddrsZpcdSeq();

				if(mzdbAddrsZpcdSeq != null && !"".equals(mzdbAddrsZpcdSeq)) {
					mzdbAddrsZpcd = mzdbAddrsZpcd + " " + mzdbAddrsZpcdSeq;
				}

				targetIO.setMzdbAddrsZpcd(mzdbAddrsZpcd); /** 주채무자주민등록주소우편번호 */

				/** 주채무자도로명주소 null 처리 */
				String mzdbRsdrgLodnmPrmad1 = sourceIO3.getMzdbRsdrgLodnmPrmad();
				String mzdbRsdrgLodnmPrmad2 = "";
				String mzdbRsdrgLodnmEtcad1 = sourceIO3.getMzdbRsdrgLodnmEtcad1();
				String mzdbRsdrgLodnmEtcad2 = sourceIO3.getMzdbRsdrgLodnmEtcad2();

				/** 기타주소 1번 */
				if(mzdbRsdrgLodnmEtcad1 != null && !"".equals(mzdbRsdrgLodnmEtcad1)) {
					mzdbRsdrgLodnmPrmad2 = mzdbRsdrgLodnmPrmad1 + " " + mzdbRsdrgLodnmEtcad1;
				}

				/** 기타주소 2번 */
				if(!mzdbRsdrgLodnmEtcad1.equals(mzdbRsdrgLodnmPrmad2)) {
					if(mzdbRsdrgLodnmEtcad2 != null && !"".equals(mzdbRsdrgLodnmEtcad2)) {
						mzdbRsdrgLodnmPrmad1 = mzdbRsdrgLodnmPrmad2 + " " + mzdbRsdrgLodnmEtcad2;
					}
				}

				targetIO.setMzdbRsdrgLodnmPrmad(mzdbRsdrgLodnmPrmad1); /** 주채무자도로명주소 */

				/** 주채무자주민등록주소전화번호 자리수 채우기 및 null 처리 */
				String mzdbTlpno1 = sourceIO3.getMzdbTlpno1();	/** 주채무자주민등록주소전화번호 */
				if(mzdbTlpno1 != null) {
					mzdbTlpno1 = String.format("%04d", Integer.parseInt(mzdbTlpno1)); 	/** 전문 송신용 자리수 채우기 : 02 => 0002 */
				}else {
					mzdbTlpno1 = "";
				}

				if(sourceIO3.getMzdbTlpno2() != null && sourceIO3.getMzdbTlpno3() != null) {
					mzdbTlpno1 = mzdbTlpno1 + sourceIO3.getMzdbTlpno2() + sourceIO3.getMzdbTlpno3();
				}

				targetIO.setMzdbTlpno(mzdbTlpno1); /** 주채무자주민등록주소전화번호 */

				/** 주채무자휴대폰번호 null 처리 */
				String mzdbMbpno = "";
				if(sourceIO3.getMzdbMbpno1() != null && sourceIO3.getMzdbMbpno2() != null && sourceIO3.getMzdbMbpno3() != null) {
					mzdbMbpno = sourceIO3.getMzdbMbpno1() + sourceIO3.getMzdbMbpno2() + sourceIO3.getMzdbMbpno3();
				}

				targetIO.setMzdbMbpno(mzdbMbpno); /** 주채무자휴대폰번호 */
			}
			resultList.add(targetIO);
		}

//		for (mciMngDSSDDTO sourceIO : resultDTO) {
//			SMOINM04DSSDVO targetIO = new SMOINM04DSSDVO();
//			targetIO.setBsdcd(sourceIO.getBsdcd()); 						/** 보증서발행상태(업무구분코드) */
//			targetIO.setBndno(sourceIO.getBndno()); 						/** 보증보험증권번호 */
//			targetIO.setMzdbRsrno(sourceIO.getMzdbRsrno()); 				/** 주채무자주민등록번호 */
//			targetIO.setMzdbName(sourceIO.getMzdbName()); 					/** 주채무자명 */
//			targetIO.setLoanRqstAmnt(sourceIO.getLoanRqstAmnt()); 			/** 대출신청금액 */
//			targetIO.setLoanIntrt(sourceIO.getLoanIntrt()); 				/** 대출산출금리 */
//			targetIO.setRpmcd(sourceIO.getRpmcd()); 						/** 상환방식구분코드 */
//			targetIO.setRpyunMntcn(sourceIO.getRpyunMntcn()); 				/** 상환주기구분코드 */
//			targetIO.setT1hRpyam(sourceIO.getT1hRpyam()); 					/** 최초상환금액 */
//			targetIO.setLnprStrdt(sourceIO.getLnprStrdt()); 				/** 대출희망일자 */
//			targetIO.setLnprEnddt(sourceIO.getLnprEnddt()); 				/** 대출만기일자 */
//			targetIO.setFrscnRpedt(sourceIO.getFrscnRpedt()); 				/** 최초상환일자 */
//			targetIO.setLoanPssam(sourceIO.getLoanPssam()); 				/** 최종승인금액(총대출가능금액) */
//			targetIO.setIncmAmnt(sourceIO.getIncmAmnt()); 					/** 연소득금액 */
//			targetIO.setInsprStrdt(sourceIO.getInsprStrdt()); 				/** 보험기간개시일자 */
//			targetIO.setApplcDate(sourceIO.getApplcDate()); 				/** 보험청약일자 */
//			targetIO.setInsprEnddt(sourceIO.getInsprEnddt()); 				/** 보험기간종료일자 */
//			targetIO.setInsrnEniam(sourceIO.getInsrnEniam()); 				/** 보험가입금액 */
//			targetIO.setInsuFee(sourceIO.getInsuFee()); 					/** 보험료 */
//			targetIO.setInsuFeert(sourceIO.getInsuFeert()); 				/** 보험료율 */
//
//			long rlesEsvam = sourceIO.getRlesEsvam();						/** 적용감정가액(부동산평가금액) */
//			double lntvLmtrt = sourceIO.getLntvLmtrt();						/** 신청(산출)LTV */
//			long orofpStupAmnt = sourceIO.getOrofpStupAmnt();				/** 선순위설정금액 */
//			long smlamTnncyGrnam = sourceIO.getSmlamTnncyGrnam();			/** 소액임대차금액 */
//			long vldtyClltrAmnt = 0;										/** 유효(가용)담보가 */
//
//			/** 유효담보가액 = (적용감정가 X LTV - 선순위설정금액 - 소액임대차금액) */
//			if(rlesEsvam > 0 && lntvLmtrt > 0 && orofpStupAmnt > 0 && smlamTnncyGrnam > 0) {
//				vldtyClltrAmnt = (long) (rlesEsvam * lntvLmtrt - orofpStupAmnt - smlamTnncyGrnam);
//			}
//
//			/** 부동산담보정보 */
//			targetIO.setClltrRlesKndcd(sourceIO.getClltrRlesKndcd()); 		/** 담보유형구분코드 */
//			targetIO.setRlesEsvam(rlesEsvam); 								/** 적용감정가액(부동산평가금액) */
//			targetIO.setOrofpStupAmnt(orofpStupAmnt); 						/** 선순위설정금액 */
//			targetIO.setSmlamTnncyGrnam(smlamTnncyGrnam); 					/** 소액임대차금액 */
//			targetIO.setLntvLmtrt(lntvLmtrt); 								/** 신청(산출)LTV */
//			targetIO.setVldtyClltrAmnt(vldtyClltrAmnt); 					/** 유효(가용)담보가 */
//			targetIO.setMciRlesVztnMthcd(sourceIO.getMciRlesVztnMthcd()); 	/** 감정평가구분코드 */
//			targetIO.setMciRlesVztnOrgcd(sourceIO.getMciRlesVztnOrgcd()); 	/** 담보평가기관구분코드 */
//			targetIO.setClltrLctnZpcd(sourceIO.getClltrLctnZpcd() + " " + sourceIO.getClltrLctnZpcdSeq()); /** 담보소재지우편번호 */
//			targetIO.setClltrLctnLodnmPrmad(sourceIO.getClltrLctnLodnmPrmad() + " " + sourceIO.getClltrLctnLodnmEtcad()); /** 담보소재지도로명주소 */
//			targetIO.setTotalVllgCount(sourceIO.getTotalVllgCount()); 		/** 총동수 */
//			targetIO.setTotalGnrtnCount(sourceIO.getTotalGnrtnCount()); 	/** 총세대수 */
//			targetIO.setPrvusAreaSqrmt(sourceIO.getPrvusAreaSqrmt()); 		/** 건물전용면적 */
//			targetIO.setRoomCount(sourceIO.getRoomCount()); 				/** 총방수 */
//			targetIO.setClltrregno(sourceIO.getClltrregno()); 				/** 등기필증일련번호(부동산고유번호) */
//
//			/** 전문송신용정보 */
//			String mzdbTlpno1 = sourceIO.getMzdbTlpno1();	/** 주채무자주민등록주소전화번호 */
//			if(mzdbTlpno1 != null) {
//				mzdbTlpno1 = String.format("%04d", Integer.parseInt(mzdbTlpno1)); 	/** 전문 송신용 자리수 채우기 : 02 => 0002 */
//			}
//
//			targetIO.setMzdbQlfctCode(sourceIO.getMzdbQlfctCode()); 		/** 소득유형코드 */
//			targetIO.setMzdbAddrsZpcd(sourceIO.getMzdbAddrsZpcd() + " " + sourceIO.getMzdbAddrsZpcdSeq()); /** 주채무자주민등록주소우편번호 */
//			targetIO.setMzdbRsdrgLodnmPrmad(sourceIO.getMzdbRsdrgLodnmPrmad() + " " + sourceIO.getMzdbRsdrgLodnmEtcad1() + " " + sourceIO.getMzdbRsdrgLodnmEtcad2()); /** 주채무자도로명주소 */
//			targetIO.setMzdbTlpno(mzdbTlpno1 + sourceIO.getMzdbTlpno2() + sourceIO.getMzdbTlpno3()); /** 주채무자주민등록주소전화번호 */
//			targetIO.setMzdbMbpno(sourceIO.getMzdbMbpno1() + sourceIO.getMzdbMbpno2() + sourceIO.getMzdbMbpno3()); /** 주채무자휴대폰번호 */
//
//			resultList.add(targetIO);
//		}

//		for (mciMngDSSDDTO sourceIO : resultDTO1) {
//			SMOINM04DSSDVO targetIO = new SMOINM04DSSDVO();
//			targetIO.setBsdcd(sourceIO.getBsdcd()); 						/** 보증서발행상태(업무구분코드) */
//			targetIO.setBndno(sourceIO.getBndno()); 						/** 보증보험증권번호 */
//			targetIO.setMzdbRsrno(sourceIO.getMzdbRsrno()); 				/** 주채무자주민등록번호 */
//			targetIO.setMzdbName(sourceIO.getMzdbName()); 					/** 주채무자명 */
//			targetIO.setLoanRqstAmnt(sourceIO.getLoanRqstAmnt()); 			/** 대출신청금액 */
//			targetIO.setLoanIntrt(sourceIO.getLoanIntrt()); 				/** 대출산출금리 */
//			targetIO.setRpmcd(sourceIO.getRpmcd()); 						/** 상환방식구분코드 */
//			targetIO.setRpyunMntcn(sourceIO.getRpyunMntcn()); 				/** 상환주기구분코드 */
//			targetIO.setT1hRpyam(sourceIO.getT1hRpyam()); 					/** 최초상환금액 */
//			targetIO.setLnprStrdt(sourceIO.getLnprStrdt()); 				/** 대출희망일자 */
//			targetIO.setLnprEnddt(sourceIO.getLnprEnddt()); 				/** 대출만기일자 */
//			targetIO.setFrscnRpedt(sourceIO.getFrscnRpedt()); 				/** 최초상환일자 */
//			targetIO.setLoanPssam(sourceIO.getLoanPssam()); 				/** 최종승인금액(총대출가능금액) */
//			targetIO.setIncmAmnt(sourceIO.getIncmAmnt()); 					/** 연소득금액 */
//			targetIO.setInsprStrdt(sourceIO.getInsprStrdt()); 				/** 보험기간개시일자 */
//			targetIO.setApplcDate(sourceIO.getApplcDate()); 				/** 보험청약일자 */
//			targetIO.setInsprEnddt(sourceIO.getInsprEnddt()); 				/** 보험기간종료일자 */
//			targetIO.setInsrnEniam(sourceIO.getInsrnEniam()); 				/** 보험가입금액 */
//			targetIO.setInsuFee(sourceIO.getInsuFee()); 					/** 보험료 */
//			targetIO.setInsuFeert(sourceIO.getInsuFeert()); 				/** 보험료율 */
//
//			resultList1.add(targetIO);
//		}
//
//		for (mciMngDSSDDTO sourceIO : resultDTO2) {
//			SMOINM04DSSDVO targetIO = new SMOINM04DSSDVO();
//
//			long rlesEsvam = sourceIO.getRlesEsvam();						/** 적용감정가액(부동산평가금액) */
//			double lntvLmtrt = sourceIO.getLntvLmtrt();						/** 신청(산출)LTV */
//			long orofpStupAmnt = sourceIO.getOrofpStupAmnt();				/** 선순위설정금액 */
//			long smlamTnncyGrnam = sourceIO.getSmlamTnncyGrnam();			/** 소액임대차금액 */
//			long vldtyClltrAmnt = 0;										/** 유효(가용)담보가 */
//
//			/** 유효담보가액 = (적용감정가 X LTV - 선순위설정금액 - 소액임대차금액) */
//			if(rlesEsvam > 0 && lntvLmtrt > 0 && orofpStupAmnt > 0 && smlamTnncyGrnam > 0) {
//				vldtyClltrAmnt = (long) (rlesEsvam * lntvLmtrt - orofpStupAmnt - smlamTnncyGrnam);
//			}
//
//			/** 부동산담보정보 */
//			targetIO.setClltrRlesKndcd(sourceIO.getClltrRlesKndcd()); 		/** 담보유형구분코드 */
//			targetIO.setRlesEsvam(rlesEsvam); 								/** 적용감정가액(부동산평가금액) */
//			targetIO.setOrofpStupAmnt(orofpStupAmnt); 						/** 선순위설정금액 */
//			targetIO.setSmlamTnncyGrnam(smlamTnncyGrnam); 					/** 소액임대차금액 */
//			targetIO.setLntvLmtrt(lntvLmtrt); 								/** 신청(산출)LTV */
//			targetIO.setVldtyClltrAmnt(vldtyClltrAmnt); 					/** 유효(가용)담보가 */
//			targetIO.setMciRlesVztnMthcd(sourceIO.getMciRlesVztnMthcd()); 	/** 감정평가구분코드 */
//			targetIO.setMciRlesVztnOrgcd(sourceIO.getMciRlesVztnOrgcd()); 	/** 담보평가기관구분코드 */
//			targetIO.setClltrLctnZpcd(sourceIO.getClltrLctnZpcd() + " " + sourceIO.getClltrLctnZpcdSeq()); /** 담보소재지우편번호 */
//			targetIO.setClltrLctnLodnmPrmad(sourceIO.getClltrLctnLodnmPrmad() + " " + sourceIO.getClltrLctnLodnmEtcad()); /** 담보소재지도로명주소 */
//			targetIO.setTotalVllgCount(sourceIO.getTotalVllgCount()); 		/** 총동수 */
//			targetIO.setTotalGnrtnCount(sourceIO.getTotalGnrtnCount()); 	/** 총세대수 */
//			targetIO.setPrvusAreaSqrmt(sourceIO.getPrvusAreaSqrmt()); 		/** 건물전용면적 */
//			targetIO.setRoomCount(sourceIO.getRoomCount()); 				/** 총방수 */
//			targetIO.setClltrregno(sourceIO.getClltrregno()); 				/** 등기필증일련번호(부동산고유번호) */
//
//			resultList2.add(targetIO);
//		}
//
//		for (mciMngDSSDDTO sourceIO : resultDTO3) {
//			SMOINM04DSSDVO targetIO = new SMOINM04DSSDVO();
//
//			/** 전문송신용정보 */
//			String mzdbTlpno1 = sourceIO.getMzdbTlpno1();	/** 주채무자주민등록주소전화번호 */
//			if(mzdbTlpno1 != null) {
//				mzdbTlpno1 = String.format("%04d", Integer.parseInt(mzdbTlpno1)); 	/** 전문 송신용 자리수 채우기 : 02 => 0002 */
//			}
//
//			targetIO.setMzdbQlfctCode(sourceIO.getMzdbQlfctCode()); 		/** 소득유형코드 */
//			targetIO.setMzdbAddrsZpcd(sourceIO.getMzdbAddrsZpcd() + " " + sourceIO.getMzdbAddrsZpcdSeq()); /** 주채무자주민등록주소우편번호 */
//			targetIO.setMzdbRsdrgLodnmPrmad(sourceIO.getMzdbRsdrgLodnmPrmad() + " " + sourceIO.getMzdbRsdrgLodnmEtcad1() + " " + sourceIO.getMzdbRsdrgLodnmEtcad2()); /** 주채무자도로명주소 */
//			targetIO.setMzdbTlpno(mzdbTlpno1 + sourceIO.getMzdbTlpno2() + sourceIO.getMzdbTlpno3()); /** 주채무자주민등록주소전화번호 */
//			targetIO.setMzdbMbpno(sourceIO.getMzdbMbpno1() + sourceIO.getMzdbMbpno2() + sourceIO.getMzdbMbpno3()); /** 주채무자휴대폰번호 */
//
//			resultList3.add(targetIO);
//		}
//
//		List<SMOINM04DSSDVO> resultList = new ArrayList<SMOINM04DSSDVO>();
//		resultList.addAll(resultList1);
//		resultList.removeAll(resultList2);
//		resultList.addAll(resultList2);
//		resultList.removeAll(resultList3);
//		resultList.addAll(resultList3);

		resultVo.setSMOINM04DSSDVO(resultList);	/** MCI관리리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 성명 마스킹 처리 한다.</p>
	 * <p>메소드인수    : String</p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */
	private String nameMasking(String name) {

		String maskName = "";

		if(name.length() <= 0) {
			return maskName;
		}

		String fstName = name.substring(0, 1);					// 성
		String midName = name.substring(1, name.length() -1);	// 가운데 이름
		String lstName = name.substring(name.length() -1);		// 마지막 글자

		String midMask = "";	// 중간 마스킹 처리

		for(int i = 0; i < midName.length(); i++) {
			midMask += "*";
		}

		if(midName.equals("")) {	// 외자일 경우
			maskName = fstName + "*";
		}else {
			maskName = fstName + midMask + lstName;
		}

		return maskName;

	}

	/**
	 * <p>메소드명      : registerSMOINM04I01 : MCI관리전문송신</p>
	 * <p>작성일자      : 2023. 4. 3.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : MCI관리 전문 송신 한다.</p>
	 * <p>메소드인수    : SMOINM04I01InVo </p>
	 * <p>메소드리턴값  : SMOINM04I01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SMOINM04I01OutVO registerSMOINM04I01(SMOINM04I01InVO inVo) throws Exception {

		SMOINM04I01OutVO resultVo = new SMOINM04I01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		try {
			stSgiInsuTrDescDTO inDto = new stSgiInsuTrDescDTO();

			int insResult = 0;

			/** 사유코드 분기 */
			String bsdcd = inVo.getSMOINM04DSSDCVO().getBsdcd();
			String rsnCd = "";

			if("A00100".equals(bsdcd)) {	//사전조회
				rsnCd = "";
			} else if("A00101".equals(bsdcd) || "A00102".equals(bsdcd)) {	//청약, 청약취소
				rsnCd = "A11";	//신규청약, 갱신청약
			} /*else if("A00102".equals(bsdcd)) {	//청약취소
				rsnCd = "A11";	//신규청약, 갱신청약취소
			}*/

			inDto.setTrMngNo(DateUtil.getServerDate(DateUtil.YYYYMMDDHHMMSS).substring(2)); 			/** 거래관리번호 */
			inDto.setBsnDivCd(bsdcd); 			/** 업무구분코드 */
			inDto.setRsnCd(rsnCd);				/** 사유코드 */
			inDto.setRsltCd("A000");	/** 결과코드 */
			inDto.setLoanCnslNo(inVo.getSMOINM04DSSDCVO().getLoanCnslNo());	/** 대출상담번호 */
			inDto.setLoanApplNo(inVo.getSMOINM04DSSDCVO().getLoanApplNo());	/** 대출신청번호 */
			inDto.setCustNo(inVo.getSMOINM04DSSDCVO().getCustNo());	/** 고객번호 */
			//inDto.setGuarBondNo(inVo.getSMOINM04DSSDCVO().getBndno());	/** 보증보험증권번호 */
			inDto.setGuarBondNo(DateUtil.getServerDate(DateUtil.HHMMSS));	/** 보증보험증권번호 */
			inDto.setTrDt(DateUtil.getServerDate(DateUtil.YYYYMMDD));	/** 거래일자 */
			inDto.setEndorNo("");	/** 배서번호 */
			inDto.setRsnOccrDt(DateUtil.getServerDate(DateUtil.YYYYMMDD));	/** 사유발생일자 */
			inDto.setMdebManResiNo(inVo.getSMOINM04DSSDCVO().getMzdbRsrno());	/** 주채무자주민등록번호 */
			inDto.setAfMdebManResiNo("");	/** 변경후_주채무자주민등록번호 */
			inDto.setMrtgEsttKindCd("1");	/** 담보부동산종류 : 1 아파트 */
			inDto.setMrtgLoctZipCd(inVo.getSMOINM04DSSDCVO().getClltrLctnZpcd());	/** 담보소재지우편번호 */
			inDto.setMrtgLoctAddr(inVo.getSMOINM04DSSDCVO().getClltrLctnAddrs());	/** 담보부동산소재지 */
			inDto.setRoomCnt(inVo.getSMOINM04DSSDCVO().getRoomCount());	/** 방칸수 */
			inDto.setEuseArea(inVo.getSMOINM04DSSDCVO().getPrvusAreaSqrmt());	/** 전용면적 */
			inDto.setPreSeqSetAmt(inVo.getSMOINM04DSSDCVO().getOrofpStupAmnt());	/** 선순위설정금액 */
			inDto.setEsttEvalAmt(inVo.getSMOINM04DSSDCVO().getRlesEsvam());	/** 부동산평가금액 */
			inDto.setTotLoanPossAmt(inVo.getSMOINM04DSSDCVO().getLoanPssam());	/** 총대출가능금액 */
			inDto.setLoanApplAmt(inVo.getSMOINM04DSSDCVO().getLoanRqstAmnt());	/** 대출신청금액 */
			inDto.setValdMrtgAmt(inVo.getSMOINM04DSSDCVO().getVldtyClltrAmnt());	/** 유효(가용)담보가 */
			//inDto.setEsttEvalMethCd(inVo.getSMOINM04DSSDCVO().getMciRlesVztnMthcd());	/** 부동산평가방법 */
			inDto.setEsttEvalMethCd("1");	/** 부동산평가방법 */
			inDto.setChngAfLoanApplAmt("");	/** 변경후_대출신청금액 */
			inDto.setChngAfValdMrtgAmt("");	/** 변경후_유효담보가 */
			inDto.setLoanStrtDt(inVo.getSMOINM04DSSDCVO().getLnprStrdt());	/** 대출기간개시일자 */
			inDto.setLoanEndDt(inVo.getSMOINM04DSSDCVO().getLnprEnddt());	/** 대출기간종료일자 */
			inDto.setCalcLoanEndDt(inVo.getSMOINM04DSSDCVO().getLnprEnddt());	/** 대출기간종료일자(보험료계산용도) */

			String rpmcd = inVo.getSMOINM04DSSDCVO().getRpmcd();
			String rmbrMethCd = "";

			String rpyunMntcn = inVo.getSMOINM04DSSDCVO().getRpyunMntcn();
			String rmbrUnit = "1";	//상환단위 : 매월

			//원리금균등
			if("10".equals(rpmcd)) {
				rmbrMethCd = "3";
			//원금균등
			} else if("20".equals(rpmcd)) {
				rmbrMethCd = "2";
			//만기일시
			} else if("30".equals(rpmcd)) {
				rmbrMethCd = "1";
				rmbrUnit = "0";	//만기일시에는 상환단위 0
			}

			inDto.setRmbrMethCd(rmbrMethCd);	/** 상환방법 */
			inDto.setRmbrUnit(rmbrUnit);	/** 상환단위 */
			inDto.setTimsRmbrAmt(inVo.getSMOINM04DSSDCVO().getT1hRpyam());	/** 1회상환금액 */
			inDto.setLoanIntRt(inVo.getSMOINM04DSSDCVO().getLoanIntrt());	/** 대출이자율 */
			inDto.setFcntRmbrDt(inVo.getSMOINM04DSSDCVO().getFrscnRpedt());	/** 초회상환일자 */
			inDto.setInsuSubsDt(inVo.getSMOINM04DSSDCVO().getApplcDate());	/** 보험청약일자 */
			inDto.setInsuEntrAmt(0);	/** 보험가입금액 */
			inDto.setInsuTermStrtDt("");	/** 보험기간개시일자 */
			inDto.setInsuTermEndDt("");	/** 보험기간종료일자(당초,변경전) */
			inDto.setChngAfInsuTermEndDt("");	/** 보험기간종료일자(변경후) */
			inDto.setAplyInsuRt(0);	/** 적용보험요율 */
			inDto.setChngAfAplyInsuRt(0);	/** 적용보험요율(변경후) */
			inDto.setFrstInsuFee(0);	/** 최초보험료 */
			inDto.setToutInsuFee(0);	/** 환급보험료 */
			inDto.setPentInsuFee(0);	/** 추징보험료 */
			inDto.setMdebManNm(inVo.getSMOINM04DSSDCVO().getMzdbName());	/** 주채무자성명 */

			String mzdbQlfctCode = inVo.getSMOINM04DSSDCVO().getMzdbQlfctCode();
			String mdebManJobCd = "";

			//근로소득
			if("00010".equals(mzdbQlfctCode)) {
				mdebManJobCd = "3";
			//사업소득
			}else if("00020".equals(mzdbQlfctCode)) {
				mdebManJobCd = "4";
			}

			inDto.setMdebManJobCd(mdebManJobCd);	/** 주채무자직업구분코드 */
			inDto.setMdebManResiZipCd(inVo.getSMOINM04DSSDCVO().getMzdbAddrsZpcd());	/** 주채무자주민등록주소우편번호 */
			inDto.setMdebManResiAddr(inVo.getSMOINM04DSSDCVO().getMzdbAddrs());	/** 주채무자주민등록주소 */
			inDto.setMdebManTelNo(inVo.getSMOINM04DSSDCVO().getMzdbTlpno());	/** 주채무자주민등록주소전화번호 */
			inDto.setMdebManHpNo(inVo.getSMOINM04DSSDCVO().getMzdbMbpno());	/** 주채무자휴대폰번호 */
			inDto.setSendDt(DateUtil.getServerDate(DateUtil.YYYYMMDD));	/** 전송일자 */
			inDto.setSendTm(DateUtil.getServerDate(DateUtil.HHMMSS));	/** 전송시각 */
			inDto.setEmptRmFg("");	/** 공실여부 */
			inDto.setLoanKindCd("2");	/** 대출종류 */
			inDto.setInsuUpdtFg("N");	/** 보험갱신계약여부 */
			inDto.setBfGuarBondNo(inVo.getSMOINM04DSSDCVO().getBndno());	/** 보험증권번호(갱신전) */
			inDto.setTotBuildCnt(inVo.getSMOINM04DSSDCVO().getTotalVllgCount());	/** 총동수 */
			inDto.setTotHshdCnt(inVo.getSMOINM04DSSDCVO().getTotalGnrtnCount());	/** 총세대수 */
			inDto.setIncoAmt(inVo.getSMOINM04DSSDCVO().getIncmAmnt());	/** 소득금액 */
			//inDto.setEsttEvalOrgCd(inVo.getSMOINM04DSSDCVO().getMciRlesVztnOrgcd());	/** 부동산평가기관 */
			inDto.setEsttEvalOrgCd("1");	/** 부동산평가기관 */
			inDto.setLtvLimRto(inVo.getSMOINM04DSSDCVO().getLntvLmtrt());	/** LTV한도 */
			inDto.setSamtLeasGuarAmt(inVo.getSMOINM04DSSDCVO().getSmlamTnncyGrnam());	/** 소액임차보증금해당액 */
			inDto.setEprtRmbrAmt(0);	/** 만기일시상환금 : 0 */
			inDto.setJobGrpCd(inVo.getSMOINM04DSSDCVO().getCnorcJbccd());	/** 직업군코드 */
			inDto.setMciEntrLimAmt("");	/** MCI가입한도(일부은행용) */
			inDto.setMciEntrAfAddLimAmt("");	/** MCI가입후추가대출한도(일부은행용) */
			inDto.setMciEntrAfLastPossAmt("");	/** MCI가입후최종대출가능금액(일부은행용) */
			inDto.setMciEntrAfValdMrtgAmt("");	/** MCI가입후유효담보가(일부은행용) */
			inDto.setJudgEvalCorpNm(inVo.getSMOINM04DSSDCVO().getMciRlesVztnOrgcd());	/** 감정평가법인명 */
			inDto.setEtcSamtLeasGuarAmt(inVo.getSMOINM04DSSDCVO().getEtcSmlamTnncyGrnam());	/** 기타주택소액임차보증금(공제대상방수) */

			/** 선택동의 여부 어떻게 거를지 확인하기 */
			inDto.setDebtManCiReadAgrFg("Y");	/** 채무자신용정보조회동의여부 */
			inDto.setDebtManOffrMndtAgrFg("Y");	/** 채무자신용정보제공필수동의여부 */
			inDto.setDebtManOffrSlctAgrFg("Y");	/** 채무자신용정보제공선택동의여부 */
			inDto.setDebtManGathUseMndtAgrFg("Y");	/** 채무자신용정보수집이용필수동의여부 */
			inDto.setDebtManGathUseSlctAgrFg("Y");	/** 채무자신용정보수집이용선택동의여부 */
			inDto.setDebtManRcgnAgrFg("Y");	/** 채무자고객식별정보동의여부 */
			inDto.setMrtgLoctPlmkBaseAddr("");	/** 담보소재지지번기본주소 */
			inDto.setMrtgLoctAddrDivCd(inVo.getSMOINM04DSSDCVO().getClltrLctnAddrsDvscd());	/** 담보소재지주소구분코드 */
			inDto.setMrtgLoctRoadBaseAddr(inVo.getSMOINM04DSSDCVO().getClltrLctnLodnmPrmad());	/** 담보소재지도로명기본주소 */
			inDto.setMrtgLoctRoadEtcAddr(inVo.getSMOINM04DSSDCVO().getClltrLctnLodnmEtcad());	/** 담보소재지도로명기타주소 */
			inDto.setMdebManAddrDivCd(inVo.getSMOINM04DSSDCVO().getMzdbRsdrgAddrsOrgcpDvscd());	/** 주채무자주소구분코드 */
			inDto.setMdebManPlmkBaseAddr("");	/** 주채무자지번기본주소 */
			inDto.setMdebManRoadBaseAddr(inVo.getSMOINM04DSSDCVO().getMzdbRsdrgLodnmPrmad());	/** 주채무자도로명기본주소 */
			inDto.setMdebManRoadEtcAddr(inVo.getSMOINM04DSSDCVO().getMzdbRsdrgLodnmEtcad());	/** 주채무자도로명기타주소 */
			inDto.setMrtgPclrNo(inVo.getSMOINM04DSSDCVO().getClltrregno());	/** 부동산고유번호 */

			/** !! 보험청약결과 임시 하드코딩 !! */
			inDto.setInsuTermStrtDt(inVo.getSMOINM04DSSDCVO().getLnprStrdt());	/** 보험기간개시일자 */
			inDto.setInsuSubsDt(inVo.getSMOINM04DSSDCVO().getLnprStrdt());	/** 보험청약일자 */
			inDto.setInsuTermEndDt(inVo.getSMOINM04DSSDCVO().getLnprEnddt());	/** 보험기간종료일자 */
			inDto.setInsuEntrAmt(123456789);	/** 보험가입금액 */
			inDto.setFrstInsuFee(123456789);	/** 보험료 */
			inDto.setAplyInsuRt(4.3);	/** 보험료율 */
			/** !! 보험청약결과 임시 하드코딩 !! */

			inDto.setLogInUserNo(inVo.getSMOINM04DSSDCVO().getLogInUserNo());	/** 로그인사용자번호 */
			inDto.setLogInEmpNo(inVo.getSMOINM04DSSDCVO().getLogInEmpNo());	/** 로그인사원번호 */

			insResult = mciMngMapper.registerStSgiInsuTrDesc(inDto);

			// !! 전문 응답코드 값 넣기 !!
			if(insResult <= 0) {
				resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
				resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
			}
		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
		}

		return resultVo;

	}
}