package hanalife.s.pd.pd.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.pd.pd.service.SPDPDM01Service;
import hanalife.s.pd.pd.vo.SPDPDM01DSDDSSVO;
import hanalife.s.pd.pd.vo.SPDPDM01DSSMVO;
import hanalife.s.pd.pd.vo.SPDPDM01InVO;
import hanalife.s.pd.pd.vo.SPDPDM01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SPDPDM01Controller.java Class
 * 클래스설명   : 상품분류관리 (SPDPDM01) Controller
 * 작성일자     : 2023. 3. 13.
 * 작성자명     : 70319 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70319 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("s/pd/pd")
@Controller
public class SPDPDM01Controller {

    @Resource(name = "SPDPDM01Service")
    private SPDPDM01Service SPDPDM01;

    private static final Logger LOGGER = LoggerFactory.getLogger(SPDPDM01Controller.class);

    /**
     * <p>메소드명      : 상품분류관리 기본 조회 /selectMainInfo.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류를 기본 조회 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/selectMainInfo.do")
    public String SPDPDM01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SPDPDM01Controller SPDPDM01S01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_PRDTCLAS_SM", request, response, model);

            /** SPDPDM01S01 내역조회 업무 서비스 호출 입력값 대입 */
            SPDPDM01DSSMVO targetVo = new SPDPDM01DSSMVO();
            targetVo.setLrgeClasCd((String) sourceMap.get("lrgeClasCd") );   /** 상품대분류 */
            targetVo.setMidClasCd((String) sourceMap.get("midClasCd"));     /** 상품중분류 */
            targetVo.setSmClasCd((String) sourceMap.get("smClasCd"));       /** 상품소분류 */
            targetVo.setClasNm((String) sourceMap.get("clasNm"));           /** 분류명 */

            /** SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
            SPDPDM01InVO InVO = new SPDPDM01InVO();
            InVO.setSPDPDM01DSSMVO(targetVo);    /** 상품분류관리 DS_SMDO 입력값 VO 객체 대입 */
            /** SPDPDM01S01 내역조회 업무 서비스 호출 수행 */
            SPDPDM01OutVO resultList = SPDPDM01.getSelectMainInfo(InVO);
            XFrame5Util.setOutputData("DS_PRDTCLAS_SD", resultList.getSPDPDM01DSDDSSVO(), model);

            LOGGER.info("##### SPDPDM01Controller SPDPDM01S01 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.toString());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.toString());

            LOGGER.info("##### SPDPDM01Controller SPDPDM01S01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }



    /**
     * <p>메소드명      : 상품분류관리_저장(등록, 수정, 삭제) /registerConsProc.do </p>
     * <p>작성일자      : 2023. 3. 13
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리_저장(등록, 수정, 삭제) 한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings("unused")
    @RequestMapping("/registerMainInfo.do")
    public String SPDPDM01I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SPDPDM01Controller SPDPDM01I01 Start #####");

        try {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
        	Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_PRDTCLAS_SM", request, response, model);
            List<Map<String, Object>> sourceMapSDList = XFrame5DataSetUtil.getXFrameDataSetList("DS_PRDTCLAS_SD", request, response, model);


            /** SPDPDM01S01 내역조회 업무 서비스 호출 입력값 대입 */
            SPDPDM01DSSMVO targetVo = new SPDPDM01DSSMVO();
            targetVo.setLrgeClasCd((String) sourceMap.get("lrgeClasCd"));   /** 상품대분류 */
            targetVo.setMidClasCd((String) sourceMap.get("midClasCd"));    	/** 상품중분류 */
            targetVo.setSmClasCd((String) sourceMap.get("smClasCd"));       /** 상품소분류 */
            targetVo.setClasNm((String) sourceMap.get("clasNm"));           /** 분류명 */
            targetVo.setUserNo((String) sourceMap.get("userNo"));           /** 사용자번호 */

            /** 품의등록 업무 서비스 호출 입력값 대입 */
            SPDPDM01InVO InVO = new SPDPDM01InVO();

            InVO.setSPDPDM01DSSMVO(targetVo);

            List<SPDPDM01DSDDSSVO> inDsSdInsertList = new ArrayList<SPDPDM01DSDDSSVO>();
            List<SPDPDM01DSDDSSVO> inDsSdUpdateList = new ArrayList<SPDPDM01DSDDSSVO>();
            List<SPDPDM01DSDDSSVO> inDsSdDeleteList = new ArrayList<SPDPDM01DSDDSSVO>();

            for(int i=0; i<sourceMapSDList.size(); i++) {
            	SPDPDM01DSDDSSVO sourceVoSD = new SPDPDM01DSDDSSVO ();

            	Map<String, Object> sourceMapSD  = sourceMapSDList.get(i);

            	String RT = (String) sourceMapSD.get("XDATASET_RECORD_TYPE");
            	sourceVoSD.setPrdtClasCd((String) sourceMapSD.get("prdtClasCd"));
            	sourceVoSD.setLrgeClasCd((String) sourceMapSD.get("lrgeClasCd"));
            	sourceVoSD.setMidClasCd((String) sourceMapSD.get("midClasCd"));
            	sourceVoSD.setSmClasCd((String) sourceMapSD.get("smClasCd"));
            	sourceVoSD.setClasDivCd((String) sourceMapSD.get("clasDivCd"));
            	sourceVoSD.setClasNm((String) sourceMapSD.get("clasNm"));
            	sourceVoSD.setDdayPrftLoseFg((String) sourceMapSD.get("ddayPrftLoseFg"));
            	sourceVoSD.setDdayPrftLoseDivCd((String) sourceMapSD.get("ddayPrftLoseDivCd"));
            	sourceVoSD.setDdayPrftLoseDivVal((String) sourceMapSD.get("ddayPrftLoseDivVal"));
            	sourceVoSD.setDdayPrftLosePamtRamtRt((String) sourceMapSD.get("ddayPrftLosePamtRamtRt"));

            	if("I".equals(RT)) {
            		inDsSdInsertList.add(sourceVoSD);
            		/** 데이터 등록에 필요한 SDDO 셋팅 */
                    InVO.setSPDPDM01DSDDSSVO(inDsSdInsertList);

                    /** 품의등록 업무 서비스 호출 수행 */
                    SPDPDM01OutVO resultI01 = SPDPDM01.registerMainInfo(InVO);

            	} else if("U".equals(RT)) {
            		inDsSdUpdateList.add(sourceVoSD);
            		/** 데이터 등록에 필요한 SDDO 셋팅 */
                    InVO.setSPDPDM01DSDDSSVO(inDsSdUpdateList);

                    /** 품의등록 업무 서비스 호출 수행 */
                    SPDPDM01OutVO resultI01 = SPDPDM01.updateMainInfo(InVO);

            	} else if("D".equals(RT)) {
            		inDsSdDeleteList.add(sourceVoSD);
            		/** 데이터 등록에 필요한 SDDO 셋팅 */
            		InVO.setSPDPDM01DSDDSSVO(inDsSdDeleteList);

            		/** 품의등록 업무 서비스 호출 수행 */
					SPDPDM01OutVO resultI01 = SPDPDM01.deleteMainInfo(InVO);
            	}
            }

            // 등록 후 조회
            SPDPDM01OutVO resultIOut = SPDPDM01.getSelectMainInfo(InVO);

            XFrame5Util.setOutputData("DS_PRDTCLAS_SD", resultIOut.getSPDPDM01DSDDSSVO(), model);


            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Normal End #####");
        } catch (Exception e) {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### RCHMNM01Controller RCHMNM0101 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}