package hanalife.s.rm.rm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.StProdIruleMapper;
import hanalife.c.co.mapper.StRuleSubMapper;
import hanalife.c.co.mapper.dto.StPrdtBaseDTO;
import hanalife.c.co.mapper.dto.StProdIruleDTO;
import hanalife.c.co.mapper.dto.StRuleSubDTO;
import hanalife.s.rm.rm.service.SRMRMM01Service;
import hanalife.s.rm.rm.vo.SRMRMM01DSSTPRODIRULEVO;
import hanalife.s.rm.rm.vo.SRMRMM01InVO;
import hanalife.s.rm.rm.vo.SRMRMM01OutVO;
import hanalife.s.rm.rm.vo.SRMRMM03DSSTRULESUBVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SRMRMM01ServiceImpl.java Class
 * 클래스설명	: 룰 MAIN관리 (SRMRMM01) Service Implements
 * 작성일자	: 2023.04.13.
 * 작성자명	: 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][702809][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : SRMRMM01S02 : 상품 목록 조회
 * </pre>
 */


@Service("SRMRMM01Service")
public class SRMRMM01ServiceImpl implements SRMRMM01Service
{
    private static final Logger LOGGER = LoggerFactory.getLogger(SRMRMM01ServiceImpl.class);


    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;


    @Autowired
    private StProdIruleMapper stProdIruleMapper;

    @Autowired
    private StRuleSubMapper stRuleSubMapper;

    /**
     * <p>메소드명			: SRMRMM01S02 : 상품 목록 조회 (ST_PRDT_BASE)_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 상품 (ST_PRDT_BASE) 내역을 조회한다.</p>
     * <p>메소드인수		: SRMRMM01S01InVO </p>
     * <p>메소드리턴값		: SRMRMM01S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public SRMRMM01OutVO SRMRMM01S02(SRMRMM01InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM01ServiceImpl SRMRMM01S02 Start");

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM01OutVO resultVo = new SRMRMM01OutVO();

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StPrdtBaseDTO> resultDTO = stProdIruleMapper.selectPrdtList();

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM01DSSTPRODIRULEVO> resultList = new ArrayList<SRMRMM01DSSTPRODIRULEVO>();
        for (StPrdtBaseDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM01DSSTPRODIRULEVO targetIO = new SRMRMM01DSSTPRODIRULEVO();
            targetIO.setProdCd                  (sourceIO.getPrdtCd()        );   //
            targetIO.setProdNm                  (sourceIO.getPrdtNm()        );   //

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM01DSSTPRODIRULEVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM01S03 : RULE 목록 조회 (PROD-IRULE 형식) 조회</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE 목록을 조회한다.</p>
     * <p>메소드인수      : SRMRMM01S01InVO </p>
     * <p>메소드리턴값    : SRMRMM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM01OutVO SRMRMM01S03(SRMRMM01InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM01ServiceImpl SRMRMM01S03 Start");

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StProdIruleDTO oSearchDto = new StProdIruleDTO();

        oSearchDto.setRuleId       (inVo.getSRMRMM01DSSTPRODIRULEVO().getRuleId()     );    //

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StProdIruleDTO> resultDTO = stProdIruleMapper.selectProdIruleList(oSearchDto);

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM01OutVO resultVo = new SRMRMM01OutVO();

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM01DSSTPRODIRULEVO> resultList = new ArrayList<SRMRMM01DSSTPRODIRULEVO>();
        for (StProdIruleDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM01DSSTPRODIRULEVO targetIO = new SRMRMM01DSSTPRODIRULEVO();
            targetIO.setRuleType          (sourceIO.getRuleType()        );
            targetIO.setRuleId            (sourceIO.getRuleId()          );
            targetIO.setRuleNm            (sourceIO.getRuleNm()          );
            targetIO.setRemark            (sourceIO.getRemark()          );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()       );
            targetIO.setContent           (sourceIO.getContent()         );

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM01DSSTPRODIRULEVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM01S03 : 파라미터 목록 조회 (PROD-IRULE 형식) 조회</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE 목록을 조회한다.</p>
     * <p>메소드인수      : SRMRMM01S01InVO </p>
     * <p>메소드리턴값    : SRMRMM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM01OutVO SRMRMM01S04(SRMRMM01InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM01ServiceImpl SRMRMM01S04 Start");

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleSubDTO oSearchDto = new StRuleSubDTO();

        oSearchDto.setRuleId       (inVo.getSRMRMM01DSSTPRODIRULEVO().getRuleId()     );    //

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleSubDTO> resultDTO = stRuleSubMapper.selectList(oSearchDto);

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM01OutVO resultVo = new SRMRMM01OutVO();

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM03DSSTRULESUBVO> resultList = new ArrayList<SRMRMM03DSSTRULESUBVO>();
        for (StRuleSubDTO sourceIO : resultDTO)
        {
            SRMRMM03DSSTRULESUBVO targetIO = new SRMRMM03DSSTRULESUBVO();
            targetIO.setRuleType          (sourceIO.getRuleType()        );
            targetIO.setRuleId            (sourceIO.getRuleId()          );
            targetIO.setRuleNm            (sourceIO.getRuleNm()          );
            targetIO.setParamId           (sourceIO.getParamId()         );
            targetIO.setParamNm           (sourceIO.getParamNm()         );
            targetIO.setParamValue        (sourceIO.getParamValue()      );
            targetIO.setRemark            (sourceIO.getRemark()          );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()       );
            targetIO.setFrstRegDt         (sourceIO.getFrstRegDt()       );
            targetIO.setFrstRegTm         (sourceIO.getFrstRegTm()       );
            targetIO.setFrstRegEmpNo      (sourceIO.getFrstRegEmpNo()    );
            targetIO.setLastProcDt        (sourceIO.getLastProcDt()      );
            targetIO.setLastProcTm        (sourceIO.getLastProcTm()      );
            targetIO.setLastProcEmpNo     (sourceIO.getLastProcEmpNo()   );

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM03DSSTRULESUBVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM01S05 : PROD_IRULE 조회</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : PROD_IRULE 목록을 조회한다.</p>
     * <p>메소드인수      : SRMRMM01S01InVO </p>
     * <p>메소드리턴값    : SRMRMM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM01OutVO SRMRMM01S05(SRMRMM01InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM01ServiceImpl SRMRMM01S05 Start");

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StProdIruleDTO oSearchDto = new StProdIruleDTO();

        oSearchDto.setProdCd       (inVo.getSRMRMM01DSSTPRODIRULEVO().getProdCd()     );    //

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StProdIruleDTO> resultDTO = stProdIruleMapper.selectProdIruleList2(oSearchDto);

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM01OutVO resultVo = new SRMRMM01OutVO();

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM01DSSTPRODIRULEVO> resultList = new ArrayList<SRMRMM01DSSTPRODIRULEVO>();
        for (StProdIruleDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM01DSSTPRODIRULEVO targetIO = new SRMRMM01DSSTPRODIRULEVO();
            targetIO.setProdCd            (sourceIO.getProdCd()                                 );
            targetIO.setRuleType          (sourceIO.getRuleType()                               );
            targetIO.setRuleId            (sourceIO.getRuleId()                                 );
            targetIO.setRuleNm            (sourceIO.getRuleNm()                                 );
            targetIO.setRemark            (sourceIO.getRemark()                                 );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()                              );
            targetIO.setContent           (sourceIO.getContent()                                );
            targetIO.setFrstRegDt         (sourceIO.getFrstRegDt()                              );
            targetIO.setFrstRegTm         (sourceIO.getFrstRegTm()                              );
            targetIO.setFrstRegEmpNo      (sourceIO.getFrstRegEmpNo()                           );
            targetIO.setLastProcDt        (sourceIO.getLastProcDt()                             );
            targetIO.setLastProcTm        (sourceIO.getLastProcTm()                             );
            targetIO.setLastProcEmpNo     (sourceIO.getLastProcEmpNo()                          );
            // targetIO.setFrstRegDtTm       (sourceIO.getFrstRegDt() + sourceIO.getFrstRegTm()    );

            String sDtTm = sourceIO.getFrstRegDt().substring(0, 4) + "-"
                         + sourceIO.getFrstRegDt().substring(4, 6) + "-"
                         + sourceIO.getFrstRegDt().substring(6, 8) + " "
                         + sourceIO.getFrstRegTm().substring(0, 2) + ":"
                         + sourceIO.getFrstRegTm().substring(2, 4) + ":"
                         + sourceIO.getFrstRegTm().substring(4, 6);
            targetIO.setFrstRegDtTm       (sDtTm);

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM01DSSTPRODIRULEVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM01I01 : PROD_IRULE 조회</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : PROD_IRULE 목록을 등록한다.</p>
     * <p>메소드인수      : SRMRMM01S01InVO </p>
     * <p>메소드리턴값    : SRMRMM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM01OutVO SRMRMM01I01(SRMRMM01InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM01ServiceImpl SRMRMM01I01 Start");

        if (inVo.getListSRMRMM01DSSTPRODIRULEVO() == null  ||  inVo.getListSRMRMM01DSSTPRODIRULEVO().size() <= 0)
        {
            return null;
        }

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StProdIruleDTO oSearchDto = new StProdIruleDTO();
        oSearchDto.setProdCd       (inVo.getSRMRMM01DSSTPRODIRULEVO().getProdCd()     );    //

        StProdIruleDTO oNextValSeqNo = stProdIruleMapper.selectNextValSeqNo(oSearchDto);
        if (oNextValSeqNo == null)
        {
            return null;
        }

        for (int i = 0; i < inVo.getListSRMRMM01DSSTPRODIRULEVO().size(); i++)
        {
            StProdIruleDTO oInDto = new StProdIruleDTO();

            oInDto.setProdCd             (inVo.getListSRMRMM01DSSTPRODIRULEVO().get(i).getProdCd()           );
            oInDto.setRuleId             (inVo.getListSRMRMM01DSSTPRODIRULEVO().get(i).getRuleId()           );
            oInDto.setSeqNo              (oNextValSeqNo.getSeqNo()                                           ); // MAX(SEQ)_NO) + 1 이 처리되어 있음
            oInDto.setFrstRegEmpNo       (inVo.getListSRMRMM01DSSTPRODIRULEVO().get(i).getFrstRegEmpNo()     );
            oInDto.setLastProcEmpNo      (inVo.getListSRMRMM01DSSTPRODIRULEVO().get(i).getLastProcEmpNo()    );

            stProdIruleMapper.insert(oInDto);
        }

        return null;
    }
}