package hanalife.s.rm.rm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.StRuleMainHistMapper;
import hanalife.c.co.mapper.StRuleMainMapper;
import hanalife.c.co.mapper.dto.StRuleMainDTO;
import hanalife.c.co.mapper.dto.StRuleMainHistDTO;
import hanalife.s.rm.rm.service.SRMRMM02Service;
import hanalife.s.rm.rm.vo.SRMRMM02DSSTRULEMAINVO;
import hanalife.s.rm.rm.vo.SRMRMM02InVO;
import hanalife.s.rm.rm.vo.SRMRMM02OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SRMRMM02ServiceImpl.java Class
 * 클래스설명	: 룰 MAIN관리 (SRMRMM02) Service Implements
 * 작성일자	: 2023.04.13.
 * 작성자명	: 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][702809][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSRMRMM02S01 : 룰 MAIN관리내역_조회
 * </pre>
 */

@Service("SRMRMM02Service")
public class SRMRMM02ServiceImpl implements SRMRMM02Service
{
    private static final Logger LOGGER = LoggerFactory.getLogger(SRMRMM02ServiceImpl.class);


    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;


    @Autowired
    private StRuleMainMapper stRuleMainMapper;

    @Autowired
    private StRuleMainHistMapper stRuleMainHistMapper;


    /**
     * <p>메소드명			: getSRMRMM02S01 : 룰 MAIN(CT_COMM_CD_KIND) 내역_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 룰 MAIN(CT_COMM_CD_KIND) 내역을 조회한다.</p>
     * <p>메소드인수		: SRMRMM02S01InVO </p>
     * <p>메소드리턴값		: SRMRMM02S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public SRMRMM02OutVO SRMRMM02S01(SRMRMM02InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM02ServiceImpl SRMRMM02S01 Start");

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM02OutVO resultVo = new SRMRMM02OutVO();

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleMainDTO oSearchDto = new StRuleMainDTO();

        oSearchDto.setRuleType     (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleType()   );  /* 코드_종류_번호 */
        oSearchDto.setRuleId       (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleId()     );  /* 코드_종류_명 */

        LOGGER.info("" + "oSearchDto.getRuleType()  : " + oSearchDto.getRuleType());
        LOGGER.info("" + "oSearchDto.getRuleId()    : " + oSearchDto.getRuleId()  );

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleMainDTO> resultDTO = stRuleMainMapper.selectList(oSearchDto);

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM02DSSTRULEMAINVO> resultList = new ArrayList<SRMRMM02DSSTRULEMAINVO>();
        for (StRuleMainDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM02DSSTRULEMAINVO targetIO = new SRMRMM02DSSTRULEMAINVO();
            targetIO.setRuleType                (sourceIO.getRuleType()        );   /* */
            targetIO.setRuleId                  (sourceIO.getRuleId()          );   /* */
            targetIO.setRuleNm                  (sourceIO.getRuleNm()          );   /* */
            targetIO.setRemark                  (sourceIO.getRemark()          );   /* */
            targetIO.setRecSttsCd               (sourceIO.getRecSttsCd()       );   /* */
            targetIO.setFrstRegDt               (sourceIO.getFrstRegDt()       );   /* */
            targetIO.setFrstRegTm               (sourceIO.getFrstRegTm()       );   /* */
            targetIO.setFrstRegEmpNo            (sourceIO.getFrstRegEmpNo()    );   /* */
            targetIO.setLastProcDt              (sourceIO.getLastProcDt()      );   /* */
            targetIO.setLastProcTm              (sourceIO.getLastProcTm()      );   /* */
            targetIO.setLastProcEmpNo           (sourceIO.getLastProcEmpNo()   );   /* */

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM02DSSTRULEMAINVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM02S01 : RULE MAIN 내역 등록</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE MAIN 내역을 등록한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM02OutVO SRMRMM02I01(SRMRMM02InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM02ServiceImpl SRMRMM02I01 Start");

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM02OutVO resultVo = new SRMRMM02OutVO();

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleMainDTO oInDto = new StRuleMainDTO();

        oInDto.setRuleType      (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleType().trim()      );
        oInDto.setRuleId        (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleId().trim()        );
        oInDto.setRuleNm        (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleNm().trim()        );
        oInDto.setRemark        (inVo.getSRMRMM02DSSTRULEMAINVO().getRemark().trim()        );
        oInDto.setRecSttsCd     (inVo.getSRMRMM02DSSTRULEMAINVO().getRecSttsCd().trim()     );
        oInDto.setFrstRegEmpNo  (inVo.getSRMRMM02DSSTRULEMAINVO().getFrstRegEmpNo().trim()  );
        oInDto.setLastProcEmpNo (inVo.getSRMRMM02DSSTRULEMAINVO().getLastProcEmpNo().trim() );

        if (oInDto.getRecSttsCd().equals("") == true)
        {
            // 기본값 사용으로 처리
            oInDto.setRecSttsCd (Constants.S12019_USE);
        }

        LOGGER.info("" + "oInDto.getRuleType()       : " + oInDto.getRuleType()      );
        LOGGER.info("" + "oInDto.getRuleId()         : " + oInDto.getRuleId()        );
        LOGGER.info("" + "oInDto.getRuleNm()         : " + oInDto.getRuleNm()        );
        LOGGER.info("" + "oInDto.getRemark()         : " + oInDto.getRemark()        );
        LOGGER.info("" + "oInDto.getRecSttsCd()      : " + oInDto.getRecSttsCd()     );
        LOGGER.info("" + "oInDto.getFrstRegEmpNo()   : " + oInDto.getFrstRegEmpNo()  );
        LOGGER.info("" + "oInDto.getLastProcEmpNo()  : " + oInDto.getLastProcEmpNo() );

        // 룰 MAIN 내역 등록 쿼리 Mapper 호출 수행
        stRuleMainMapper.insert(oInDto);

        insertStRuleMainHist(oInDto.getRuleType(), oInDto.getRuleId(), oInDto.getFrstRegEmpNo());

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleMainDTO> resultDTO = stRuleMainMapper.selectList(oInDto);

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM02DSSTRULEMAINVO> resultList = new ArrayList<SRMRMM02DSSTRULEMAINVO>();
        for (StRuleMainDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM02DSSTRULEMAINVO targetIO = new SRMRMM02DSSTRULEMAINVO();
            targetIO.setRuleType                (sourceIO.getRuleType()        );   /* */
            targetIO.setRuleId                  (sourceIO.getRuleId()          );   /* */
            targetIO.setRuleNm                  (sourceIO.getRuleNm()          );   /* */
            targetIO.setRemark                  (sourceIO.getRemark()          );   /* */
            targetIO.setRecSttsCd               (sourceIO.getRecSttsCd()       );   /* */
            targetIO.setFrstRegDt               (sourceIO.getFrstRegDt()       );   /* */
            targetIO.setFrstRegTm               (sourceIO.getFrstRegTm()       );   /* */
            targetIO.setFrstRegEmpNo            (sourceIO.getFrstRegEmpNo()    );   /* */
            targetIO.setLastProcDt              (sourceIO.getLastProcDt()      );   /* */
            targetIO.setLastProcTm              (sourceIO.getLastProcTm()      );   /* */
            targetIO.setLastProcEmpNo           (sourceIO.getLastProcEmpNo()   );   /* */

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM02DSSTRULEMAINVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM02S01 : RULE MAIN 내역 수정</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE MAIN 내역을 수정한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM02OutVO SRMRMM02U01(SRMRMM02InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM02ServiceImpl SRMRMM02U01 Start");

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM02OutVO resultVo = new SRMRMM02OutVO();

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleMainDTO oInDto = new StRuleMainDTO();

        oInDto.setRuleType      (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleType().trim()      );
        oInDto.setRuleId        (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleId().trim()        );
        oInDto.setRuleNm        (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleNm().trim()        );
        oInDto.setRemark        (inVo.getSRMRMM02DSSTRULEMAINVO().getRemark().trim()        );
        oInDto.setRecSttsCd     (inVo.getSRMRMM02DSSTRULEMAINVO().getRecSttsCd().trim()     );
        oInDto.setFrstRegEmpNo  (inVo.getSRMRMM02DSSTRULEMAINVO().getFrstRegEmpNo().trim()  );
        oInDto.setLastProcEmpNo (inVo.getSRMRMM02DSSTRULEMAINVO().getLastProcEmpNo().trim() );

        LOGGER.info("" + "oInDto.getRuleType()       : " + oInDto.getRuleType()      );
        LOGGER.info("" + "oInDto.getRuleId()         : " + oInDto.getRuleId()        );
        LOGGER.info("" + "oInDto.getRuleNm()         : " + oInDto.getRuleNm()        );
        LOGGER.info("" + "oInDto.getRemark()         : " + oInDto.getRemark()        );
        LOGGER.info("" + "oInDto.getRecSttsCd()      : " + oInDto.getRecSttsCd()     );
        LOGGER.info("" + "oInDto.getFrstRegEmpNo()   : " + oInDto.getFrstRegEmpNo()  );
        LOGGER.info("" + "oInDto.getLastProcEmpNo()  : " + oInDto.getLastProcEmpNo() );

        // 룰 MAIN 내역 등록 쿼리 Mapper 호출 수행
        stRuleMainMapper.update(oInDto);

        insertStRuleMainHist(oInDto.getRuleType(), oInDto.getRuleId(), oInDto.getLastProcEmpNo());

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleMainDTO> resultDTO = stRuleMainMapper.selectList(oInDto);

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM02DSSTRULEMAINVO> resultList = new ArrayList<SRMRMM02DSSTRULEMAINVO>();
        for (StRuleMainDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM02DSSTRULEMAINVO targetIO = new SRMRMM02DSSTRULEMAINVO();
            targetIO.setRuleType                (sourceIO.getRuleType()        );   /* */
            targetIO.setRuleId                  (sourceIO.getRuleId()          );   /* */
            targetIO.setRuleNm                  (sourceIO.getRuleNm()          );   /* */
            targetIO.setRemark                  (sourceIO.getRemark()          );   /* */
            targetIO.setRecSttsCd               (sourceIO.getRecSttsCd()       );   /* */
            targetIO.setFrstRegDt               (sourceIO.getFrstRegDt()       );   /* */
            targetIO.setFrstRegTm               (sourceIO.getFrstRegTm()       );   /* */
            targetIO.setFrstRegEmpNo            (sourceIO.getFrstRegEmpNo()    );   /* */
            targetIO.setLastProcDt              (sourceIO.getLastProcDt()      );   /* */
            targetIO.setLastProcTm              (sourceIO.getLastProcTm()      );   /* */
            targetIO.setLastProcEmpNo           (sourceIO.getLastProcEmpNo()   );   /* */

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM02DSSTRULEMAINVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM02S01 : RULE MAIN 내역 삭제</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE MAIN 내역을 삭제한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM02OutVO SRMRMM02D01(SRMRMM02InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM02ServiceImpl SRMRMM02D01 Start");

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM02OutVO resultVo = new SRMRMM02OutVO();

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleMainDTO oInDto = new StRuleMainDTO();

        oInDto.setRuleType      (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleType().trim()      );
        oInDto.setRuleId        (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleId().trim()        );
        oInDto.setRuleNm        (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleNm().trim()        );
        oInDto.setRemark        (inVo.getSRMRMM02DSSTRULEMAINVO().getRemark().trim()        );
        oInDto.setRecSttsCd     (inVo.getSRMRMM02DSSTRULEMAINVO().getRecSttsCd().trim()     );
        oInDto.setFrstRegEmpNo  (inVo.getSRMRMM02DSSTRULEMAINVO().getFrstRegEmpNo().trim()  );
        oInDto.setLastProcEmpNo (inVo.getSRMRMM02DSSTRULEMAINVO().getLastProcEmpNo().trim() );

        LOGGER.info("" + "oInDto.getRuleType()       : " + oInDto.getRuleType()      );
        LOGGER.info("" + "oInDto.getRuleId()         : " + oInDto.getRuleId()        );
        LOGGER.info("" + "oInDto.getRuleNm()         : " + oInDto.getRuleNm()        );
        LOGGER.info("" + "oInDto.getRemark()         : " + oInDto.getRemark()        );
        LOGGER.info("" + "oInDto.getRecSttsCd()      : " + oInDto.getRecSttsCd()     );
        LOGGER.info("" + "oInDto.getFrstRegEmpNo()   : " + oInDto.getFrstRegEmpNo()  );
        LOGGER.info("" + "oInDto.getLastProcEmpNo()  : " + oInDto.getLastProcEmpNo() );

        insertStRuleMainHist(oInDto.getRuleType(), oInDto.getRuleId(), oInDto.getLastProcEmpNo());

        // 룰 MAIN 내역 등록 쿼리 Mapper 호출 수행
        stRuleMainMapper.delete(oInDto);

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleMainDTO> resultDTO = stRuleMainMapper.selectList(oInDto);

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM02DSSTRULEMAINVO> resultList = new ArrayList<SRMRMM02DSSTRULEMAINVO>();
        for (StRuleMainDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM02DSSTRULEMAINVO targetIO = new SRMRMM02DSSTRULEMAINVO();
            targetIO.setRuleType                (sourceIO.getRuleType()        );   /* */
            targetIO.setRuleId                  (sourceIO.getRuleId()          );   /* */
            targetIO.setRuleNm                  (sourceIO.getRuleNm()          );   /* */
            targetIO.setRemark                  (sourceIO.getRemark()          );   /* */
            targetIO.setRecSttsCd               (sourceIO.getRecSttsCd()       );   /* */
            targetIO.setFrstRegDt               (sourceIO.getFrstRegDt()       );   /* */
            targetIO.setFrstRegTm               (sourceIO.getFrstRegTm()       );   /* */
            targetIO.setFrstRegEmpNo            (sourceIO.getFrstRegEmpNo()    );   /* */
            targetIO.setLastProcDt              (sourceIO.getLastProcDt()      );   /* */
            targetIO.setLastProcTm              (sourceIO.getLastProcTm()      );   /* */
            targetIO.setLastProcEmpNo           (sourceIO.getLastProcEmpNo()   );   /* */

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM02DSSTRULEMAINVO(resultList);

        return resultVo;
    }


    private int getNextVal_StRuleMainHist_SeqNo(String sRuleType, String sRuleId) throws Exception
    {
        int nNextVal = 0;

        StRuleMainHistDTO oDto = new StRuleMainHistDTO();
        oDto.setRuleType      (sRuleType);
        oDto.setRuleId        (sRuleId);

        try
        {
            oDto = stRuleMainHistMapper.selectNextValSeqNo(oDto);
            nNextVal = oDto.getSeqNo();
        }
        catch (Exception e)
        {
            throw e;
        }

        return nNextVal;
    }


    private boolean insertStRuleMainHist(String sRuleType, String sRuleId, String sLastProcEmpNo) throws Exception
    {
        // 룰 이력 생성 입력값 객체 생성 및 대입 수행
        StRuleMainDTO oSelectDto = new StRuleMainDTO();
        oSelectDto.setRuleType(sRuleType);
        oSelectDto.setRuleId  (sRuleId);

        oSelectDto = stRuleMainMapper.select(oSelectDto);

        if (oSelectDto == null)
        {
            return false;
        }

        int nNextVal_StRuleMainHist_SeqNo = getNextVal_StRuleMainHist_SeqNo(sRuleType, sRuleId);
        if (nNextVal_StRuleMainHist_SeqNo <= 0)
        {
            return false;
        }

        // 룰 이력 생성 입력값 객체 생성 및 대입 수행
        StRuleMainHistDTO oInsertDto = new StRuleMainHistDTO();
        oInsertDto.setRuleType      (oSelectDto.getRuleType()        );
        oInsertDto.setRuleId        (oSelectDto.getRuleId()          );
        oInsertDto.setSeqNo         (nNextVal_StRuleMainHist_SeqNo   );
        oInsertDto.setRuleNm        (oSelectDto.getRuleNm()          );
        oInsertDto.setRemark        (oSelectDto.getRemark()          );
        oInsertDto.setRecSttsCd     (oSelectDto.getRecSttsCd()       );
        oInsertDto.setFrstRegDt     (oSelectDto.getFrstRegDt()       );
        oInsertDto.setFrstRegTm     (oSelectDto.getFrstRegTm()       );
        oInsertDto.setFrstRegEmpNo  (oSelectDto.getFrstRegEmpNo()    );
        // oInsertDto.setLastProcDt (oSelectDto.getLastProcDt()      );
        // oInsertDto.setLastProcTm (oSelectDto.getLastProcTm()      );
        oInsertDto.setLastProcEmpNo (sLastProcEmpNo                  );

        stRuleMainHistMapper.insert(oInsertDto);

        return true;
    }
}