package hanalife.s.rm.rm.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.StRuleMainMapper;
import hanalife.c.co.mapper.StRuleSubHistMapper;
import hanalife.c.co.mapper.StRuleSubMapper;
import hanalife.c.co.mapper.dto.StRuleMainDTO;
import hanalife.c.co.mapper.dto.StRuleSubDTO;
import hanalife.c.co.mapper.dto.StRuleSubHistDTO;
import hanalife.s.rm.rm.service.SRMRMM03Service;
import hanalife.s.rm.rm.vo.SRMRMM02DSSTRULEMAINVO;
import hanalife.s.rm.rm.vo.SRMRMM03DSSTRULESUBVO;
import hanalife.s.rm.rm.vo.SRMRMM03InVO;
import hanalife.s.rm.rm.vo.SRMRMM03OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SRMRMM03ServiceImpl.java Class
 * 클래스설명	: 룰 MAIN관리 (SRMRMM03) Service Implements
 * 작성일자	: 2023.04.13.
 * 작성자명	: 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][702809][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSRMRMM03S01 : 룰 MAIN관리내역_조회
 * </pre>
 */

@Service("SRMRMM03Service")
public class SRMRMM03ServiceImpl implements SRMRMM03Service
{
    private static final Logger LOGGER = LoggerFactory.getLogger(SRMRMM03ServiceImpl.class);


    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;


    @Autowired
    private StRuleMainMapper stRuleMainMapper;

    @Autowired
    private StRuleSubMapper stRuleSubMapper;

    @Autowired
    private StRuleSubHistMapper stRuleSubHistMapper;


    /**
     * <p>메소드명			: getSRMRMM03S01 : 룰 MAIN(CT_COMM_CD_KIND) 내역_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 룰 MAIN(CT_COMM_CD_KIND) 내역을 조회한다.</p>
     * <p>메소드인수		: SRMRMM03S01InVO </p>
     * <p>메소드리턴값		: SRMRMM03S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public SRMRMM03OutVO SRMRMM03S01(SRMRMM03InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM03ServiceImpl SRMRMM03S01 Start");

        // 룰 MAIN관리 내역 서비스 결과값 객체 생성
        SRMRMM03OutVO resultVo = new SRMRMM03OutVO();

        // 룰 MAIN관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleMainDTO oSearchDto = new StRuleMainDTO();

        oSearchDto.setRuleType     (inVo.getSRMRMM02DSSTRULEMAINVO().getRuleType()   );  /* 코드_종류_번호 */

        LOGGER.info("" + "oSearchDto.getRuleType()  : " + oSearchDto.getRuleType());

        // 룰 MAIN 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleMainDTO> resultDTO = stRuleMainMapper.selectList2(oSearchDto);

        // 룰 MAIN 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM02DSSTRULEMAINVO> resultList = new ArrayList<SRMRMM02DSSTRULEMAINVO>();
        for (StRuleMainDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM02DSSTRULEMAINVO targetIO = new SRMRMM02DSSTRULEMAINVO();
            targetIO.setRuleType                (sourceIO.getRuleType()        );   /* */
            targetIO.setRuleId                  (sourceIO.getRuleId()          );   /* */
            targetIO.setRuleNm                  (sourceIO.getRuleNm()          );   /* */

            // 룰 MAIN 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 MAIN내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM02DSSTRULEMAINVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명			: getSRMRMM03S01 : 룰 SUB 내역_조회</p>
     * <p>작성일자			: 2023.03.30.
     * <p>작성자(author)	: 70280 / 성관용
     * <p>설명			    : 룰 SUB 내역을 조회한다.</p>
     * <p>메소드인수		: SRMRMM03S01InVO </p>
     * <p>메소드리턴값		: SRMRMM03S01OutVO</p>
     * <p>예외처리			: Exception</p>
     */
    @Override
    public SRMRMM03OutVO SRMRMM03S02(SRMRMM03InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM03ServiceImpl SRMRMM03S02 Start");

        // 룰 SUB 내역 서비스 결과값 객체 생성
        SRMRMM03OutVO resultVo = new SRMRMM03OutVO();

        // 룰 SUB 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleSubDTO oSearchDto = new StRuleSubDTO();

        oSearchDto.setRuleType     (inVo.getSRMRMM03DSSTRULESUBVO().getRuleType()   );  //
        oSearchDto.setRuleId       (inVo.getSRMRMM03DSSTRULESUBVO().getRuleId()     );  //
        oSearchDto.setParamId      (inVo.getSRMRMM03DSSTRULESUBVO().getParamId()    );  //

        LOGGER.info("" + "oSearchDto.getRuleType()  : " + oSearchDto.getRuleType());
        LOGGER.info("" + "oSearchDto.getRuleId()    : " + oSearchDto.getRuleId()  );
        LOGGER.info("" + "oSearchDto.getParamId()   : " + oSearchDto.getParamId() );

        // 룰 SUB 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleSubDTO> resultDTO = stRuleSubMapper.selectList(oSearchDto);

        // 룰 SUB 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM03DSSTRULESUBVO> resultList = new ArrayList<SRMRMM03DSSTRULESUBVO>();
        for (StRuleSubDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM03DSSTRULESUBVO targetIO = new SRMRMM03DSSTRULESUBVO();
            targetIO.setRuleType          (sourceIO.getRuleType()        );
            targetIO.setRuleId            (sourceIO.getRuleId()          );
            targetIO.setRuleNm            (sourceIO.getRuleNm()          );
            targetIO.setParamId           (sourceIO.getParamId()         );
            targetIO.setParamNm           (sourceIO.getParamNm()         );
            targetIO.setParamValue        (sourceIO.getParamValue()      );
            targetIO.setRemark            (sourceIO.getRemark()          );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()       );
            targetIO.setFrstRegDt         (sourceIO.getFrstRegDt()       );
            targetIO.setFrstRegTm         (sourceIO.getFrstRegTm()       );
            targetIO.setFrstRegEmpNo      (sourceIO.getFrstRegEmpNo()    );
            targetIO.setLastProcDt        (sourceIO.getLastProcDt()      );
            targetIO.setLastProcTm        (sourceIO.getLastProcTm()      );
            targetIO.setLastProcEmpNo     (sourceIO.getLastProcEmpNo()   );

            // 룰 SUB 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 SUB내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM03DSSTRULESUBVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM03S01 : RULE SUB 내역 등록</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE SUB 내역을 등록한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM03OutVO SRMRMM03I01(SRMRMM03InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM03ServiceImpl SRMRMM03I01 Start");

        // 룰 SUB관리 내역 서비스 결과값 객체 생성
        SRMRMM03OutVO resultVo = new SRMRMM03OutVO();

        // 룰 SUB관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleSubDTO oInDto = new StRuleSubDTO();

        oInDto.setRuleType      (inVo.getSRMRMM03DSSTRULESUBVO().getRuleType().trim()      );
        oInDto.setRuleId        (inVo.getSRMRMM03DSSTRULESUBVO().getRuleId().trim()        );
        oInDto.setParamId       (inVo.getSRMRMM03DSSTRULESUBVO().getParamId().trim()       );
        oInDto.setParamNm       (inVo.getSRMRMM03DSSTRULESUBVO().getParamNm().trim()       );
        oInDto.setParamValue    (inVo.getSRMRMM03DSSTRULESUBVO().getParamValue().trim()    );
        oInDto.setRemark        (inVo.getSRMRMM03DSSTRULESUBVO().getRemark().trim()        );
        oInDto.setRecSttsCd     (inVo.getSRMRMM03DSSTRULESUBVO().getRecSttsCd().trim()     );
        oInDto.setFrstRegEmpNo  (inVo.getSRMRMM03DSSTRULESUBVO().getFrstRegEmpNo().trim()  );
        oInDto.setLastProcEmpNo (inVo.getSRMRMM03DSSTRULESUBVO().getLastProcEmpNo().trim() );

        if (oInDto.getRecSttsCd().equals("") == true)
        {
            // 기본값 사용으로 처리
            oInDto.setRecSttsCd (Constants.S12019_USE);
        }

        LOGGER.info("" + "oInDto.getRuleType()       : " + oInDto.getRuleType()      );
        LOGGER.info("" + "oInDto.getRuleId()         : " + oInDto.getRuleId()        );
        LOGGER.info("" + "oInDto.getParamId()        : " + oInDto.getParamId()       );
        LOGGER.info("" + "oInDto.getParamNm()        : " + oInDto.getParamNm()       );
        LOGGER.info("" + "oInDto.getParamValue()     : " + oInDto.getParamValue()    );
        LOGGER.info("" + "oInDto.getRemark()         : " + oInDto.getRemark()        );
        LOGGER.info("" + "oInDto.getRecSttsCd()      : " + oInDto.getRecSttsCd()     );
        LOGGER.info("" + "oInDto.getFrstRegEmpNo()   : " + oInDto.getFrstRegEmpNo()  );
        LOGGER.info("" + "oInDto.getLastProcEmpNo()  : " + oInDto.getLastProcEmpNo() );

        // 룰 SUB 내역 등록 쿼리 Mapper 호출 수행
        stRuleSubMapper.insert(oInDto);

        insertStRuleSubHist(oInDto.getRuleType(), oInDto.getRuleId(), oInDto.getParamId(), oInDto.getFrstRegEmpNo());

        // 룰 SUB 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleSubDTO> resultDTO = stRuleSubMapper.selectList(oInDto);

        // 룰 SUB 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM03DSSTRULESUBVO> resultList = new ArrayList<SRMRMM03DSSTRULESUBVO>();
        for (StRuleSubDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM03DSSTRULESUBVO targetIO = new SRMRMM03DSSTRULESUBVO();
            targetIO.setRuleType          (sourceIO.getRuleType()        );
            targetIO.setRuleId            (sourceIO.getRuleId()          );
            targetIO.setRuleNm            (sourceIO.getRuleNm()          );
            targetIO.setParamId           (sourceIO.getParamId()         );
            targetIO.setParamNm           (sourceIO.getParamNm()         );
            targetIO.setParamValue        (sourceIO.getParamValue()      );
            targetIO.setRemark            (sourceIO.getRemark()          );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()       );
            targetIO.setFrstRegDt         (sourceIO.getFrstRegDt()       );
            targetIO.setFrstRegTm         (sourceIO.getFrstRegTm()       );
            targetIO.setFrstRegEmpNo      (sourceIO.getFrstRegEmpNo()    );
            targetIO.setLastProcDt        (sourceIO.getLastProcDt()      );
            targetIO.setLastProcTm        (sourceIO.getLastProcTm()      );
            targetIO.setLastProcEmpNo     (sourceIO.getLastProcEmpNo()   );

            // 룰 SUB 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 SUB내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM03DSSTRULESUBVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM03S01 : RULE SUB 내역 수정</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE SUB 내역을 수정한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM03OutVO SRMRMM03U01(SRMRMM03InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM03ServiceImpl SRMRMM03U01 Start");

        // 룰 SUB관리 내역 서비스 결과값 객체 생성
        SRMRMM03OutVO resultVo = new SRMRMM03OutVO();

        // 룰 SUB관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleSubDTO oInDto = new StRuleSubDTO();

        oInDto.setRuleType      (inVo.getSRMRMM03DSSTRULESUBVO().getRuleType().trim()      );
        oInDto.setRuleId        (inVo.getSRMRMM03DSSTRULESUBVO().getRuleId().trim()        );
        oInDto.setParamId       (inVo.getSRMRMM03DSSTRULESUBVO().getParamId().trim()       );
        oInDto.setParamNm       (inVo.getSRMRMM03DSSTRULESUBVO().getParamNm().trim()       );
        oInDto.setParamValue    (inVo.getSRMRMM03DSSTRULESUBVO().getParamValue().trim()    );
        oInDto.setRemark        (inVo.getSRMRMM03DSSTRULESUBVO().getRemark().trim()        );
        oInDto.setRecSttsCd     (inVo.getSRMRMM03DSSTRULESUBVO().getRecSttsCd().trim()     );
        oInDto.setFrstRegEmpNo  (inVo.getSRMRMM03DSSTRULESUBVO().getFrstRegEmpNo().trim()  );
        oInDto.setLastProcEmpNo (inVo.getSRMRMM03DSSTRULESUBVO().getLastProcEmpNo().trim() );

        LOGGER.info("" + "oInDto.getRuleType()       : " + oInDto.getRuleType()      );
        LOGGER.info("" + "oInDto.getRuleId()         : " + oInDto.getRuleId()        );
        LOGGER.info("" + "oInDto.getParamId()        : " + oInDto.getParamId()       );
        LOGGER.info("" + "oInDto.getParamNm()        : " + oInDto.getParamNm()       );
        LOGGER.info("" + "oInDto.getParamValue()     : " + oInDto.getParamValue()    );
        LOGGER.info("" + "oInDto.getRemark()         : " + oInDto.getRemark()        );
        LOGGER.info("" + "oInDto.getRecSttsCd()      : " + oInDto.getRecSttsCd()     );
        LOGGER.info("" + "oInDto.getFrstRegEmpNo()   : " + oInDto.getFrstRegEmpNo()  );
        LOGGER.info("" + "oInDto.getLastProcEmpNo()  : " + oInDto.getLastProcEmpNo() );

        // 룰 SUB 내역 등록 쿼리 Mapper 호출 수행
        stRuleSubMapper.update(oInDto);

        insertStRuleSubHist(oInDto.getRuleType(), oInDto.getRuleId(), oInDto.getParamId(), oInDto.getLastProcEmpNo());

        // 룰 SUB 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleSubDTO> resultDTO = stRuleSubMapper.selectList(oInDto);

        // 룰 SUB 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM03DSSTRULESUBVO> resultList = new ArrayList<SRMRMM03DSSTRULESUBVO>();
        for (StRuleSubDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM03DSSTRULESUBVO targetIO = new SRMRMM03DSSTRULESUBVO();

            targetIO.setRuleType          (sourceIO.getRuleType()        );
            targetIO.setRuleId            (sourceIO.getRuleId()          );
            targetIO.setRuleNm            (sourceIO.getRuleNm()          );
            targetIO.setParamId           (sourceIO.getParamId()         );
            targetIO.setParamNm           (sourceIO.getParamNm()         );
            targetIO.setParamValue        (sourceIO.getParamValue()      );
            targetIO.setRemark            (sourceIO.getRemark()          );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()       );
            targetIO.setFrstRegDt         (sourceIO.getFrstRegDt()       );
            targetIO.setFrstRegTm         (sourceIO.getFrstRegTm()       );
            targetIO.setFrstRegEmpNo      (sourceIO.getFrstRegEmpNo()    );
            targetIO.setLastProcDt        (sourceIO.getLastProcDt()      );
            targetIO.setLastProcTm        (sourceIO.getLastProcTm()      );
            targetIO.setLastProcEmpNo     (sourceIO.getLastProcEmpNo()   );

            // 룰 SUB 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 SUB내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM03DSSTRULESUBVO(resultList);

        return resultVo;
    }


    /**
     * <p>메소드명        : SRMRMM03S01 : RULE SUB 내역 삭제</p>
     * <p>작성일자        : 2023.04.13.
     * <p>작성자(author)  : 70280 / 성관용
     * <p>설명            : RULE SUB 내역을 삭제한다.</p>
     * <p>메소드인수      : CBCCCM01S01InVO </p>
     * <p>메소드리턴값    : CBCCCM01S01OutVO</p>
     * <p>예외처리        : Exception</p>
     */
    @Override
    public SRMRMM03OutVO SRMRMM03D01(SRMRMM03InVO inVo) throws Exception
    {
        LOGGER.debug("SRMRMM03ServiceImpl SRMRMM03D01 Start");

        // 룰 SUB관리 내역 서비스 결과값 객체 생성
        SRMRMM03OutVO resultVo = new SRMRMM03OutVO();

        // 룰 SUB관리 내역조회 조건 입력값 객체 생성 및 대입 수행
        StRuleSubDTO oInDto = new StRuleSubDTO();

        oInDto.setRuleType      (inVo.getSRMRMM03DSSTRULESUBVO().getRuleType().trim()      );
        oInDto.setRuleId        (inVo.getSRMRMM03DSSTRULESUBVO().getRuleId().trim()        );
        oInDto.setParamId       (inVo.getSRMRMM03DSSTRULESUBVO().getParamId().trim()       );
        oInDto.setParamNm       (inVo.getSRMRMM03DSSTRULESUBVO().getParamNm().trim()       );
        oInDto.setParamValue    (inVo.getSRMRMM03DSSTRULESUBVO().getParamValue().trim()    );
        oInDto.setRemark        (inVo.getSRMRMM03DSSTRULESUBVO().getRemark().trim()        );
        oInDto.setRecSttsCd     (inVo.getSRMRMM03DSSTRULESUBVO().getRecSttsCd().trim()     );
        oInDto.setFrstRegEmpNo  (inVo.getSRMRMM03DSSTRULESUBVO().getFrstRegEmpNo().trim()  );
        oInDto.setLastProcEmpNo (inVo.getSRMRMM03DSSTRULESUBVO().getLastProcEmpNo().trim() );

        LOGGER.info("" + "oInDto.getRuleType()       : " + oInDto.getRuleType()      );
        LOGGER.info("" + "oInDto.getRuleId()         : " + oInDto.getRuleId()        );
        LOGGER.info("" + "oInDto.getParamId()        : " + oInDto.getParamId()       );
        LOGGER.info("" + "oInDto.getParamNm()        : " + oInDto.getParamNm()       );
        LOGGER.info("" + "oInDto.getParamValue()     : " + oInDto.getParamValue()    );
        LOGGER.info("" + "oInDto.getRemark()         : " + oInDto.getRemark()        );
        LOGGER.info("" + "oInDto.getRecSttsCd()      : " + oInDto.getRecSttsCd()     );
        LOGGER.info("" + "oInDto.getFrstRegEmpNo()   : " + oInDto.getFrstRegEmpNo()  );
        LOGGER.info("" + "oInDto.getLastProcEmpNo()  : " + oInDto.getLastProcEmpNo() );

        insertStRuleSubHist(oInDto.getRuleType(), oInDto.getRuleId(), oInDto.getParamId(), oInDto.getLastProcEmpNo());

        // 룰 SUB 내역 등록 쿼리 Mapper 호출 수행
        stRuleSubMapper.delete(oInDto);

        // 룰 SUB 내역 조회 쿼리 Mapper 호출 수행
        List<StRuleSubDTO> resultDTO = stRuleSubMapper.selectList(oInDto);

        // 룰 SUB 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SRMRMM03DSSTRULESUBVO> resultList = new ArrayList<SRMRMM03DSSTRULESUBVO>();
        for (StRuleSubDTO sourceIO : resultDTO)
        {
            // 상수리스트관리내역조회 VO에 조회된 Mapper DTO 값을 대입
            SRMRMM03DSSTRULESUBVO targetIO = new SRMRMM03DSSTRULESUBVO();
            targetIO.setRuleType          (sourceIO.getRuleType()        );
            targetIO.setRuleId            (sourceIO.getRuleId()          );
            targetIO.setRuleNm            (sourceIO.getRuleNm()          );
            targetIO.setParamId           (sourceIO.getParamId()         );
            targetIO.setParamNm           (sourceIO.getParamNm()         );
            targetIO.setParamValue        (sourceIO.getParamValue()      );
            targetIO.setRemark            (sourceIO.getRemark()          );
            targetIO.setRecSttsCd         (sourceIO.getRecSttsCd()       );
            targetIO.setFrstRegDt         (sourceIO.getFrstRegDt()       );
            targetIO.setFrstRegTm         (sourceIO.getFrstRegTm()       );
            targetIO.setFrstRegEmpNo      (sourceIO.getFrstRegEmpNo()    );
            targetIO.setLastProcDt        (sourceIO.getLastProcDt()      );
            targetIO.setLastProcTm        (sourceIO.getLastProcTm()      );
            targetIO.setLastProcEmpNo     (sourceIO.getLastProcEmpNo()   );

            // 룰 SUB 내역조회 List 객체에 추가
            resultList.add(targetIO);
        }

        // 룰 SUB내역조회 화면 출력 결과값 대입
        resultVo.setListSRMRMM03DSSTRULESUBVO(resultList);

        return resultVo;
    }


    private int getNextVal_StRuleSubHist_SeqNo(String sRuleType, String sRuleId, String sParamId) throws Exception
    {
        int nNextVal = 0;

        StRuleSubHistDTO oDto = new StRuleSubHistDTO();
        oDto.setRuleType      (sRuleType);
        oDto.setRuleId        (sRuleId);
        oDto.setParamId       (sParamId);

        try
        {
            oDto = stRuleSubHistMapper.selectNextValSeqNo(oDto);
            nNextVal = oDto.getSeqNo();
        }
        catch (Exception e)
        {
            throw e;
        }

        return nNextVal;
    }


    private boolean insertStRuleSubHist(String sRuleType, String sRuleId, String sParamId, String sLastProcEmpNo) throws Exception
    {
        // 룰 이력 생성 입력값 객체 생성 및 대입 수행
        StRuleSubDTO oSelectDto = new StRuleSubDTO();
        oSelectDto.setRuleType(sRuleType);
        oSelectDto.setRuleId  (sRuleId);
        oSelectDto.setParamId (sParamId);

        oSelectDto = stRuleSubMapper.select(oSelectDto);

        if (oSelectDto == null)
        {
            return false;
        }

        int nNextVal_StRuleSubHist_SeqNo = getNextVal_StRuleSubHist_SeqNo(sRuleType, sRuleId, sParamId);
        if (nNextVal_StRuleSubHist_SeqNo <= 0)
        {
            return false;
        }

        // 룰 이력 생성 입력값 객체 생성 및 대입 수행
        StRuleSubHistDTO oInsertDto = new StRuleSubHistDTO();
        oInsertDto.setRuleType      (oSelectDto.getRuleType()        );
        oInsertDto.setRuleId        (oSelectDto.getRuleId()          );
        oInsertDto.setParamId       (oSelectDto.getParamId()         );
        oInsertDto.setSeqNo         (nNextVal_StRuleSubHist_SeqNo    );
        oInsertDto.setParamNm       (oSelectDto.getParamNm()         );
        oInsertDto.setParamValue    (oSelectDto.getParamValue()      );
        oInsertDto.setRemark        (oSelectDto.getRemark()          );
        oInsertDto.setRecSttsCd     (oSelectDto.getRecSttsCd()       );
        oInsertDto.setFrstRegDt     (oSelectDto.getFrstRegDt()       );
        oInsertDto.setFrstRegTm     (oSelectDto.getFrstRegTm()       );
        oInsertDto.setFrstRegEmpNo  (oSelectDto.getFrstRegEmpNo()    );
        // oInsertDto.setLastProcDt (oSelectDto.getLastProcDt()      );
        // oInsertDto.setLastProcTm (oSelectDto.getLastProcTm()      );
        oInsertDto.setLastProcEmpNo (sLastProcEmpNo                  );

        stRuleSubHistMapper.insert(oInsertDto);

        return true;
    }
}