package hanalife.s.rm.rm.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.rm.rm.service.SRMRMM03Service;
import hanalife.s.rm.rm.vo.SRMRMM02DSSTRULEMAINVO;
import hanalife.s.rm.rm.vo.SRMRMM03DSSTRULESUBVO;
import hanalife.s.rm.rm.vo.SRMRMM03InVO;
import hanalife.s.rm.rm.vo.SRMRMM03OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명    : SRMRMM03Controller.java Class
 * 클래스설명    : RULE 관리 (SRMRMM03) Controller
 * 작성일자    : 2023.04.13.
 * 작성자명    : 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][수정자 ][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][70280][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/rm/rm")
@Controller
public class SRMRMM03Controller
{
    @Resource(name = "SRMRMM03Service")
    private SRMRMM03Service SRMRMM03;

    private static final Logger LOGGER = LoggerFactory.getLogger(SRMRMM03Controller.class);

    /**
     * <p>메소드명            : 룰 목록 조회 (콤보박스 설정용)/SRMRMM03S01.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰관리내역을 조회한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM03S01.do")
    public String SRMRMM03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM03 Controller SRMRMM03S01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM03 Controller SRMRMM03S01 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_MAIN_SEARCH", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM02DSSTRULEMAINVO oSearchVo = new SRMRMM02DSSTRULEMAINVO();
            oSearchVo.setRuleType     (searchMap.get("ruleType").toString().trim()       );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM03InVO InVO = new SRMRMM03InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM02DSSTRULEMAINVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM03OutVO resultListVo = SRMRMM03.SRMRMM03S01(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_RULE_MAIN", resultListVo.getListSRMRMM02DSSTRULEMAINVO(), model);

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03S01 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03S01 Exception End #####");
        }

        LOGGER.info("##### SRMRMM03 Controller SRMRMM03S01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명            : 룰SUB내역 조회 /SRMRMM03S02.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰SUB내역을 조회한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM03S02.do")
    public String SRMRMM03S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM03 Controller SRMRMM03S02 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM03 Controller SRMRMM03S02 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_SEARCH", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oSearchVo = new SRMRMM03DSSTRULESUBVO();
            oSearchVo.setRuleType     (searchMap.get("ruleType").toString().trim() );
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()   );
            oSearchVo.setParamId      (searchMap.get("paramId").toString().trim()  );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM03InVO InVO = new SRMRMM03InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM03OutVO resultListVo = SRMRMM03.SRMRMM03S02(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_RULE_SUB", resultListVo.getListSRMRMM03DSSTRULESUBVO(), model);

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03S02 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03S02 Exception End #####");
        }

        LOGGER.info("##### SRMRMM03 Controller SRMRMM03S02 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명            : 룰SUB내역 등록 /SRMRMM03I01.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰SUB내역을 등록한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM03I01.do")
    public String SRMRMM02I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM02 Controller SRMRMM03I01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM03 Controller SRMRMM02I01 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_SEARCH", request, response, model);
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_CRUD", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oSearchVo = new SRMRMM03DSSTRULESUBVO();
            oSearchVo.setRuleType     (searchMap.get("ruleType").toString().trim()       );
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()         );
            oSearchVo.setRuleId       (searchMap.get("paramId").toString().trim()        );

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oRuleSubVo = new SRMRMM03DSSTRULESUBVO();
            oRuleSubVo.setRuleType     (sourceMap.get("ruleType").toString().trim()      );
            oRuleSubVo.setRuleId       (sourceMap.get("ruleId").toString().trim()        );
            oRuleSubVo.setParamId      (sourceMap.get("paramId").toString().trim()       );
            oRuleSubVo.setParamNm      (sourceMap.get("paramNm").toString().trim()       );
            oRuleSubVo.setParamValue   (sourceMap.get("paramValue").toString().trim()    );
            oRuleSubVo.setRemark       (sourceMap.get("remark").toString().trim()        );
            oRuleSubVo.setRecSttsCd    (sourceMap.get("recSttsCd").toString().trim()     );
            oRuleSubVo.setFrstRegEmpNo (sourceMap.get("frstRegEmpNo").toString().trim()  );
            oRuleSubVo.setLastProcEmpNo(sourceMap.get("lastProcEmpNo").toString().trim() );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM03InVO InVO = new SRMRMM03InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oRuleSubVo);

            // 룰 등록
            SRMRMM03.SRMRMM03I01(InVO);

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM03OutVO resultListVo = SRMRMM03.SRMRMM03S02(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_RULE_SUB", resultListVo.getListSRMRMM03DSSTRULESUBVO(), model);

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03I01 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03I01 Exception End #####");
        }

        LOGGER.info("##### SRMRMM03 Controller SRMRMM03I01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명            : 룰관리내역 수정 /SRMRMM02U01.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰관리내역을 수정한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM03U01.do")
    public String SRMRMM03U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM03 Controller SRMRMM03U01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM03 Controller SRMRMM03U01 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_SEARCH", request, response, model);
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_CRUD", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oSearchVo = new SRMRMM03DSSTRULESUBVO();
            oSearchVo.setRuleType     (searchMap.get("ruleType").toString().trim()       );
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()         );
            oSearchVo.setParamId      (searchMap.get("paramId").toString().trim()        );

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oRuleSubVo = new SRMRMM03DSSTRULESUBVO();
            oRuleSubVo.setRuleType     (sourceMap.get("ruleType").toString().trim()      );
            oRuleSubVo.setRuleId       (sourceMap.get("ruleId").toString().trim()        );
            oRuleSubVo.setParamId      (sourceMap.get("paramId").toString().trim()       );
            oRuleSubVo.setParamNm      (sourceMap.get("paramNm").toString().trim()       );
            oRuleSubVo.setParamValue   (sourceMap.get("paramValue").toString().trim()    );
            oRuleSubVo.setRemark       (sourceMap.get("remark").toString().trim()        );
            oRuleSubVo.setRecSttsCd    (sourceMap.get("recSttsCd").toString().trim()     );
            oRuleSubVo.setFrstRegEmpNo (sourceMap.get("frstRegEmpNo").toString().trim()  );
            oRuleSubVo.setLastProcEmpNo(sourceMap.get("lastProcEmpNo").toString().trim() );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM03InVO InVO = new SRMRMM03InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oRuleSubVo);

            // 룰 수정
            SRMRMM03.SRMRMM03U01(InVO);

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM03OutVO resultListVo = SRMRMM03.SRMRMM03S02(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_RULE_SUB", resultListVo.getListSRMRMM03DSSTRULESUBVO(), model);

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03U01 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03U01 Exception End #####");
        }

        LOGGER.info("##### SRMRMM03 Controller SRMRMM03U01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명            : 룰관리내역 삭제 /SRMRMM02D01.do </p>
     * <p>작성일자            : 2023.03.31.
     * <p>작성자(author)      : 70280
     * <p>설명                : 룰관리내역을 삭제한다.</p>
     * <p>예외처리            : Exception</p>
     */
    @RequestMapping("/SRMRMM03D01.do")
    public String SRMRMM03D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SRMRMM03 Controller SRMRMM03D01 Start #####");

        try
        {
            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            LOGGER.info("##### SRMRMM03 Controller SRMRMM03D01 추출 #####");

            Map<String, Object> searchMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_SEARCH", request, response, model);
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ST_RULE_SUB_CRUD", request, response, model);

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oSearchVo = new SRMRMM03DSSTRULESUBVO();
            oSearchVo.setRuleType     (searchMap.get("ruleType").toString().trim()       );
            oSearchVo.setRuleId       (searchMap.get("ruleId").toString().trim()         );
            oSearchVo.setParamId      (searchMap.get("paramId").toString().trim()        );

            // 룰관리내역 조회 업무 서비스 호출 입력값 대입
            SRMRMM03DSSTRULESUBVO oRuleSubVo = new SRMRMM03DSSTRULESUBVO();
            oRuleSubVo.setRuleType     (sourceMap.get("ruleType").toString().trim()      );
            oRuleSubVo.setRuleId       (sourceMap.get("ruleId").toString().trim()        );
            oRuleSubVo.setParamId      (sourceMap.get("paramId").toString().trim()       );
            oRuleSubVo.setParamNm      (sourceMap.get("paramNm").toString().trim()       );
            oRuleSubVo.setParamValue   (sourceMap.get("paramValue").toString().trim()    );
            oRuleSubVo.setRemark       (sourceMap.get("remark").toString().trim()        );
            oRuleSubVo.setRecSttsCd    (sourceMap.get("recSttsCd").toString().trim()     );
            oRuleSubVo.setFrstRegEmpNo (sourceMap.get("frstRegEmpNo").toString().trim()  );
            oRuleSubVo.setLastProcEmpNo(sourceMap.get("lastProcEmpNo").toString().trim() );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SRMRMM03InVO InVO = new SRMRMM03InVO();

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oRuleSubVo);

            // 룰 삭제
            SRMRMM03.SRMRMM03D01(InVO);

            // 룰관리 내역조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSRMRMM03DSSTRULESUBVO(oSearchVo);

            // 룰관리내역 조회 업무 서비스 호출 수행
            SRMRMM03OutVO resultListVo = SRMRMM03.SRMRMM03S02(InVO);

            // 룰관리내역 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_ST_RULE_SUB", resultListVo.getListSRMRMM03DSSTRULESUBVO(), model);

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03D01 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SRMRMM03 Controller SRMRMM03D01 Exception End #####");
        }

        LOGGER.info("##### SRMRMM03 Controller SRMRMM03D01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }
}