package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
//import hanalife.c.sc.pg.mapper.dto.CnstMngDSSMDODTO;
//import hanalife.c.sc.pg.vo.CSCPGM05I01InVO;
import hanalife.s.sp.as.mapper.SSPASM02Mapper;
import hanalife.s.sp.as.mapper.dto.SSPASM02DSSDDTO;
import hanalife.s.sp.as.mapper.dto.SSPASM02DSSMDTO;
import hanalife.s.sp.as.service.SSPASM02Service;
import hanalife.s.sp.as.vo.SSPASM02DSSDVO;
import hanalife.s.sp.as.vo.SSPASM02I01InVO;
import hanalife.s.sp.as.vo.SSPASM02InVO;
import hanalife.s.sp.as.vo.SSPASM02OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASM02ServiceImpl.java Class
 * 클래스설명	: 특수지역관리 (SSPASM02) Service Interface
 * 작성일자	: 2023.04.13.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.13.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASM02S01	: 시도명 조회
 *			getSSPASM02S02	: 시군구명 조회
 *			getSSPASM02S03	: 읍면동명 조회
 *			getSSPASM02S04	: 리명 조회
 *			getSSPASM02S05	: 특수지역관리내역 조회
 *			saveSSPASM02	: 특수지역관리내역 등록
 *			deleteSSPASM02	: 특수지역관리내역 삭제
 * </pre>
 */
@Service("SSPASM02Service")
public class SSPASM02ServiceImpl implements SSPASM02Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASM02ServiceImpl.class);

	@Autowired
	private SSPASM02Mapper sSPASM02Mapper;

	/**
	 * <p> 메소드명	: getSSPASM02S01 - 시도명 조회 </p>
	 * <p> 작성일자	: 2023.04.13. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 시도 내역을 조회한다. </p>
	 * <p> 메소드인수	: SSPASM02InVO </p>
	 * <p> 메소드리턴값	: SSPASM02OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
    public SSPASM02OutVO getSSPASM02S01(SSPASM02InVO inVo) throws Exception
	{
		LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S01 Start #####");

	    // 시도 내역조회 서비스 결과값 객체 생성
		SSPASM02OutVO resultVo = new SSPASM02OutVO();

	    // 시도 내역조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM02DSSMDTO i01Dto = new SSPASM02DSSMDTO();
		/** 입력값 없음 */

        // 시도 내역조회 쿼리 Mapper 호출 수행
        List<SSPASM02DSSDDTO> resultDTO = sSPASM02Mapper.srchProvNm(i01Dto);

        // 시도 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM02DSSDVO> resultList = new ArrayList<SSPASM02DSSDVO>();
       	for (SSPASM02DSSDDTO sourceIO : resultDTO)
       	{
       		// 시도 내역조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM02DSSDVO targetIO = new SSPASM02DSSDVO();

   		    targetIO.setLdongCd(sourceIO.getLdongCd());    /* 법정동코드 */
   		    targetIO.setProvNm(sourceIO.getProvNm());      /* 시도명 */

            // 시도 내역조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S01 End #####");

        // 시도 내역조회 화면 출력 결과값 대입
        resultVo.setListSSPASM02DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p> 메소드명	: getSSPASM02S02 - 시군구명 조회 </p>
	 * <p> 작성일자	: 2023.04.13. </p>
	 * <p> 작성자명	: 70305 / KBS </p>
	 * <p> 설명		: 시군구 내역을 조회한다. </p>
	 * <p> 메소드인수	: SSPASM02InVO </p>
	 * <p> 메소드리턴값	: SSPASM02OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
    public SSPASM02OutVO getSSPASM02S02(SSPASM02InVO inVo) throws Exception
	{
		LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S02 Start #####");

	    // 시도 내역조회 서비스 결과값 객체 생성
		SSPASM02OutVO resultVo = new SSPASM02OutVO();

	    // 시도 내역조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM02DSSMDTO i01Dto = new SSPASM02DSSMDTO();
		i01Dto.setProvNm(inVo.getSSPASM02DSSMVO().getProvNm());    /** 시도명 */

        // 시도 내역조회 쿼리 Mapper 호출 수행
        List<SSPASM02DSSDDTO> resultDTO = sSPASM02Mapper.srchCigunguNm(i01Dto);

        // 시도 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM02DSSDVO> resultList = new ArrayList<SSPASM02DSSDVO>();
       	for (SSPASM02DSSDDTO sourceIO : resultDTO)
       	{
       		// 시도 내역조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM02DSSDVO targetIO = new SSPASM02DSSDVO();

   		    targetIO.setLdongCd(sourceIO.getLdongCd());        /* 법정동코드 */
   		    targetIO.setProvNm(sourceIO.getProvNm());          /* 시도명 */
		    targetIO.setCigunguNm(sourceIO.getCigunguNm());    /* 시군구명 */

            // 시도 내역조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S02 End #####");

        // 시도 내역조회 화면 출력 결과값 대입
        resultVo.setListSSPASM02DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p> 메소드명	: getSSPASM02S03 - 읍면동명 내역조회 </p>
	 * <p> 작성일자	: 2023.04.13. </p>
	 * <p> 작성자명	: 70305 / KBS </p>
	 * <p> 설명		: 읍면동 내역을 조회한다.</p>
	 * <p> 메소드인수	: SSPASM02InVO </p>
	 * <p> 메소드리턴값	: SSPASM02OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
    public SSPASM02OutVO getSSPASM02S03(SSPASM02InVO inVo) throws Exception
	{
		LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S03 Start #####");

	    // 시도 내역조회 서비스 결과값 객체 생성
		SSPASM02OutVO resultVo = new SSPASM02OutVO();

	    // 시도 내역조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM02DSSMDTO i01Dto = new SSPASM02DSSMDTO();
		i01Dto.setProvNm(inVo.getSSPASM02DSSMVO().getProvNm());         /** 시도명 */
		i01Dto.setCigunguNm(inVo.getSSPASM02DSSMVO().getCigunguNm());   /** 시군구명 */

        // 시도 내역조회 쿼리 Mapper 호출 수행
        List<SSPASM02DSSDDTO> resultDTO = sSPASM02Mapper.srchEubmyundongNm(i01Dto);

        // 시도 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM02DSSDVO> resultList = new ArrayList<SSPASM02DSSDVO>();

       	for (SSPASM02DSSDDTO sourceIO : resultDTO)
       	{
       		// 시도 내역조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM02DSSDVO targetIO = new SSPASM02DSSDVO();

   		    targetIO.setLdongCd(sourceIO.getLdongCd());                /* 법정동코드 */
   		    targetIO.setProvNm(sourceIO.getProvNm());                  /* 시도명 */
		    targetIO.setCigunguNm(sourceIO.getCigunguNm());            /* 시군구명 */
		    targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());    /* 읍면동명 */

            // 시도 내역조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S03 End #####");

        // 시도 내역조회 화면 출력 결과값 대입
        resultVo.setListSSPASM02DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p> 메소드명	: getSSPASM02S04 - 리명 내역조회 </p>
	 * <p> 작성일자	: 2023.04.17. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 리 내역을 조회한다. </p>
	 * <p> 메소드인수	: SSPASM02InVO </p>
	 * <p> 메소드리턴값	: SSPASM02OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
    public SSPASM02OutVO getSSPASM02S04(SSPASM02InVO inVo) throws Exception
	{
		LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S04 Start #####");

	    // 시도 내역조회 서비스 결과값 객체 생성
		SSPASM02OutVO resultVo = new SSPASM02OutVO();

	    // 시도 내역조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM02DSSMDTO i01Dto = new SSPASM02DSSMDTO();
		i01Dto.setProvNm(inVo.getSSPASM02DSSMVO().getProvNm());    /** 시도명 */
		i01Dto.setCigunguNm(inVo.getSSPASM02DSSMVO().getCigunguNm());    /** 시군구명 */
		i01Dto.setEubmyundongNm(inVo.getSSPASM02DSSMVO().getEubmyundongNm());    /** 읍면동명 */

        // 시도 내역조회 쿼리 Mapper 호출 수행
        List<SSPASM02DSSDDTO> resultDTO = sSPASM02Mapper.srchRiNm(i01Dto);

        // 시도 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM02DSSDVO> resultList = new ArrayList<SSPASM02DSSDVO>();

       	for (SSPASM02DSSDDTO sourceIO : resultDTO)
       	{
       		// 시도 내역조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM02DSSDVO targetIO = new SSPASM02DSSDVO();

   		    targetIO.setLdongCd(sourceIO.getLdongCd());                /* 법정동코드 */
   		    targetIO.setProvNm(sourceIO.getProvNm());                  /* 시도명 */
		    targetIO.setCigunguNm(sourceIO.getCigunguNm());            /* 시군구명 */
		    targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());    /* 읍면동명 */
		    targetIO.setRiNm(sourceIO.getRiNm());                      /* 리명 */

            // 시도 내역조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S04 End #####");

        // 시도 내역조회 화면 출력 결과값 대입
        resultVo.setListSSPASM02DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p> 메소드명	: getSSPASM02S05 - 특수지역관리내역 조회 </p>
	 * <p> 작성일자	: 2023.04.17. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 특수지역관리내역을 조회한다. </p>
	 * <p> 메소드인수	: SSPASM02InVO </p>
	 * <p> 메소드리턴값	: SSPASM02OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
    public SSPASM02OutVO getSSPASM02S05(SSPASM02InVO inVo) throws Exception
	{
		LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S05 Start #####");

	    // 특수지역 내역조회 서비스 결과값 객체 생성
		SSPASM02OutVO resultVo = new SSPASM02OutVO();

	    // 특수지역 내역조회 조건 입력값 객체 생성 및 대입 수행
		SSPASM02DSSMDTO i01Dto = new SSPASM02DSSMDTO();

        i01Dto.setLdongCd1            (inVo.getSSPASM02DSSMVO().getLdongCd1            ()); /** 법정동코드1 */
        i01Dto.setLdongCd2            (inVo.getSSPASM02DSSMVO().getLdongCd2            ()); /** 법정동코드2 */
        i01Dto.setLdongCd3            (inVo.getSSPASM02DSSMVO().getLdongCd3            ()); /** 법정동코드3 */
        i01Dto.setLdongCd4            (inVo.getSSPASM02DSSMVO().getLdongCd4            ()); /** 법정동코드4 */
        i01Dto.setSpcuZoneFg          (inVo.getSSPASM02DSSMVO().getSpcuZoneFg().toString()); /** 투기지역여부 */
        i01Dto.setSpcuZoneExclFg      (inVo.getSSPASM02DSSMVO().getSpcuZoneExclFg      ()); /** 투기지역제외여부 */
        i01Dto.setSpcuOverhRegnFg     (inVo.getSSPASM02DSSMVO().getSpcuOverhRegnFg     ()); /** 투기과열지구여부 */
        i01Dto.setSpcuOverhRegnExclFg (inVo.getSSPASM02DSSMVO().getSpcuOverhRegnExclFg ()); /** 투기과열지구제외여부 */
        i01Dto.setOverpCotrZoneFg     (inVo.getSSPASM02DSSMVO().getOverpCotrZoneFg     ()); /** 과밀억제권역여부 */
        i01Dto.setOverpCotrZoneExclFg (inVo.getSSPASM02DSSMVO().getOverpCotrZoneExclFg ()); /** 과밀억제권역제외여부 */
        i01Dto.setAdjuRegnFg          (inVo.getSSPASM02DSSMVO().getAdjuRegnFg          ()); /** 조정지역여부 */
        i01Dto.setAdjuRegnExclFg      (inVo.getSSPASM02DSSMVO().getAdjuRegnExclFg      ()); /** 조정지역제외여부 */
        i01Dto.setWdarCiFg            (inVo.getSSPASM02DSSMVO().getWdarCiFg            ()); /** 광역시여부 */
        i01Dto.setWdarCiExclFg        (inVo.getSSPASM02DSSMVO().getWdarCiExclFg        ()); /** 광역시제외여부 */
        i01Dto.setCapiRegnFg          (inVo.getSSPASM02DSSMVO().getCapiRegnFg          ()); /** 수도권여부 */
        i01Dto.setCapiRegnExclFg      (inVo.getSSPASM02DSSMVO().getCapiRegnExclFg      ()); /** 수도권제외여부 */
        i01Dto.setSpclAdmtZoneFg      (inVo.getSSPASM02DSSMVO().getSpclAdmtZoneFg      ()); /** 특별인정지역여부 */
        i01Dto.setSpclAdmtZoneExclFg  (inVo.getSSPASM02DSSMVO().getSpclAdmtZoneExclFg  ()); /** 특별인정지역제외여부 */
        i01Dto.setEtcZoneFg           (inVo.getSSPASM02DSSMVO().getEtcZoneFg           ()); /** 기타지역여부 */
        i01Dto.setEtcZoneExclFg       (inVo.getSSPASM02DSSMVO().getEtcZoneExclFg       ()); /** 기타지역제외여부 */

        LOGGER.info("" + "i01Dto.getLdongCd1           () : " + i01Dto.getLdongCd1           ());
        LOGGER.info("" + "i01Dto.getLdongCd2           () : " + i01Dto.getLdongCd2           ());
        LOGGER.info("" + "i01Dto.getLdongCd3           () : " + i01Dto.getLdongCd3           ());
        LOGGER.info("" + "i01Dto.getLdongCd4           () : " + i01Dto.getLdongCd4           ());
        LOGGER.info("" + "i01Dto.getSpcuZoneFg         () : " + i01Dto.getSpcuZoneFg().toString());
        LOGGER.info("" + "i01Dto.getSpcuZoneExclFg     () : " + i01Dto.getSpcuZoneExclFg     ());
        LOGGER.info("" + "i01Dto.getSpcuOverhRegnFg    () : " + i01Dto.getSpcuOverhRegnFg    ());
        LOGGER.info("" + "i01Dto.getSpcuOverhRegnExclFg() : " + i01Dto.getSpcuOverhRegnExclFg());
        LOGGER.info("" + "i01Dto.getOverpCotrZoneFg    () : " + i01Dto.getOverpCotrZoneFg    ());
        LOGGER.info("" + "i01Dto.getOverpCotrZoneExclFg() : " + i01Dto.getOverpCotrZoneExclFg());
        LOGGER.info("" + "i01Dto.getAdjuRegnFg         () : " + i01Dto.getAdjuRegnFg         ());
        LOGGER.info("" + "i01Dto.getAdjuRegnExclFg     () : " + i01Dto.getAdjuRegnExclFg     ());
        LOGGER.info("" + "i01Dto.getWdarCiFg           () : " + i01Dto.getWdarCiFg           ());
        LOGGER.info("" + "i01Dto.getWdarCiExclFg       () : " + i01Dto.getWdarCiExclFg       ());
        LOGGER.info("" + "i01Dto.getCapiRegnFg         () : " + i01Dto.getCapiRegnFg         ());
        LOGGER.info("" + "i01Dto.getCapiRegnExclFg     () : " + i01Dto.getCapiRegnExclFg     ());
        LOGGER.info("" + "i01Dto.getSpclAdmtZoneFg     () : " + i01Dto.getSpclAdmtZoneFg     ());
        LOGGER.info("" + "i01Dto.getSpclAdmtZoneExclFg () : " + i01Dto.getSpclAdmtZoneExclFg ());
        LOGGER.info("" + "i01Dto.getEtcZoneFg          () : " + i01Dto.getEtcZoneFg          ());
        LOGGER.info("" + "i01Dto.getEtcZoneExclFg      () : " + i01Dto.getEtcZoneExclFg      ());

        // 특수지역 내역조회 쿼리 Mapper 호출 수행
        List<SSPASM02DSSDDTO> resultDTO = sSPASM02Mapper.srchSpclZoneMng(i01Dto);

        // 특수지역 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASM02DSSDVO> resultList = new ArrayList<SSPASM02DSSDVO>();
       	for (SSPASM02DSSDDTO sourceIO : resultDTO)
       	{
       		// 특수지역 내역조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASM02DSSDVO targetIO = new SSPASM02DSSDVO();

   		    targetIO.setLdongCd(sourceIO.getLdongCd());                         /** 법정동코드 */
   		    targetIO.setProvNm(sourceIO.getProvNm());                           /** 시도명 */
   		    targetIO.setCigunguNm(sourceIO.getCigunguNm());                     /** 시군구명 */
   		    targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());             /** 읍면동명 */
   		    targetIO.setRiNm(sourceIO.getRiNm());                               /** 리명 */
   		    targetIO.setSpcuZoneFg(sourceIO.getSpcuZoneFg());                   /** 투기지역여부 */
   		    targetIO.setSpcuZoneExclFg(sourceIO.getSpcuZoneExclFg());           /** 투기지역제외여부 */
   		    targetIO.setSpcuOverhRegnFg(sourceIO.getSpcuOverhRegnFg());         /** 투기과열지구여부 */
   		    targetIO.setSpcuOverhRegnExclFg(sourceIO.getSpcuOverhRegnExclFg()); /** 투기과열지구제외여부 */
   		    targetIO.setOverpCotrZoneFg(sourceIO.getOverpCotrZoneFg());         /** 과밀억제권역여부 */
   		    targetIO.setOverpCotrZoneExclFg(sourceIO.getOverpCotrZoneExclFg()); /** 과밀억제권역제외여부 */
   		    targetIO.setWdarCiFg(sourceIO.getWdarCiFg());                       /** 광역시여부 */
   		    targetIO.setWdarCiExclFg(sourceIO.getWdarCiExclFg());               /** 광역시제외여부 */
   		    targetIO.setCapiRegnFg(sourceIO.getCapiRegnFg());                   /** 수도권여부 */
   		    targetIO.setCapiRegnExclFg(sourceIO.getCapiRegnExclFg());           /** 수도권제외여부 */
   		    targetIO.setAdjuRegnFg(sourceIO.getAdjuRegnFg());                   /** 조정지역여부 */
   		    targetIO.setAdjuRegnExclFg(sourceIO.getAdjuRegnExclFg());           /** 조정지역제외여부 */
   		    targetIO.setSpclAdmtZoneFg(sourceIO.getSpclAdmtZoneFg());           /** 특별인정지역여부 */
   		    targetIO.setSpclAdmtZoneExclFg(sourceIO.getSpclAdmtZoneExclFg());   /** 특별인정지역제외여부 */
   		    targetIO.setEtcZoneFg(sourceIO.getEtcZoneFg());                     /** 기타지역여부 */
   		    targetIO.setEtcZoneExclFg(sourceIO.getEtcZoneExclFg());             /** 기타지역제외여부 */

            // 특수지역 내역조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASM02 ServiceImpl getSSPASM02S05 End #####");

        // 특수지역 내역조회 화면 출력 결과값 대입
        resultVo.setListSSPASM02DSSDVO(resultList);

        return resultVo;
	}

    /**
     * <p> 메소드명		: saveSSPASM02 - 특수지역관리내역 등록 </p>
	 * <p> 작성일자		: 2023.04.12. </p>
	 * <p> 작성자(author)	: 70305 / kbs </p>
	 * <p> 설명			: 특수지역관리내역을 등록한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		: Exception </p>
     */
	@Override
	public SSPASM02OutVO saveSSPASM02(SSPASM02I01InVO inVO) throws Exception
	{
		LOGGER.info("SSPASM02 ServiceImpl saveSSPASM02 Start");

		// 결과값 출력 객체 VO 선언 및 정상 초기값 설정
		SSPASM02OutVO resultVo = new SSPASM02OutVO();
		resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

      	// 검색조건 체크
		String strLdongCd             = inVO.getSSPASM02DSSDVO().getLdongCd().toString();               // 법정동코드
		String strProvNm              = inVO.getSSPASM02DSSDVO().getProvNm().toString();                // 시도명
		String strCigunguNm           = inVO.getSSPASM02DSSDVO().getCigunguNm().toString();             // 시군구명
		String strEubmyundongNm       = inVO.getSSPASM02DSSDVO().getEubmyundongNm().toString();         // 읍면동명
		String strRiNm                = inVO.getSSPASM02DSSDVO().getRiNm().toString();                  // 리명
		String strSpcuZoneFg          = inVO.getSSPASM02DSSDVO().getSpcuZoneFg().toString();            // 투기지역여부
		String strSpcuZoneExclFg      = inVO.getSSPASM02DSSDVO().getSpcuZoneExclFg().toString();        // 투기지역제외여부
		String strSpcuOverhRegnFg     = inVO.getSSPASM02DSSDVO().getSpcuOverhRegnFg().toString();       // 투기과열지구여부
		String strSpcuOverhRegnExclFg = inVO.getSSPASM02DSSDVO().getSpcuOverhRegnExclFg().toString();   // 투기과열지구제외여부
		String strOverpCotrZoneFg     = inVO.getSSPASM02DSSDVO().getOverpCotrZoneFg().toString();       // 과밀억제권역여부
		String strOverpCotrZoneExclFg = inVO.getSSPASM02DSSDVO().getOverpCotrZoneExclFg().toString();   // 과밀억제권역제외여부
		String strWdarCiFg            = inVO.getSSPASM02DSSDVO().getWdarCiFg().toString();              // 광역시여부
		String strWdarCiExclFg        = inVO.getSSPASM02DSSDVO().getWdarCiExclFg().toString();          // 광역시제외여부
		String strCapiRegnFg          = inVO.getSSPASM02DSSDVO().getCapiRegnFg().toString();            // 수도권여부
		String strCapiRegnExclFg      = inVO.getSSPASM02DSSDVO().getCapiRegnExclFg().toString();        // 수도권제외여부
		String strAdjuRegnFg          = inVO.getSSPASM02DSSDVO().getAdjuRegnFg().toString();            // 조정지역여부
		String strAdjuRegnExclFg      = inVO.getSSPASM02DSSDVO().getAdjuRegnExclFg().toString();        // 조정지역제외여부
		String strSpclAdmtZoneFg      = inVO.getSSPASM02DSSDVO().getSpclAdmtZoneFg().toString();        // 특별인정지역여부
		String strSpclAdmtZoneExclFg  = inVO.getSSPASM02DSSDVO().getSpclAdmtZoneExclFg().toString();    // 특별인정지역제외여부
		String strEtcZoneFg           = inVO.getSSPASM02DSSDVO().getEtcZoneFg().toString();             // 기타지역여부
		String strEtcZoneExclFg       = inVO.getSSPASM02DSSDVO().getEtcZoneExclFg().toString();         // 기타지역제외여부
		String strFrstRegEmpNo        = inVO.getSSPASM02DSSDVO().getFrstRegEmpNo().toString();          // 최초등록사원번호
		String strLastProcEmpNo       = inVO.getSSPASM02DSSDVO().getLastProcEmpNo().toString();         // 최종처리사원번호

		LOGGER.info("" + "inVO.strLdongCd             : " + strLdongCd             );
		LOGGER.info("" + "inVO.strProvNm              : " + strProvNm              );
		LOGGER.info("" + "inVO.strCigunguNm           : " + strCigunguNm           );
		LOGGER.info("" + "inVO.strEubmyundongNm       : " + strEubmyundongNm       );
		LOGGER.info("" + "inVO.strRiNm                : " + strRiNm                );
		LOGGER.info("" + "inVO.strSpcuZoneFg          : " + strSpcuZoneFg          );
		LOGGER.info("" + "inVO.strSpcuZoneExclFg      : " + strSpcuZoneExclFg      );
		LOGGER.info("" + "inVO.strSpcuOverhRegnFg     : " + strSpcuOverhRegnFg     );
		LOGGER.info("" + "inVO.strSpcuOverhRegnExclFg : " + strSpcuOverhRegnExclFg );
		LOGGER.info("" + "inVO.strOverpCotrZoneFg     : " + strOverpCotrZoneFg     );
		LOGGER.info("" + "inVO.strOverpCotrZoneExclFg : " + strOverpCotrZoneExclFg );
		LOGGER.info("" + "inVO.strWdarCiFg            : " + strWdarCiFg            );
		LOGGER.info("" + "inVO.strWdarCiExclFg        : " + strWdarCiExclFg        );
		LOGGER.info("" + "inVO.strCapiRegnFg          : " + strCapiRegnFg          );
		LOGGER.info("" + "inVO.strCapiRegnExclFg      : " + strCapiRegnExclFg      );
		LOGGER.info("" + "inVO.strAdjuRegnFg          : " + strAdjuRegnFg          );
		LOGGER.info("" + "inVO.strAdjuRegnExclFg      : " + strAdjuRegnExclFg      );
		LOGGER.info("" + "inVO.strSpclAdmtZoneFg      : " + strSpclAdmtZoneFg      );
		LOGGER.info("" + "inVO.strSpclAdmtZoneExclFg  : " + strSpclAdmtZoneExclFg  );
		LOGGER.info("" + "inVO.strEtcZoneFg           : " + strEtcZoneFg           );
		LOGGER.info("" + "inVO.strEtcZoneExclFg       : " + strEtcZoneExclFg       );
		LOGGER.info("" + "inVO.strFrstRegEmpNo        : " + strFrstRegEmpNo        );
		LOGGER.info("" + "inVO.strLastProcEmpNo       : " + strLastProcEmpNo       );

		// key값 체크(법정동 코드)
		if( StringUtils.isEmpty(strLdongCd) )
		{
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

		try
		{
        	// 특수지역관리내역 등록
			SSPASM02DSSDDTO inDto = new SSPASM02DSSDDTO();
    		inDto.setLdongCd             (strLdongCd);              // 법정동코드
    		inDto.setProvNm              (strProvNm);               // 시도명
    		inDto.setCigunguNm           (strCigunguNm);            // 시군구명
    		inDto.setEubmyundongNm       (strEubmyundongNm);        // 읍면동명
    		inDto.setRiNm                (strRiNm);                 // 리명
    		inDto.setSpcuZoneFg          (strSpcuZoneFg);           // 투기지역여부
    		inDto.setSpcuZoneExclFg      (strSpcuZoneExclFg);       // 투기지역제외여부
    		inDto.setSpcuOverhRegnFg     (strSpcuOverhRegnFg);      // 투기과열지구여부
    		inDto.setSpcuOverhRegnExclFg (strSpcuOverhRegnExclFg);  // 투기과열지구제외여부
    		inDto.setOverpCotrZoneFg     (strOverpCotrZoneFg);      // 과밀억제권역여부
    		inDto.setOverpCotrZoneExclFg (strOverpCotrZoneExclFg);  // 과밀억제권역제외여부
    		inDto.setWdarCiFg            (strWdarCiFg);             // 광역시여부
    		inDto.setWdarCiExclFg        (strWdarCiExclFg);         // 광역시제외여부
    		inDto.setCapiRegnFg          (strCapiRegnFg);           // 수도권여부
    		inDto.setCapiRegnExclFg      (strCapiRegnExclFg);       // 수도권제외여부
    		inDto.setAdjuRegnFg          (strAdjuRegnFg);           // 조정지역여부
    		inDto.setAdjuRegnExclFg      (strAdjuRegnExclFg);       // 조정지역제외여부
    		inDto.setSpclAdmtZoneFg      (strSpclAdmtZoneFg);       // 특별인정지역여부
    		inDto.setSpclAdmtZoneExclFg  (strSpclAdmtZoneExclFg);   // 특별인정지역제외여부
    		inDto.setEtcZoneFg           (strEtcZoneFg);            // 기타지역여부
    		inDto.setEtcZoneExclFg       (strEtcZoneExclFg);        // 기타지역제외여부
    		inDto.setFrstRegEmpNo        (strFrstRegEmpNo);         // 최초등록사원번호
    		inDto.setLastProcEmpNo       (strLastProcEmpNo);        // 최종처리사원번호

    		sSPASM02Mapper.insertSpclZoneMng(inDto);

        }
		catch (Exception e)
		{
            LOGGER.error("[특수지역관리내역 등록 오류] : 특수지역관리내역 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
		LOGGER.info("SSPASM02 ServiceImpl saveSSPASM02 End");
        return resultVo;
    }

    /**
     * <p> 메소드명		: deleteSSPASM02 - 특수지역관리내역 삭제 </p>
	 * <p> 작성일자		: 2023.04.21. </p>
	 * <p> 작성자(author)	: 70305 / kbs </p>
	 * <p> 설명			: 특수지역관리내역을 삭제한다. </p>
	 * <p> 메소드인수		: SSPASM02InVO </p>
	 * <p> 메소드리턴값		: SSPASM02OutVO </p>
	 * <p> 예외처리		: Exception </p>
     */
    @Override
    public SSPASM02OutVO deleteSSPASM02(SSPASM02I01InVO inVO) throws Exception {

    	LOGGER.info("SSPASM02 ServiceImpl deleteSSPASM02 Start");

        // ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
    	SSPASM02OutVO resultVo = new SSPASM02OutVO();
        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // ■ 조건 체크
		String strLdongCd = inVO.getSSPASM02DSSDVO().getLdongCd().toString();    // 법정동코드
		LOGGER.info("" + "inVO.strLdongCd : " + strLdongCd);

        if( StringUtils.isEmpty(strLdongCd) )
        {
            resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getDescription());

            return resultVo;
        }
        try
        {
        	// ■ 특수지역관리내역 삭제
			SSPASM02DSSDDTO inDto = new SSPASM02DSSDDTO();
    		inDto.setLdongCd(strLdongCd);

    		sSPASM02Mapper.deleteSpclZoneMng(inDto);
        }
        catch (Exception e)
        {
            LOGGER.error("[특수지역관리 삭제오류] : 특수지역관리내역 삭제 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
        LOGGER.info("SSPASM02 ServiceImpl deleteSSPASM02 End");
        return resultVo;
    }

}
