package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.s.sp.as.mapper.SSPASP01Mapper;
import hanalife.s.sp.as.mapper.dto.AptMkprSrchDSSDDTO;
import hanalife.s.sp.as.mapper.dto.AptMkprSrchDSSMDTO;
import hanalife.s.sp.as.service.SSPASP01Service;
import hanalife.s.sp.as.vo.SSPASP01DSAPTMKPRFLCTNSDVO;
import hanalife.s.sp.as.vo.SSPASP01DSAPTMKPRSPECSDVO;
import hanalife.s.sp.as.vo.SSPASP01InVO;
import hanalife.s.sp.as.vo.SSPASP01OutVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP01ServiceImpl.java Class
 * 클래스설명	: KB아파트시세조회 (SSPASP01) Service Interface
 * 작성일자	: 2023.04.10.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.10.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASP01S01	: KB아파트시세조회_상세내역_조회
 * 			getSSPASP02S02	: KB아파트시세조회_변동내역_조회
 * </pre>
 */
@Service("SSPASP01Service")
public class SSPASP01ServiceImpl implements SSPASP01Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP01ServiceImpl.class);

	@Autowired
	private SSPASP01Mapper sSPASP01Mapper;

	/**
	 * <p>메소드명		: getSSPASP01S01 : KB아파트시세조회_상세내역_조회</p>
	 * 작성일자		: 2023.04.10.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_상세내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASP01InVO </p>
	 * <p>메소드리턴값	: SSPASP01OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
	public SSPASP01OutVO getSSPASP01S01(SSPASP01InVO inVo) throws Exception {
		LOGGER.info("##### SSPASP01 ServiceImpl getSSPASP01S01 상세내역 조회 Start #####");

	    // KB아파트시세_상세내역_조회 결과값 객체 생성
		SSPASP01OutVO resultVo = new SSPASP01OutVO();

	    // KB아파트시세_상세내역_조회 조건입력값 객체 생성 및 대입 수행
	    AptMkprSrchDSSMDTO i01Dto = new AptMkprSrchDSSMDTO();

   		i01Dto.setEsttGodsCd(inVo.getSSPASP01DSSMVO().getEsttGodsCd());    /** 부동산물건코드 */
   		i01Dto.setPntpSeq   (inVo.getSSPASP01DSSMVO().getPntpSeq());       /** 평형순번 */
   		i01Dto.setRschStndDt(inVo.getSSPASP01DSSMVO().getRschStndDt());    /** 조사기준일 */

   		LOGGER.info("부동산물건코드"	+ "i01Dto.getEsttGodsCd()	: " + i01Dto.getEsttGodsCd());
   		LOGGER.info("평형순번"		+ "i01Dto.getPntpSeq()		: " + i01Dto.getPntpSeq());
   		LOGGER.info("조사기준일"	+ "i01Dto.getRschStndDt()	: " + i01Dto.getRschStndDt());

        // KB아파트시세_상세내역_조회 쿼리 Mapper 호출 수행
        List<AptMkprSrchDSSDDTO> resultDTO = sSPASP01Mapper.srchAptMkprSpec(i01Dto);

        // KB아파트시세_상세내역_조회화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP01DSAPTMKPRSPECSDVO> resultList = new ArrayList<SSPASP01DSAPTMKPRSPECSDVO>();
       	for (AptMkprSrchDSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세_상세내역_조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASP01DSAPTMKPRSPECSDVO targetIO = new SSPASP01DSAPTMKPRSPECSDVO();

       		targetIO.setEsttGodsCd   (sourceIO.getEsttGodsCd   ());    /* 부동산물건코드 */
       		targetIO.setProvNm       (sourceIO.getProvNm       ());    /* 시도명 */
       		targetIO.setCigunguNm    (sourceIO.getCigunguNm    ());    /* 시군구명 */
       		targetIO.setGuNm         (sourceIO.getGuNm         ());    /* 구명 */
       		targetIO.setEubmyundongNm(sourceIO.getEubmyundongNm());    /* 읍면동명 */
       		targetIO.setRiNm         (sourceIO.getRiNm         ());    /* 리명 */
       		targetIO.setStno         (sourceIO.getStno         ());    /* 번지 */
       		targetIO.setEtcStno      (sourceIO.getEtcStno      ());    /* 기타번지 */
       		targetIO.setTotHshdcnt   (sourceIO.getTotHshdcnt   ());    /* 총세대수 */
       		targetIO.setTotDongcnt   (sourceIO.getTotDongcnt   ());    /* 총동수 */
       		targetIO.setGrpMaxflor   (sourceIO.getGrpMaxflor   ());    /* 단지최고층 */
       		targetIO.setGrpMinflor   (sourceIO.getGrpMinflor   ());    /* 단지최저층 */
       		targetIO.setCmplYymm     (sourceIO.getCmplYymm     ());    /* 준공년월 */
       		targetIO.setConsVndrNm   (sourceIO.getConsVndrNm   ());    /* 건설업체명 */
       		targetIO.setHeatFrml     (sourceIO.getHeatFrml     ());    /* 난방방식 */
       		targetIO.setHeatFuel     (sourceIO.getHeatFuel     ());    /* 난방연료 */
       		targetIO.setParkQty      (sourceIO.getParkQty      ());    /* 주차대수 */
       		targetIO.setMngOffcTelNo (sourceIO.getMngOffcTelNo ());    /* 관리사무소전화번호 */
       		targetIO.setBunygRigtFg  (sourceIO.getBunygRigtFg  ());    /* 분양권여부 */
       		targetIO.setInHousYymm   (sourceIO.getInHousYymm   ());    /* 입주년월 */
       		targetIO.setHousShopMixFg(sourceIO.getHousShopMixFg());    /* 주상복합여부 */
       		targetIO.setPntpKind     (sourceIO.getPntpKind     ());    /* 평형종류 */
       		targetIO.setPntpSeq      (sourceIO.getPntpSeq      ());    /* 평형순번 */
       		targetIO.setSplyArea     (sourceIO.getSplyArea     ());    /* 공급면적 */
       		targetIO.setPntpDiv      (sourceIO.getPntpDiv      ());    /* 평형구분 */
       		targetIO.setEuseArea     (sourceIO.getEuseArea     ());    /* 전용면적 */
       		targetIO.setHshdCnt      (sourceIO.getHshdCnt      ());    /* 세대수 */
       		targetIO.setRoomCnt      (sourceIO.getRoomCnt      ());    /* 방수 */
       		targetIO.setBathCnt      (sourceIO.getBathCnt      ());    /* 욕실수 */
       		targetIO.setNowclasCons  (sourceIO.getNowclasCons  ());    /* 현관구조 */
       		targetIO.setRschStndDt   (sourceIO.getRschStndDt   ());    /* 조사기준일 */
       		targetIO.setAptNm        (sourceIO.getAptNm        ());    /* 아파트명 */
       		targetIO.setSaleBtmlAmt  (sourceIO.getSaleBtmlAmt  ());    /* 매매하한가 */
       		targetIO.setSaleGenTrAmt (sourceIO.getSaleGenTrAmt ());    /* 매매일반거래가 */
       		targetIO.setSaleUplmitAmt(sourceIO.getSaleUplmitAmt());    /* 매매상한가 */
       		targetIO.setDpstBtmlAmt  (sourceIO.getDpstBtmlAmt  ());    /* 전세하한가 */
       		targetIO.setDpstGenTrAmt (sourceIO.getDpstGenTrAmt ());    /* 전세일반거래가 */
       		targetIO.setDpstUplmitAmt(sourceIO.getDpstUplmitAmt());    /* 전세상한가 */

            // KB아파트시세_상세내역_조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASP01 ServiceImpl getSSPASP01S01 End #####");

        // KB아파트시세_상세내역_조회  화면 출력 결과값 대입
        resultVo.setListSSPASP01DSAPTMKPRSPECSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p>메소드명		: getSSPASP01S02 : KB아파트시세조회_변동내역_조회</p>
	 * 작성일자		: 2023.04.11.
	 * 작성자명		: 70305 / KBS / 가계대출 시스템 구축
	 * <p>설명		: KB아파트시세조회_변동내역을 조회한다.</p>
	 * <p>메소드인수	: SSPASP01InVO </p>
	 * <p>메소드리턴값	: SSPASP01OutVO</p>
	 * <p>예외처리		: Exception</p>
	 */
	@Override
	public SSPASP01OutVO getSSPASP01S02(SSPASP01InVO inVo) throws Exception {
		LOGGER.info("##### SSPASP01 ServiceImpl getSSPASP01S02 변동내역 조회 Start #####");

	    // KB아파트시세_변동내역_조회 결과값 객체 생성
		SSPASP01OutVO resultVo = new SSPASP01OutVO();

	    // KB아파트시세_변동내역_조회 입력값 객체 생성 및 대입 수행
	    AptMkprSrchDSSMDTO i01Dto = new AptMkprSrchDSSMDTO();

   		i01Dto.setEsttGodsCd(inVo.getSSPASP01DSSMVO().getEsttGodsCd());    /** 부동산물건코드 */
   		i01Dto.setPntpSeq   (inVo.getSSPASP01DSSMVO().getPntpSeq());       /** 평형순번 */
   		i01Dto.setRschStndDt(inVo.getSSPASP01DSSMVO().getRschStndDt());    /** 조사기준일 */
   		i01Dto.setRschFromDt(inVo.getSSPASP01DSSMVO().getRschFromDt());    /** 조사기준 시작일 */
   		i01Dto.setRschToDt  (inVo.getSSPASP01DSSMVO().getRschToDt());      /** 조사기준 종료일 */

   		LOGGER.info("S02"	+ "i01Dto.getEsttGodsCd()	: " + i01Dto.getEsttGodsCd());
   		LOGGER.info("S02"	+ "i01Dto.getPntpSeq()		: " + i01Dto.getPntpSeq());
   		LOGGER.info("S02"	+ "i01Dto.getRschStndDt()	: " + i01Dto.getRschStndDt());

   		LOGGER.info("S02"	+ "i01Dto.getRschFromDt()	: " + i01Dto.getRschFromDt());
   		LOGGER.info("S02"	+ "i01Dto.getRschToDt()     : " + i01Dto.getRschToDt());

        // KB아파트시세_변동내역_조회 쿼리 Mapper 호출 수행
        List<AptMkprSrchDSSDDTO> resultDTO = sSPASP01Mapper.srchAptMkprFlctn(i01Dto);

        // KB아파트시세_변동내역_조회화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP01DSAPTMKPRFLCTNSDVO> resultList = new ArrayList<SSPASP01DSAPTMKPRFLCTNSDVO>();
       	for (AptMkprSrchDSSDDTO sourceIO : resultDTO) {

        	// KB아파트시세_변동내역_조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASP01DSAPTMKPRFLCTNSDVO targetIO = new SSPASP01DSAPTMKPRFLCTNSDVO();

       		targetIO.setEsttGodsCd   (sourceIO.getEsttGodsCd());       /* 부동산물건코드 */
       		targetIO.setPntpSeq      (sourceIO.getPntpSeq());          /* 평형순번 */
       		targetIO.setRschStndDt   (sourceIO.getRschStndDt());       /* 조사기준일 */
       		targetIO.setSaleUplmitAmt(sourceIO.getSaleUplmitAmt());    /* 매매상한가 */
       		targetIO.setSaleBtmlAmt  (sourceIO.getSaleBtmlAmt());      /* 매매하한가 */
       		targetIO.setSaleGenTrAmt (sourceIO.getSaleGenTrAmt());     /* 매매일반가 */
       		targetIO.setDpstUplmitAmt(sourceIO.getDpstUplmitAmt());    /* 전세상한가 */
       		targetIO.setDpstBtmlAmt  (sourceIO.getDpstBtmlAmt());      /* 전세하한가 */
       		targetIO.setDpstGenTrAmt (sourceIO.getDpstGenTrAmt());     /* 전세일반가 */

            // KB아파트시세_변동내역_조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASP01 ServiceImpl getSSPASP01S02 End #####");

        // KB아파트시세_변동내역_조회  화면 출력 결과값 대입
        resultVo.setListSSPASP01DSAPTMKPRFLCTNSDVO(resultList);

        return resultVo;
	}

}
