package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.sp.as.mapper.ApplNoSrchMapper;
import hanalife.s.sp.as.mapper.dto.ApplNoSrchDSSDDTO;
import hanalife.s.sp.as.mapper.dto.ApplNoSrchDSSMDTO;
import hanalife.s.sp.as.service.SSPASP04Service;
import hanalife.s.sp.as.vo.SSPASP04DSSDVO;
import hanalife.s.sp.as.vo.SSPASP04S01InVO;
import hanalife.s.sp.as.vo.SSPASP04S01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP04ServiceImpl.java Class
 * 클래스설명   : 신청번호검색 (SSPASP04) Service Implements
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSSPASP04S01 : 신청번호검색목록조회

 * </pre>
 */
@Service("SSPASP04Service")
public class SSPASP04ServiceImpl implements SSPASP04Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP04ServiceImpl.class);

	private MsgEnum msgEnum;

	@Autowired
	private ApplNoSrchMapper applNoSrchMapper;

	/**
	 * <p>메소드명      : getSSPASP04S01 : 신청번호검색</p>
	 * <p>작성일자      : 2023. 3. 22.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 신청번호검색 조회한다.</p>
	 * <p>메소드인수    : SSPASP04S01InVo </p>
	 * <p>메소드리턴값  : SSPASP04S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SSPASP04S01OutVO getSSPASP04S01(SSPASP04S01InVO inVo) throws Exception {

		SSPASP04S01OutVO resultVo = new SSPASP04S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		ApplNoSrchDSSMDTO inDto = new ApplNoSrchDSSMDTO();

		inDto.setApplDtFr(inVo.getSSPASP04DSSMVO().getApplDtFr()); 				/** 신청일자시작 */
		inDto.setApplDtTo(inVo.getSSPASP04DSSMVO().getApplDtTo()); 				/** 신청일자종료 */
		inDto.setCustNm(inVo.getSSPASP04DSSMVO().getCustNm()); 					/** 고객명 */
		inDto.setCustBirth(inVo.getSSPASP04DSSMVO().getCustBirth()); 			/** 생년월일 */

		List<ApplNoSrchDSSDDTO> resultDTO = applNoSrchMapper.searchApplNoList(inDto);	/** 신청번호검색리스트*/

		List<SSPASP04DSSDVO> resultList = new ArrayList<SSPASP04DSSDVO>();

		for (ApplNoSrchDSSDDTO sourceIO : resultDTO) {
			SSPASP04DSSDVO targetIO = new SSPASP04DSSDVO();
			targetIO.setApplDt(sourceIO.getApplDt()); 							/** 신청일자 */
			targetIO.setLoanApplNo(sourceIO.getLoanApplNo()); 					/** 대출신청번호 */
			targetIO.setCustNo(sourceIO.getCustNo()); 							/** 고객번호 */
			targetIO.setCustNm(sourceIO.getCustNm()); 							/** 고객명 */
			targetIO.setMaskCustNm(this.nameMasking(sourceIO.getCustNm())); 	/** 고객명 */
			targetIO.setCustBirth(sourceIO.getCustBirth()); 					/** 생년월일 */
			targetIO.setLoanPrgsStatCd(sourceIO.getLoanPrgsStatCd()); 			/** 대출진행상태코드 */
			targetIO.setLoanApplAmt(sourceIO.getLoanApplAmt()); 				/** 대출신청금액 */

			resultList.add(targetIO);
		}

		resultVo.setSSPASP04DSSDVO(resultList);	/** 신청번호검색리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 성명 마스킹 처리 한다.</p>
	 * <p>메소드인수    : String</p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */
	private String nameMasking(String name) {

		String maskName = "";

		if(name.length() <= 0) {
			return maskName;
		}

		String fstName = name.substring(0, 1);					// 성
		String midName = name.substring(1, name.length() -1);	// 가운데 이름
		String lstName = name.substring(name.length() -1);		// 마지막 글자

		String midMask = "";	// 중간 마스킹 처리

		for(int i = 0; i < midName.length(); i++) {
			midMask += "*";
		}

		if(midName.equals("")) {	// 외자일 경우
			maskName = fstName + "*";
		}else {
			maskName = fstName + midMask + lstName;
		}

		return maskName;

	}

}
