package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.s.sp.as.mapper.SSPASP06Mapper;
import hanalife.s.sp.as.mapper.dto.SSPASP06DSSDDODTO;
import hanalife.s.sp.as.mapper.dto.SSPASP06DSSMDODTO;
import hanalife.s.sp.as.service.SSPASP06Service;
import hanalife.s.sp.as.vo.SSPASP06DSSDDOVO;
import hanalife.s.sp.as.vo.SSPASP06InVO;
import hanalife.s.sp.as.vo.SSPASP06OutVO;

/**
/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP06Service.java Class
 * 클래스설명	: 심사의견등록 (SSPASP06) Service Interface
 * 작성일자	: 2023.05.12.
 * 작성자명	: 70398 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.05.12.][70398 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :  getSSPASP06S01 : 심사의견등록 조회
 *           getSSPASP12S02  : 전결권자대행대상 조회
 *           getSSPASP12S03  : 전결권자대행상태 등록전 중복여부 조회
 *           updSSPASP12U01  : 전결대행자 수정(해지)
 *           insertSSPASP12  : 전결대행자 신규등록
 * </pre>
 */
@Service("SSPASP06Service")
public class SSPASP06ServiceImpl implements SSPASP06Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP06ServiceImpl.class);

	@Autowired
	private SSPASP06Mapper sSPASP06Mapper;

	/**
	 * <p> 메소드명 : getSSPASP06S01 / 심사의견등록 조회 </p>
	 * <p> 작성일자 : 2023.05.12. </p>
	 * <p> 작성자명 : 70398 / KBS </p>
	 * <p> 설명 : 심사의견등록을 조회한다. </p>
	 * <p> 메소드인수 : SSPASP06InVO </p>
	 * <p> 메소드리턴값 : SSPASP06OutVO </p>
	 * <p> 예외처리 : Exception </p>
	 */
	@Override
	public SSPASP06OutVO getSSPASP06S01(SSPASP06InVO inVO) throws Exception {
        LOGGER.info("##### SSPASP06 ServiceImpl getSSPASP06S01 Start #####");

        // 심사의견등록 조회 서비스 결과값 객체 생성
        SSPASP06OutVO resultVo = new SSPASP06OutVO();

        // 심사의견등록 조회 조건 입력값 객체 생성 및 대입 수행
        SSPASP06DSSMDODTO i01Dto = new SSPASP06DSSMDODTO();

        i01Dto.setUserNo(inVO.getSSPASP06DSSMDOVO().getUserNo());    /** 사용자번호 */
        LOGGER.info("getSSPASP06S01 serviceImpl : i01Dto.getUserNo() : " + i01Dto.getUserNo());

        // 심사의견등록 조회 쿼리 Mapper 호출 수행
        List<SSPASP06DSSDDODTO> resultDTO = sSPASP06Mapper.srchExamOpnReg(i01Dto);

        // 심사의견등록 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP06DSSDDOVO> resultList = new ArrayList<SSPASP06DSSDDOVO>();

        for (SSPASP06DSSDDODTO sourceIO : resultDTO)
        {
            // 심사의견등록 조회 VO에 조회된 Mapper DTO 값을 대입
        	SSPASP06DSSDDOVO targetIO = new SSPASP06DSSDDOVO();

			targetIO.setAplyCustMngNo(sourceIO.getAplyCustMngNo());
			targetIO.setCustNm(sourceIO.getCustNm());
			targetIO.setApplRealStsCd(sourceIO.getApplRealStsCd());
			targetIO.setExamManFst(sourceIO.getExamManFst());
			targetIO.setExamManSnd(sourceIO.getExamManSnd());
			targetIO.setExamManTrd(sourceIO.getExamManTrd());
			targetIO.setExamMemoFst(sourceIO.getExamMemoFst());
			targetIO.setExamMemoSnd(sourceIO.getExamMemoSnd());
			targetIO.setExamMemoTrd(sourceIO.getExamMemoTrd());
			targetIO.setSrngYmdFst(sourceIO.getSrngYmdFst());
			targetIO.setSrngYmdSnd(sourceIO.getSrngYmdSnd());
			targetIO.setSrngYmdTrd(sourceIO.getSrngYmdTrd());

            // 심사의견등록 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
        }
        
        LOGGER.info("##### SSPASP06 ServiceImpl getSSPASP06S01 End #####");

        // 심사의견등록 조회 화면 출력 결과값 대입
        resultVo.setListSSPASP06DSSDDOVO(resultList);

        return resultVo;

	}

}
