package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.sp.as.mapper.SSPASP10Mapper;
import hanalife.s.sp.as.mapper.dto.SSPASP10DSSDDTO;
import hanalife.s.sp.as.mapper.dto.SSPASP10DSSMDTO;
import hanalife.s.sp.as.service.SSPASP10Service;
import hanalife.s.sp.as.vo.SSPASP10DSSDVO;
import hanalife.s.sp.as.vo.SSPASP10I01InVO;
import hanalife.s.sp.as.vo.SSPASP10InVO;
import hanalife.s.sp.as.vo.SSPASP10OutVO;

/**
/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP10Service.java Class
 * 클래스설명	: 결재선지정 (SSPASP10) Service Interface
 * 작성일자	: 2023.04.26.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.26.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	getSSPASP10S01	: 결재선 조회
 *          saveSSPASP10    : 결재선 저장
 *          deleteSSPASP10  : 결재선 삭제
 *
 * </pre>
 */
@Service("SSPASP10Service")
public class SSPASP10ServiceImpl implements SSPASP10Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP10ServiceImpl.class);

	@Autowired
	private SSPASP10Mapper sSPASP10Mapper;

	/**
	 * <p> 메소드명	: getSSPASP10S01 - 결재선 조회 </p>
	 * <p> 작성일자	: 2023.04.26. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 결재선 내역을 조회한다. </p>
	 * <p> 메소드인수	: SSPASP10InVO </p>
	 * <p> 메소드리턴값	: SSPASP10OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
    public SSPASP10OutVO getSSPASP10S01(SSPASP10InVO inVo) throws Exception
	{
		LOGGER.info("##### SSPASP10 ServiceImpl getSSPASP10S01 Start #####");

	    // 시도 내역조회 서비스 결과값 객체 생성
		SSPASP10OutVO resultVo = new SSPASP10OutVO();

	    // 시도 내역조회 조건 입력값 객체 생성 및 대입 수행
		SSPASP10DSSMDTO i01Dto = new SSPASP10DSSMDTO();

		i01Dto.setUserNo       (inVo.getSSPASP10DSSMVO().getUserNo());           /** 사번 */
		i01Dto.setApplRealStsCd(inVo.getSSPASP10DSSMVO().getApplRealStsCd());    /** 신청현재잰행상태코드 */

		LOGGER.info("kbs 서비스 입력" + "사용자번호 = i01Dto.getUserNo()             : " + i01Dto.getUserNo());
		LOGGER.info("kbs 서비스 입력" + "신청현재진행상태코드=i01Dto.getApplRealStsCd() : " + i01Dto.getApplRealStsCd());

        // 시도 내역조회 쿼리 Mapper 호출 수행
        List<SSPASP10DSSDDTO> resultDTO = sSPASP10Mapper.srchAtrzMngm(i01Dto);

        // 시도 내역조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP10DSSDVO> resultList = new ArrayList<SSPASP10DSSDVO>();
       	for (SSPASP10DSSDDTO sourceIO : resultDTO)
       	{
       		// 시도 내역조회 VO에 조회된 Mapper DTO 값을 대입
       		SSPASP10DSSDVO targetIO = new SSPASP10DSSDVO();

   		    targetIO.setUserNo       (sourceIO.getUserNo());           /* 사용자번호 */
   		    targetIO.setUserNm       (sourceIO.getUserNm());           /* 사용자명 */
   		    targetIO.setDeptCd       (sourceIO.getDeptCd());           /* 부서코드 */
   		    targetIO.setPosiCd       (sourceIO.getPosiCd());           /* 직위코드 */
   		    targetIO.setUseFg        (sourceIO.getUseFg());            /* 사용여부 */
   		    targetIO.setLoanCnslNo   (sourceIO.getLoanCnslNo());       /* 대출상담번호 */
		    targetIO.setApplRealStsCd(sourceIO.getApplRealStsCd());    /* 신청현재진행상태코드 */
		    targetIO.setRoleDivCd    (sourceIO.getRoleDivCd());        /* 직무구분코드 */
		    targetIO.setAgncStat     (sourceIO.getAgncStat());         /* 대리상태코드 */
		    targetIO.setRoleNo       (sourceIO.getRoleNo());           /* 역할번호 */

            // 시도 내역조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
		}
       	LOGGER.info("##### SSPASP10 ServiceImpl getSSPASP10S01 End #####");

        // 시도 내역조회 화면 출력 결과값 대입
        resultVo.setListSSPASP10DSSDVO(resultList);

        return resultVo;
	}

	/**
	 * <p> 메소드명	: saveSSPASP10 - 결재선 저장 </p>
	 * <p> 작성일자	: 2023.04.28. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 결재선 내역을 저장한다. </p>
	 * <p> 메소드인수	: SSPASP10I01InVO </p>
	 * <p> 메소드리턴값	: SSPASP10OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
	public SSPASP10OutVO saveSSPASP10(SSPASP10I01InVO inVO) throws Exception
	{
		LOGGER.info("SSPASP10 ServiceImpl saveSSPASP10 Start");

		// 결과값 출력 객체 VO 선언 및 정상 초기값 설정
		SSPASP10OutVO resultVo = new SSPASP10OutVO();
		LOGGER.info("SSPASP10 ServiceImpl saveSSPASP10 1111");
		resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

      	// 입력조건 체크
		String strLoanCnslNo	 = inVO.getSSPASP10DSSDVO().getLoanCnslNo().toString();    // 대출상담번호
		String strApplRealStsCd	 = inVO.getSSPASP10DSSDVO().getApplRealStsCd().toString(); // 신청현재진행상태코드
		String strLoanApplNo	 = inVO.getSSPASP10DSSDVO().getLoanApplNo().toString();    // 대출신청번호
		String strIngUserId		 = inVO.getSSPASP10DSSDVO().getIngUserId().toString();     // 진행담당자ID
		String strIngUserNm		 = inVO.getSSPASP10DSSDVO().getIngUserNm().toString();     // 진행담당자성명
//		String strDcdeIngUserId	 = inVO.getSSPASP10DSSDVO().getDcdeIngUserId().toString(); // 대리결제-진행담당자ID
//		String strDcdeIngUserNm	 = inVO.getSSPASP10DSSDVO().getDcdeIngUserNm().toString(); // 대리결제-진행담당자성명
		String strRoleDivCd		 = inVO.getSSPASP10DSSDVO().getRoleDivCd().toString();     // 직무구분코드
		String strFrstRegEmpNo	 = inVO.getSSPASP10DSSDVO().getFrstRegEmpNo ().toString(); // 최초등록사원번호
		String strLastProcEmpNo	 = inVO.getSSPASP10DSSDVO().getLastProcEmpNo().toString(); // 최종처리사원번호

//		LOGGER.info("serviceImpl" + "inVO.strLoanCnslNo	   : " + strLoanCnslNo);
//		LOGGER.info("serviceImpl" + "inVO.strApplRealStsCd : " + strApplRealStsCd);
//		LOGGER.info("serviceImpl" + "inVO.strLoanApplNo	   : " + strLoanApplNo);
//		LOGGER.info("serviceImpl" + "inVO.strIngUserId	   : " + strIngUserId);
//		LOGGER.info("serviceImpl" + "inVO.strIngUserNm	   : " + strIngUserNm);
//		LOGGER.info("serviceImpl" + "inVO.strDcdeIngUserId : " + strDcdeIngUserId);
//		LOGGER.info("serviceImpl" + "inVO.strDcdeIngUserNm : " + strDcdeIngUserNm);
//		LOGGER.info("serviceImpl" + "inVO.strRoleDivCd	   : " + strRoleDivCd);
//		LOGGER.info("serviceImpl" + "inVO.strFrstRegEmpNo  : " + strFrstRegEmpNo);
//		LOGGER.info("serviceImpl" + "inVO.strLastProcEmpNo : " + strLastProcEmpNo);

		// key1값 체크(대출상담번호)
		if( StringUtils.isEmpty(strLoanCnslNo) )
		{
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}
		// key2값 체크(신청현재진행상태코드)
		if( StringUtils.isEmpty(strApplRealStsCd) )
		{
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

		try
		{
        	// 결재선 등록
			SSPASP10DSSDDTO inDto = new SSPASP10DSSDDTO();

    		inDto.setLoanCnslNo    (strLoanCnslNo);    // 대출상담번호
    		inDto.setApplRealStsCd (strApplRealStsCd); // 신청현재진행상태코드
    		inDto.setLoanApplNo	   (strLoanApplNo);    // 대출신청번호
    		inDto.setIngUserId	   (strIngUserId);     // 진행담당자ID
    		inDto.setIngUserNm     (strIngUserNm);     // 진행담당자성명
//    		inDto.setDcdeIngUserId (strDcdeIngUserId); // 대리결제-진행담당자ID
//    		inDto.setDcdeIngUserNm (strDcdeIngUserNm); // 대리결제-진행담당자성명
    		inDto.setRoleDivCd     (strRoleDivCd);     // 직무구분코드
    		inDto.setFrstRegEmpNo  (strFrstRegEmpNo);  // 최초등록사원번호
    		inDto.setLastProcEmpNo (strLastProcEmpNo); // 최종처리사원번호

    		// mapper 호출
    		sSPASP10Mapper.insertAtrzMngm(inDto);

        }
		catch (Exception e)
		{
            LOGGER.error("[결재선 등록 오류] : 결재선 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
		LOGGER.info("SSPASP10 ServiceImpl saveSSPASP10 Normal End");
        return resultVo;
    }

	/**
	 * <p> 메소드명	: deleteSSPASP10 - 결재선 삭제 </p>
	 * <p> 작성일자	: 2023.04.28. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 결재선 내역을 삭제한다. </p>
	 * <p> 메소드인수	: SSPASP10I01InVO </p>
	 * <p> 메소드리턴값	: SSPASP10OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
	public SSPASP10OutVO deleteSSPASP10(SSPASP10I01InVO inVO) throws Exception
	{
    	LOGGER.info("SSPASM02 ServiceImpl deleteSSPASM02 Start");

        // ■ 결과값 출력 객체 VO 선언 및 정상 초기값 설정
    	SSPASP10OutVO resultVo = new SSPASP10OutVO();
        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // ■ 조건 체크
		String strLoanCnslNo	 = inVO.getSSPASP10DSSDVO().getLoanCnslNo().toString();    // 대출상담번호

		LOGGER.info("serviceImpl" + "inVO.strLoanCnslNo	   : " + strLoanCnslNo);

		// key1값 체크(대출상담번호)
		if( StringUtils.isEmpty(strLoanCnslNo) )
		{
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

        try
        {
        	// ■ 결재선 내역 삭제
        	SSPASP10DSSDDTO inDto = new SSPASP10DSSDDTO();
    		inDto.setLoanCnslNo    (strLoanCnslNo);    // 대출상담번호

    		sSPASP10Mapper.deleteAtrzMngm(inDto);
        }
        catch (Exception e)
        {
            LOGGER.error("[결재선내역관리 삭제오류] : 결재선내역 삭제 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
        LOGGER.info("SSPASP10 ServiceImpl deleteSSPASM02 Normal End");
        return resultVo;

	}

	/**
	 * <p> 메소드명	: getSSPASP10S02 - 결재선 등록 전 등록여부 조회 </p>
	 * <p> 작성일자	: 2023.05.02. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 결재선 등록 전 등록여부 조회한다. </p>
	 * <p> 메소드인수	: SSPASP10InVO </p>
	 * <p> 메소드리턴값	: SSPASP10OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
	public int getSSPASP10S02(SSPASP10I01InVO inVo) throws Exception {

		LOGGER.info("SSPASP10 ServiceImpl getSSPASP10S02 Start");

		int iVal = 0;

        // 검색조건(pk값)
		String strLoanCnslNo = inVo.getSSPASP10DSSDVO().getLoanCnslNo().toString();    // 대출상담번호

        // 1차 결재선 입력 전 중복체크 입력 데이터
        SSPASP10DSSDDTO inDto = new SSPASP10DSSDDTO();
        inDto.setLoanCnslNo(strLoanCnslNo);

        // mapper 호출
        String strRtnVal = sSPASP10Mapper.selectAtrzMngmCount(inDto);
        iVal = Integer.parseInt(strRtnVal);

        return iVal;
    }

	/**
	 * <p> 메소드명	: insertSSPASP10 - 심사승인관리_신규 심사건 담당자 저장 </p>
	 * <p> 작성일자	: 2023.05.02. </p>
	 * <p> 작성자명	: 70305 / KBS  </p>
	 * <p> 설명		: 심사승인관리_신규 심사건 1차 담당자를 저장한다. </p>
	 * <p> 메소드인수	: SSPASP10I01InVO </p>
	 * <p> 메소드리턴값	: SSPASP10OutVO </p>
	 * <p> 예외처리	: Exception </p>
	 */
	@Override
	public SSPASP10OutVO insertSSPASP10(SSPASP10I01InVO inVO) throws Exception
	{
		LOGGER.info("SSPASP10 ServiceImpl insertSSPASP10 Start");

		// 결과값 출력 객체 VO 선언 및 정상 초기값 설정
		SSPASP10OutVO resultVo = new SSPASP10OutVO();

		resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

      	// 입력조건 체크
		String strLoanCnslNo	 = inVO.getSSPASP10DSSDVO().getLoanCnslNo().toString();    // 대출상담번호
		String strApplRealStsCd	 = inVO.getSSPASP10DSSDVO().getApplRealStsCd().toString(); // 신청현재진행상태코드
		String strLoanApplNo	 = inVO.getSSPASP10DSSDVO().getLoanApplNo().toString();    // 대출신청번호
		String strIngUserId		 = inVO.getSSPASP10DSSDVO().getIngUserId().toString();     // 진행담당자ID
		String strRoleDivCd		 = inVO.getSSPASP10DSSDVO().getRoleDivCd().toString();     // 직무구분코드
		String strFrstRegEmpNo	 = inVO.getSSPASP10DSSDVO().getFrstRegEmpNo ().toString(); // 최초등록사원번호
		String strLastProcEmpNo	 = inVO.getSSPASP10DSSDVO().getLastProcEmpNo().toString(); // 최종처리사원번호

		LOGGER.info("serviceImpl" + "inVO.strLoanCnslNo	   : " + strLoanCnslNo);
		LOGGER.info("serviceImpl" + "inVO.strApplRealStsCd : " + strApplRealStsCd);
		LOGGER.info("serviceImpl" + "inVO.strLoanApplNo	   : " + strLoanApplNo);
		LOGGER.info("serviceImpl" + "inVO.strIngUserId	   : " + strIngUserId);
		LOGGER.info("serviceImpl" + "inVO.strRoleDivCd	   : " + strRoleDivCd);
		LOGGER.info("serviceImpl" + "inVO.strFrstRegEmpNo  : " + strFrstRegEmpNo);
		LOGGER.info("serviceImpl" + "inVO.strLastProcEmpNo : " + strLastProcEmpNo);

		// key1값 체크(대출상담번호)
		if( StringUtils.isEmpty(strLoanCnslNo) )
		{
			resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
			resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

			return resultVo;
		}

		try
		{
        	// 결재선_1차 심사자 등록
			SSPASP10DSSDDTO inDto = new SSPASP10DSSDDTO();

    		inDto.setLoanCnslNo    (strLoanCnslNo);    // 대출상담번호
    		inDto.setApplRealStsCd (strApplRealStsCd); // 신청현재진행상태코드
    		inDto.setLoanApplNo	   (strLoanApplNo);    // 대출신청번호
    		inDto.setIngUserId	   (strIngUserId);     // 진행담당자ID
    		inDto.setRoleDivCd     (strRoleDivCd);     // 직무구분코드
    		inDto.setFrstRegEmpNo  (strFrstRegEmpNo);  // 최초등록사원번호
    		inDto.setLastProcEmpNo (strLastProcEmpNo); // 최종처리사원번호

    		// mapper 호출
    		sSPASP10Mapper.insertAtrzMngmBase(inDto);

        }
		catch (Exception e)
		{
            LOGGER.error("[결재선 등록 오류] : 결재선 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
		LOGGER.info("SSPASP10 ServiceImpl saveSSPASP10 Normal End");
        return resultVo;
    }
}
