package hanalife.s.sp.as.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hanati.elec.sign.common.StringUtils;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.sp.as.mapper.SSPASP12Mapper;
import hanalife.s.sp.as.mapper.dto.SSPASP12DSSDDTO;
import hanalife.s.sp.as.mapper.dto.SSPASP12DSSMDTO;
import hanalife.s.sp.as.service.SSPASP12Service;
import hanalife.s.sp.as.vo.SSPASP12DSSDVO;
import hanalife.s.sp.as.vo.SSPASP12I01InVO;
import hanalife.s.sp.as.vo.SSPASP12InVO;
import hanalife.s.sp.as.vo.SSPASP12OutVO;

/**
/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP12Service.java Class
 * 클래스설명	: 전결권자대행등록 (SSPASP12) Service Interface
 * 작성일자	: 2023.05.03.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.26.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :  getSSPASP12S01 : 전결권자대행목록 조회
 *           getSSPASP12S02  : 전결권자대행대상 조회
 *           getSSPASP12S03  : 전결권자대행상태 등록전 중복여부 조회
 *           updSSPASP12U01  : 전결대행자 수정(해지)
 *           insertSSPASP12  : 전결대행자 신규등록
 * </pre>
 */
@Service("SSPASP12Service")
public class SSPASP12ServiceImpl implements SSPASP12Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP12ServiceImpl.class);

	@Autowired
	private SSPASP12Mapper sSPASP12Mapper;

	/**
	 * <p> 메소드명 : getSSPASP12S01 / 전결권자대행목록 조회 </p>
	 * <p> 작성일자 : 2023.05.03. </p>
	 * <p> 작성자명 : 70305 / KBS </p>
	 * <p> 설명 : 전결권자대행목록을 조회한다. </p>
	 * <p> 메소드인수 : SSPASP12InVO </p>
	 * <p> 메소드리턴값 : SSPASP12OutVO </p>
	 * <p> 예외처리 : Exception </p>
	 */
    @Override
    public SSPASP12OutVO getSSPASP12S01(SSPASP12InVO inVo) throws Exception
    {
        LOGGER.info("##### SSPASP12 ServiceImpl getSSPASP12S01 Start #####");

        // 전결권자대행목록 조회 서비스 결과값 객체 생성
        SSPASP12OutVO resultVo = new SSPASP12OutVO();

        // 전결권자대행목록 조회 조건 입력값 객체 생성 및 대입 수행
        SSPASP12DSSMDTO i01Dto = new SSPASP12DSSMDTO();

        i01Dto.setUserNo(inVo.getSSPASP12DSSMVO().getUserNo());    /** 사용자번호 */
        LOGGER.info("getSSPASP12S01 serviceImpl : i01Dto.getUserNo() : " + i01Dto.getUserNo());

        // 전결권자대행목록 조회 쿼리 Mapper 호출 수행
        List<SSPASP12DSSDDTO> resultDTO = sSPASP12Mapper.srchArvdAgncMngm(i01Dto);

        // 전결권자대행목록 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP12DSSDVO> resultList = new ArrayList<SSPASP12DSSDVO>();

        for (SSPASP12DSSDDTO sourceIO : resultDTO)
        {
            // 전결권자대행목록 조회 VO에 조회된 Mapper DTO 값을 대입
            SSPASP12DSSDVO targetIO = new SSPASP12DSSDVO();

            targetIO.setArvdSeq       (sourceIO.getArvdSeq());       /* 사용자번호 */
            targetIO.setUserNo        (sourceIO.getUserNo());        /* 사용자번호 */
            targetIO.setUserNm        (sourceIO.getUserNm());        /* 사용자명 */
            targetIO.setAgncUserNo    (sourceIO.getAgncUserNo());    /* 업무대행사원번호 */
            targetIO.setAgncUserNm    (sourceIO.getAgncUserNm());    /* 업무대행자사원명 */
            targetIO.setAgncStrtDt    (sourceIO.getAgncStrtDt());    /* 대리시작일자 */
            targetIO.setAgncEndDt     (sourceIO.getAgncEndDt());     /* 대리종료일자 */
            targetIO.setAgncStat      (sourceIO.getAgncStat());      /* 대리상태 */
            targetIO.setFrstRegDt     (sourceIO.getFrstRegDt());     /* 최초등록일자 */
            targetIO.setFrstRegTm     (sourceIO.getFrstRegTm());     /* 최초등록시각 */
            targetIO.setFrstRegEmpNo  (sourceIO.getFrstRegEmpNo());  /* 최초등록사원번호 */
            targetIO.setLastProcDt    (sourceIO.getLastProcDt());    /* 최종처리일자 */
            targetIO.setLastProcTm    (sourceIO.getLastProcTm());    /* 최종처리시각 */
            targetIO.setLastProcEmpNo (sourceIO.getLastProcEmpNo()); /* 최종처리사원번호 */

            // 전결권자대행목록 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
        }
        LOGGER.info("##### SSPASP12 ServiceImpl getSSPASP12S01 End #####");

        // 전결권자대행목록 조회 화면 출력 결과값 대입
        resultVo.setListSSPASP12DSSDVO(resultList);

        return resultVo;
    }


    /**
     * <p> 메소드명 : getSSPASP12S02 / 전결권자대행 대상 조회 </p>
     * <p> 작성일자 : 2023.05.03. </p>
     * <p> 작성자명 : 70305 / KBS </p>
     * <p> 설명 : 전결권자대행 대상을 조회한다. </p>
     * <p> 메소드인수 : SSPASP12InVO </p>
     * <p> 메소드리턴값 : SSPASP12OutVO </p>
     * <p> 예외처리 : Exception </p>
     */
    @Override
    public SSPASP12OutVO getSSPASP12S02(SSPASP12InVO inVo) throws Exception
    {
        LOGGER.info("##### SSPASP12 ServiceImpl getSSPASP12S02 Start #####");

        // 전결권자대행목록 조회 서비스 결과값 객체 생성
        SSPASP12OutVO resultVo = new SSPASP12OutVO();

        // 전결권자대행목록 조회 조건 입력값 객체 생성 및 대입 수행
        SSPASP12DSSMDTO i01Dto = new SSPASP12DSSMDTO();

        i01Dto.setUserNo(inVo.getSSPASP12DSSMVO().getUserNo());    /** 사용자번호 */

        // 전결권자대행목록 조회 쿼리 Mapper 호출 수행
        List<SSPASP12DSSDDTO> resultDTO = sSPASP12Mapper.srchArvdAgncUser(i01Dto);

        // 전결권자대행목록 조회 화면 출력을 위한 결과값 List VO 객체 생성
        List<SSPASP12DSSDVO> resultList = new ArrayList<SSPASP12DSSDVO>();

        for (SSPASP12DSSDDTO sourceIO : resultDTO)
        {
            // 전결권자대행목록 조회 VO에 조회된 Mapper DTO 값을 대입
            SSPASP12DSSDVO targetIO = new SSPASP12DSSDVO();
            targetIO.setUserNo        (sourceIO.getUserNo());        /* 사용자번호 */
            targetIO.setUserNm        (sourceIO.getUserNm());        /* 사용자명 */

            // 전결권자대행목록 조회 List 객체에 추가하도록 수행
            resultList.add(targetIO);
        }
        LOGGER.info("##### SSPASP12 ServiceImpl getSSPASP12S02 End #####");

        // 전결권자대행목록 조회 화면 출력 결과값 대입
        resultVo.setListSSPASP12DSSDVO(resultList);

        return resultVo;
    }

    /**
     * <p>메소드명 : updSSPASP12U01 : 전결대행상태 수정(해지) </p>
     * <p>작성일자 : 2023.05.04. </p>
     * <p>작성자(author) : 70305 / KBS </p>
     * <p>설명 : 전결대행상태를 수정(해지)한다. </p>
     * <p>메소드인수 : SSPASP12I01InVO </p>
     * <p>메소드리턴값 : SSPASP12OutVO </p>
     * <p>예외처리 : Exception </p>
     */
    @Override
    public SSPASP12OutVO updSSPASP12U01(SSPASP12I01InVO inVo) throws Exception {

        LOGGER.info("##### SSPASP12 ServiceImpl getSSPASP12U01 Start #####");

        SSPASP12OutVO resultVo = new SSPASP12OutVO();

        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // 검색조건 체크
        String strUserNo        = inVo.getSSPASP12DSSMVO().getUserNo().toString();      // 사용자번호
        String strAgncUserNo    = inVo.getSSPASP12DSSMVO().getAgncUserNo().toString();  // 사용자번호
        String strAgncStrtDt    = inVo.getSSPASP12DSSMVO().getAgncStrtDt().toString();  // 업무대리시작일자
        String StrLastProcEmpNo = inVo.getSSPASP12DSSMVO().getLastProcEmpNo();          // 최종변경사원번호

        LOGGER.info("getSSPASP12S01 serviceImpl : strUserNo        : " + inVo.getSSPASP12DSSMVO().getUserNo().toString());
        LOGGER.info("getSSPASP12S01 serviceImpl : strAgncUserNo    : " + inVo.getSSPASP12DSSMVO().getAgncUserNo().toString());
        LOGGER.info("getSSPASP12S01 serviceImpl : strAgncStrtDt    : " + inVo.getSSPASP12DSSMVO().getAgncStrtDt().toString());
        LOGGER.info("getSSPASP12S01 serviceImpl : StrLastProcEmpNo : " + inVo.getSSPASP12DSSMVO().getLastProcEmpNo().toString());

        // key값 체크(업무영역 & 상수명)
        if( StringUtils.isEmpty(strUserNo) ) {
            resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

            return resultVo;
        }

        if( StringUtils.isEmpty(strAgncStrtDt) ) {
            resultVo.setRsltCd(MsgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn(MsgEnum.IS_EMPTY.getErrorCn());

            return resultVo;
        }

        try {
            // 전결대행상태 수정
            SSPASP12DSSMDTO inDto = new SSPASP12DSSMDTO();

            inDto.setUserNo(strUserNo);
            inDto.setAgncUserNo(strAgncUserNo);
            inDto.setAgncStrtDt(strAgncStrtDt);
            inDto.setLastProcEmpNo(StrLastProcEmpNo);

            // 전결대행상태수정(해지) 서비스 호출
            sSPASP12Mapper.updateArvdAgncMngm(inDto);

        }  catch (Exception e) {

            LOGGER.error("[전결대행상태 수정 오류] : " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }

        return resultVo;
    }

    /**
     * <p> 메소드명 : getSSPASP12S03 - 결재선 등록 전 등록여부 조회 </p>
     * <p> 작성일자 : 2023.05.02. </p>
     * <p> 작성자명 : 70305 / KBS </p>
     * <p> 설명 : 결재선 등록 전 등록여부 조회한다. </p>
     * <p> 메소드인수 : SSPASP10InVO </p>
     * <p> 메소드리턴값 : SSPASP10OutVO </p>
     * <p> 예외처리 : Exception </p>
     */
    @Override
    public int getSSPASP12S03(SSPASP12I01InVO srchVO) throws Exception {

        LOGGER.info("SSPASP12 ServiceImpl getSSPASP10S03 Start");

        int iVal = 0;
        // 검색조건
        String strUserNo  = srchVO.getSSPASP12DSSMVO().getUserNo().toString();    // 사용자번호
        String strArvdSeq = srchVO.getSSPASP12DSSMVO().getArvdSeq().toString();   // 전결대리번호

        LOGGER.info("serviceImpl" + "inVo.strUserNo        : " + strArvdSeq);
        LOGGER.info("serviceImpl" + "inVo.strAgncUserNo    : " + strUserNo);

        // 전결대리 등록 전 기 등록여부 체크
        SSPASP12DSSMDTO inDto = new SSPASP12DSSMDTO();

        inDto.setArvdSeq(strArvdSeq);
        inDto.setUserNo (strUserNo);

        // mapper 호출
        String strRtnVal = sSPASP12Mapper.selectArvdAgncMngmCount(inDto);
        iVal = Integer.parseInt(strRtnVal);

        return iVal;
    }


    /**
     * <p>메소드명 : insertSSPASP12 : 전결대행자 신규등록</p>
     * <p>작성일자 : 2023.05.04. </p>
     * <p>작성자(author) : 70305 / KBS </p>
     * <p>설명 : 전결대행자내역을 신규 등록한다.</p>
     * <p>메소드인수 : SSPASP12I01InVO </p>
     * <p>메소드리턴값 : SSPASP12OutVO</p>
     * <p>예외처리 : Exception</p>
     */
    @Override
    public SSPASP12OutVO insertSSPASP12(SSPASP12I01InVO inVo) throws Exception
    {
        LOGGER.info("SSPASP12 ServiceImpl insertSSPASP12 Start");

        // 결과값 출력 객체 VO 선언 및 정상 초기값 설정
        SSPASP12OutVO resultVo = new SSPASP12OutVO();

        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // 입력조건 체크
        String strUserNo         = inVo.getSSPASP12DSSMVO().getUserNo().toString();        // 사용자번호
        String strAgncUserNo     = inVo.getSSPASP12DSSMVO().getAgncUserNo().toString();    // 대리결재자번호
        String strAgncStrtDt     = inVo.getSSPASP12DSSMVO().getAgncStrtDt().toString();    // 대리결재시작일자
        String strAgncEndDt      = inVo.getSSPASP12DSSMVO().getAgncEndDt().toString();     // 대리결재종료일자
        String strFrstRegEmpNo   = inVo.getSSPASP12DSSMVO().getFrstRegEmpNo ().toString(); // 최초등록사원번호
        String strLastProcEmpNo  = inVo.getSSPASP12DSSMVO().getLastProcEmpNo().toString(); // 최종처리사원번호

        LOGGER.info("serviceImpl" + "inVo.strUserNo        : " + strUserNo);
        LOGGER.info("serviceImpl" + "inVo.strAgncUserNo    : " + strAgncUserNo);
        LOGGER.info("serviceImpl" + "inVo.strAgncStrtDt    : " + strAgncStrtDt);
        LOGGER.info("serviceImpl" + "inVo.strAgncEndDt     : " + strAgncEndDt);
        LOGGER.info("serviceImpl" + "inVo.strFrstRegEmpNo  : " + strFrstRegEmpNo);
        LOGGER.info("serviceImpl" + "inVo.strLastProcEmpNo : " + strLastProcEmpNo);

        try
        {
            // 전결권자대행 등록
            SSPASP12DSSMDTO inDto = new SSPASP12DSSMDTO();

            inDto.setUserNo        (strUserNo);        // 사용자번호
            inDto.setAgncUserNo    (strAgncUserNo);    // 대리결재자번호
            inDto.setAgncStrtDt    (strAgncStrtDt);    // 대리결재시작일자
            inDto.setAgncEndDt     (strAgncEndDt);     // 대리결재종료일자
            inDto.setFrstRegEmpNo  (strFrstRegEmpNo);  // 최초등록사원번호
            inDto.setLastProcEmpNo (strLastProcEmpNo); // 최종처리사원번호

            // mapper 호출
            sSPASP12Mapper.insertArvdAgncMngm(inDto);

        }
        catch (Exception e)
        {
            LOGGER.error("[전결대행자등록] : 전결대행자 등록 중 오류  " + e.getMessage());
            resultVo.setRsltCd( MsgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn( e.getMessage() );

            return resultVo;
        }
        LOGGER.info("SSPASP12 ServiceImpl saveSSPASP12 Normal End");
        return resultVo;
    }

}
