package hanalife.s.sp.as.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP01Service;
import hanalife.s.sp.as.vo.SSPASP01DSSMVO;
import hanalife.s.sp.as.vo.SSPASP01InVO;
import hanalife.s.sp.as.vo.SSPASP01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP01Controller.java Class
 * 클래스설명	: KB아파트시세조회_팝업 (SSPASP01) Controller
 * 작성일자	: 2023.04.10.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.03.21.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :	KB아파트시세조회_상세조회	: /SSPASP01S01.do
 * 			KB아파트시세조회_변동조회	: /SSPASP01S02.do
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP01Controller {

	@Resource(name = "SSPASP01Service")
	private SSPASP01Service SSPASP01;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP01Controller.class);

	/**
	 * <p>메소드명			: KB아파트시세조회_상세조회 /SSPASP01S01.do </p>
	 * <p>작성일자			: 2023.04.10.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_상세내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASP01S01.do")
	public String SSPASP01S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASP01 Controller SSPASP01S01 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASP01 Controller SSPASP01S01 추출 #####");

			// 화면의 DSSMDO Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_APT_MKPR_SPEC_SEARCH_SM", request, response, model);

			// KB아파트시세 상세조회 서비스 호출 입력값 대입
			SSPASP01DSSMVO dsSEARCHVO = new SSPASP01DSSMVO();
			dsSEARCHVO.setEsttGodsCd ((String)sourceMap.get("esttGodsCd"));               /* 부동산물건코드  */
			dsSEARCHVO.setPntpSeq    (Long.parseLong((String) sourceMap.get("pntpSeq"))); /* 평형순번 */
			dsSEARCHVO.setRschStndDt ((String)sourceMap.get("rschStndDt"));               /* 조사기준일  */

			LOGGER.info("" + "dsSEARCHVO.getEsttGodsCd()  : " + dsSEARCHVO.getEsttGodsCd());
			LOGGER.info("" + "dsSEARCHVO.getPntpSeq()     : " + dsSEARCHVO.getPntpSeq());
			LOGGER.info("" + "dsSEARCHVO.getRschStndDt()  : " + dsSEARCHVO.getRschStndDt());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASP01InVO InVO = new SSPASP01InVO();

			// KB아파트시세 상세내역 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASP01DSSMVO(dsSEARCHVO);

			// KB아파트시세 상세내역 조회 업무 서비스 호출 수행
			SSPASP01OutVO resultListVo = SSPASP01.getSSPASP01S01(InVO);

			// KB아파트시세 상세내역 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_APT_MKPR_SPEC_SD", resultListVo.getListSSPASP01DSAPTMKPRSPECSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP01 Controller SSPASP01S01 Exception End #####");

		}
		LOGGER.info("##### SSPASP01 Controller SSPASP01S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}



	/**
	 * <p>메소드명			: KB아파트시세조회_상세조회 /SSPASP01S02.do </p>
	 * <p>작성일자			: 2023.04.11.
	 * <p>작성자(author)	: 70305
	 * <p>설명			: KB아파트시세조회_변동내역을 조회한다.</p>
	 * <p>예외처리			: Exception</p>
	 */
    @RequestMapping("/SSPASP01S02.do")
	public String SSPASP01S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASP01 Controller SSPASP01S02 Start #####");

		try {
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASP01 Controller SSPASP01S02 추출 #####");

			// 화면의 Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_APT_MKPR_SPEC_SEARCH2_SM", request, response, model);

			// KB아파트시세 변경내역 조회 서비스 호출 입력값 대입
			SSPASP01DSSMVO dsSEARCHVO = new SSPASP01DSSMVO();
			dsSEARCHVO.setEsttGodsCd ((String)sourceMap.get("esttGodsCd"));                  /* 부동산물건코드  */
			dsSEARCHVO.setPntpSeq    (Long.parseLong((String) sourceMap.get("pntpSeq")));    /* 평형순번 */
			dsSEARCHVO.setRschStndDt ((String)sourceMap.get("rschStndDt"));                  /* 조사기준일  */
			dsSEARCHVO.setRschFromDt ((String)sourceMap.get("rschFromDt"));                  /* 조사기준 시작일  */
			dsSEARCHVO.setRschToDt   ((String)sourceMap.get("rschToDt"));                    /* 조사기준 종료일  */

			LOGGER.info("" + "dsSEARCHVO.getEsttGodsCd()  : " + dsSEARCHVO.getEsttGodsCd());
			LOGGER.info("" + "dsSEARCHVO.getPntpSeq()     : " + dsSEARCHVO.getPntpSeq());
			LOGGER.info("" + "dsSEARCHVO.getRschStndDt()  : " + dsSEARCHVO.getRschStndDt());
			LOGGER.info("" + "dsSEARCHVO.getRschFromDt()  : " + dsSEARCHVO.getRschFromDt());
			LOGGER.info("" + "dsSEARCHVO.getRschToDt()    : " + dsSEARCHVO.getRschToDt());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASP01InVO InVO = new SSPASP01InVO();

			// KB아파트시세 변경내역 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASP01DSSMVO(dsSEARCHVO);

			// KB아파트시세 변경내역 조회 업무 서비스 호출 수행
			SSPASP01OutVO resultListVo = SSPASP01.getSSPASP01S02(InVO);

			// KB아파트시세 변경내역 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_APT_MKPR_FLCTN_SD", resultListVo.getListSSPASP01DSAPTMKPRFLCTNSDVO(), model);

		}catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP01 Controller SSPASP01S02 Exception End #####");

		}
		LOGGER.info("##### SSPASP01 Controller SSPASP01S02 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

}
