package hanalife.s.sp.as.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.contants.Constants;
import hanalife.c.sc.sq.util.Util;
import hanalife.s.ln.lm.service.RmbrPlanCrteService;
import hanalife.s.ln.lm.vo.LoanBaseObj;
import hanalife.s.ln.lm.vo.LoanPiamtObj;
import hanalife.s.ln.lm.vo.RmbrPlanObj;
import hanalife.s.sp.as.vo.SSPASP03S01DSSDVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP03Controller.java Class
 *
 * 클래스설명   : 대출계산기 (SSPASP03) Controller
 * 작성일자     : 2023. 4. 24.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 24.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP03Controller {

	private Constants constants;

	@Resource(name = "RmbrPlanCrteService")
	private RmbrPlanCrteService rmbrPlanCrt;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP03Controller.class);

	/**
	 * <p>메소드명      : 대출계산기 /SSPASP03S01.do </p>
	 * <p>작성일자      : 2023. 4. 24.
	 * <p>작성자(author): 70323
	 * <p>설명          : 대출계산기 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASP03S01.do")
	public String SSPASP03S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASP03Controller SSPASP03S01 Start #####");

		try {
			Map<String, Object> reqMap = XFrame5Util.xFrame5Map(request, response, model);

			XFrame5Util.printMetaInfoMap(reqMap);
			Util.printDataSetfromMap(reqMap);

			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			List<Map<String,Object>> sourceList = XFrame5Util.getDataMapList(reqMap, "DS_SM_C");

			/** 대출계산기내역조회 업무 서비스 호출 입력값 대입 */
			LoanBaseObj loanBaseObj = new LoanBaseObj();
			loanBaseObj.loanNo = (String) sourceList.get(0).get("loanNo");
			loanBaseObj.loanSeq = (String) sourceList.get(0).get("loanSeq");
			loanBaseObj.rmbrPlanTypeDivCd = constants.RMBR_PLAN_TYPE_SIMUL;										/** 상환계획유형구분코드(1.생성,2.시뮬레이션) */
			loanBaseObj.loanPamt = Long.parseLong((String) sourceList.get(0).get("loanPamt"));					/** 대출금액 */
			loanBaseObj.loanTerm = Integer.parseInt((String) sourceList.get(0).get("loanTerm")) * 12;			/** 대출회차 */
			loanBaseObj.loanDt = (String) sourceList.get(0).get("loanDt");										/** 대출일자 */
			loanBaseObj.fcntDueDt = (String) sourceList.get(0).get("fcntDueDt");								/** 초회납입일자 */
			loanBaseObj.fcntMopaCalcFg = (String) sourceList.get(0).get("fcntMopaCalcFg");						/** 초회월할여부 */

			List loanPiamtList = new ArrayList();

			for(int i = 0; i < sourceList.size(); i++) {
				LoanPiamtObj loanPiamtObj = new LoanPiamtObj();
				loanPiamtObj.loanNo = (String) sourceList.get(i).get("loanNo");
				loanPiamtObj.loanSeq = (String) sourceList.get(i).get("loanSeq");
				int aa = Integer.parseInt((String) sourceList.get(i).get("trSnum"));
				int bb = Integer.parseInt((String) sourceList.get(i).get("dueCycl"));

				loanPiamtObj.trSnum = Integer.parseInt((String) sourceList.get(i).get("trSnum"));				/** 거래일련번호 */
				loanPiamtObj.frstRank = Integer.parseInt((String) sourceList.get(i).get("frstRank"));			/** 우선순위 */

				String rmbrFrmlCd = (String) sourceList.get(i).get("rmbrFrmlCd");
				if(constants.S12028_02.equals(rmbrFrmlCd)) {
					rmbrFrmlCd = constants.RMBR_FRML_CD_1;	//원리금균등
				}else if(constants.S12028_01.equals(rmbrFrmlCd)) {
					rmbrFrmlCd = constants.RMBR_FRML_CD_2;	//원금균등
				}else {
					rmbrFrmlCd = constants.RMBR_FRML_CD_4;	//거치
				}

				loanPiamtObj.rmbrFrmlCd = rmbrFrmlCd;															/** 상환방식코드 */
				loanPiamtObj.loanPamt = Long.parseLong((String) sourceList.get(i).get("loanPamt"));				/** 대출금액 */
				loanPiamtObj.term = Integer.parseInt((String) sourceList.get(i).get("term"));					/** 회차 */
				loanPiamtObj.strtTims = Integer.parseInt((String) sourceList.get(i).get("strtTims"));			/** 시작회차 */
				loanPiamtObj.intRt = Double.parseDouble((String) sourceList.get(i).get("intRt"));				/** 이자율 */
				loanPiamtObj.dueCycl = Integer.parseInt((String) sourceList.get(i).get("dueCycl"));				/** 상환주기 */
				loanPiamtObj.dueStrtTims = Integer.parseInt((String) sourceList.get(i).get("dueStrtTims"));		/** 상환시작회차 */

				loanPiamtList.add(loanPiamtObj);
			}

			loanBaseObj.piamtObjList = loanPiamtList;

			/** 대출계산기내역조회 업무 서비스 호출 수행 */
			loanBaseObj = rmbrPlanCrt.createRmblPlan(loanBaseObj);

			List resultSSPASP03S01 = new ArrayList();

			for(int j = 0; j < sourceList.size(); j++) {
				LoanPiamtObj loanPiamt = (LoanPiamtObj) loanBaseObj.piamtObjList.get(j);

				for (int i = 0; i < loanPiamt.rmbrObjList.size(); i++) {
					RmbrPlanObj rmbrObj = (RmbrPlanObj) loanPiamt.rmbrObjList.get(i);
					SSPASP03S01DSSDVO resultObj = new SSPASP03S01DSSDVO();

					resultObj.setTims(rmbrObj.tims);						/** 회차 */
					resultObj.setDueDt(rmbrObj.dueDt);						/** 납입일 */
					resultObj.setMmPamt(rmbrObj.mmPamt);					/** 원금 */
					resultObj.setMmInt(rmbrObj.mmInt);						/** 이자 */
					resultObj.setMmPiamt(rmbrObj.mmPiamt);					/** 금액 */
					resultObj.setTimsAfPamtRamt(rmbrObj.timsAfPamtRamt);	/** 잔액 */

					resultSSPASP03S01.add(resultObj);
				}
			}

			XFrame5Util.setOutputData("DS_SD", resultSSPASP03S01, model);

			LOGGER.info("##### SSPASP03Controller SSPASP03S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP03Controller SSPASP03S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
