package hanalife.s.sp.as.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.util.BeanUtil;
import hanalife.s.sp.as.service.SSPASP04Service;
import hanalife.s.sp.as.vo.SSPASP04DSSMVO;
import hanalife.s.sp.as.vo.SSPASP04S01InVO;
import hanalife.s.sp.as.vo.SSPASP04S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP04Controller.java Class
 *
 * 클래스설명   : 신청번호검색 (SSPASP04) Controller
 * 작성일자     : 2023. 3. 22.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 7.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP04Controller {

	@Resource(name = "SSPASP04Service")
	private SSPASP04Service SSPASP04;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP04Controller.class);

	/**
	 * <p>메소드명      : 신청번호검색 /SSPASP04S01.do </p>
	 * <p>작성일자      : 2023. 3. 22.
	 * <p>작성자(author): 70323
	 * <p>설명          : 신청번호검색 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASP04S01.do")
	public String SSPASP04S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASP04Controller SSPASP04S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 신청번호검색내역조회 업무 서비스 호출 입력값 대입 */
			SSPASP04S01InVO targetVo = new SSPASP04S01InVO();
			SSPASP04DSSMVO smVo = new SSPASP04DSSMVO();

			BeanUtil.mapToBean(sourceMap, smVo);	/** Map을 VO로 변환 */

			targetVo.setSSPASP04DSSMVO(smVo);

			/** 신청번호검색내역조회 업무 서비스 호출 수행 */
			SSPASP04S01OutVO resultSSPASP04S01 = SSPASP04.getSSPASP04S01(targetVo);

			XFrame5Util.setOutputData("DS_SD", resultSSPASP04S01.getSSPASP04DSSDVO(), model);

			model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, resultSSPASP04S01.getRsltCd());
			model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, resultSSPASP04S01.getRsltCntn());

			LOGGER.info("##### SSPASP04Controller SSPASP04S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP04Controller SSPASP04S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}

}
