package hanalife.s.sp.as.web;

import java.math.BigDecimal;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.StringUtil;
import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.framework.comm.vo.UserSessionVO;
import hanalife.s.sp.as.service.SSPASP05Service;
import hanalife.s.sp.as.vo.SSPASP05DSSTCSSINCOMEVO;
import hanalife.s.sp.as.vo.SSPASP05S01InVO;
import hanalife.s.sp.as.vo.SSPASP05S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP05Controller.java Class
 *
 * 클래스설명   : 연소득 (SSPASP05) Controller
 * 작성일자     : 2023.04.03.
 * 작성자명     : 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.04.03.][70280][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP05Controller
{

    @Resource(name = "SSPASP05Service")
    private SSPASP05Service SSPASP05;

    private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP05Controller.class);


    /**
     * <p>메소드명      : 연소득 정보 조회 /SSPASP05S02.do </p>
     * <p>작성일자      : 2023.04.05.
     * <p>작성자(author): 70280
     * <p>설명          : 연소득 정보 목록을 조회한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SSPASP05S02.do")
    public String SSPASP05S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SSPASP05Controller SSPASP05S02 Start #####");

        try
        {
            /** 세션 정보 호출 */
            HttpSession session = request.getSession();
            UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CT_CSS_INCOME_SEARCH", request, response, model);

            SSPASP05DSSTCSSINCOMEVO inSearchVo = new SSPASP05DSSTCSSINCOMEVO();
            inSearchVo.setLoanCnslNo(sourceMap.get("loanCnslNo").toString().trim());
            inSearchVo.setProdGbCd(sourceMap.get("prodGbCd").toString().trim());

             // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SSPASP05S01InVO InVo = new SSPASP05S01InVO();
            InVo.setsSPASP05DSSTCSSINCOMEVO(inSearchVo);

            SSPASP05S01OutVO OutVo = SSPASP05.getSSPASP05S02(InVo);

            XFrame5Util.setOutputData("DS_CT_CSS_INCOME", OutVo.getListSSPASP05DSSTCSSINCOMEVO(), model);

            LOGGER.info("##### SSPASP05Controller SSPASP05S02 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP05Controller SSPASP05S02 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명      : 연소득 정보 등록 /SSPASP05I01.do </p>
     * <p>작성일자      : 2023.04.05.
     * <p>작성자(author): 70280
     * <p>설명          : 연소득 정보를 등록한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SSPASP05I01.do")
    public String SSPASP05I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SSPASP05Controller SSPASP05I01 Start #####");

        try
        {
            /** 세션 정보 호출 */
            HttpSession session = request.getSession();
            UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CT_CSS_INCOME_C", request, response, model);         // DS_CT_CSS_INCOME

            String sLoanCnslNo         = sourceMap.get("loanCnslNo").toString().trim();                // 대출상담번호
            String sProdGbCd           = sourceMap.get("prodGbCd").toString().trim();                  // 상품구분코드
            String sIncoObjDivCd       = sourceMap.get("incoObjDivCd").toString().trim();              // 소득대상구분코드
            String sIncoKindDivCd      = sourceMap.get("incoKindDivCd").toString().trim();             // 소득종류구분코드
            String sIncoProfDocCd      = sourceMap.get("incoProfDocCd").toString().trim();             // 소득증빙서류코드
            String sIncoDataSubmTermCd = sourceMap.get("incoDataSubmTermCd").toString().trim();        // 소득자료제출기간코드
            String sRcntYyIncoAmt      = sourceMap.get("rcntYyIncoAmt").toString().trim();             // 최근년도연소득금액
            String sRcntBfYyIncoAmt    = sourceMap.get("rcntBfYyIncoAmt").toString().trim();           // 최근년도직전년도연소득금액
            String sCvrtYyIncoAmt      = "0";                                                          // 환산연소득은 무조건 0원입력 처리
            String sFrstRegDt          = sourceMap.get("frstRegDt").toString().trim();
            String sFrstRegTm          = sourceMap.get("frstRegTm").toString().trim();
            String sFrstRegEmpNo       = sourceMap.get("frstRegEmpNo").toString().trim();
            String sLastProcDt         = sourceMap.get("lastProcDt").toString().trim();
            String sLastProcTm         = sourceMap.get("lastProcTm").toString().trim();
            String sLastProcEmpNo      = sourceMap.get("lastProcEmpNo").toString().trim();

            // 인정소득? -> "0" 처리
            if (sIncoKindDivCd.equals(Constants.S12020_ADMT))
            {
                sRcntBfYyIncoAmt       = "0";
                sIncoDataSubmTermCd    = " "; // TODO. 20230408. 성관용. 연소득 테이블에서 소득자료제출기간 PK 제거 후. 이 라인 제거할 것.
            }

            // 신고소득? -> "0" 처리
            if (sIncoKindDivCd.equals(Constants.S12020_DECL))
            {
                sRcntBfYyIncoAmt       = "0";
                sIncoDataSubmTermCd    = " "; // TODO. 20230408. 성관용. 연소득 테이블에서 소득자료제출기간 PK 제거 후. 이 라인 제거할 것.
            }

            SSPASP05DSSTCSSINCOMEVO incomeVo = new SSPASP05DSSTCSSINCOMEVO();
            incomeVo.setLoanCnslNo         (sLoanCnslNo                                             );
            incomeVo.setProdGbCd           (sProdGbCd                                               );
            incomeVo.setIncoObjDivCd       (sIncoObjDivCd                                           );
            incomeVo.setIncoKindDivCd      (sIncoKindDivCd                                          );
            incomeVo.setIncoProfDocCd      (sIncoProfDocCd                                          );
            incomeVo.setIncoDataSubmTermCd (sIncoDataSubmTermCd                                     );
            incomeVo.setRcntYyIncoAmt      (new BigDecimal(StringUtil.parseLong(sRcntYyIncoAmt))    );
            incomeVo.setRcntBfYyIncoAmt    (new BigDecimal(StringUtil.parseLong(sRcntBfYyIncoAmt))  );
            incomeVo.setCvrtYyIncoAmt      (new BigDecimal(StringUtil.parseLong(sCvrtYyIncoAmt))    );
            incomeVo.setFrstRegDt          (sFrstRegDt                                              );
            incomeVo.setFrstRegTm          (sFrstRegTm                                              );
            incomeVo.setFrstRegEmpNo       (sFrstRegEmpNo                                           );
            incomeVo.setLastProcDt         (sLastProcDt                                             );
            incomeVo.setLastProcTm         (sLastProcTm                                             );
            incomeVo.setLastProcEmpNo      (sLastProcEmpNo                                          );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SSPASP05S01InVO InVo = new SSPASP05S01InVO();
            InVo.setsSPASP05DSSTCSSINCOMEVO(incomeVo);

            SSPASP05S01OutVO OutVo = null;
            OutVo = SSPASP05.insertStCssIncome(InVo);
            if (OutVo.getRsltCd().equals(MsgEnum.SUCCESS.getErrorCd()) != true)
            {
                model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, OutVo.getRsltCd());
                model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, OutVo.getRsltCntn());
            }

            OutVo = SSPASP05.getSSPASP05S02(InVo);
            XFrame5Util.setOutputData("DS_CT_CSS_INCOME", OutVo.getListSSPASP05DSSTCSSINCOMEVO(), model);

            LOGGER.info("##### SSPASP05Controller SSPASP05I01 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP05Controller SSPASP05I01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }


    /**
     * <p>메소드명      : 연소득 정보 삭제 /SSPASP05D01.do </p>
     * <p>작성일자      : 2023.04.05.
     * <p>작성자(author): 70280
     * <p>설명          : 연소득 정보를 삭제한다.</p>
     * <p>예외처리      : Exception</p>
     */
    @RequestMapping("/SSPASP05D01.do")
    public String SSPASP05D01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception
    {
        LOGGER.info("##### SSPASP05Controller SSPASP05D01 Start #####");

        try
        {
            /** 세션 정보 호출 */
            HttpSession session = request.getSession();
            UserSessionVO sessionVO = (UserSessionVO) session.getAttribute("UserSessionVO");

            /** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_CT_CSS_INCOME_D", request, response, model);         // DS_CT_CSS_INCOME

            String sLoanCnslNo         = sourceMap.get("loanCnslNo").toString().trim();                // 대출상담번호
            String sProdGbCd           = sourceMap.get("prodGbCd").toString().trim();                  // 상품구분코드
            String sIncoObjDivCd       = sourceMap.get("incoObjDivCd").toString().trim();              // 소득대상구분코드
            String sIncoKindDivCd      = sourceMap.get("incoKindDivCd").toString().trim();             // 소득종류구분코드
            String sIncoProfDocCd      = sourceMap.get("incoProfDocCd").toString().trim();             // 소득증빙서류코드
            String sIncoDataSubmTermCd = sourceMap.get("incoDataSubmTermCd").toString().trim();        // 소득자료제출기간코드
            String sRcntYyIncoAmt      = sourceMap.get("rcntYyIncoAmt").toString().trim();             // 최근년도연소득금액
            String sRcntBfYyIncoAmt    = sourceMap.get("rcntBfYyIncoAmt").toString().trim();           // 최근년도직전년도연소득금액
            String sCvrtYyIncoAmt      = "0";                                                          // 환산연소득은 무조건 0원입력 처리
            String sFrstRegDt          = sourceMap.get("frstRegDt").toString().trim();
            String sFrstRegTm          = sourceMap.get("frstRegTm").toString().trim();
            String sFrstRegEmpNo       = sourceMap.get("frstRegEmpNo").toString().trim();
            String sLastProcDt         = sourceMap.get("lastProcDt").toString().trim();
            String sLastProcTm         = sourceMap.get("lastProcTm").toString().trim();
            String sLastProcEmpNo      = sourceMap.get("lastProcEmpNo").toString().trim();

            SSPASP05DSSTCSSINCOMEVO incomeVo = new SSPASP05DSSTCSSINCOMEVO();
            incomeVo.setLoanCnslNo         (sLoanCnslNo                                             );
            incomeVo.setProdGbCd           (sProdGbCd                                               );
            incomeVo.setIncoObjDivCd       (sIncoObjDivCd                                           );
            incomeVo.setIncoKindDivCd      (sIncoKindDivCd                                          );
            incomeVo.setIncoProfDocCd      (sIncoProfDocCd                                          );
            incomeVo.setIncoDataSubmTermCd (sIncoDataSubmTermCd                                     );
            incomeVo.setRcntYyIncoAmt      (new BigDecimal(StringUtil.parseLong(sRcntYyIncoAmt))    );
            incomeVo.setRcntBfYyIncoAmt    (new BigDecimal(StringUtil.parseLong(sRcntBfYyIncoAmt))  );
            incomeVo.setCvrtYyIncoAmt      (new BigDecimal(StringUtil.parseLong(sCvrtYyIncoAmt))    );
            incomeVo.setFrstRegDt          (sFrstRegDt                                              );
            incomeVo.setFrstRegTm          (sFrstRegTm                                              );
            incomeVo.setFrstRegEmpNo       (sFrstRegEmpNo                                           );
            incomeVo.setLastProcDt         (sLastProcDt                                             );
            incomeVo.setLastProcTm         (sLastProcTm                                             );
            incomeVo.setLastProcEmpNo      (sLastProcEmpNo                                          );

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SSPASP05S01InVO InVo = new SSPASP05S01InVO();
            InVo.setsSPASP05DSSTCSSINCOMEVO(incomeVo);

            SSPASP05S01OutVO OutVo = null;
            OutVo = SSPASP05.deleteStCssIncome(InVo);
            if (OutVo.getRsltCd().equals(MsgEnum.SUCCESS.getErrorCd()) != true)
            {
                model.addAttribute(XFrame5View.XFRAME5_MSG_CODE, OutVo.getRsltCd());
                model.addAttribute(XFrame5View.XFRAME5_MSG_DETAIL, OutVo.getRsltCntn());
            }

            OutVo = SSPASP05.getSSPASP05S02(InVo);

            XFrame5Util.setOutputData("DS_CT_CSS_INCOME", OutVo.getListSSPASP05DSSTCSSINCOMEVO(), model);

            LOGGER.info("##### SSPASP05Controller SSPASP05D01 Normal End #####");
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP05Controller SSPASP05D01 Exception End #####");
        }

        return XFrame5View.XFRAME5_VIEW;
    }
}