package hanalife.s.sp.as.web;

import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP08Service;
import hanalife.s.sp.as.vo.SSPASP08DSSMVO;
import hanalife.s.sp.as.vo.SSPASP08S01InVO;
import hanalife.s.sp.as.vo.SSPASP08S01OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SSPASP08Controller.java Class
 * 클래스설명   : todo1 (SSPASP08) Controller
 * 작성일자     : 2023. 3. 10.
 * 작성자명     : 70324 / WoongHee.Lee / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 10.][70324 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP08Controller {

	@Resource(name = "SSPASP08Service")
	private SSPASP08Service SSPASP08;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP08Controller.class);

	/**
	 * <p>메소드명      : 대출현황계좌목록 조회팝업 /SSPASP08S01.do </p>
	 * <p>작성일자      : 2023. 3. 10.
	 * <p>작성자(author): 70324
	 * <p>설명          : 대출현황계좌목록을 조회한다.</p>
	 * <p>예외처리      : Exception</p>
	 */
	@RequestMapping("/SSPASP08S01.do")
	public String SSPASP08S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

		LOGGER.info("##### SSPASP08Controller SSPASP08S01 Start #####");

		try {
			/** XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다. */
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_SM", request, response, model);

			/** 대출현황계좌조회(팝업) DataSet 항목값 VO 객체 입력값 대입 */
			SSPASP08DSSMVO dsSMInVo = new SSPASP08DSSMVO();
			dsSMInVo.setInqrKey((String) sourceMap.get("inqrKey"));          // 사업자번호
			dsSMInVo.setUseGbCd((String) sourceMap.get("useGbCd"));          // 가상계좌사용구분코드

            /** Service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입 */
			SSPASP08S01InVO InVO = new SSPASP08S01InVO();
            InVO.setSSPASP08DSSMVO(dsSMInVo); /** 연락불능자목록조회 DS_SMDO 입력값 VO 객체 대입 */
            /** 대출현황계좌조회(팝업) 업무 서비스 호출 수행 */
            SSPASP08S01OutVO resultListVo = SSPASP08.getSSPASP08S01(InVO);
            /** 대출현황계좌조회(팝업) DataSet 결과값 설정 */
			XFrame5Util.setOutputData("DS_SD", resultListVo.getSSPASP08DSSDVO(), model);

			LOGGER.info("##### SSPASP08Controller SSPASP08S01 Normal End #####");
		} catch (Exception e) {
			LOGGER.error("Error >>> " + e.getMessage());
			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP08Controller SSPASP08S01 Exception End #####");
		}

		return XFrame5View.XFRAME5_VIEW;
	}


}
