package hanalife.s.sp.as.web;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import hanalife.c.co.util.XFrame5DataSetUtil;
import hanalife.s.sp.as.service.SSPASP12Service;
import hanalife.s.sp.as.vo.SSPASP12DSSMVO;
import hanalife.s.sp.as.vo.SSPASP12I01InVO;
import hanalife.s.sp.as.vo.SSPASP12InVO;
import hanalife.s.sp.as.vo.SSPASP12OutVO;
import xdataset5spring.XFrame5Util;
import xdataset5spring.XFrame5View;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SSPASP12Controller.java Class
 * 클래스설명	: 전결권자대행등록 (SSPASP12) Controller
 * 작성일자	: 2023.05.04.
 * 작성자명	: 70305 / KBS / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [수정일자][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023.05.04.][70305 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 *           전결권자대행목록 조회: /SSPASP12S01.do
 *           전결권자대행대상 조회: /SSPASP12S02.do
 *           전결권자대행대상 해지: /SSPASP12U01.do
 *           전결권자대행 신규등록: /SSPASP12I01.do
 * </pre>
 */

@RequestMapping("/s/sp/as")
@Controller
public class SSPASP12Controller {

	@Resource(name = "SSPASP12Service")
	private SSPASP12Service SSPASP12;

	private static final Logger LOGGER = LoggerFactory.getLogger(SSPASP12Controller.class);

	/**
	 * <p> 메소드명 		: 전결권자대행목록 조회 /SSPASP12S01.do </p>
	 * <p> 작성일자 		: 2023.05.04. </p>
	 * <p> 작성자(author) : 70305 / KBS </p>
	 * <p> 설명 			: 전결권자대행목록을 조회한다. </p>
	 * <p> 예외처리 		: Exception </p>
	 */
	@RequestMapping("/SSPASP12S01.do")
	public String SSPASP12S01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
		LOGGER.info("##### SSPASP12 Controller SSPASP12S01 Start #####");

		try
		{
			// XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
			LOGGER.info("##### SSPASP12 Controller SSPASP12S01 추출 #####");

			// 화면의 입력값 Dataset setting
			Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ARVD_AGNC_SRCH", request, response, model);

			// 전결권자대행목록 조회 서비스 호출 입력값 대입
			SSPASP12DSSMVO dsSEARCHVO = new SSPASP12DSSMVO();

			// 전결권자대행목록 조회 업무 서비스 호출 입력값 대입
			dsSEARCHVO.setUserNo((String)sourceMap.get("userNo"));    /** 사용자번호 */
//			LOGGER.info("SSPASP12S01 Controller :: dsSEARCHVO.getUserNo() : " + dsSEARCHVO.getUserNo());

			// service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
			SSPASP12InVO InVO = new SSPASP12InVO();

			// 전결권자대행목록 조회 DS_SMDO 입력값 VO 객체 대입
			InVO.setSSPASP12DSSMVO(dsSEARCHVO);

			// 전결권자대행목록 조회 업무 서비스 호출 수행
			SSPASP12OutVO resultListVo = SSPASP12.getSSPASP12S01(InVO);

			// 전결권자대행목록 조회 DataSet 결과값 설정
			XFrame5Util.setOutputData("DS_ARVD_AGNC_SD", resultListVo.getListSSPASP12DSSDVO(), model);

		}
		catch (Exception e)
		{
			LOGGER.error("Error >>> " + e.getMessage());

			// 오류 메시지 정보 설정
			model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
			model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

			LOGGER.info("##### SSPASP12 Controller SSPASP12S01 Exception End #####");

		}
		LOGGER.info("##### SSPASP12 Controller SSPASP12S01 End #####");
		return XFrame5View.XFRAME5_VIEW;
	}

	/**
     * <p> 메소드명 : 전결권자대행대상 조회 /SSPASP12S02.do </p>
     * <p> 작성일자 : 2023.05.04. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 전결권자대행목록을 조회한다. </p>
     * <p> 예외처리 : Exception </p>
     */
    @RequestMapping("/SSPASP12S02.do")
    public String SSPASP12S02(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {
        LOGGER.info("##### SSPASP12 Controller SSPASP12S01 Start #####");

        try
        {
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            LOGGER.info("##### SSPASP12 Controller SSPASP12S01 추출 #####");

            // 화면의 입력값 Dataset setting
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ARVD_AGNC_SRCH", request, response, model);

            // 전결권자대행 대상 조회 서비스 호출 입력값 대입
            SSPASP12DSSMVO dsSEARCHVO = new SSPASP12DSSMVO();

            // 전결권자대행 대상 조회 업무 서비스 호출 입력값 대입
            dsSEARCHVO.setUserNo((String)sourceMap.get("userNo"));    /** 사용자번호 */
//            LOGGER.info("SSPASP12S01 Controller :: dsSEARCHVO.getUserNo() : " + dsSEARCHVO.getUserNo());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SSPASP12InVO InVO = new SSPASP12InVO();

            // 전결권자대행 대상 조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSSPASP12DSSMVO(dsSEARCHVO);

            // 전결권자대행 대상 조회 업무 서비스 호출 수행
            SSPASP12OutVO resultListVo = SSPASP12.getSSPASP12S02(InVO);

            // 전결권자대행 대상 조회 DataSet 결과값 설정
            XFrame5Util.setOutputData("DS_AGNC_USER_SD", resultListVo.getListSSPASP12DSSDVO(), model);

        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP12 Controller SSPASP12S01 Exception End #####");

        }
        LOGGER.info("##### SSPASP12 Controller SSPASP12S01 End #####");
        return XFrame5View.XFRAME5_VIEW;

    }

    /**
     * <p> 메소드명 : 전결권자대행 대상 해지 /SSPASP12U01.do </p>
     * <p> 작성일자 : 2023.05.04. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 전결권자대행목록 업데이트(해지)한다. </p>
     * <p> 예외처리 : Exception </p>
     */
    @RequestMapping("/SSPASP12U01.do")
    public String SSPASP12U01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPASP12Controller SSPASP12U01 Start #####");

        try
        {
            // 화면의 입력값 Dataset setting
            Map<String, Object> sourceMap = XFrame5DataSetUtil.getXFrameDataSet("DS_ARVD_AGNC_SRCH", request, response, model);

            // 전결권자대행 대상 조회 서비스 호출 입력값 대입
            SSPASP12DSSMVO dsSEARCHVO = new SSPASP12DSSMVO();

            // 전결권자대행 대상 조회 업무 서비스 호출 입력값 대입
            dsSEARCHVO.setUserNo       ((String)sourceMap.get("userNo"));        /** 사용자번호 */
            dsSEARCHVO.setAgncUserNo   ((String)sourceMap.get("agncUserNo"));    /** 업무대행사용자번호 */
            dsSEARCHVO.setAgncStrtDt   ((String)sourceMap.get("agncStrtDt"));    /** 업무대행시작일자 */
            dsSEARCHVO.setLastProcEmpNo((String)sourceMap.get("lastProcEmpNo"));    /** 최종변경사원번호 */

//            LOGGER.info("SSPASP12S01 Controller :: dsSEARCHVO.getUserNo()          : " + dsSEARCHVO.getUserNo());
//            LOGGER.info("SSPASP12S01 Controller :: dsSEARCHVO.getAgncUserNo()      : " + dsSEARCHVO.getAgncUserNo());
//            LOGGER.info("SSPASP12S01 Controller :: dsSEARCHVO.getAgncStrtDtNo()    : " + dsSEARCHVO.getAgncStrtDt());
//            LOGGER.info("SSPASP12S01 Controller :: dsSEARCHVO.getLastProcEmpNoNo() : " + dsSEARCHVO.getLastProcEmpNo());

            // service 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            SSPASP12I01InVO InVO = new SSPASP12I01InVO();

            // 전결권자대행 대상 조회 DS_SMDO 입력값 VO 객체 대입
            InVO.setSSPASP12DSSMVO(dsSEARCHVO);

            // 전결권자대행 대상 조회 업무 서비스 호출 수행
            SSPASP12OutVO resultListVo = SSPASP12.updSSPASP12U01(InVO);

            LOGGER.info("##### SSPASP12Controller SSPASP12U01 Normal End #####");

        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());
            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP12Controller SSPASP12U01 Exception End #####");
        }
        return XFrame5View.XFRAME5_VIEW;
    }

    /**
     * <p> 메소드명 : 전결권자대행 신규등록 /SSPASP12I01.do </p>
     * <p> 작성일자 : 2023.05.04. </p>
     * <p> 작성자(author) : 70305 / KBS </p>
     * <p> 설명 : 전결권자대행을 신규등록한다. </p>
     * <p> 예외처리 : Exception </p>
     */
    @RequestMapping("/SSPASP12I01.do")
    public String SSPASP12I01(HttpServletRequest request, HttpServletResponse response, ModelMap model) throws Exception {

        LOGGER.info("##### SSPASP12 Controller SSPASP12I01 Start #####");

        try
        {
            // XFrame5 UI에서 전달된 특정 DataSet 정보를 추출한다.
            List<Map<String, Object>> sourceMapC = XFrame5DataSetUtil.getXFrameDataSetList("DS_ARVD_AGNC_SRCH", request, response, model);

            // ■ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
            Map<String, Object> inMap = new HashMap<String, Object>();

            // ■ 등록 전 데이터 중복여부 조회를 위한 INVO
            SSPASP12I01InVO srchVO = new SSPASP12I01InVO();

            // ■ 등록 처리
            SSPASP12OutVO resultI01 = new SSPASP12OutVO();

            if (sourceMapC.size() > 0)
            {
                for (int idx = 0; idx < sourceMapC.size(); idx++)
                {
                    // ▣ 1차 심사자 데이터 등록
                    inMap = sourceMapC.get(idx);

                    // ▣ SERVICE 호출을 위한 입력 VO 객체에 DataSet VO 입력값 대입
                    SSPASP12DSSMVO inSddoVo = new SSPASP12DSSMVO();

                    inSddoVo.setArvdSeq      (inMap.get("arvdSeq").toString());         /* 전결대리순번 */
                    inSddoVo.setUserNo       (inMap.get("userNo").toString());           /* 사용자번호 */
                    inSddoVo.setAgncUserNo   (inMap.get("agncUserNo").toString());       /* 대리결재자번호 */
                    inSddoVo.setAgncStrtDt   (inMap.get("agncStrtDt").toString());       /* 대리결재시작일자 */
                    inSddoVo.setAgncEndDt    (inMap.get("agncEndDt").toString());        /* 대리결재종료일자 */
                    inSddoVo.setFrstRegEmpNo (inMap.get("frstRegEmpNo").toString());     /* 최초등록사원번호 */
                    inSddoVo.setLastProcEmpNo(inMap.get("lastProcEmpNo").toString());    /* 최종처리사원번호 */

//                    LOGGER.info("getArvdSeq       :'" + inSddoVo.getArvdSeq()       + "'");
//                    LOGGER.info("getUserNo        :'" + inSddoVo.getUserNo()        + "'");
//                    LOGGER.info("getAgncUserNo    :'" + inSddoVo.getAgncUserNo()    + "'");
//                    LOGGER.info("getAgncStrtDt    :'" + inSddoVo.getAgncStrtDt()    + "'");
//                    LOGGER.info("getAgncEndDt     :'" + inSddoVo.getAgncEndDt()     + "'");
//                    LOGGER.info("getFrstRegEmpNo  :'" + inSddoVo.getFrstRegEmpNo()  + "'");
//                    LOGGER.info("getLastProcEmpNo :'" + inSddoVo.getLastProcEmpNo() + "'");

                    // ▣ 전결권자 등록 서비스 호출 입력값 대입
                    SSPASP12I01InVO InVo = new SSPASP12I01InVO();
                    InVo.setSSPASP12DSSMVO(inSddoVo);

                    // ▣ 전결권자 등록 전 중복여부 확인
                    srchVO.setSSPASP12DSSMVO(inSddoVo);
                    int iCount = SSPASP12.getSSPASP12S03(srchVO);

                    if( iCount == 0 )
                    {
                        // 전결권자 미등록
                        resultI01 = SSPASP12.insertSSPASP12(InVo);
                    }
                    else
                    {
                        // 이미 등록
                        LOGGER.info("이미 등록된 사용자!!!!!!!!!!!!!");
                    }
                }
            }
        }
        catch (Exception e)
        {
            LOGGER.error("Error >>> " + e.getMessage());

            // 오류 메시지 정보 설정
            model.addAttribute(XFrame5View.XFRAME5_ERR_CODE, "-100");
            model.addAttribute(XFrame5View.XFRAME5_ERR_DETAIL, e.getMessage());

            LOGGER.info("##### SSPASP12Controller SSPASP12I01 Exception End #####");
        }
        LOGGER.info("##### SSPASP12 Controller SSPASP12I01 End #####");
        return XFrame5View.XFRAME5_VIEW;
    }
}
