package hanalife.s.sp.gd.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.DateUtil;
import hanalife.s.sp.gd.mapper.StndIntRtMapper;
import hanalife.s.sp.gd.mapper.dto.SSPGDM03DSSDOutDTO;
import hanalife.s.sp.gd.mapper.dto.SSPGDM03SrchDTO;
import hanalife.s.sp.gd.service.SSPGDM03Service;
import hanalife.s.sp.gd.vo.SSPGDM03DSDDSSVO;
import hanalife.s.sp.gd.vo.SSPGDM03InVO;
import hanalife.s.sp.gd.vo.SSPGDM03OutVO;
import hanalife.util.format.ServerSysDate;

/**
 * <pre>
 * 클래스명    : SSPGDM03ServiceImpl.java Class
 * 클래스설명  : 상품분류관리 (SSPGDM03) ServiceImple
 * 프로젝트명  : DOBSCAP
 * 작성일자    : 2023. 3. 13.
 * 작성자명    : 70319 / 가계대출 시스템 구축
 * 변경이력
 * -----------------------------------------------------------------------------
 * [  변경일자  ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 13.][70317 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */
@Service("SSPGDM03Service")
public class SSPGDM03ServiceImpl implements SSPGDM03Service {

    @SuppressWarnings("unused")
	private static final Logger LOGGER = LoggerFactory.getLogger(SSPGDM03ServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private static MsgEnum msgEnum;

    @Autowired
    private StndIntRtMapper stndIntRtMapper;                      // 기준금리요울

    @Autowired
    private CommBizService commBizService;

    String sysdate_del = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD_WITH_DELIMETER);
    String sysdate = ServerSysDate.getServerDate(ServerSysDate.YYYYMMDD);
    /**
     * <p>메소드명      : getSelectMainInfo : 상품분류관리를 조회</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 조회 한다.</p>
     * <p>메소드인수    : SSPGDM03InVO </p>
     * <p>메소드리턴값  : SSPGDM03OutVO</p>
     * <p>예외처리      : Exception</p>
     */
    @SuppressWarnings("static-access")
	@Override
    public SSPGDM03OutVO getSelectMainInfo(SSPGDM03InVO inVo) throws Exception{
    	LOGGER.info("##### SSPGDM03ServiceImpl SSPGDM03S01 Start #####");

    	SSPGDM03OutVO resultVo = new SSPGDM03OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        // 결과 리턴 List
        List<SSPGDM03DSDDSSVO> returnList = new ArrayList<SSPGDM03DSDDSSVO>();

        // 검색조건 세팅
        SSPGDM03SrchDTO srchDTO = new SSPGDM03SrchDTO();
        srchDTO.setIntRtDivCd(inVo.getIntRtDivCd());	// 금리종류코드
        srchDTO.setAplyStrtMm(inVo.getAplyStrtMm());	// 적용시작월
        srchDTO.setAplyEndMm(inVo.getAplyEndMm());		// 적용종료월

        // 기본정보 조회
        List<SSPGDM03DSSDOutDTO> outList01 = stndIntRtMapper.searchStndIntRt(srchDTO);

        for( SSPGDM03DSSDOutDTO dto : outList01 ) {
        	SSPGDM03DSDDSSVO vo = new SSPGDM03DSDDSSVO();

            vo.setIntRtDivCd(dto.getIntRtDivCd());          // 금리종류코드
            vo.setAplyStrtDt(dto.getAplyStrtDt());          // 적용시작일자
            vo.setAplyEndDt(dto.getAplyEndDt());            // 적용종료일자
            vo.setBaseInt(dto.getBaseInt());              	// 기준금리

            returnList.add(vo);
        }

        /* 출력 결과값 대입 */
        resultVo.setSSPGDM03DSDDSSVO(returnList);

        LOGGER.info("##### SSPGDM03ServiceImpl SSPGDM03S01 End #####");

        return resultVo;
    }

    /**
     * <p>메소드명      : registerMainInfo : 상품분류관리를 등록</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 등록 한다.</p>
     * <p>메소드인수    : SSPGDM03InVO </p>
     * <p>메소드리턴값  : SSPGDM03OutVO</p>
     * <p>예외처리      : Exception</p>
     */
	@SuppressWarnings("static-access")
	@Override
	public SSPGDM03OutVO insertMainInfo(SSPGDM03InVO inVo) throws Exception {

		LOGGER.info("##### SSPGDM03ServiceImpl SSPGDM03I01 Start #####");

		SSPGDM03OutVO resultVo = new SSPGDM03OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        String empNo = inVo.getUserNo();

        // 전영업일의 데이터 등록여부 체크
        SSPGDM03SrchDTO chekDTO = new SSPGDM03SrchDTO();
        String pastWkDt = commBizService.isLastWkdt(inVo.getAplyStrtDt(), "N");
        LOGGER.info(" 전영업일     >>>>>     " + pastWkDt);
        chekDTO.setIntRtDivCd(inVo.getIntRtDivCd());
        chekDTO.setAplyStrtDt(pastWkDt);

        // 금리종류별 등록건수 조회 (최초등록시 전영업일 건이 없으므로 조회하여 체크)
        SSPGDM03DSSDOutDTO cntVo = stndIntRtMapper.selectRegCnt(chekDTO);

        SSPGDM03DSSDOutDTO chkVo = stndIntRtMapper.selectPastWkDt(chekDTO);

        LOGGER.info(" 등록건수     >>>>>     " + cntVo.getRegCnt());
        if(Integer.parseInt(cntVo.getRegCnt()) > 0) {
            if(chkVo.getRegFg().equals("N")) {
                throw new Exception( pastWkDt + "일에 등록된 데이터가 없습니다.\n이전 영업일 데이터를 등록 후 다시 등록하시기 바랍니다.");
            }
        }
        // 등록된 데이터중 마지막 데이터의 종료일자를 등록하려고 하는 데이터의 시작일자 -1로 세팅 하여 수정
        SSPGDM03SrchDTO updateDTO = new SSPGDM03SrchDTO();
        updateDTO.setIntRtDivCd(inVo.getIntRtDivCd());                                                // 금리종류코드
        updateDTO.setAplyStrtDt(inVo.getAplyStrtDt());                         // 적용시작일자
        updateDTO.setAplyEndDt(DateUtil.addDay(inVo.getAplyStrtDt(), -1));     // 적용종료일자
        updateDTO.setBaseInt(inVo.getBaseInt());                                                      // 기준금리
        updateDTO.setEmpNo(empNo);

        stndIntRtMapper.updateStndIntRt(updateDTO);

        //신규 데이터 등록
        SSPGDM03SrchDTO insertDTO = new SSPGDM03SrchDTO();
        insertDTO.setIntRtDivCd(inVo.getIntRtDivCd());                                                // 금리종류코드
        insertDTO.setAplyStrtDt(inVo.getAplyStrtDt());                         // 적용시작일자
        insertDTO.setAplyEndDt("9999-12-31");                                                         // 신규금리등록건의 적용종료일자
        insertDTO.setBaseInt(inVo.getBaseInt());                                                      // 기준금리
        insertDTO.setEmpNo(empNo);

        stndIntRtMapper.insertStndIntRt(insertDTO);

        // 국고채3년물 또는 국고채5년물인 경우에만 평균금리 계산
        if(inVo.getIntRtDivCd().equals(Constants.TH_TRS_BOND) || inVo.getIntRtDivCd().equals(Constants.FI_TRS_BOND)) {
            // 평균금리 생성(현재월에 등록된 데이터를 가지고 익월 평균금리를 계산해 놓는다.
            // 등록된 현재월 데이터로 익월 평균금리를 계산해서 데이터를 생성한다.
            SSPGDM03SrchDTO srchDTO = new SSPGDM03SrchDTO();
            srchDTO.setIntRtDivCd(inVo.getIntRtDivCd());
            srchDTO.setAplyStrtMm(sysdate_del.substring(0, 7)); //현재월
            SSPGDM03DSSDOutDTO outData = stndIntRtMapper.calchAveIntRt(srchDTO);

            //평균굼리 익월데이터 존재 여부
            if(inVo.getIntRtDivCd().equals(Constants.TH_TRS_BOND)) {
                srchDTO.setIntRtDivCd(Constants.TH_TRS_BOND_AVE_MNRT);
            } else {
                srchDTO.setIntRtDivCd(Constants.FI_TRS_BOND_AVE_MNRT);
            }
            srchDTO.setAplyStrtMm(DateUtil.addMonth(sysdate_del, 1).substring(0, 7)); //익월
            List<SSPGDM03DSSDOutDTO> outList = stndIntRtMapper.searchAveIntRt(srchDTO);

            if(outList.size() == 0) {
                // 평균금리 신규생성
                SSPGDM03SrchDTO insertDTO01 = new SSPGDM03SrchDTO();
                if(inVo.getIntRtDivCd().equals(Constants.TH_TRS_BOND)) {
                    insertDTO01.setIntRtDivCd(Constants.TH_TRS_BOND_AVE_MNRT);
                } else {
                    insertDTO01.setIntRtDivCd(Constants.FI_TRS_BOND_AVE_MNRT);
                }
                insertDTO01.setAplyStrtDt(DateUtil.addMonth(sysdate_del, 1).substring(0, 8)+"01");
                insertDTO01.setAplyEndDt(DateUtil.lastDayOfMonth(sysdate.substring(0, 6)));
                insertDTO01.setBaseInt(outData.getAveMnrt());
                insertDTO01.setEmpNo(empNo);

                stndIntRtMapper.insertStndIntRt(insertDTO01);
            } else {
                // 평균금리 업데이트
                SSPGDM03SrchDTO updateDTO01 = new SSPGDM03SrchDTO();
                if(inVo.getIntRtDivCd().equals(Constants.TH_TRS_BOND)) {
                    updateDTO01.setIntRtDivCd(Constants.TH_TRS_BOND_AVE_MNRT);
                } else {
                    updateDTO01.setIntRtDivCd(Constants.FI_TRS_BOND_AVE_MNRT);
                }
                updateDTO01.setAplyStrtDt(DateUtil.addMonth(sysdate_del, 1).substring(0, 8)+"01");
                updateDTO01.setBaseInt(outData.getAveMnrt());
                updateDTO01.setEmpNo(empNo);

                stndIntRtMapper.updateStndIntRt(updateDTO01);
            }
        }

        LOGGER.info("##### SSPGDM03ServiceImpl SSPGDM03I01 End #####");

		return resultVo;
	}

	/**
     * <p>메소드명      : deleteMainInfo : 상품분류관리를 삭제</p>
     * <p>작성일자      : 2023. 3. 09.
     * <p>작성자(author): 70319
     * <p>설명          : 상품분류관리를 삭제 한다.</p>
     * <p>메소드인수    : SSPGDM03InVO </p>
     * <p>메소드리턴값  : SSPGDM03OutVO</p>
     * <p>예외처리      : Exception</p>
     */
	@SuppressWarnings("static-access")
	@Override
	public SSPGDM03OutVO deleteMainInfo(SSPGDM03InVO inVo) throws Exception {
		LOGGER.info("##### SSPGDM03ServiceImpl SSPGDM03D01 Start #####");

		SSPGDM03OutVO resultVo = new SSPGDM03OutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        SSPGDM03SrchDTO srchDTO = new SSPGDM03SrchDTO();

    	srchDTO.setIntRtDivCd(inVo.getIntRtDivCd());	 // 금리종류코드
    	srchDTO.setAplyStrtDt(inVo.getAplyStrtDt());	 // 적용시작일자

    	//선택건 삭제
    	stndIntRtMapper.deleteStndIntRt(srchDTO);

    	//기존건의 종료일자 수정
    	srchDTO.setEmpNo(inVo.getUserNo());	 	// 적용시작일자

    	stndIntRtMapper.updateStndIntRt01(srchDTO);

    	LOGGER.info("##### SSPGDM03ServiceImpl SSPGDM03I01 End #####");

		return resultVo;
	}
}