package hanalife.s.xm.pv.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.s.xm.pv.service.SXMPVM02StrgLicnService;
import hanalife.s.xm.pv.service.SXMPVM02StrgLmtService;
import hanalife.s.xm.pv.service.SXMPVM02StrgMainService;
import hanalife.s.xm.pv.service.SXMPVM02StrgMnrtService;
import hanalife.s.xm.pv.vo.SXMPVM02StrgLicnInVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgLicnVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgLmtInVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgLmtVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgMainOutVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgMainVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgMnrtInVO;
import hanalife.s.xm.pv.vo.SXMPVM02StrgMnrtVO;

/**
 * <pre>
 * 프로젝트명	: 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명	: SXMPVM02StrgMainServiceImpl.java Class
 * 클래스설명	: 전략-메인 (SXMPVM02StrgMain) Service Implements
 * 작성일자	: 2023.05.09.
 * 작성자명	: 70280 / 성관용 / 가계대출 시스템 구축
 * Copyrightⓒ2022 Hana Life Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [ 수정일자 ][ 수정자 ][ 변경사유-수정내용 ]
 * -----------------------------------------------------------------------------
 * [2023. 05. 03.][70398][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 :
 * </pre>
 */

/*
○ 전략메인 사양서


@PGM_START

    @SUBCALL (INIT_RTN);

    @SUBCALL (INPUT_CHECK_RTN);

    @SUBCALL (ST_RULE_SUB_HIST_RTN);

    IF  변_1.입.거래구분코드 = "01"
    THEN
            DO:
                @SUBCALL (채널-상담정보 테이블_READ_RTN)
            END:
    ENDIF;

    IF  변_1.입.거래구분코드 = "02"  OR  "03" OR "04" OR "05" OR "06"
    THEN
            DO:
                @SUBCALL (ST_APPL_LDGR_READ_RTN)
            END:
    ENDIF;

    IF  변_1.입.거래구분코드  =  01, 02, 04, 05
    THEN
            DO:
                @SUBCALL (대외기관_호출_RTN);

                @SUBCALL (자격판정_RTN);

                IF  변_2.출.대표판정결과코드  =  "Y"                                                                                *> 자격판정 승인일 경우
삭제                    &&  변_1.입.거래구분코드      =  02,  04
                &&  변_1.입.거래구분코드      =  02
                THEN
                    DO:
                        @SUBCALL (금리산출_RTN);

                        IF  변_1.입.거래구분코드  =  02
                        THEN
                                @SUBCALL (한도산출_RTN);
                        ENDIF;
                    END:
                ENDIF;
            END:
    ELSE
            DO:
                IF  변_1.입.거래구분코드  = 03
                THEN
                        DO:
                            @SUBCALL (한도산출_RTN);
                        END:
                ENDIF;

                IF  변_1.입.거래구분코드  = 06
                THEN
                        DO:
                            @SUBCALL (금리산출_RTN);
                        END:
                ENDIF;
            END:
    ENDIF;


    @SUBCALL (DB_AND_OUPUT_RTN)


@PGM_END



@SUBPROC_STA (INIT_RTN)

    ※ 변_1.출.정의컬럼 INIT

        변_1.출.*.*          =  '';                                                                    *> 변수 I/O정의 참조


    ※ WORK 변수  INIT

        WK_*.*               =  '';                                                                    *> 사양서내의 "WK_" 변수는 INIT를 수행한다.


@SUBPROC_END (INIT_RTN)



@SUBPROC_STA (INPUT_CHECK_RTN)

        IF  변_1.입.거래구분코드  =  01, 02, 03, 04, 05, 06
        THEN;
        ELSE            DO;                                                                            // Error처리 --------------------
                        변_1.출.Return_Code  =  "9";
                        변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                        Error처리 ---------
                    ENDDO;
        ENDIF;

        IF  변_1.입.거래일   =  system.today
        THEN;
        ELSE            DO;                                                                            // Error처리 --------------------
                        변_1.출.Return_Code  =  "9";
                        변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                        Error처리 ---------
                    ENDDO;
        ENDIF;

    ※ 변_1.입.거래일 중 휴일여부를 check ------------------------------
        @HUILCHK (변_1.입.거래일)                                            *> 휴일시 Error 처리  -> 영업일 및 영업시간 확인 하여 수행 여부 판단 필요

        IF  변_1.입.상담번호      =  NOT NULL
        OR  변_1.입.신청번호      =  NOT NULL
        OR  (변_1.입.대출번호      =  NOT NULL  AND 변_1.입.대출번호일련번호 = NOT NULL)
        THEN;
        ELSE            DO;                                                                            // Error처리 --------------------
                        변_1.출.Return_Code  =  "9";
                        변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                        Error처리 ---------
                    ENDDO;
        ENDIF;

        IF  변_1.입.전략-자격요청여부 = "Y"
        OR  변_1.입.전략-한도요청여부 = "Y"
        OR  변_1.입.전략-금리요청여부 = "Y"
        THEN;
        ELSE            DO;                                                                            // Error처리 --------------------
                        변_1.출.Return_Code  =  "9";
                        변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                        Error처리 ---------
                    ENDDO;
        ENDIF;


@SUBPROC_END (INPUT_CHECK_RTN)



@SUBPROC_STA (ST_RULE_SUB_HIST_RTN)

        ※ RULE 관리 PARAMETER 를 읽는다
        -- ST_PROD_IRULE JOIN ST_RULE_SUB_HIST"
            << SUBSTR(PARAMATER_ID,1,3) = "CSS" && (SUBSTR(PARAMATER_ID,4,1) = "B")  && 레코드상태 = "00010"  >>

        - Read 필드명                            - TA_* 로 표기
            관련 PARAM 정보들 모두


@SUBPROC_END (ST_RULE_SUB_HIST_RTN)



@SUBPROC_STA (채널-상담정보 테이블_READ_RTN)


        ※ 채널-상담정보-테이블    JOIN   ST_CSS_JUDG                                                                                           // 추가 필요정보는 채널팀과 협의 후 채널원장에 보관하구 있어야 한다
            - TC_* 로 표기
                                                                                                // 채널 - 대출상담원장
        SELECT            A    자금용도구분코드
                    "대표 상품코드"  AS  상품코드
                    "대표 금리코드"  AS  금리코드
                    A    대출상담번호
                    A    선순위설정금액
                    A    임대차보증금액
                    A    동일세대주택보유수
                    A    해당층수
                    A    평형
                    A    시도명
                    A    시군구명
                    A    읍면동명
                    A    시세조회기준일
                    A    아파트코드
                    A    평형순번
                    A    매매일반거래가금액
                    A    매매하한가금액
                    B.신용등급유효기일 (NULL 일 경우 "99999999"
        FROM            채널-대출상담정보                                    A
                    ST_CSS_JUDG                                    B
        WHERE            A.대출상담번호                                    =        변_1.입.대출상담번호
                    B.대출상담번호(+)                                    =        변_1.입.대출상담번호
                    B.CSS일련번호(+)                                    =        MAX

        WK_KSIC_FLAG = "Y"

        IF  ROW-COUNT  >  0
        THEN
                    IF  변_1.입.거래일  =  TC_신용등급유효기일
                    THEN
                            WK_KSIC_FLAG = "N"
                    ENDIF;
        ENDIF;

        IF  WK_KSIC_FLAG = "Y"                                                                                        // 세부 I/O는 대외계와 협의할것
        THEN
                @UCALL (신정원_INTERFACE,    신정원_PARAM1 = 변_1.입.차주(신청인)주민번호);
        ENDIF;

@SUBPROC_END (채널-상담정보 테이블_READ_RTN)



@SUBPROC_STA (ST_APPL_LDGR_READ_RTN);


        ※ ST_APPL_LDGR    JOIN   담보원장  JOIN  담보평가정보                                                                                        // 추가 필요정보는 신청, 담보원장등에 저장 하여 그 정보를 이용 하여야 한다
            - TE_* 로 표기

        SELECT
                    A    상품코드
                    A    금리코드
                    A    상환방식구분코드
                    A    자금용도구분코드
                    A    대출신청금액
                    A    대출상담번호
                    A    연소득금액
                    A    소득합산구분코드
                    A    배우자소득금액
                    A    신용보증기금출연료구분코드
                    A    비거치분할상환 여부
                    A    MCI가입 여부
                    A    타사대환 여부
                    A    심사역조정금리
                    B    해당층수
                    B    평형
                    B    시도명
                    B    시군구명
                    B    읍면동명
                    C    시세조회기준일
                    C    아파트코드
                    C    평형순번
                    C    매매일반거래가금액
                    C    매매하한가금액
                    C    적용감정가액
                    C    선순위설정금액
                    C    선순위상환금액
                    C    임대차금액
                    C    소액임대차금액
        FROM                ST_APPL_LDGR    A,
                    담보원장         B
                    담보평가정보     C
        WHERE             A.대출신청번호  = 변_1.입.대출신청번호
        AND            B.대출상담번호  = A.대출상담번호
        AND            C.대출상담번호  = A.대출상담번호
        AND            C.평가순번      = B.평가일련번호

        IF  ROW-COUNT  >  0
        THEN:
        ELSE            DO;                                                                            // Error처리 --------------------
                        변_1.출.Return_Code  =  "9";
                        변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                        Error처리 ---------
                    ENDDO;
        ENDIF;


@SUBPROC_END (ST_APPL_LDGR_READ_RTN);



@SUBPROC_STA (대외기관_호출_RTN)


        #####################################################################################################################/
        ##            [KCB 신용조회]
        ##            1. 0400/437 (신용평점, 연체정보)
        ##
        ##            [신정원 신용조회]
        ##            1. 0200/900 (신용정보)                                                                2. [DSR 정보] 0200/235,   0200/236
        ##                (신정원A 전문으로 표현)                                                                                    (신정원B 전문으로 표현)
        #####################################################################################################################/

        IF  TE_신용등급유효기일  =  변_1.입.거래일
        THEN
                DO:
                    WK_차주 신정원-A 거래관리고유번호                                                        =  TE_차주_신정원_A_거래관리고유번호
                    WK_차주 신정원-B 거래관리고유번호                                                        =  TE_차주_신정원_B_거래관리고유번호
                    WK_차주 KCB거래관리고유번호                                                        =  TE_차주_KCB거래관리고유번호
                END:
        ELSE
                DO:
                    @UCALL (신정원 A 전문_INTERFACE,    신정원_PARAM1 = 변.1.입.차주(신청인)주민번호);
                    WK_차주 신정원-A 거래관리고유번호                                                        =  [@UCALL 호출 OUTPUT 값] 신정원거래관리고유번호

                    IF  변_1.입.거래구분코드  =  "02"
                    THEN
                            DO:
                                @UCALL (신정원 B 전문_INTERFACE,    신정원_PARAM1 = 변.1.입.차주(신청인)주민번호);
                                WK_차주 신정원-B 거래관리고유번호                                                        =  [@UCALL 호출 OUTPUT 값] 신정원거래관리고유번호
                            END:
                    ENDIF;

                    IF  변_1.입.거래구분코드  <>  "01"
                    THEN
                            DO:
                                @UCALL (KCB_INTERFACE,       KCB_PARAM1    = 변.1.입.차주(신청인)주민번호);
                                WK_차주 KCB거래관리고유번호                                                    =  [@UCALL 호출 OUTPUT 값] KCB거래관리고유번호
                            END:
                    ENDIF;
                END:
        ENDIF;

        IF  변_1.입.배우자주민번호  IS NOT NULL                                                                                                                    *> 배우자정보 소득합산 OR 담보제공인-배우자
        THEN
                DO:
                    IF  TE_신용등급유효기일  =  변_1.입.거래일
                    THEN
                            DO:
                                WK_배우자 신정원-A 거래관리고유번호                                                                =  TE_배우자_신정원_A_거래관리고유번호
                                WK_배우자 신정원-B 거래관리고유번호                                                                =  TE_배우자_신정원_B_거래관리고유번호
                                WK_배우자 KCB거래관리고유번호                                                                =  TE_배우자_KCB거래관리고유번호
                            END:
                    ELSE
                            DO:
                                @UCALL (신정원 A 전문_INTERFACE,    신정원_PARAM1 = 변.1.입.배우자주민번호);
                                WK_배우자 신정원-A 거래관리고유번호                                                                =  [@UCALL 호출 OUTPUT 값] 신정원거래관리고유번호

                                IF  변_1.입.거래구분코드  =  "02"
                                THEN
                                        DO:
                                            @UCALL (신정원 B 전문_INTERFACE,    신정원_PARAM1 = 변.1.입.배우자주민번호);
                                            WK_배우자 신정원-B 거래관리고유번호                                                        =  [@UCALL 호출 OUTPUT 값] 신정원거래관리고유번호
                                        END:
                                ENDIF;

                                IF  변_1.입.거래구분코드  <>  "01"
                                THEN
                                        DO:
                                            @UCALL (KCB_INTERFACE,       KCB_PARAM1    = 변.1.입.배우자주민번호);
                                            WK_배우자 KCB거래관리고유번호                                                    =  [@UCALL 호출 OUTPUT 값] KCB거래관리고유번호
                                        END:
                                ENDIF;
                            END:
                    ENDIF;
                END:
        ENDIF;


@SUBPROC_END (대외기관_호출_RTN)



@SUBPROC_STA (자격판정_RTN);


        SELECT  변_1.입.거래구분코드
            WHEN  "01"                        변_2.입.거래구분코드                                                =        01;
            WHEN  "02"                        변_2.입.거래구분코드                                                =        02;
            WHEN  "03"                        변_2.입.거래구분코드                                                =        03;
            WHEN  "04"                        변_2.입.거래구분코드                                                =        03;
            WHEN  "05"                        변_2.입.거래구분코드                                                =        03;
            WHEN  "06"                        변_2.입.거래구분코드                                                =        03;
        END-SELECT;

        변_2.입.거래일                                                            =        변_1.입.거래일;
        변_2.입.상담번호                                                            =        변_1.입.상담번호;
        변_2.입.신청번호                                                            =        변_1.입.신청번호;
        변_2.입.차주(신청인)주민번호                                                            =        변_1.입.차주(신청인)주민번호

        변_2.입.차주_신정원거래관리고유번호                                                            =        WK_차주 신정원-A 거래관리고유번호
        변_2.입.차주_KCB거래관리고유번호                                                            =        WK_차주 KCB거래관리고유번호

        IF 변_1.입.배우자주민번호 IS NOT NULL
        THEN
                Do;
                    변_2.입.배우자주민번호                                                            =        변_1.입.배우자주민번호
                    변_2.입.배우자_신정원거래관리고유번호                                                            =        WK_배우자 신정원-A 거래관리고유번호
                    변_2.입.배우자_KCB거래관리고유번호                                                            =        WK_배우자 KCB거래관리고유번호
                END:
        ENDIF;

        변_2.입.RULE-SUB정보                                                            =        TA_*                                                                            *> CSS RULE PARAMETER VO 정보를 공유 한다

        @UCALL (자격판정, "변_2" VO);

        IF  변_2.출.Return_Code   =   '0'
        THEN:
        ELSE
                DO;                                                                            // Error처리 --------------------
                    변_1.출.Return_Code  =  "9";
                    변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                    Error처리 ---------
                ENDDO;
        ENDIF;


@SUBPROC_END (자격판정_RTN)



@SUBPROC_STA (한도산출_RTN)


        SELECT  변_1.입.거래구분코드
            WHEN  "01"                    변_3.입.거래구분코드                                            =        01;
            WHEN  "02"                    변_3.입.거래구분코드                                            =        02;
            WHEN  "03"                    변_3.입.거래구분코드                                            =        03;
        END-SELECT;

        변_3.입.거래일                                                        =        변_1.입.거래일;
        변_3.입.대출상담번호                                                        =        변_1.입.대출상담번호

        IF  변_1.입.거래구분코드  =  01
        THEN
                DO:
                    변_3.입.KB 시도명                                                        =        TC_KB 시도명
                    변_3.입.KB 시군구명                                                        =        TC_KB 시군구명
                    변_3.입.KB 적용감정가금액                                                        =        TC_KB 적용감정가금액
                    변_3.입.과밀억제권지역여부                                                        =        TC_과밀억제권지역여부
                    변_3.입.MCI 가입여부                                                        =        TC_MCI 가입여부

                    변_3.입.자금용도관리코드                                                        =        TC_자금용도관리코드
                    변_3.입.주택소유구분코드                                                        =        TC_주택소유구분코드

                    변_3.입.선순위설정금액                                                        =        TC_선순위설정금액
                    변_3.입.선순위상환금액                                                        =        TC_선순위설정금액                                                        // 전액대환만 허용한다는 업무요건

                    변_3.입.임대차금액                                                        =        TC_임대차금액
                END:
        ELSE
                DO:
                    IF  변_1.입.거래구분코드  "02"
                    THEN
                        DO:
                            변_3.입.차주_신정원-A거래관리고유번호                                                                =        WK_차주 신정원-A 거래관리고유번호
                            변_3.입.차주_신정원-B거래관리고유번호                                                                =        WK_차주 신정원-B 거래관리고유번호

                            IF 변_1.입.배우자주민번호 IS NOT NULL
                            THEN
                                    Do;
                                        변_3.입.배우자주민번호                                                    =        변_1.입.배우자주민번호

                                        변_3.입.배우자_신정원-A거래관리고유번호                                                                =        WK_배우자 신정원-A 거래관리고유번호
                                        변_3.입.배우자_신정원-B거래관리고유번호                                                                =        WK_배우자 신정원-B 거래관리고유번호
                                    END:
                            ENDIF;
                        END:
                    ENDIF;

                    변_3.입.KB 시도명                                                        =        TD_KB 시도명
                    변_3.입.KB 시군구명                                                        =        TD_KB 시군구명
                    변_3.입.KB 적용감정가금액                                                        =        TD_KB 적용감정가금액
                    변_3.입.과밀억제권지역여부                                                        =        TD_과밀억제권지역여부
                    변_3.입.MCI 가입여부                                                        =        TD_MCI 가입여부

                    변_3.입.MCI 가입여부                                                        =        TD_MCI 가입여부
                    변_3.입.MCI 가입금액                                                        =        TD_MCI 가입금액
                    변_3.입.서민실수요자여부                                                        =        TD_서민실수요자여부
                    변_3.입.생애최초여부                                                        =        TD_입.생애최초여부

                    변_3.입.자금용도관리코드                                                        =        TD_자금용도관리코드
                    변_3.입.주택소유구분코드                                                        =        TD_주택소유구분코드

                    IF  TD_서민실소유자여부  =  "Y"
                    THEN
                            변_3.입.주택소유구분코드                                                        =        "00040"
                    ELSE
                            IF  TD_생애최초여부  =  "Y"
                            THEN
                                    변_3.입.주택소유구분코드                                                        =        "00050"
                            ENDIF;
                    ENDIF;

                    변_3.입.대출신청금액                                                        =        TD_대출신청금액

                    변_3.입.선순위설정금액                                                        =        TD_선순위설정금액
                    변_3.입.선순위상환금액                                                        =        TD_선순위설정금액                                                        // 전액대환만 허용한다는 업무요건

                    변_3.입.임대차금액                                                        =        TD_임대차금액

                    변_3.입.(본인)연소득금액                                                        =        TD_(본인)연소득금액
                    변_3.입.(배우자)연소득금액                                                        =        TD_(배우자)연소득금액
                END:
        ENDIF;

        변_3.입.산출금리                                                        =        변_4.출.산출금리;
        변_3.입.RULE-SUB 정보                                                        =        TA_*                                                                            *> CSS RULE PARAMETER VO 정보를 공유 한다

        @UCALL (한도산출, "변_3" 전문);

        IF  변_3.출.Return_Code   =   '0'
        THEN:
        ELSE
                DO;                                                                            // Error처리 --------------------
                    변_1.출.Return_Code  =  "9";
                    변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                    Error처리 ---------
                ENDDO;
        ENDIF;


@SUBPROC_END (한도산출_RTN)



@SUBPROC_STA (금리산출_RTN)


        SELECT  변_1.입.거래구분코드
            WHEN  "01"                    변_4.입.거래구분코드                                            =        01;
            WHEN  "02"                    변_4.입.거래구분코드                                            =        02;
            WHEN  "04"                    변_4.입.거래구분코드                                            =        02;
            WHEN  "05"                    변_4.입.거래구분코드                                            =        02;
            WHEN  "06"                    변_4.입.거래구분코드                                            =        03;
        END-SELECT;

        변_4.입.거래일                                                        =        변_1.입.거래일;
        변_4.입.대출상담번호                                                        =        변_1.입.대출상담번호
        변_4.입.RULE-SUB정보                                                        =        TA_*                                                            *> CSS RULE PARAMETER VO 정보를 공유 한다

        IF  변_4.입.거래구분코드  =  01, 02
        THEN
            DO:
                IF  변_4.입.거래구분코드 = 02
                THEN
                    DO:
                        변_4.입.금리코드                                                        =        TE_금리코드

                        변_4.입.내부신용등급                                                        =        TE_내부신용등급

                        변_4.입.신용보증기금출연료구분                                                        =        TE_신용보증기금출연료구분

                        변_4.입.신용평점                                                        =        TE_입.신용평점

                        변_4.입.비거치분할상환 여부                                                        =        TE_비거치분할상환 여부
                        변_4.입.MCI가입여부                                                        =        TE_입.MCI가입여부
                        변_4.입.타사대환여부                                                        =        TE_입.타사대환여부

                        변_4.입.심사역조정금리                                                        =        TE_입.심사역조정금리
                    END:
                ELSE
                        변_4.입.금리코드                                                        =        TC_금리코드
                ENDIF;
            END:
        ELSE
            IF  변_4.입.거래구분코드 = 03
            THEN
                DO:
                        변_4.입.현재적용금리                                                        =        "TODAY  실행 후 금리원장의 대출적용금리"  (주의,주의)
                END:
            ENDIF;
        ENDIF;

        @UCALL (금리산출, "변_4" 전문);

        IF  변_4.출.Return_Code   =   '0'
        THEN:
        ELSE
                DO;                                                                            // Error처리 --------------------
                    변_1.출.Return_Code  =  "9";
                    변_1.출.Error내용  =  [Error 내용 조립 ~~~~~~~~~~]

                    Error처리 ---------
                ENDDO;
        ENDIF;



@SUBPROC_END (금리산출_RTN)



@SUBPROC_STA (DB_AND_OUPUT_RTN)

        ==> 다음은 예시이다
        ==> [ 구현하는 로직 FLOW 에 따라 가변적으로 정의하여 사용 할것 ]
        ==> 다음은 예시이다

        변_1.출Return_Code   =   '0';

        IF  변_1.입.전략-자격요청여부  =  "Y"
        THEN
                DO:
                        변_1,출.전략-자격'VO                                    =        변_2.출.전략-자격 VO

                        ※ ST_CSS_RESULT 테이블을 생성한다
                        - 변_2.출.전략-자격 VO 참고
                END:
        ENDIF;

        IF  변_1.입.전략-한도요청여부  =  "Y"
        THEN
                DO:
                        변_1,출.전략-한도'VO                                    =        변_3.출.전략-한도 VO

                        ※ ST_EVUL_AMT 테이블을 생성한다
                        - 변_2.출.전략-자격 VO 참고
                END:
        ENDIF;

        IF  변_1.입.전략-금리요청여부  =  "Y"
        THEN
                DO:
                        변_1,출.전략-자격'VO                                    =        변_4.출.전략-금리 VO

                        ※ ST_CSS_RATE 테이블을 생성한다
                        - 변_2.출.전략-자격 VO 참고
                END:
        ENDIF;

        ※ ST_CSS_JUDG 테이블을 생성한다
        - 변_2, 변_3, 변_4 VO 참고


@SUBPROC_END (DB_AND_OUPUT_RTN)

*/

@Service("SXMPVM02StrgMainService")
public class SXMPVM02StrgMainServiceImpl implements SXMPVM02StrgMainService
{
	private static final Logger LOGGER = LoggerFactory.getLogger(SXMPVM02StrgMainServiceImpl.class);

    @Autowired
    private SXMPVM02StrgLicnService strgLicnService;                        // 전략-자격 서비스

    @Autowired
    private SXMPVM02StrgLmtService strgLmtService;                          // 전략-한도 서비스

    @Autowired
    private SXMPVM02StrgMnrtService strgMnrtService;                        // 전략-금리 서비스

    @Override
    public SXMPVM02StrgMainVO executeStrgMain(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl executeStrgMain Start");

		// 변수 초기화
        this.initRtn(strgMainVo);

        // 입력 유효성 체크
        this.inputCheckRtn(strgMainVo);

        // 상담원장/신청원장 조회
        this.loadLdgrRtn(strgMainVo);

        // 룰 조회
        this.loadRuleRtn(strgMainVo);

        // 판정 수행
        this.executeJudg(strgMainVo);

        // 결과 저장 & 결과 응답
        this.makeStrgRslt(strgMainVo);

        return strgMainVo;
    }


    /**
     * 변수 초기화 Rtn
     */
    private boolean initRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl initRtn Start");

        SXMPVM02StrgMainOutVO strgMainOutVo = new SXMPVM02StrgMainOutVO();
        strgMainOutVo.setRsltCd(MsgEnum.CSS_SUCCESS.getErrorCd());              // 결과코드
        strgMainOutVo.setRsltCntn(MsgEnum.CSS_SUCCESS.getDescription());        // 결과내용

        strgMainOutVo.setStrgLicnOutVo(null);                                   // 전략-자격 Out VO
        strgMainOutVo.setStrgLmtOutVo(null);                                    // 전략-한도 Out VO
        strgMainOutVo.setStrgMnrtOutVo(null);                                   // 전략-금리 Out VO

        strgMainVo.setStrgMainOutVo(strgMainOutVo);                             // 전략-메인 Out VO

        return true;
    }


    /**
     * 입력 유효성 체크
     */
    private boolean inputCheckRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl inputCheckRtn Start");

        // 입력 VO
        if (strgMainVo.getStrgMainInVo() == null)
        {
            strgMainVo.getStrgMainOutVo().setRsltCd(MsgEnum.CSS_ERROR.getErrorCd());                                       // 결과코드
            strgMainVo.getStrgMainOutVo().setRsltCntn("입력정보 오류입니다.");                                             // 결과내용
            return false;
        }

        // 전략 거래구분코드
        if (Constants.S12054_LOAN_CNSL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == false             // 대출상담단계
            ||  Constants.S12054_LOAN_APPL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == false         // 대출심사단계
            ||  Constants.S12054_MRTG_RE_EVAL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == false      // 담보재평가
            ||  Constants.S12054_LOAN_EXEC.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == false              // 대출실행
            ||  Constants.S12054_MNRT_DOWN_RQST_RIGT.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == false    // 금리인하요구권
            ||  Constants.S12054_DISC_MNRT_RE_APLY.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == false)     // 할인금리재적용
        {
            strgMainVo.getStrgMainOutVo().setRsltCd(MsgEnum.CSS_ERROR.getErrorCd());                                       // 결과코드
            strgMainVo.getStrgMainOutVo().setRsltCntn("전략-메인 거래구분코드 입력 오류입니다.");                          // 결과내용
            return false;
        }

        // 거래일자
        if (DateUtil.getCurrentDateString("yyyyMMdd").equals(strgMainVo.getStrgMainInVo().getStrgMainTrDt()) == false)
        {
            strgMainVo.getStrgMainOutVo().setRsltCd(MsgEnum.CSS_ERROR.getErrorCd());                                       // 결과코드
            strgMainVo.getStrgMainOutVo().setRsltCntn("전략 거래일자 입력 오류입니다.");                                   // 결과내용
            return false;
        }

        // 휴일
        // TODO. 영업일 체크 추가 필요
        // ※ 변_1.입.거래일 중 휴일여부를 check ------------------------------
        // @HUILCHK (변_1.입.거래일)            *> 휴일시 Error 처리  -> 영업일 및 영업시간 확인 하여 수행 여부 판단 필요

        // 키 정보(상담번호, 신청번호, 대출번호/대출일련번호)
        if (StringUtil.isNullT(strgMainVo.getStrgMainInVo().getLoanCnslNo()) == true                                        // 대출상담번호
            &&  StringUtil.isNullT(strgMainVo.getStrgMainInVo().getLoanApplNo()) == true                                    // 대출신청번호
            &&  (StringUtil.isNullT(strgMainVo.getStrgMainInVo().getLoanNo()) == true                                       // 대출번호
            ||  StringUtil.isNullT(strgMainVo.getStrgMainInVo().getLoanSeq()) == true))                                     // 대출일련번호
        {
            strgMainVo.getStrgMainOutVo().setRsltCd(MsgEnum.CSS_ERROR.getErrorCd());                                        // 결과코드
            strgMainVo.getStrgMainOutVo().setRsltCntn("키정보(상담번호,신청번호,대출번호/대출일련번호) 입력 오류입니다.");  // 결과내용
            return false;
        }

        // 차주 주민번호 (배우자 주민번호는 다시 체크 함)
        if (StringUtil.isNullT(strgMainVo.getStrgMainInVo().getBrwrResiNo()) == true)                                       // 차주 주민번호
        {
            strgMainVo.getStrgMainOutVo().setRsltCd(MsgEnum.CSS_ERROR.getErrorCd());                                        // 결과코드
            strgMainVo.getStrgMainOutVo().setRsltCntn("차주 주민번호 입력 오류입니다.");                                    // 결과내용
            return false;
        }

        // 배우자 주민번호

        // 전략 요청 여부
        if ("Y".equals(strgMainVo.getStrgMainInVo().getStrgLicnRqstYn()) == false
            &&  "Y".equals(strgMainVo.getStrgMainInVo().getStrgLmtRqstYn()) == false
            &&  "Y".equals(strgMainVo.getStrgMainInVo().getStrgMnrtRqstYn()) == false)
        {
            strgMainVo.getStrgMainOutVo().setRsltCd(MsgEnum.CSS_ERROR.getErrorCd());                                        // 결과코드
            strgMainVo.getStrgMainOutVo().setRsltCntn("전략 요청여부 입력 오류입니다.");                                    // 결과내용
            return false;
        }

        return true;
    }


    /**
     * 상담원장/신청원장 조회
     */
    private boolean loadLdgrRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadLdgrRtn Start");

        // 전략 거래구분코드
        if (Constants.S12054_LOAN_CNSL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true)                      // 대출상담단계
        {
            // 채널 상담원장 조회
            this.loadChannelLoanCnslRtn(strgMainVo);
        }
        else if (Constants.S12054_LOAN_APPL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true                  // 대출심사단계
                 ||  Constants.S12054_MRTG_RE_EVAL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true           // 담보재평가
                 ||  Constants.S12054_LOAN_EXEC.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true                   // 대출실행
                 ||  Constants.S12054_MNRT_DOWN_RQST_RIGT.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true         // 금리인하요구권
                 ||  Constants.S12054_DISC_MNRT_RE_APLY.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true)          // 할인금리재적용
        {
            // 기간계 신청원장 조회
            this.loadBackendLoanApplRtn(strgMainVo);
        }

        return true;
    }


    /**
     * 채널-상담원장 조회
     */
    private boolean loadChannelLoanCnslRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadChannelLoanCnslRt Start");

        return true;
    }


    /**
     * 기간계-신청원장 조회
     */
    private boolean loadBackendLoanApplRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadBackendLoanApplRtn Start");

        return true;
    }


    /**
     * 룰 조회
     */
    private boolean loadRuleRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadRuleRtn Start");

        // 상품룰
        loadProdIruleRtn(strgMainVo);

        // 룰메인
        loadRuleMainRtn(strgMainVo);

        // 룰파라미터
        loadRuleSubRtn(strgMainVo);

        return true;
    }


    /**
     * 상품룰 조회
     */
    private boolean loadProdIruleRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadProdIruleRtn Start");

        return true;
    }


    /**
     * 룰메인 조회
     */
    private boolean loadRuleMainRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadRuleMainRtn Start");

        return true;
    }


    /**
     * 룰파라미터 조회
     */
    private boolean loadRuleSubRtn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl loadRuleSubRtn Start");

        return true;
    }


    /**
     * 판정 수행
     */
    private boolean executeJudg(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl execJudg Start");

        if (Constants.S12054_LOAN_CNSL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true              // 대출상담단계
            ||  Constants.S12054_LOAN_APPL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true          // 대출심사단계
            ||  Constants.S12054_LOAN_EXEC.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true               // 대출실행
            ||  Constants.S12054_MNRT_DOWN_RQST_RIGT.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true)    // 금리인하요구권
        {
            // 대외기관 호출 (신정원, KCB)
            this.callExtrCrdtOrg(strgMainVo);

            // 전략-자격 호출
            this.executeStrgLicn(strgMainVo);

            /*
            IF  변_2.출.대표판정결과코드  =  "Y"                                                                                *> 자격판정 승인일 경우
            &&  변_1.입.거래구분코드      =  02
            THEN
                DO:
                    @SUBCALL (금리산출_RTN);

                    IF  변_1.입.거래구분코드  =  02
                    THEN
                            @SUBCALL (한도산출_RTN);
                    ENDIF;
                END:
            ENDIF;
            */
        }
        else if (Constants.S12054_MRTG_RE_EVAL_STAG.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true)     // 담보재평가
        {
            // 전략-한도 호출
            this.executeStrgLmt(strgMainVo);
        }
        else if (Constants.S12054_DISC_MNRT_RE_APLY.equals(strgMainVo.getStrgMainInVo().getStrgMainTrDivCd()) == true)     // 할인금리재적용
        {
            // 전략-금리 호출
            this.executeStrgMnrt(strgMainVo);
        }

        return true;
    }


    /**
     * 대외기관 호출 (신정원, KCB)
     */
    private boolean callExtrCrdtOrg(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl callExtrCrdtOrg Start");

		return true;
    }


    /**
     * 전략-자격 수행
     */
    private boolean executeStrgLicn(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl executeStrgLicn Start");

		SXMPVM02StrgLicnInVO strgLicnInVo = new SXMPVM02StrgLicnInVO();

		SXMPVM02StrgLicnVO strgLicnVo = new SXMPVM02StrgLicnVO();

        strgLicnService.executeStrgLicn(strgLicnVo);                        // 전략-자격 서비스

        return true;
    }


    /**
     * 전략-한도 수행
     */
    private boolean executeStrgLmt(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl executeStrgLmt Start");

		SXMPVM02StrgLmtInVO strgLmtInVo = new SXMPVM02StrgLmtInVO();

		SXMPVM02StrgLmtVO strgLmtVo = new SXMPVM02StrgLmtVO();

        strgLmtService.executeStrgLmt(strgLmtVo);                             // 전략-한도 서비스

        return true;
    }


    /**
     * 전략-금리 수행
     */
    private boolean executeStrgMnrt(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl executeStrgMnrt Start");

		SXMPVM02StrgMnrtInVO strgMnrtInVo = new SXMPVM02StrgMnrtInVO();

		SXMPVM02StrgMnrtVO strgMnrtVo = new SXMPVM02StrgMnrtVO();

        strgMnrtService.executeStrgMnrt(strgMnrtVo);                          // 전략-금리 서비스

        return true;
    }


    /**
     * 결과 저장 & 응답
     */
    private boolean makeStrgRslt(SXMPVM02StrgMainVO strgMainVo) throws Exception
    {
		LOGGER.debug("SXMPVM02StrgMainServiceImpl makeStrgRslt Start");

        return true;
    }
}