package hanalife.s.xm.pv.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.s.xm.pv.mapper.FamMembRegMapper;
import hanalife.s.xm.pv.mapper.dto.FamMembRegDSCNTDTO;
import hanalife.s.xm.pv.mapper.dto.FamMembRegDSSDCDTO;
import hanalife.s.xm.pv.mapper.dto.FamMembRegDSSDDDTO;
import hanalife.s.xm.pv.mapper.dto.FamMembRegDSSDDTO;
import hanalife.s.xm.pv.mapper.dto.FamMembRegDSSDHDTO;
import hanalife.s.xm.pv.mapper.dto.FamMembRegDSSMDTO;
import hanalife.s.xm.pv.service.SXMPVM03Service;
import hanalife.s.xm.pv.vo.SXMPVM03DSCNTVO;
import hanalife.s.xm.pv.vo.SXMPVM03DSSDVO;
import hanalife.s.xm.pv.vo.SXMPVM03S01InVO;
import hanalife.s.xm.pv.vo.SXMPVM03S01OutVO;
import hanalife.s.xm.pv.vo.SXMPVM03U01InVO;
import hanalife.s.xm.pv.vo.SXMPVM03U01OutVO;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : SXMPVM03ServiceImpl.java Class
 * 클래스설명   : 세대원등록 (SXMPVM03) Service Implements
 * 작성일자     : 2023. 5. 9.
 * 작성자명     : 70323 / HeoHyemi / 가계대출 시스템 구축
 * Copyrightⓒ2023 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 9.][70323 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : getSXMPVM03S01 : 세대원등록조회
 * 			 	registerSXMPVM03U01 : 세대원등록
 * 			 	modifySXMPVM03U01 : 세대원등록수정
 * 			 	deleteSXMPVM03U01 : 세대원등록삭제

 * </pre>
 */
@Service("SXMPVM03Service")
public class SXMPVM03ServiceImpl implements SXMPVM03Service {

	private static final Logger LOGGER = LoggerFactory.getLogger(SXMPVM03ServiceImpl.class);

    private MsgEnum msgEnum;

	@Autowired
	private FamMembRegMapper famMembRegMapper;

	/**
	 * <p>메소드명      : getSXMPVM03S01 : 세대원등록조회</p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 세대원등록 조회한다.</p>
	 * <p>메소드인수    : SXMPVM03S01InVo </p>
	 * <p>메소드리턴값  : SXMPVM03S01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SXMPVM03S01OutVO getSXMPVM03S01(SXMPVM03S01InVO inVo) throws Exception {

		SXMPVM03S01OutVO resultVo = new SXMPVM03S01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		FamMembRegDSSMDTO inDto = new FamMembRegDSSMDTO();

		inDto.setLoanApplNo(inVo.getSXMPVM03DSSMVO().getLoanApplNo()); 		/** 대출신청번호 */
		inDto.setCustNm(inVo.getSXMPVM03DSSMVO().getCustNm()); 				/** 고객명 */
		inDto.setHomsStepCd(inVo.getSXMPVM03DSSMVO().getHomsStepCd()); 		/** HOMS진행상태 */

		// 세대원등록 기본 목록 조회
		List<FamMembRegDSCNTDTO> cntDTO = famMembRegMapper.selectFamMembCnt(inDto);		/** 세대원수*/
		List<FamMembRegDSSDDTO> resultDTO = famMembRegMapper.searchFamMembList(inDto);	/** 세대원목록*/

		List<SXMPVM03DSCNTVO> cntList = new ArrayList<SXMPVM03DSCNTVO>();
		List<SXMPVM03DSSDVO> resultList = new ArrayList<SXMPVM03DSSDVO>();

		for (FamMembRegDSCNTDTO sourceIO : cntDTO) {
			SXMPVM03DSCNTVO cntIO = new SXMPVM03DSCNTVO();

			cntIO.setAgrFamMembCnt(sourceIO.getAgrFamMembCnt()); 			/** 동의세대원수 */
			cntIO.setDcsnFamMembCnt(sourceIO.getDcsnFamMembCnt()); 			/** 확정세대원수 */

			cntList.add(cntIO);
		}

		resultVo.setSXMPVM03DSCNTVO(cntList);		/** 세대원수 */

		for (FamMembRegDSSDDTO sourceIO : resultDTO) {
			SXMPVM03DSSDVO targetIO = new SXMPVM03DSSDVO();

			targetIO.setLoanCnslNo(sourceIO.getLoanCnslNo()); 				/** 대출상담번호 */
			targetIO.setRelaMangNo(sourceIO.getRelaMangNo()); 				/** 관련인관리번호 */
			targetIO.setLoanApplNo(sourceIO.getLoanApplNo()); 				/** 대출신청번호 */
			targetIO.setHomsStepCd(sourceIO.getHomsStepCd()); 				/** HOMS진행상태 */
			targetIO.setRelaGbCd(sourceIO.getRelaGbCd()); 					/** 관련인구분코드 */
			targetIO.setFamMembInclCd(sourceIO.getFamMembInclCd()); 		/** 세대원포함여부 */
			targetIO.setJvnlFamMembCd(sourceIO.getJvnlFamMembCd()); 		/** 미성년세대원구분 */
			targetIO.setRelaBorn(sourceIO.getRelaBorn()); 					/** 관련인띠 */
			targetIO.setRelaNm(sourceIO.getRelaNm()); 						/** 관련인성명 */
			targetIO.setMaskRelaNm(this.nameMasking(sourceIO.getRelaNm())); /** 관련인성명_마스킹 */
			targetIO.setRelaAge(sourceIO.getRelaAge()); 					/** 관련인나이 */

			String relaResId = sourceIO.getRelaResId();						/** 관련인주민번호_복호화 */
			String maskRelaResId = "";										/** 관련인주민번호_마스킹처리 */

			if(relaResId.length() > 8) {
				maskRelaResId = relaResId.substring(0, 8) + "******";		/** 관련인주민번호_마스킹 */
			}

			targetIO.setRelaResId(relaResId); 								/** 관련인주민번호 */
			targetIO.setMaskRelaResId(maskRelaResId);						/** 관련인주민번호_마스킹 */
			targetIO.setFamMembAgreCd(sourceIO.getFamMembAgreCd()); 		/** 세대원동의여부 */

			String famMembAgreDt = sourceIO.getFamMembAgreDt();				/** 세대원동의일자 */
			String famMembAgreTm = sourceIO.getFamMembAgreTm();				/** 세대원동의시각 */
			String famMembAgreDtm = "";										/** 세대원동의일시 */

			if((famMembAgreDt != null && !"".equals(famMembAgreDt)) && (famMembAgreTm != null && !"".equals(famMembAgreTm))) {
				famMembAgreDtm = famMembAgreDt + famMembAgreTm;
			}

			targetIO.setFamMembAgreDtm(famMembAgreDtm); 					/** 세대원동의일시 */
			targetIO.setFamMembAgreDt(famMembAgreDt); 						/** 세대원동의일자 */
			targetIO.setFamMembAgreTm(famMembAgreTm); 						/** 세대원동의시각 */

			// 대리동의인성명은 필수값 아님
			String agtNm = sourceIO.getAgtNm();								/** 대리동의인성명 */
			String maskAgtNm = "";

			if(agtNm != null && !"".equals(agtNm)) {
				maskAgtNm = this.nameMasking(agtNm);
			}

			targetIO.setAgtNm(agtNm); 										/** 대리동의인성명 */
			targetIO.setMaskAgtNm(maskAgtNm); 								/** 대리동의인성명_마스킹 */
			targetIO.setAgtBrdd(sourceIO.getAgtBrdd()); 					/** 대리인생년월일 */
			targetIO.setAgtRelaCd(sourceIO.getAgtRelaCd()); 				/** 대리인관계 */
			targetIO.setLoanHoldYn(sourceIO.getLoanHoldYn()); 				/** 신정원대출보유여부 */
			targetIO.setKcisReadDt(sourceIO.getKcisReadDt()); 				/** 신정원조회일자 */
			targetIO.setKcisReadTm(sourceIO.getKcisReadTm()); 				/** 신정원조회시각 */
			targetIO.setKcisMgmnNo(sourceIO.getKcisMgmnNo()); 				/** 신정원전문관리번호 */
			targetIO.setKcisLoanCnt(sourceIO.getKcisLoanCnt()); 			/** 대출보유건수 */
			targetIO.setKcisLoanAmt(sourceIO.getKcisLoanAmt()); 			/** 대출보유금액 */
			targetIO.setTelcoCd(sourceIO.getTelcoCd()); 					/** 통신사코드 */
			targetIO.setMobArea(sourceIO.getMobArea()); 					/** 휴대폰지역번호 */
			targetIO.setMobHeadNum(sourceIO.getMobHeadNum()); 				/** 휴대폰국번 */
			targetIO.setMobSerialNum(sourceIO.getMobSerialNum()); 			/** 휴대폰일련번호 */

			resultList.add(targetIO);
		}

		resultVo.setSXMPVM03DSSDVO(resultList);		/** 프로그램리스트 */

		return resultVo;
	}

	/**
	 * <p>메소드명      : nameMasking : 성명 마스킹 처리</p>
	 * <p>작성일자      : 2023. 4. 12.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 성명 마스킹 처리 한다.</p>
	 * <p>메소드인수    : String</p>
	 * <p>메소드리턴값  : String</p>
	 * <p>예외처리      : Exception</p>
	 */
	private String nameMasking(String name) {

		String maskName = "";

		if(name.length() <= 0) {
			return maskName;
		}

		String fstName = name.substring(0, 1);					// 성
		String midName = name.substring(1, name.length() -1);	// 가운데 이름
		String lstName = name.substring(name.length() -1);		// 마지막 글자

		String midMask = "";	// 중간 마스킹 처리

		for(int i = 0; i < midName.length(); i++) {
			midMask += "*";
		}

		if(midName.equals("")) {	// 외자일 경우
			maskName = fstName + "*";
		}else {
			maskName = fstName + midMask + lstName;
		}

		return maskName;
	}

	/**
	 * <p>메소드명      : registerSXMPVM03U01 : 세대원등록</p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 세대원등록 등록 한다.</p>
	 * <p>메소드인수    : SXMPVM03U01InVo </p>
	 * <p>메소드리턴값  : SXMPVM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SXMPVM03U01OutVO registerSXMPVM03U01(SXMPVM03U01InVO inVo) throws Exception {

		SXMPVM03U01OutVO resultVo = new SXMPVM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		FamMembRegDSSDCDTO inDto = new FamMembRegDSSDCDTO();

		int insResult = 0;

		inDto.setLoanCnslNo(inVo.getSXMPVM03DSSDCVO().getLoanCnslNo()); 			/** 대출상담번호 */
		inDto.setRelaMangNo(inVo.getSXMPVM03DSSDCVO().getRelaMangNo()); 			/** 관련인관리번호 */
		inDto.setLoanApplNo(inVo.getSXMPVM03DSSDCVO().getLoanApplNo()); 			/** 대출신청번호 */
		inDto.setRelaGbCd(inVo.getSXMPVM03DSSDCVO().getRelaGbCd()); 				/** 관련인구분코드 */
		inDto.setRelaResId(inVo.getSXMPVM03DSSDCVO().getRelaResId()); 				/** 관련인주민번호 */
		inDto.setRelaNm(inVo.getSXMPVM03DSSDCVO().getRelaNm()); 					/** 관련인성명 */
		inDto.setRelaAge(inVo.getSXMPVM03DSSDCVO().getRelaAge()); 					/** 관련인나이 */
		inDto.setJvnlFamMembCd(inVo.getSXMPVM03DSSDCVO().getJvnlFamMembCd()); 		/** 미성년세대원구분 */
		inDto.setRelaBorn(inVo.getSXMPVM03DSSDCVO().getRelaBorn()); 				/** 관련인띠 */
		inDto.setFamMembInclCd(inVo.getSXMPVM03DSSDCVO().getFamMembInclCd()); 		/** 세대원포함여부 */
		inDto.setFamMembAgreCd(inVo.getSXMPVM03DSSDCVO().getFamMembAgreCd()); 		/** 세대원동의여부 */
		inDto.setFamMembAgreDt(inVo.getSXMPVM03DSSDCVO().getFamMembAgreDt()); 		/** 세대원동의일자 */
		inDto.setFamMembAgreTm(inVo.getSXMPVM03DSSDCVO().getFamMembAgreTm()); 		/** 세대원동의시각 */
		inDto.setAgtNm(inVo.getSXMPVM03DSSDCVO().getAgtNm()); 						/** 대리동의인성명 */
		inDto.setAgtBrdd(inVo.getSXMPVM03DSSDCVO().getAgtBrdd()); 					/** 대리인생년월일 */
		inDto.setAgtRelaCd(inVo.getSXMPVM03DSSDCVO().getAgtRelaCd()); 				/** 대리인관계 */
		inDto.setLoanHoldYn(inVo.getSXMPVM03DSSDCVO().getLoanHoldYn()); 			/** 신정원대출보유여부 */
		inDto.setKcisReadDt(inVo.getSXMPVM03DSSDCVO().getKcisReadDt()); 			/** 신정원조회일자 */
		inDto.setKcisReadTm(inVo.getSXMPVM03DSSDCVO().getKcisReadTm()); 			/** 신정원조회시각 */
		inDto.setKcisMgmnNo(inVo.getSXMPVM03DSSDCVO().getKcisMgmnNo()); 			/** 신정원전문관리번호 */
		inDto.setKcisLoanCnt(inVo.getSXMPVM03DSSDCVO().getKcisLoanCnt()); 			/** 대출보유건수 */
		inDto.setKcisLoanAmt(inVo.getSXMPVM03DSSDCVO().getKcisLoanAmt()); 			/** 대출보유금액 */
		inDto.setTelcoCd(inVo.getSXMPVM03DSSDCVO().getTelcoCd()); 					/** 통신사코드 */
		inDto.setMobArea(inVo.getSXMPVM03DSSDCVO().getMobArea()); 					/** 휴대폰지역번호 */
		inDto.setMobHeadNum(inVo.getSXMPVM03DSSDCVO().getMobHeadNum()); 			/** 휴대폰국번 */
		inDto.setMobSerialNum(inVo.getSXMPVM03DSSDCVO().getMobSerialNum()); 		/** 휴대폰일련번호 */
		inDto.setLogInEmpNo(inVo.getSXMPVM03DSSDCVO().getLogInEmpNo()); 			/** 로그인사원번호 */

		insResult = famMembRegMapper.registerFamMembReg(inDto);					/** 프로그램역할 등록 */

		if(insResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;

	}

	/**
	 * <p>메소드명      : modifySXMPVM03U01 : 세대원등록수정</p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 세대원등록 수정 한다.</p>
	 * <p>메소드인수    : SXMPVM03U01InVo </p>
	 * <p>메소드리턴값  : SXMPVM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SXMPVM03U01OutVO modifySXMPVM03U01(SXMPVM03U01InVO inVo) throws Exception {

		SXMPVM03U01OutVO resultVo = new SXMPVM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		FamMembRegDSSDCDTO inDto = new FamMembRegDSSDCDTO();

		int updResult = 0;

		inDto.setLoanCnslNo(inVo.getSXMPVM03DSSDCVO().getLoanCnslNo()); 			/** 대출상담번호 */
		inDto.setRelaMangNo(inVo.getSXMPVM03DSSDCVO().getRelaMangNo()); 			/** 관련인관리번호 */
		inDto.setLoanApplNo(inVo.getSXMPVM03DSSDCVO().getLoanApplNo()); 			/** 대출신청번호 */
		inDto.setRelaGbCd(inVo.getSXMPVM03DSSDCVO().getRelaGbCd()); 				/** 관련인구분코드 */
		inDto.setRelaResId(inVo.getSXMPVM03DSSDCVO().getRelaResId()); 				/** 관련인주민번호 */
		inDto.setRelaNm(inVo.getSXMPVM03DSSDCVO().getRelaNm()); 					/** 관련인성명 */
		inDto.setRelaAge(inVo.getSXMPVM03DSSDCVO().getRelaAge()); 					/** 관련인나이 */
		inDto.setJvnlFamMembCd(inVo.getSXMPVM03DSSDCVO().getJvnlFamMembCd()); 		/** 미성년세대원구분 */
		inDto.setRelaBorn(inVo.getSXMPVM03DSSDCVO().getRelaBorn()); 				/** 관련인띠 */
		inDto.setFamMembInclCd(inVo.getSXMPVM03DSSDCVO().getFamMembInclCd()); 		/** 세대원포함여부 */
		inDto.setFamMembAgreCd(inVo.getSXMPVM03DSSDCVO().getFamMembAgreCd()); 		/** 세대원동의여부 */
		inDto.setFamMembAgreDt(inVo.getSXMPVM03DSSDCVO().getFamMembAgreDt()); 		/** 세대원동의일자 */
		inDto.setFamMembAgreTm(inVo.getSXMPVM03DSSDCVO().getFamMembAgreTm()); 		/** 세대원동의시각 */
		inDto.setAgtNm(inVo.getSXMPVM03DSSDCVO().getAgtNm()); 						/** 대리동의인성명 */
		inDto.setAgtBrdd(inVo.getSXMPVM03DSSDCVO().getAgtBrdd()); 					/** 대리인생년월일 */
		inDto.setAgtRelaCd(inVo.getSXMPVM03DSSDCVO().getAgtRelaCd()); 				/** 대리인관계 */
		inDto.setLoanHoldYn(inVo.getSXMPVM03DSSDCVO().getLoanHoldYn()); 			/** 신정원대출보유여부 */
		inDto.setKcisReadDt(inVo.getSXMPVM03DSSDCVO().getKcisReadDt()); 			/** 신정원조회일자 */
		inDto.setKcisReadTm(inVo.getSXMPVM03DSSDCVO().getKcisReadTm()); 			/** 신정원조회시각 */
		inDto.setKcisMgmnNo(inVo.getSXMPVM03DSSDCVO().getKcisMgmnNo()); 			/** 신정원전문관리번호 */
		inDto.setKcisLoanCnt(inVo.getSXMPVM03DSSDCVO().getKcisLoanCnt()); 			/** 대출보유건수 */
		inDto.setKcisLoanAmt(inVo.getSXMPVM03DSSDCVO().getKcisLoanAmt()); 			/** 대출보유금액 */
		inDto.setTelcoCd(inVo.getSXMPVM03DSSDCVO().getTelcoCd()); 					/** 통신사코드 */
		inDto.setMobArea(inVo.getSXMPVM03DSSDCVO().getMobArea()); 					/** 휴대폰지역번호 */
		inDto.setMobHeadNum(inVo.getSXMPVM03DSSDCVO().getMobHeadNum()); 			/** 휴대폰국번 */
		inDto.setMobSerialNum(inVo.getSXMPVM03DSSDCVO().getMobSerialNum()); 		/** 휴대폰일련번호 */
		inDto.setLogInEmpNo(inVo.getSXMPVM03DSSDCVO().getLogInEmpNo()); 			/** 로그인사원번호 */

		updResult = famMembRegMapper.modifyFamMembReg(inDto);	/** 세대원등록수정리스트*/

		if(updResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : modifySXMPVM03U02 : HOMS진행상태수정</p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : HOMS진행상태 수정 한다.</p>
	 * <p>메소드인수    : SXMPVM03U01InVo </p>
	 * <p>메소드리턴값  : SXMPVM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SXMPVM03U01OutVO modifySXMPVM03U02(SXMPVM03U01InVO inVo) throws Exception {

		SXMPVM03U01OutVO resultVo = new SXMPVM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		FamMembRegDSSDHDTO inDto = new FamMembRegDSSDHDTO();

		int updResult = 0;

		inDto.setLoanCnslNo(inVo.getSXMPVM03DSSDHVO().getLoanCnslNo()); 		/** 대출상담번호 */
		inDto.setLoanApplNo(inVo.getSXMPVM03DSSDHVO().getLoanApplNo()); 		/** 대출신청번호 */
		inDto.setHomsStepCd(inVo.getSXMPVM03DSSDHVO().getHomsStepCd()); 		/** HOMS진행상태 */
		inDto.setLogInEmpNo(inVo.getSXMPVM03DSSDHVO().getLogInEmpNo()); 		/** 로그인사원번호 */

		updResult = famMembRegMapper.modifyHomsStep(inDto);						/** HOMS진행상태수정리스트*/

		if(updResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

	/**
	 * <p>메소드명      : deleteSXMPVM03U01 : 세대원등록삭제</p>
	 * <p>작성일자      : 2023. 5. 9.
	 * <p>작성자(author): 70323 / HeoHyemi
	 * <p>설명          : 세대원등록 삭제 한다.</p>
	 * <p>메소드인수    : SXMPVM03U01InVo </p>
	 * <p>메소드리턴값  : SXMPVM03U01OutVo</p>
	 * <p>예외처리      : Exception</p>
	 */
	@Override
	public SXMPVM03U01OutVO deleteSXMPVM03U01(SXMPVM03U01InVO inVo) throws Exception {

		SXMPVM03U01OutVO resultVo = new SXMPVM03U01OutVO();
		resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
		resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

		FamMembRegDSSDDDTO inDto = new FamMembRegDSSDDDTO();

		int delResult = 0;

		inDto.setLoanCnslNo(inVo.getSXMPVM03DSSDDVO().getLoanCnslNo()); 			/** 대출상담번호 */
		inDto.setRelaMangNo(inVo.getSXMPVM03DSSDDVO().getRelaMangNo()); 			/** 관련인관리번호 */
		inDto.setLoanApplNo(inVo.getSXMPVM03DSSDDVO().getLoanApplNo()); 			/** 대출신청번호 */

		delResult = famMembRegMapper.deleteFamMembReg(inDto);	/** 세대원등록삭제리스트*/

		if(delResult < 0) {
			resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
			resultVo.setRsltCntn(msgEnum.ERR_SYSTEM.getErrorCn());
		}

		return resultVo;
	}

}