package hanalife.t.ch.on.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.util.DateUtil;
import hanalife.t.ch.on.mapper.LoanApplMapper;
import hanalife.t.ch.on.mapper.dto.LoanAgrInfoDTO;
import hanalife.t.ch.on.mapper.dto.LoanApplInfoDTO;
import hanalife.t.ch.on.mapper.dto.LoanApplSpecDTO;
import hanalife.t.ch.on.mapper.dto.LoanCnslInfoDTO;
import hanalife.t.ch.on.mapper.dto.LoanContInfoDTO;
import hanalife.t.ch.on.mapper.dto.StAddrMangDTO;
import hanalife.t.ch.on.mapper.dto.StApplLdgrDTO;
import hanalife.t.ch.on.mapper.dto.StMrtgLgdrDTO;
import hanalife.t.ch.on.mapper.dto.StMrtgLgdrHistDTO;
import hanalife.t.ch.on.mapper.dto.StRelaInfoDTO;
import hanalife.t.ch.on.mapper.dto.StTelMangDTO;
import hanalife.t.ch.on.service.TCHON002Service;
import hanalife.t.ch.on.vo.ReqBodyVO;
import hanalife.t.ch.on.vo.ResBodyVO;
import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON003ServiceImpl.java Class
 * 클래스설명    : 대출신청 Service Implements
 * 작성일자     : 2023. 3. 28.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 3. 28.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : saveLoanApplInfo : 대출신청
 * </pre>
 */
@Service("TCHON002Service")
public class TCHON002ServiceImpl implements TCHON002Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(TCHON002ServiceImpl.class);

    @Autowired
    private LoanApplMapper loanApplMapper;

    /**
     *<pre>
     * 메소드명      : saveLoanApplInfo : 대출신청정보 저장
     * 작성일자      : 2023. 3. 28.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : 대출신청정보를 저장한다.
     * 메소드인수    : TCHONInVO
     * 메소드리턴값  : TCHONInVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public ResBodyVO saveLoanApplInfoTest(ReqBodyVO inVo) throws Exception {

        ResBodyVO resultVo = new ResBodyVO();


        try {


            // 시퀀스 테스트

            // 대출신청번호 : S + yyyymmdd + 9999(시퀀스)
            String sTempSeq     = Integer.toString(loanApplMapper.getLoanApplNoSeq()); // 대출신청번호 마지막 4자리로 설정되는 시퀀스 취득
            String loanApplNo   = "S" + DateUtil.getCurrentDateString() + GramUtil.fixEndZero(sTempSeq, 4);

            // AMLKEY 채번 : 5 + 0000001 (7자리)
            String amlkeySeq = Integer.toString(loanApplMapper.getAmlkeySeq()); // amlkey 시퀀스 취득
            String amlkey = "5" + GramUtil.fixEndZero(amlkeySeq, 7);

            // 결과값 : 처리결과, 대출신청번호 리턴
            resultVo.setRspnCd("000");
            resultVo.setRspnMsg("대출신청 처리성공");
            resultVo.setLoanApplNo(loanApplNo);     //대출신청번호
            resultVo.setAmlkey(amlkey);     //대출신청번호

        } catch (Exception e) {
            // TODO: handle exception
            // 오류 결과값 설정후 리턴

            resultVo.setRspnCd("999");
            resultVo.setRspnMsg("오류발생"+e.getMessage());
        }

        return resultVo;

    }

    /**
     *<pre>
     * 메소드명      : saveLoanApplInfo : 대출신청정보 저장
     * 작성일자      : 2023. 3. 28.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : 대출신청정보를 저장한다.
     * 메소드인수    : TCHONInVO
     * 메소드리턴값  : TCHONInVO
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public ResBodyVO saveLoanApplInfo(ReqBodyVO inVo) throws Exception {

        ResBodyVO resultVo = new ResBodyVO();


        try {

            String loanCnslNo = inVo.getLoanCnslNo();   // 신정정보 등록대상 상담번호

            LoanCnslInfoDTO loanCnslInfoDTO = new LoanCnslInfoDTO();    // 대출_상담_정보
            LoanApplInfoDTO loanApplInfoDTO = new LoanApplInfoDTO();    // 대출_신청_정보
            LoanApplSpecDTO loanApplSpecDTO = new LoanApplSpecDTO();    // 대출_신청_상세
            LoanAgrInfoDTO  loanAgrInfoDTO  = new LoanAgrInfoDTO();     // 대출_동의_정보
            LoanContInfoDTO loanContInfoDTO = new LoanContInfoDTO();    // 대출_약정_정보

            // 대출 상담번호로 채널 DB 데이터 확인
            loanCnslInfoDTO.setLoanCnslNo   (loanCnslNo);
            loanApplInfoDTO.setLoanCnslNo   (loanCnslNo);
            loanApplSpecDTO.setLoanCnslNo   (loanCnslNo);
            loanAgrInfoDTO.setLoanCnslNo    (loanCnslNo);
            loanContInfoDTO.setLoanCnslNo   (loanCnslNo);

            // 대출_상담_정보 (채널)
            loanCnslInfoDTO = new LoanCnslInfoDTO();    // 대출_상담_정보
            loanCnslInfoDTO = loanApplMapper.getLoanCnslInfo(loanCnslInfoDTO);

            // 주요데이터 체크
            if(loanCnslInfoDTO.getChnlCustNo().isEmpty()) {

            }


            // 대출_신청_정보 (채널)
            loanApplInfoDTO = loanApplMapper.getLoanApplInfo(loanApplInfoDTO);

            // 대출_신청_상세 (채널)
            loanApplSpecDTO = loanApplMapper.getLoanApplSpec(loanApplSpecDTO);

            // 대출_동의_정보 리스트(채널)
            List<LoanAgrInfoDTO> loanAgrInfoDTOList = loanApplMapper.getLoanAgrInfoList(loanAgrInfoDTO);

            // 대출_약정_정보 (채널)
            loanContInfoDTO = loanApplMapper.getLoanContInfo(loanContInfoDTO);

            LOGGER.debug(" 채널계 데이터 Validation 체크 ");


            LOGGER.debug(" 이상이 없으면 ");
            LOGGER.debug(" 기간계 대출신청정보 저장 처리 START ");

            //saveLoanApplInfo

            // ※ 채널DB 테이블 관련 항목 확인 필요
            // SELECT 및 이상유무 확인후 등록
            // ※ 주의 : 암호화 컬럼 있음


            /*
             * 신정정보 저장처리 (기간계)
             * */
            // 대출신청번호 채번 :
            // 시퀀스 가져오는거 확인 필요
            // prePix 상수 등록해야할지 확인

            // 신청데이터 적재 : 테이블 및 등록 항목 확인
            // 담보정보 적재 :
            // 관련인정보 적재 : 최초 신청시에는 관련인 수만 옴
            // 고객정보 : 채널 DB직적참조 가져오기때문에 저장 필요 없음
            // 확인결과 관련인 동의정보가 신청시에 넘어온다고 함

            // 대출신청번호 : S + yyyymmdd + 9999(시퀀스)
            int tempSeq         = loanApplMapper.getLoanApplNoSeq();
            String sTempSeq     = Integer.toString(loanApplMapper.getLoanApplNoSeq()); // 대출신청번호 마지막 4자리로 설정되는 시퀀스
            String loanApplNo   = "S" + DateUtil.getCurrentDateString() + GramUtil.fixEndZero(sTempSeq, 4);

            // TODO : 중요!!!
            // 대출번호 : LOAN_NO
            // 채번 : 5 + 0000001 (7자리)
            // 채널에 내려줘야함


            StApplLdgrDTO       applLdgrInDto       = new StApplLdgrDTO();        // 여신신청원장
            StMrtgLgdrDTO       mrtgLgdrInDto       = new StMrtgLgdrDTO();        //담보원장
            StMrtgLgdrHistDTO   mrtgLgdrHistInDto   = new StMrtgLgdrHistDTO();    //담보원장 이력
            StRelaInfoDTO       relaInfoInDto       = new StRelaInfoDTO();        //관련인정보
            StAddrMangDTO       addrMangInDto       = new StAddrMangDTO();        //고객주소정보관리
            StTelMangDTO        telMangInDto        = new StTelMangDTO();         //고객전화정보관리

            // 1. 여신신청원장 (ST_APPL_LDGR)
            // 등록 데이터 셋팅
            // (별도 메소드로 만드는것 고려)
            applLdgrInDto.setLoanApplNo(     loanApplNo);
            /*
            applLdgrInDto.setApplModifyNo(     test);
            applLdgrInDto.setProdModifySeq(     test);
            applLdgrInDto.setCustModifySeq(     test);
            applLdgrInDto.setCollModifySeq(     test);
            applLdgrInDto.setInWayGbCd(     test);
            applLdgrInDto.setApplBefStsCd(     test);
            applLdgrInDto.setApplRealStsCd(     test);
            applLdgrInDto.setApplNextStsCd(     test);
            applLdgrInDto.setApplFnshStepCd(     test);
            applLdgrInDto.setRetnStrtStepCd(     test);
            applLdgrInDto.setCustAge(     test);
            applLdgrInDto.setGradAvailDt(     test);
            applLdgrInDto.setCssSeqNo(     test);
            applLdgrInDto.setRejtTinkGbCd(     test);
            applLdgrInDto.setCnclTinkGbCd(     test);
            applLdgrInDto.setLastJudgDt(     test);
            applLdgrInDto.setLastJudgGbCd(     test);
            applLdgrInDto.setProdCd(     test);
            applLdgrInDto.setRepayTypeGbCd(     test);
            applLdgrInDto.setRepayCyclGbCd(     test);
            applLdgrInDto.setCapUseGbCd(     test);
            applLdgrInDto.setRateCd(     test);
            applLdgrInDto.setRateGbCd(     test);
            applLdgrInDto.setRateChanCycl(     test);
            applLdgrInDto.setLonPossAmt(     test);
            applLdgrInDto.setLonApplAmt(     test);
            applLdgrInDto.setUnder1SJudgAmt(     test);
            applLdgrInDto.setUnder2SJudgAmt(     test);
            applLdgrInDto.setUnder3SJudgAmt(     test);
            applLdgrInDto.setLastJudgAmt(     test);
            applLdgrInDto.setLonRate(     test);
            applLdgrInDto.setFrstJudgRate(     test);
            applLdgrInDto.setScndJudgRate(     test);
            applLdgrInDto.setThrdJudgRate(     test);
            applLdgrInDto.setLastJudgRate(     test);
            applLdgrInDto.setLastJudgStepDt(     test);
            applLdgrInDto.setLastJudgStepCd(     test);
            applLdgrInDto.setLastJudgStepUserId(     test);
            applLdgrInDto.setLastJudgStepUserNm(     test);
            applLdgrInDto.setLonTerm(     test);
            applLdgrInDto.setGracTerm(     test);
            applLdgrInDto.setLoanCnslNo(     test);
            applLdgrInDto.setLoanNo(     test);
            applLdgrInDto.setLoanSeq(     test);
            applLdgrInDto.setCustNo(     test);
            applLdgrInDto.setChnlCustNo(     test);
            applLdgrInDto.setAmlkey(     test);
            applLdgrInDto.setCustResiNo(     test);
            applLdgrInDto.setCustNm(     test);
            applLdgrInDto.setWifeResiNo(     test);
            applLdgrInDto.setWifeNm(     test);
            applLdgrInDto.setEmal(     test);
            applLdgrInDto.setYearIncomeAmt(     test);
            applLdgrInDto.setIncmTotGbCd(     test);
            applLdgrInDto.setApplDt(     test);
            applLdgrInDto.setDisbHopeDt(     test);
            applLdgrInDto.setSettDt(     test);
            applLdgrInDto.setLonDueDt(     test);
            applLdgrInDto.setFixRateYn(     test);
            applLdgrInDto.setAcptIncmYn(     test);
            applLdgrInDto.setChanOwnGbCd(     test);
            applLdgrInDto.setSrId(     test);
            applLdgrInDto.setSrNm(     test);
            applLdgrInDto.setAutoBankCd(     test);
            applLdgrInDto.setAutoAccoNo(     test);
            applLdgrInDto.setAutoResId(     test);
            applLdgrInDto.setAutoDepoCust(     test);
            applLdgrInDto.setActTrsfBankCd(     test);
            applLdgrInDto.setActTrsfAccNo(     test);
            applLdgrInDto.setActTrsfDpstNm(     test);
            applLdgrInDto.setBef1SBankCd(     test);
            applLdgrInDto.setBef1SAccoNo(     test);
            applLdgrInDto.setBef1SResId(     test);
            applLdgrInDto.setBef1SDepoCust(     test);
            applLdgrInDto.setBef2SBankCd(     test);
            applLdgrInDto.setBef2SAccoNo(     test);
            applLdgrInDto.setBef2SResId(     test);
            applLdgrInDto.setBef2SDepoCust(     test);
            applLdgrInDto.setPrefAmt(     test);
            applLdgrInDto.setPrefRepayAmt(     test);
            applLdgrInDto.setHiApplCnt(     test);
            applLdgrInDto.setHiEcpnDescCd(     test);
            applLdgrInDto.setHiEcpnDescCont(     test);
            applLdgrInDto.setSposResiYn(     test);
            applLdgrInDto.setChoiHandlAreaYn(     test);
            applLdgrInDto.setEregCertKey(     test);
            applLdgrInDto.setHomsStepCd(     test);
            applLdgrInDto.setHomsRqstDt(     test);
            applLdgrInDto.setHomsRqstEmpNo(     test);
            applLdgrInDto.setHomsRsltDt(     test);
            applLdgrInDto.setHomsRsltEmpNo(     test);
            applLdgrInDto.setCrdtGuarFundGbCd(     test);
            applLdgrInDto.setNoDefrDivsRmbrYn(     test);
            applLdgrInDto.setMciEntrYn(     test);
            applLdgrInDto.setAnotComRlnYn(     test);
            applLdgrInDto.setFactDemdYn(     test);
            applLdgrInDto.setOverpCotrZoneYn(     test);
            applLdgrInDto.setMciEntrAmt(     test);
            applLdgrInDto.setFrstRegDt(     test);
            applLdgrInDto.setFrstRegTm(     test);
            applLdgrInDto.setFrstRegEmpNo(     test);
            applLdgrInDto.setLastProcDt(     test);
            applLdgrInDto.setLastProcTm(     test);
            applLdgrInDto.setLastProcEmpNo(     test);
            */

            int i = loanApplMapper.insertStApplLdgr(applLdgrInDto);



            // 2.-1 담보원원장 (ST_MRTG_LGDR)
            mrtgLgdrInDto.setLoanCnslNo(loanCnslNo);    // 대출상담번호
            //
            //



            loanApplMapper.insertStMrtgLgdr(mrtgLgdrInDto);

            // 2-2. 담보원원장이력(ST_MRTG_LGDR_HIST)
            // 위의 담보원장과 같은 dto 사용해도 됨!!!!!!!!!!!!!!!!!!!
            loanApplMapper.insertStMrtgLgdrHist(mrtgLgdrHistInDto);

            // 3. 관련인정보 (ST_RELA_INFO) : 인원수 만큼 등록 0 or n건

            // 관련인 동의가 있다면
            relaInfoInDto.setLoanCnslNo(loanCnslNo);
            relaInfoInDto.setLoanCnslNo(loanCnslNo);

            loanApplMapper.insertStRelaInfo(relaInfoInDto);

            // 3. 고객주소정보관리 (ST_ADDR_MANG)
            loanApplMapper.insertStAddrMang(addrMangInDto);

            // 3. 고객전화정보관리 (ST_TEL_MANG)
            loanApplMapper.insertStTelMang(telMangInDto);

            // 결과값 : 처리결과, 대출신청번호 리턴
            resultVo.setRspnCd("");
            resultVo.setRspnMsg("");
            resultVo.setLoanApplNo(loanApplNo);     //대출신청번호

        } catch (Exception e) {
            // TODO: handle exception
            // 오류 결과값 설정후 리턴
        }

        return resultVo;

    }

}
