package hanalife.t.comm.service.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.t.comm.mapper.IF_CommonMapper;
import hanalife.t.comm.service.IF_CommonService;


/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : IF_CommonServiceImpl.java Class
 * 클래스설명   : 인터페이스의 전문일련번호를 취득한다.
 * 작성일자     : 2023. 4. 25.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 25.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("IF_CommonService")
public class IF_CommonServiceImpl implements IF_CommonService {

    private static final Logger LOGGER = LoggerFactory.getLogger(IF_CommonServiceImpl.class);

    @Autowired
    private IF_CommonMapper if_CommonMapper;

    /**
     *<pre>
     * 메소드명      : getKCBOnlnSeq :
     * 작성일자      : 2023. 4. 25.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : KCB 전문일련번호 채번
     *               - 일자(8자리) + 일련번호(7자리)
     * 메소드인수    :
     * 메소드리턴값  : String
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public String getKCBOnlnSeq() throws Exception {

        /*--------------------------------------------------
         * KCB 전문일련번호 리턴
         *  - YYYYMMDD+SEQ_NO(7자리)
         --------------------------------------------------*/
        String returnSeq = "";
        int seq = if_CommonMapper.selectKCBOnlnSeq();
        returnSeq = DateUtil.getCurrentDateString() + StringUtil.lpad(seq, 7, "0");

        LOGGER.debug("KCB 전문일련번호" + returnSeq);
        return returnSeq;
    }

    /**
     *<pre>
     * 메소드명      : getKFBOnlnSeq :
     * 작성일자      : 2023. 4. 25.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : 신용정보원 전문일련번호 채번
     *               - 일자(8자리) + 일련번호(7자리)
     * 메소드인수    :
     * 메소드리턴값  : String
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public String getKFBOnlnSeq() throws Exception{

        /*--------------------------------------------------
         * 신용정보원 전문일련번호 리턴
         *  - YYYYMMDD+SEQ_NO(7자리)
         --------------------------------------------------*/
        String returnSeq = "";
        int seq = if_CommonMapper.selectKFBOnlnSeq();
        returnSeq = DateUtil.getCurrentDateString() + StringUtil.lpad(seq, 7, "0");

        LOGGER.debug("신용정보원 전문일련번호" + returnSeq);
        return returnSeq;
    }

    /**
     *<pre>
     * 메소드명      : getHIOnlnSeq
     * 작성일자      : 2023. 4. 25.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : 하나손보 전문일련번호 채번
     *               - 일자(8자리) + 일련번호(7자리)
     * 메소드인수    :
     * 메소드리턴값  : String
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public String getHIOnlnSeq() throws Exception{

        /*--------------------------------------------------
         * 하나손보 전문일련번호 리턴
         *  - YYYYMMDD+SEQ_NO(7자리)
         --------------------------------------------------*/
        String returnSeq = "";
        int seq = if_CommonMapper.selectHIOnlnSeq();
        returnSeq = DateUtil.getCurrentDateString() + StringUtil.lpad(seq, 7, "0");

        LOGGER.debug("하나손보 전문일련번호" + returnSeq);
        return returnSeq;
    }

    /**
     *<pre>
     * 메소드명      : getFPOnlnSeq
     * 작성일자      : 2023. 4. 25.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : 피노텍 전문일련번호 채번
     *               - 일자(8자리) + 일련번호(7자리)
     * 메소드인수    :
     * 메소드리턴값  : String
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public String getFPOnlnSeq() throws Exception{
        /*--------------------------------------------------
         * 피노텍 전문일련번호 리턴
         *  - YYYYMMDD+SEQ_NO(7자리)
         --------------------------------------------------*/
        String returnSeq = "";
        int seq = if_CommonMapper.selectFPOnlnSeq();
        returnSeq = DateUtil.getCurrentDateString() + StringUtil.lpad(seq, 7, "0");

        LOGGER.debug("피노텍 전문일련번호" + returnSeq);
        return returnSeq;
    }

    /**
     *<pre>
     * 메소드명      : getSGIOnlnSeq
     * 작성일자      : 2023. 4. 25.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : SGI(신용보증보험) 전문일련번호 취득
     *               - 일자(8자리) + 일련번호(7자리)
     * 메소드인수    :
     * 메소드리턴값  : String
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public String getSGIOnlnSeq() throws Exception{
        /*--------------------------------------------------
         * SGI(신용보증보험) 전문일련번호 리턴
         *  - YYYYMMDD+SEQ_NO(7자리)
         --------------------------------------------------*/
        String returnSeq = "";
        int seq = if_CommonMapper.selectSGIOnlnSeq();
        returnSeq = DateUtil.getCurrentDateString() + StringUtil.lpad(seq, 7, "0");

        LOGGER.debug("SGI(신용보증보험) 전문일련번호" + returnSeq);
        return returnSeq;
    }

}