package hanalife.t.kc.on.service.impl;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.StKcbOnlnMstrMapper;
import hanalife.c.co.mapper.StKcbOnlnSeg100Mapper;
import hanalife.c.co.mapper.StKcbOnlnSeg103Mapper;
import hanalife.c.co.mapper.dto.StKcbOnlnMstrDTO;
import hanalife.c.co.mapper.dto.StKcbOnlnSeg100DTO;
import hanalife.c.co.mapper.dto.StKcbOnlnSeg103DTO;
import hanalife.c.co.util.DateUtil;
import hanalife.framework.comm.util.PropertiesHandler;
import hanalife.t.comm.service.IF_CommonService;
import hanalife.t.kc.on.service.TKCON001Service;
import hanalife.t.kc.on.vo.KCB100SegEntity;
import hanalife.t.kc.on.vo.KCB103SegEntity;
import hanalife.t.kc.on.vo.KCB400RecvInfoEntity;
import hanalife.t.kc.on.vo.KCB400RqstInfoEntity;
import hanalife.t.kc.on.vo.KCB400Send100Entity;
import hanalife.t.kc.on.vo.KCB400Send103Entity;
import hanalife.t.kc.on.vo.KCBCommonEntity;
import hanalife.t.kc.on.vo.KCBOnlnVo;
import hanalife.util.anylink.AnylinkSender;
import hanalife.util.gram.GramUtil;
import hanalife.util.gram.OnLineUtil;

//[KCB] - 한국개인신용 복수카드 조회(0400/437)

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TCHON001ServiceImpl.java Class
 * 클래스설명   : [KCB] - 한국개인신용 복수카드 조회 Service Implements
 * 작성일자     : 2023. 4. 18.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 18.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : KCB_0400_Call : [KCB] - 한국개인신용 복수카드 조회
 * </pre>
 */
@Service("TKCON001Service")
public class TKCON001ServiceImpl implements TKCON001Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(TKCON001ServiceImpl.class);

    @Autowired
    private StKcbOnlnMstrMapper     kcbOnlnMstrMapper;      // KCB 온라인 마스터
    private StKcbOnlnSeg100Mapper   kcbSeg100Mapper;        // KCB 세그먼트 100
    private StKcbOnlnSeg103Mapper   kcbSeg103Mapper;        // KCB 세그먼트 103

    @Resource(name = "IF_CommonService")
    private IF_CommonService if_CommonService;

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 **/
    //private MsgEnum msgEnum;

    private String gramSeq  = "";


    private String resiNo;               // 주민등록번호
    private String resiNm;               // 고객명
    private String loanCnslNo;           // 대출상담번호
    private String loanApplNo;           // 대출신청번호
    private String loanNo;               // 대출번호
    private String custNo;               // 고객번호
    private String readDeptNm;           // 조회지점명
    private String empNo;                // 담당자 ID


    private final int LENG_100 = 140;
    private final int LENG_103 = 21;


    /**
     *<pre>
     * 메소드명      : KCB_0400_Call
     * 작성일자      : 2023. 4. 18.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명         : [KCB] - 한국개인신용 복수카드 조회 처리
     * 메소드인수    : KCBOnlnVo
     * 메소드리턴값   : KCBOnlnVo
     * 예외처리     : Exception
     *</pre>
     */
    @Override

    public KCBOnlnVo KCB_0400_Call(KCBOnlnVo inVo) throws Exception {

        KCBOnlnVo resultVo = new KCBOnlnVo();
        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());
/*
        // 필수 체크 TODO (필요?), 주민번호 복호화 되서 들어오는것 확인 필요
        // 1. 주민등록번호 체크
        if("".equals(inVo.getResiNo().trim()) || inVo.getResiNo() == null) {
            // TODO : CONSTANTS 혹은 메시지 em에 설정할 것

            resultVo.setRsltCd(MsgEnum.ISNULL_LOAN_NO.getErrorCd());
            resultVo.setRsltCntn("주민등록번호가 없어.");
            return resultVo;
        }
        // 2. 대출상담번호 체크
        if("".equals(inVo.getResiNm().trim()) || inVo.getResiNm() == null) {

            resultVo.setRsltCd  (MsgEnum.HI_APPL_MNGM_NO_EMPTY.getErrorCd()    );
            resultVo.setRsltCntn(MsgEnum.HI_APPL_MNGM_NO_EMPTY.getDescription());


            return resultVo;
        }
        // 3. 대출상담번호 체크
        if("".equals(inVo.getLoanCnslNo().trim()) || inVo.getLoanCnslNo() == null) {
            return resultVo;
        }
*/
        this.resiNo         = inVo.getResiNo();         // 주민등록번호
        this.resiNm         = inVo.getResiNm();         // 고객명
        this.loanCnslNo     = inVo.getLoanCnslNo();     // 대출상담번호
        this.loanApplNo     = inVo.getLoanApplNo();     // 대출신청번호
        this.loanNo         = inVo.getLoanNo();         // 대출번호
        this.custNo         = inVo.getCustNo();         // 고객번호
        this.readDeptNm     = inVo.getReadDeptNm();     // 조회지점명
        this.empNo          = inVo.getEmpNo();          // 담당자 ID
        // TODO : 채널의 한도산출인지, 심사CSS 의 호출인지, 그외의 호출인지 조회(호출)사유 추가할지 고려 필요

        LOGGER.debug("[Kcb 전문] Start");
        /** 1. 송신 공통부 선언 */
        KCBCommonEntity kcbComm       = new KCBCommonEntity("0400","437"); // 요청전문코드 : 0400 , 업무구분코드 : 437

        /** 2. 송신 요청 정보 선언 */
        KCB400RqstInfoEntity kcb400RqstInfo = new KCB400RqstInfoEntity();

        /** 3. 수신 응답 정보 선언 */
        KCB400RecvInfoEntity kcb400RecvInfo = new KCB400RecvInfoEntity();

        /** 4. 송신 요청 반복부 선언*/
        KCB400Send103Entity kcb400Send103 = new KCB400Send103Entity();  // CB Score 반복부
        KCB400Send100Entity kcb400Send100 = new KCB400Send100Entity();  // CPS 반복부

        try {

            // KCB 전문일련번호 채번 : YYYYMMDD+SEQ_NO(7자리)
            gramSeq = if_CommonService.getKCBOnlnSeq();

            /** 1. KCB 송신 후 수신결과 내용을 가져옴 */
            String[] oFrame = callOnLine(kcbComm, kcb400RqstInfo, kcb400RecvInfo, kcb400Send103, kcb400Send100);
            LOGGER.debug("[Kcb 전문응답코드 [" + resiNo + "]["+kcbComm.getRspnCd()+"]");

            if (kcbComm.getRspnCd().equals("0000")) {

                LOGGER.debug("### 400 gramSeq : "+gramSeq);
                kcb400RecvInfo.setRecvObj(oFrame[1]);    // 응답정보부

                // 온라인 마스터 등록
                insertKCBOnlnMaser(kcbComm, kcb400RqstInfo, kcb400RecvInfo, gramSeq);

                //setRecvData(kcb100RecvInfo, oFrame[2]);
                setRecvData(kcb400RecvInfo, oFrame[2]);

                //조회 할 자료가 없을 때 까지 looping
                for(int i=0; i < 100 && (kcb400RecvInfo.getInfoContFg().equals("Y"));i++){   // 10 -> 30변경 2018-08-01 (두비스), 30 -> 100 변경 BHP100412

                    kcbComm.setGramKindCd       ("0500"                             );  // 전문종별코드 재호출 (layTpCd =>gramKindCd)
                    kcbComm.setSendRecvFg       ("B"                                );
                    kcbComm.setRspnCd           (GramUtil.fillSpace("",4)     );
                    kcbComm.setKcbLayMngNo      (GramUtil.fixEndZero("",7)          );
                    kcbComm.setKcbLaySendTm     (GramUtil.fixEndZero("",14)    );
                    kcbComm.setWricLayMngNo     (GramUtil.fixEndZero("",7)     );
                    kcbComm.setWricLaySendTm    (GramUtil.fixEndZero("",14)    );
                    kcbComm.setKcbSystInfo      (GramUtil.fillSpace("",16)    );
                    kcbComm.setViewAgreeFg      ("1"                                ) ;
                    kcbComm.setFiller           (GramUtil.fillSpace("",42)    );

                    kcb400RqstInfo.setConfNo        (GramUtil.fillSpace(kcb400RecvInfo.getConfNo(),12)                            );
                    kcb400RqstInfo.setReRqstCnt     (GramUtil.fixEndZero(""+(this.parseInt(kcb400RecvInfo.getReRspnCnt())+1),2)    );  //재요청회수
                    kcb400RqstInfo.setCbTotCnt      (GramUtil.fixEndZero(kcb400RecvInfo.getScoreTotRcvCnt(),3)                     );  // CB Score 총수신건수 (이전회차의 총송신건수 설정) :
                    kcb400RqstInfo.setCbCpsTotCnt   (GramUtil.fixEndZero(kcb400RecvInfo.getCpsTotRcvCnt(),3)                       );  // CPS 총수신건수 (이전회차의 총송신건수 설정)
                    // 요청건수 : 기본설정치 (99)

                    // 재호출
                    oFrame = callOnLine(kcbComm, kcb400RqstInfo, kcb400RecvInfo, kcb400Send103, kcb400Send100);

                    kcbComm.setRecvObj(oFrame[0]);                              //공통정보부
                    if (kcbComm.getRspnCd().equals("0000")){                    //2018-08-01 (두비스)
                        kcb400RecvInfo.setRecvObj(oFrame[1]);                      //응답정보부
                        setRecvData(kcb400RecvInfo, oFrame[2]);
                    }
                }
            }
            if (kcbComm.getRspnCd().equals("B001")){                             //조회정보 없음은 오류로 보지않음(2018-08-01 (두비스))
                LOGGER.debug("[Kcb 미등록 고객 : [" + resiNo + "]");
            }

            resultVo.setRsltCd("0000"); // 처리결과
            resultVo.setRsltCd("처리완료"); // 처리결과

            return resultVo;

        } catch (Exception e) {
            // 에러 처리
            LOGGER.error("Error >>> " + e.getMessage());

            resultVo.setRsltCd("9999"); // 결과 에러
            resultVo.setRsltCd("Exception : "+ e.getMessage());

            // 에러 내용 KCB 온라인 마스터에 적재
            StKcbOnlnMstrDTO masterMapper = new StKcbOnlnMstrDTO();

            masterMapper.setGramSeq         (gramSeq                        );        // 채번된 KCB용 전문일련번호
            masterMapper.setLoanCnslNo      (loanCnslNo                     );        // 대출상담번호
            masterMapper.setLoanApplNo      (loanApplNo                     );        // 대출신청번호
            masterMapper.setLoanNo          (loanNo                         );        // 대출번호 (존재시 등록)
            masterMapper.setCustNo          (custNo                         );        // 고객번호
            masterMapper.setGramKindCd      (kcbComm.getGramKindCd()        );        // 전문종별코드
            masterMapper.setBsnDivCd        (kcbComm.getBsnDivCd()          );        // 업무구분코드
            masterMapper.setRspnCd          (kcbComm.getRspnCd()            );        // 응답코드
            masterMapper.setKcbLayMngNo     ("9999999"                      );        // KCB 전문 관리번호
            masterMapper.setKcbLaySendTm    (DateUtil.getCurrentBaseDateString());    // KCB 전문 전송시간
            masterMapper.setWricLayMngNo    (kcbComm.getWricLayMngNo()      );        // 회원사 전문 관리번호
            masterMapper.setWricLaySendTm   (kcbComm.getWricLaySendTm()     );        // 회원사 전문전송 시간
            masterMapper.setViewAgreeFg     (kcbComm.getViewAgreeFg()       );        // 조회동의코드
            masterMapper.setCustTpCd        (""                             );        // 개인/법인구분코드
            masterMapper.setResiNo          (""                             );        // 주민등록번호 (필수)
            masterMapper.setCustNm          (""                             );        // 성명
            masterMapper.setReadObjCd       (""                             );        // 조회목적코드 : 요청정보 "01:단순상담" 고정
            //masterMapper.setFrstRegEmpNo    ();        // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
            //masterMapper.setLastProcEmpNo   ();        // 최종_처리_사원_번호
            masterMapper.setFrstRegEmpNo    ("SYSUSER");
            masterMapper.setLastProcEmpNo   ("SYSUSER");

            kcbOnlnMstrMapper.insert(masterMapper);

        }
        return resultVo;
    }

    /**
     * KCB 통신및 KCB 에서 받은 데이터를 이용하여 엔터티 클래스들 데이터 세팅
     * @return a boolean  - 한신정에서 받은 데이터가 엔터티에 잘저장되었는지 여부
     */
    private String[] callOnLine(KCBCommonEntity kcbComm,
            KCB400RqstInfoEntity kcb400RqstInfo, KCB400RecvInfoEntity kcb400RecvInfo,
            KCB400Send103Entity kcb400Send103, KCB400Send100Entity kcb400Send100) throws Exception{

        /** 1. KCB 기본신용정보 공통헤더 셋팅 */
        String timeStamp = DateUtil.getCurrentBaseDateString();   // 오늘 날짜 (14: yyyyMMddHHmmss)
        kcbComm.setWricLaySendTm(GramUtil.fixEndZero(timeStamp,14)); //회원사전문전송시간
        kcbComm.setViewAgreeFg("1");                                      //조회동의코드

        /** 2. KCB 기본신용정보 요청정보부 셋팅 */
        kcb400RqstInfo.setResiNo        (GramUtil.fillSpace (resiNo,13));           // 고객번호(주민번호) 셋팅
        kcb400RqstInfo.setReadObjCd     ("02"                               );      //조회목적코드
        kcb400RqstInfo.setCustNm        (GramUtil.fillPkStringB(resiNm,50));        // 고객명 셋팅
        kcb400RqstInfo.setReadDeptNm    (GramUtil.fillPkStringB(readDeptNm, 20));   //조회지점명
        kcb400RqstInfo.setEmpNo         (GramUtil.fixEndZero(empNo,15));            //담당자ID
        kcb400RqstInfo.setCbCpsReqCnt   (GramUtil.fixEndZero("0",3));               //cps 총건수
        kcb400RqstInfo.setCbCpsReqCnt   (GramUtil.fixEndZero("2",2));               //cps 요청건수
        kcb400RqstInfo.setCbTotCnt      (GramUtil.fixEndZero("0",3));               // cbscore 총건수
        kcb400RqstInfo.setCbReqCnt      (GramUtil.fixEndZero(kcb400Send100.getSend100Cnt(),2));  //cbscore 요청건수

        String strSendData = kcbComm.getSendStr() + kcb400RqstInfo.getSendStr()
                           + kcb400Send103.getSendStr103() + kcb400Send100.getSendStr100();
        byte[] bSend = strSendData.getBytes();
        int nCnt = bSend.length;
        String strTotLength = Integer.toString(nCnt);   // 송수신전문길이
        strSendData = OnLineUtil.fixEndZero(strTotLength, 4) + strSendData; // 송수신전문길이(4) + 요청전문

        // TODO :  AnyLink 대외계 서비스 호출 부 Start
        String serverMode = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
        AnylinkSender anylinkSender = new AnylinkSender(serverMode);
        byte[] msg      = anylinkSender.makeHeader("KCI", "KCJ", "0200", "560", strSendData);   // TODO : 재설정 필요
        byte[] rtnMsg   = anylinkSender.jmapperCall(msg);
        String sData    = new String(rtnMsg);

        // test data
        sData = "00001234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890";
        // TODO AnyLink 대외계 서비스 호출 부 End

        int totalByte = 0;
        String[] sResponseData = new String[3];
        sResponseData[0] = new String(sData.getBytes(), totalByte+=4, 130); //전문길이 10Byte 제외

        //로컬헤더를 제외한 실제 기관에서 보낸 전문을 하나로 만든다
        kcbComm.setRecvObj(sResponseData[0]); //공통정보부

        if (kcbComm.getRspnCd().equals("0000")) {
            sResponseData[1] = new String(sData.getBytes(), totalByte+=130, 145);
            sResponseData[2] = new String(sData.getBytes(), totalByte+=145, sData.getBytes().length-totalByte);
        }

        return sResponseData;
    }

    /**
     * KCB 에서 받은 데이터를 이용하여 엔터티 클래스들 데이터 세팅
     * @return a boolean  - 한신정에서 받은 데이터가 엔터티에 잘저장되었는지 여부
     */
    private boolean setRecvData(KCB400RecvInfoEntity kcb400RecvInfo, String oFrame) throws Exception{

        LOGGER.debug("_setRecvData_400");
        LOGGER.debug("### 개별응답부");
        LOGGER.debug(oFrame);

        int totlByte = 0;

        if (oFrame.length() <= 1){
            LOGGER.debug( "setRecvData()  : KCB 리턴 바이트가 너무작음");
            return false;
        }

        try {

            int rspnCnt             = this.parseInt(kcb400RecvInfo.getReRspnCnt());

            int scoreTotRcvCnt      = this.parseInt(kcb400RecvInfo.getScoreTotRcvCnt());       //SEG100 총수신건수
            int scoreRcvCnt         = this.parseInt(kcb400RecvInfo.getScoreRcvCnt());          //SEG100 응답건수

            int cpsTotRcvCnt        = this.parseInt(kcb400RecvInfo.getCpsTotRcvCnt());         //SEG103 총수신건수
            int cpsRcvCnt           = this.parseInt(kcb400RecvInfo.getCpsRcvCnt());            //SEG103 응답건수

            int seq = 0;
            byte[] convData = oFrame.getBytes();

            // CB Score (segment 100)
            for(int i=0; i < scoreRcvCnt;i++){
                LOGGER.debug( "SEG 100 시작");
                seq = scoreTotRcvCnt - scoreRcvCnt + i + 1; // seq 필요시 사용
                KCB100SegEntity kcb100 = new KCB100SegEntity();
                kcb100.setRecvObj(new String(convData, totlByte, LENG_100));    // 140
                insertSeg100(gramSeq, kcb400RecvInfo.getCustNm(), kcb100);      // seq 필요할지 판단
                totlByte += LENG_100;
            }

            // CPS (segment 103)
            for(int i=0;i<cpsRcvCnt;i++){
                LOGGER.debug( "SEG 103 시작");

                seq = cpsTotRcvCnt - cpsRcvCnt + i + 1; // SEQ
                KCB103SegEntity  kcb103 = new KCB103SegEntity();
                kcb103.setRecvObj(new String(convData, totlByte, LENG_103));    // 21
                insertSeg103(gramSeq, kcb400RecvInfo.getCustNm(), kcb103);
                totlByte += LENG_103;
            }


        } catch (Exception e) {
            e.printStackTrace();
            LOGGER.debug( "KCB 자료처리시 오류 : \n" + e.toString());
            throw new Exception("KCB 자료처리시 오류 \n" + e.toString());
        } finally {

        }
        return true;
    }

    /**
     * <pre>
     * 메소드명      : KCB 온라인 마스터 등록
     * 작성일자      : 2023. 4. .
     * 작성자(author): 70278 younghwe.Kim
     * 설명          : 을(를) 조회 한다.
     * 메소드인수1   : todo1 입력
     * 메소드리턴값  : todo1 출력
     * 예외처리      : Exception
     * </pre>
     */
    private void insertKCBOnlnMaser(KCBCommonEntity kcbComm, KCB400RqstInfoEntity kcb400RqstInfo, KCB400RecvInfoEntity kcb400RecvInfo, String gramSeq) throws Exception {

        // 온라인 마스터 등록
        StKcbOnlnMstrDTO masterMapper = new StKcbOnlnMstrDTO();

        masterMapper.setGramSeq         (gramSeq                        );        // 채번된 KCB용 전문일련번호
        masterMapper.setLoanCnslNo      (loanCnslNo                     );        // 대출상담번호
        masterMapper.setLoanApplNo      (loanApplNo                     );        // 대출신청번호
        masterMapper.setLoanNo          (loanNo                         );        // 대출번호 (존재시 등록)
        masterMapper.setCustNo          (custNo                         );        // 고객번호
        masterMapper.setGramKindCd      (kcbComm.getGramKindCd()        );        // 전문종별코드
        masterMapper.setBsnDivCd        (kcbComm.getBsnDivCd()          );        // 업무구분코드
        masterMapper.setRspnCd          (kcbComm.getRspnCd()            );        // 응답코드
        masterMapper.setKcbLayMngNo     (kcbComm.getKcbLayMngNo()       );        // KCB 전문 관리번호
        masterMapper.setKcbLaySendTm    (kcbComm.getKcbLaySendTm()      );        // KCB 전문 전송시간
        masterMapper.setWricLayMngNo    (kcbComm.getWricLayMngNo()      );        // 회원사 전문 관리번호
        masterMapper.setWricLaySendTm   (kcbComm.getWricLaySendTm()     );        // 회원사 전문전송 시간
        masterMapper.setViewAgreeFg     (kcbComm.getViewAgreeFg()       );        // 조회동의코드
        masterMapper.setCustTpCd        (kcb400RecvInfo.getCustTpCd()   );        // 개인/법인구분코드
        masterMapper.setResiNo          (kcb400RecvInfo.getResiNo()     );        // 주민등록번호 (필수)
        masterMapper.setCustNm          (kcb400RecvInfo.getCustNm()     );        // 성명
        masterMapper.setReadObjCd       (kcb400RqstInfo.getReadObjCd()  );        // 조회목적코드 : 요청정보 "01:단순상담" 고정
        //masterMapper.setFrstRegEmpNo    ();        // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
        //masterMapper.setLastProcEmpNo   ();        // 최종_처리_사원_번호
        masterMapper.setFrstRegEmpNo    ("SYSUSER");
        masterMapper.setLastProcEmpNo   ("SYSUSER");

        kcbOnlnMstrMapper.insert(masterMapper);
    }

    // KCB 세그먼트 100 등록
    private void insertSeg100(String gramSeq, String custName, KCB100SegEntity kcb100) throws Exception {

        StKcbOnlnSeg100DTO kcbSeg100DTO = new StKcbOnlnSeg100DTO();

        kcbSeg100DTO.setGramSeq         (gramSeq                        );      // 전문일련번호
        kcbSeg100DTO.setScorDivCd       (kcb100.getScorDivCd()          );      // 스코어(Score)_구분_코드
        kcbSeg100DTO.setStndDt          (kcb100.getStndDt()             );      // 기준_일자
        kcbSeg100DTO.setErrCd           (kcb100.getErrCd()              );      // 에러 코드
        kcbSeg100DTO.setAplyExclRsnCd1  (kcb100.getAplyExclRsnCd1()     );      // 적용_제외_사유_코드1
        kcbSeg100DTO.setAplyExclRsnCd2  (kcb100.getAplyExclRsnCd2()     );      // 적용_제외_사유_코드2
        kcbSeg100DTO.setAplyExclRsnCd3  (kcb100.getAplyExclRsnCd3()     );      // 적용_제외_사유_코드3
        kcbSeg100DTO.setCrdtAvsco       (parseInt(kcb100.getCrdtAvsco()));      // 신용_평점
        kcbSeg100DTO.setCrdtDgre        (parseInt(kcb100.getCrdtDgre()) );      // 신용_등급
        kcbSeg100DTO.setAllRank         (parseInt(kcb100.getAllRank())  );      // 전체_순위
        kcbSeg100DTO.setRelVal1         (kcb100.getRelVal1()            );      // 관련값1
        kcbSeg100DTO.setRelVal2         (kcb100.getRelVal2()            );      // 관련값2
        kcbSeg100DTO.setRelVal3         (kcb100.getRelVal3()            );      // 관련값3
        kcbSeg100DTO.setRelVal4         (kcb100.getRelVal4()            );      // 관련값4
        kcbSeg100DTO.setRelVal5         (kcb100.getRelVal5()            );      // 관련값5
        kcbSeg100DTO.setRelVal6         (kcb100.getRelVal6()            );      // 관련값6
        kcbSeg100DTO.setRsnCd1          (kcb100.getRsnCd1()             );      // 사유코드1
        kcbSeg100DTO.setRsnCd2          (kcb100.getRsnCd2()             );      // 사유코드2
        kcbSeg100DTO.setRsnCd3          (kcb100.getRsnCd3()             );      // 사유코드3
        kcbSeg100DTO.setRsnCd4          (kcb100.getRsnCd4()             );      // 사유코드4
        kcbSeg100DTO.setRsnCd5          (kcb100.getRsnCd5()             );      // 사유코드5
        kcbSeg100DTO.setRsnCd6          (kcb100.getRsnCd6()             );      // 사유코드6

        kcbSeg100DTO.setFrstRegEmpNo("SYSUSER");    // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
        kcbSeg100DTO.setLastProcEmpNo("SYSUSER");


        kcbSeg100Mapper.insert(kcbSeg100DTO);
    }

    // KCB 세그먼트 103 등록
    private void insertSeg103(String gramSeq, String custName, KCB103SegEntity kcb103) throws Exception {

        StKcbOnlnSeg103DTO kcbSeg103DTO = new StKcbOnlnSeg103DTO();

        kcbSeg103DTO.setGramSeq     (gramSeq                );
        kcbSeg103DTO.setProfileCd   (kcb103.getProfileCd()  );
        kcbSeg103DTO.setProfileVal  (kcb103.getProfileVal() );

        kcbSeg103DTO.setFrstRegEmpNo("SYSUSER");    // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
        kcbSeg103DTO.setLastProcEmpNo("SYSUSER");

        kcbSeg103Mapper.insert(kcbSeg103DTO);
    }


    // TODO : 'L00'을 확인한후 문제 없으면 직접 parseing하거나 공통 UTIL의 함수를(없으면 만들어서) 이용하는것 고려
    //String 입력값이 "" 인경우는 0을 반환한다.
    public int parseInt(String value) {
        int rtn = 0;

        if(value != null && !"L00".equals(value)) {
            if(!"".equals(value)) {
                rtn = Integer.parseInt(value);
            }
        }
        return rtn;
    }


}
