package hanalife.t.kf.on.service.impl;

import java.util.ArrayList;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.StKfbLoanDsrSpecHistMapper;
import hanalife.c.co.mapper.StKfbLoanDsrSpecMapper;
import hanalife.c.co.mapper.StKfbOnlnMstrMapper;
import hanalife.c.co.mapper.dto.StKfbLoanDsrSpecDTO;
import hanalife.c.co.mapper.dto.StKfbLoanDsrSpecHistDTO;
import hanalife.c.co.mapper.dto.StKfbOnlnMstrDTO;
import hanalife.framework.comm.util.PropertiesHandler;
import hanalife.t.comm.service.IF_CommonService;
import hanalife.t.kf.on.service.TKFON003Service;
import hanalife.t.kf.on.vo.KFB0200236Entity;
import hanalife.t.kf.on.vo.KFBCommonEntity;
import hanalife.t.kf.on.vo.KFBOnlnVo;
import hanalife.util.anylink.AnylinkSender;
import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : TKFON003ServiceImpl
 * 클래스설명   : [신정원] 대출/단기카드대출 실질DSR 상세 정보 (0200/236) Service Implements
 * 작성일자     : 2023. 5. 5.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 5.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * 서비스구성 : KFB_0200236_Call : [신정원] 대출/단기카드대출 실질DSR 상세 정보 (0200/236)
 * </pre>
 */
@Service("TKFON003Service")
public class TKFON003ServiceImpl implements TKFON003Service {

    private static final Logger LOGGER = LoggerFactory.getLogger(TKFON003ServiceImpl.class);

    @Autowired
    private StKfbOnlnMstrMapper kfbOnlnMstrMapper;                  // KFB 온라인 마스터

    private StKfbLoanDsrSpecMapper kfbLoanDsrSpecMapper;            // ST_신정원_대출DSR상세정보
    private StKfbLoanDsrSpecHistMapper kfbLoanDsrSpecHistMapper;    // ST_신정원_대출DSR상세정보이력(회보)

    @Resource(name = "IF_CommonService")
    private IF_CommonService if_CommonService;

    private String gramSeq = "";
    private String resiNo = "";
    private String resiNm = "";
    private String deptNm = "";
    private String empNo = "";

    private String loanCnslNo;           // 대출상담번호
    private String loanApplNo;           // 대출신청번호
    private String loanNo;               // 대출번호
    private String custNo;               // 고객번호
    private String readDeptNm;           // 조회지점명

    /**
     *<pre>
     * 메소드명      : KFB_0200236_Call : 대출/단기카드대출 실질DSR 상세 정보 (0200/236)
     * 작성일자      : 2023. 5. 5.
     * 작성자(author): 70278 / KiHwan.Park
     * 설명          : 대출/단기카드대출 실질DSR 상세 정보
     * 메소드인수    : KFBOnlnVo
     * 메소드리턴값  : KFBOnlnVo
     * 예외처리      : Exception
     *</pre>
     */
    @Override
    public KFBOnlnVo KFB_0200236_Call(KFBOnlnVo inVo) throws Exception {

        KFBOnlnVo resultVo = new KFBOnlnVo();
        resultVo.setRsltCd(MsgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(MsgEnum.SUCCESS.getErrorCn());

        // 입력값 체크
        // 1. 주민등록번호 체크
        // 2. 대출상담번호 체크

        resiNo ="";             // 주민등록번호 (입력치) TODO : 확인
        resiNm ="";             // 고객명 (입력치) TODO : 확인
        deptNm ="";             // TODO : 설정치 확인
        empNo ="";              //  TODO : 설정치 확인

        this.resiNo         = inVo.getResiNo();         // 주민등록번호
        this.resiNm         = inVo.getResiNm();         // 고객명
        this.loanCnslNo     = inVo.getLoanCnslNo();     // 대출상담번호
        this.loanApplNo     = inVo.getLoanApplNo();     // 대출신청번호
        this.loanNo         = inVo.getLoanNo();         // 대출번호
        this.custNo         = inVo.getCustNo();         // 고객번호
        //this.readDeptNm     = inVo.getReadDeptNm();     // 조회지점명
        //this.empNo          = inVo.getEmpNo();          // 담당자 ID


        /** 1. 공통정보부 선언 */
        KFBCommonEntity kfbComm = new KFBCommonEntity();

        // 공통정보부 설정 TODO

        /** 2. 조회정보부 선언 */
        KFB0200236Entity kfb236= new KFB0200236Entity();

        try {

            // KFB 전문일련번호 채번 : YYYYMMDD+SEQ_NO(7자리)
            gramSeq = if_CommonService.getKFBOnlnSeq();

            /** 1. KFB 송신 후 수신결과 내용을 가져옴 */
            String[] oFrame = callOnLine(kfbComm, kfb236);
            kfbComm.setRecvObj(oFrame[0]);  // 공통부

            LOGGER.debug("[KFB 전문응답코드 [" + resiNo + "]["+kfbComm.getRspnCd()+"]");

            if (kfbComm.getRspnCd().equals("000") || kfbComm.getRspnCd().equals("009")){
                kfb236.setRecvObj(oFrame[1]);

                // 온라인 마스터 등록 (마스터는 1회만 등록)
                insertKFBOnlnMaser(kfbComm, kfb236, gramSeq);
                // ST_신정원_대출DSR상세정보 등록
                insertLoanDsrSpec(kfb236, gramSeq);
                // 회보등록
                setRecvData(kfb236, 0);

                // 재호출
                for (int i=0; i<10 && (kfb236.getLoanInfoMore().equals("1") && kfbComm.getRspnCd().equals("000")); i++){
                    kfbComm.setGramKindCd("0300");
                    kfbComm.setSnrFg("B");
                    kfbComm.setRspnCd("   ");

                    oFrame = callOnLine(kfbComm, kfb236);
                    kfbComm.setRecvObj(oFrame[0]);  // 공통부

                    if (kfbComm.getRspnCd().equals("000")){
                        kfb236.setRecvObj(oFrame[1]);
                        // 회보등록
                        setRecvData(kfb236, 0);
                    }
                }
            }
        } catch (Exception e) {
            // 에러 처리
            LOGGER.error("Error >>> " + e.getMessage());

            resultVo.setRsltCd("9999"); // 결과 에러 TODO : 에러 메시지 정의 필요 constants
            resultVo.setRsltCd("Exception : "+ e.getMessage());

            // 에러 내용 KFB 온라인 마스터에 적재
            StKfbOnlnMstrDTO masterMapper = new StKfbOnlnMstrDTO();

            masterMapper.setGramSeq         (gramSeq                    );      // 채번된 KFB용 전문일련번호
            masterMapper.setLoanCnslNo      (loanCnslNo                 );      // 대출상담번호
            masterMapper.setLoanApplNo      (loanApplNo                 );      // 대출신청번호
            masterMapper.setLoanNo          (loanNo                     );      // 대출번호 (존재시 등록)
            masterMapper.setCustNo          (custNo                     );      // 고객번호

            masterMapper.setGramKindCd      (kfbComm.getGramKindCd()    );      // 전문종별코드
            masterMapper.setBsnDivCd        (kfbComm.getBsnDivCd()      );      // 업무구분코드
            masterMapper.setRspnCd          ("9999"                     );      // 응답코드 (에러 설정)
            masterMapper.setOrgMngNo        (kfbComm.getOrgMngNo()      );      // 금융기관전문관리번호
            masterMapper.setOrgSndTm        (kfbComm.getOrgSndTm()      );      // 금융기관전문전송시간
            masterMapper.setUnionMngNo      (kfbComm.getUnionMngNo()    );      // 신용정보원전문관리번호
            masterMapper.setUnionSndTm      (kfbComm.getUnionSndTm()    );      // 신용정보원전문전송시간
            masterMapper.setResiNo          (""                         );      // 주민등록번호 (IF/Table 변수명 다름)
            masterMapper.setResiNoDiv       (""                         );      // 주민등록번호 구분
            masterMapper.setDataUseDiv      (""                         );      // 자료이용목적
            masterMapper.setInqAgrFg        (""                         );      // 조회 동의 여부

            masterMapper.setFrstRegEmpNo    ("SYSUSER"                  );      // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
            masterMapper.setLastProcEmpNo   ("SYSUSER"                  );      // 최종_처리_사원_번호

            kfbOnlnMstrMapper.insert(masterMapper);
        }

        return resultVo;
    }

    /**
     * KFB 통신및 KFB 에서 받은 데이터를 이용하여 엔터티 클래스들 데이터 세팅
     * @return a boolean  - 한신정에서 받은 데이터가 엔터티에 잘저장되었는지 여부
     */
    private String[] callOnLine(KFBCommonEntity kfbComm, KFB0200236Entity kfb236) throws Exception{

        String[] oFrame = new String[2];
        try {

        } catch (Exception e) {
            throw new Exception("KFB0200310Session callOnLine Exception \n" + e.toString());
        }


        kfb236.setReason("04");     // 자료이용목적

        String strSendData =  kfbComm.getSendStr()  // 공통정보부
                                        + kfb236.getSendStr() ;  // 정보부
        LOGGER.debug("KFB_CHK_BF_GRAM[0200_236] : [" + strSendData + "]");

        //String strGramLen = StringUtils.fillPkNumber(""+(XlinkUtil.getByteLen(strSendGram_bf) -9),4);
        int intGramLen = chkByteLen(strSendData.substring(9)) ;     // 전체길이 -9 (txcode 길이)
        String strGramLen = GramUtil.fixEndZero(""+intGramLen,4);

        String sRequestData = strSendData.substring(0,9) + strGramLen + strSendData.substring(9);
        LOGGER.debug("KFB_CHK_AF_GRAM[0200_236] : [" + sRequestData + "]");

        // AnyLink 호출
        // TODO :  AnyLink 대외계 서비스 호출 부 Start
        String serverMode = PropertiesHandler.getInstance().getProperty("global.current.access.SERVER");
        AnylinkSender anylinkSender = new AnylinkSender(serverMode);
        byte[] rtnMsg = anylinkSender.jmapperCall(strSendData.getBytes());
        String strRspnData = new String(rtnMsg);

        byte[] convData = strRspnData.getBytes();
        oFrame[0] = new String(convData, 0, 94);                        // 은행연합회 공통해더(94)
        oFrame[1] = new String(convData, 94,convData.length - 94);      // 대출조회 정보부

        return oFrame;
    }

    /**
     * KFB 에서 받은 데이터를 이용하여 엔터티 클래스들 데이터 세팅
     * @return a boolean  - 한신정에서 받은 데이터가 엔터티에 잘저장되었는지 여부
     */
    @SuppressWarnings("rawtypes")
    private boolean setRecvData(KFB0200236Entity kfb236, int seq) throws Exception{

        LOGGER.debug("_setRecvData_");
        LOGGER.debug("### 개별응답부");

        try {

            // ST_신정원_개인회생신청정보이력(회보)
            ArrayList list = (ArrayList)kfb236.getDsrInfoArry();
            for(int i=0; i<list.size(); i++){
                String[] infoRept = (String[])list.get(i);
                int subSeq = i+seq*20;  //회보 순번(0 to 20 Times)

                insertLoanDsrSpecHist(infoRept, subSeq);
            }
        } catch (Exception e) {
            e.printStackTrace();
            LOGGER.debug( "KFB 자료처리시 오류 : \n" + e.toString());
            throw new Exception("KFB 자료처리시 오류 \n" + e.toString());
        } finally {

        }
        return true;
    }

    /**
     * <pre>
     * 메소드명      : KFB 신정원 온라인 마스터 등록
     * 작성일자      : 2023. 5. 5.
     * 작성자(author): 70278 KiHwan.Park
     * 설명          : 을(를) 조회 한다.
     * 메소드인수1   : todo1 입력
     * 메소드리턴값  : todo1 출력
     * 예외처리      : Exception
     * </pre>
     */
    private void insertKFBOnlnMaser(KFBCommonEntity kfbComm, KFB0200236Entity kfb236, String gramSeq) throws Exception {

        // 온라인 마스터 등록
        StKfbOnlnMstrDTO masterMapper = new StKfbOnlnMstrDTO();

        masterMapper.setGramSeq     (gramSeq                    );      // 채번된 KFB용 전문일련번호
        masterMapper.setLoanCnslNo  (loanCnslNo                 );      // 대출상담번호
        masterMapper.setLoanApplNo  (loanApplNo                 );      // 대출신청번호
        masterMapper.setLoanNo      (loanNo                     );      // 대출번호 (존재시 등록)
        masterMapper.setCustNo      (custNo                     );      // 고객번호
        masterMapper.setGramKindCd  (kfbComm.getGramKindCd()    );      // 전문종별코드
        masterMapper.setBsnDivCd    (kfbComm.getBsnDivCd()      );      // 업무구분코드
        masterMapper.setRspnCd      (kfbComm.getRspnCd()        );      // 응답코드
        masterMapper.setOrgMngNo    (kfbComm.getOrgMngNo()      );      // 금융기관전문관리번호
        masterMapper.setOrgSndTm    (kfbComm.getOrgSndTm()      );      // 금융기관전문전송시간
        masterMapper.setUnionMngNo  (kfbComm.getUnionMngNo()    );      // 신용정보원전문관리번호
        masterMapper.setUnionSndTm  (kfbComm.getUnionSndTm()    );      // 신용정보원전문전송시간
        masterMapper.setResiNo      (kfb236.getRegNo()          );      // 주민등록번호 (IF/Table 변수명 다름)
        masterMapper.setResiNoDiv   (""                         );      // 주민등록번호 구분
        masterMapper.setDataUseDiv  (kfb236.getReason()         );      // 자료이용목적
        masterMapper.setInqAgrFg    (kfb236.getViewAgreeFg()    );      // 조회 동의 여부

        //masterMapper.setFrstRegEmpNo    ();        // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
        //masterMapper.setLastProcEmpNo   ();        // 최종_처리_사원_번호
        masterMapper.setFrstRegEmpNo    ("SYSUSER");
        masterMapper.setLastProcEmpNo   ("SYSUSER");

        kfbOnlnMstrMapper.insert(masterMapper);
    }

    // 신정원_개인회생신청정보 등록
    private void insertLoanDsrSpec(KFB0200236Entity kfb236, String gramSeq) throws Exception {

        StKfbLoanDsrSpecDTO dsrSpecDTO = new StKfbLoanDsrSpecDTO();

        dsrSpecDTO.setGramSeq               (gramSeq                                );  // 전문일련번호
        dsrSpecDTO.setResiNo                (kfb236.getRegNo()                      );  // 주민등록번호
        dsrSpecDTO.setUseObjCd              (kfb236.getReason()                     );  // 자료이용목적
        dsrSpecDTO.setInqAgrYn              (kfb236.getViewAgreeFg()                );  // 조회 동의 여부
        dsrSpecDTO.setDsrStndDt             (kfb236.getDsrStndDt()                  );  // DSR 산정만기 기준일자
        dsrSpecDTO.setMtalNm                (kfb236.getComName()                    );  // 상호(기업체명)
        dsrSpecDTO.setCustNm                (kfb236.getName()                       );  // 성명(대표자)
                                                                                        //upCode : 직업코드 미사용
        dsrSpecDTO.setBzitDivCd             (kfb236.getJCode()                      );  // 업종 코드
        dsrSpecDTO.setLoan100MillionOverDiv (kfb236.getLoan100MillionOverDiv()      );  // 신용대출 1억초과 구분
        dsrSpecDTO.setBrwrUnitDsrAplyDiv    (kfb236.getBrwrUnitDsrAplyDiv()         );  // 차주단위 DSR적용 신용대출 차주 구분
        // unUse1 미사용
        dsrSpecDTO.setLastUpdtDt            (kfb236.getLastUpdateDt()               );  // 대출정보 Update 최근 일자
        dsrSpecDTO.setInfoMoreFg            (kfb236.getLoanInfoMore()               );  // 대출･단기카드대출 정보 More
        dsrSpecDTO.setLoanTotCnt            (parseInt(kfb236.getLoanInfoTotCnt())   );  // 대출･단기카드대출 정보 총 건수
        dsrSpecDTO.setLoanHistCnt           (parseInt(kfb236.getLoanInfoReptCnt())  );  // 대출･단기카드대출 정보 회보 건수

        dsrSpecDTO.setFrstRegEmpNo("SYSUSER");    // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
        dsrSpecDTO.setLastProcEmpNo("SYSUSER");

        kfbLoanDsrSpecMapper.insert(dsrSpecDTO);
    }

    // 회보등록
    private void insertLoanDsrSpecHist(String[] item, int subSeq) throws Exception {

        StKfbLoanDsrSpecHistDTO histDTO = new StKfbLoanDsrSpecHistDTO();

        histDTO.setGramSeq              (gramSeq    );  // 전문일련번호
        histDTO.setSubSeq               (subSeq     );  // 서브 일련번호
        histDTO.setRsnCd                (item[0]    );  // 등록 코드
        histDTO.setShopCd               (item[1]    );  // 점포 코드
        histDTO.setOccrDt               (item[2]    );  // 발생일
        histDTO.setLoanAmt              (item[3]    );  // 등록 금액 (단위 : 천원)
        histDTO.setChngDt               (item[4]    );  // 변동일
        histDTO.setAcntNo               (item[5]    );  // 계좌번호
        histDTO.setLoanDivCd            (item[6]    );  // 대출(담보)종류 구분
        histDTO.setDsrEstmDivCd         (item[7]    );  // 산정_미산정코드
        histDTO.setDsrChngDt            (item[8]    );  // 금리 등 정보 변동일
        histDTO.setDsrRgltObjMrtgDivCd  (item[9]    );  // DSR 규제대상 주택담보대출 구분
        histDTO.setMrtgSpecKindCd       (item[10]   );  // 담보 세부 종류(코드)
        histDTO.setYrRepayAmt           (parseInt(item[11]) );  // [신정원 산정]연간 상환 예정액
        histDTO.setYrRepayAmtStr        (parseInt(item[12]) );  // [신정원 산정]연간 상환 예정액(스트레스 금리 가산)
        histDTO.setLnkProjDiv           (item[13]   );  // 연계대출 및 집단대출 구분

        histDTO.setFrstRegEmpNo("SYSUSER");     // 최초_등록_사원_번호   // TODO: 사원번호 확인 필요, 화면호출은 사원번호 없으면 sysuser 설정 필요할 듯 일단 SYSUSER설정
        histDTO.setLastProcEmpNo("SYSUSER");    // 최종_처리_사원번호
        kfbLoanDsrSpecHistMapper.insert(histDTO);
    }

    // TODO : 'L00'을 확인한후 문제 없으면 직접 parseing하거나 공통 UTIL의 함수를(없으면 만들어서) 이용하는것 고려
    //String 입력값이 "" 인경우는 0을 반환한다.
    public int parseInt(String value) {
        int rtn = 0;

        if(value != null && !"L00".equals(value)) {
            if(!"".equals(value)) {
                rtn = Integer.parseInt(value);
            }
        }
        return rtn;
    }
    private int chkByteLen(String inStr) {
        byte[] inStrBytes = inStr.getBytes();
        int inLen = inStrBytes.length;
        return inLen ;
    }

}
