package hanalife.t.kf.on.vo;

import java.util.ArrayList;
import java.util.List;

import hanalife.util.gram.GramUtil;

/**
 * <pre>
 * 프로젝트명    : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : KFB0200236Entity
 * 클래스설명    : [신정원] 대출/단기카드대출 실질DSR 상세 정보 (0200/236) 용 Entity (VO)
 * 작성일자     : 2023. 5. 02.
 * 작성자명     : 70278 / KiHwan.Park / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 5. 02.][70278 ][최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
@SuppressWarnings("rawtypes")
public class KFB0200236Entity {

    private String regNo;                   // 주주(사업자)등록번호
    private String reason;                  // 자료이용목적
    private String viewAgreeFg;             // 조회 동의 여부
    private String dsrStndDt;               // DSR 산정만기 기준일자 (DSR 기준일자)
    private String comName;                 // 상호(기업체명)
    private String name;                    // 성명(대표자)
    private String jCode;                   // 직업 코드(미사용)
    private String upCode;                  // 업종 코드
    private String loan100MillionOverDiv;   // 신용대출 1억초과 구분
    private String brwrUnitDsrAplyDiv;      // 차주단위 DSR적용 신용대출 차주 구분
    private String unUse1;                  // 미사용
    private String lastUpdateDt;            // 대출정보 Update 최근 일자
    private String loanInfoMore;            // 대출･단기카드대출 정보 More
    private String loanInfoTotCnt;          // 대출･단기카드대출 정보 총 건수
    private String loanInfoReptCnt;         // 대출.현금서비스 정보 회보 건수
    private List   dsrInfoArry;             // 대출･단기카드대출 정보 회보 사항 (1 to 20 Times) → (120 × 20 = 2,400)



    // 생성자
    public KFB0200236Entity() {
        setRegNo                  (GramUtil.fixEndZero("",13 ));     // 주민등록번호 (13)
        setReason                 (GramUtil.fixEndZero("", 1 ));     // 주민등록번호 구분 (1)
        setViewAgreeFg            (GramUtil.fixEndZero("", 2 ));     // 자료이용목적 (2)
        setDsrStndDt              (GramUtil.fixEndZero("", 1 ));     // 조회 동의 여부 (1)
        setComName                (GramUtil.fixEndZero("",20 ));     // 성명 (20)
        setName                   (GramUtil.fixEndZero("", 1 ));     // 등록코드구분 (1)
        setJCode                  (GramUtil.fixEndZero("", 8 ));     // 발생일자 (8)
        setUpCode                 (GramUtil.fixEndZero("", 7 ));     // 법원코드 (7)
        setLoan100MillionOverDiv  (GramUtil.fixEndZero("",20 ));     // 사건번호 (20)
        setBrwrUnitDsrAplyDiv     (GramUtil.fixEndZero("", 8 ));     // 최신 업데이트 일자 (8)
        setUnUse1                 (GramUtil.fixEndZero("", 1 ));     // 개인회생 신청 등 정보 More (1)
        setLastUpdateDt           (GramUtil.fixEndZero("", 5 ));     // 개인회생 신청 등 정보 총건수 (4)
        setLoanInfoMore           (GramUtil.fixEndZero("", 2 ));     // 개인회생 신청 등 정보 회보 건수 (2)
        setLoanInfoTotCnt         (GramUtil.fixEndZero("", 2 ));     // 개인회생 신청 등 정보 회보 건수 (2)
        setLoanInfoReptCnt        (GramUtil.fixEndZero("", 2 ));     // 개인회생 신청 등 정보 회보 건수 (2)
        setDsrInfoArry            (""                              );     // 대출･단기카드대출 정보 회보 사항 (1 to 20 Times) → (120 × 20 = 2,400)
    }

    public String getRegNo                        () { return this.regNo                  ; }
    public String getReason                       () { return this.reason                 ; }
    public String getViewAgreeFg                  () { return this.viewAgreeFg            ; }
    public String getDsrStndDt                    () { return this.dsrStndDt              ; }
    public String getComName                      () { return this.comName                ; }
    public String getName                         () { return this.name                   ; }
    public String getJCode                        () { return this.jCode                  ; }
    public String getUpCode                       () { return this.upCode                 ; }
    public String getLoan100MillionOverDiv        () { return this.loan100MillionOverDiv  ; }
    public String getBrwrUnitDsrAplyDiv           () { return this.brwrUnitDsrAplyDiv     ; }
    public String getUnUse1                       () { return this.unUse1                 ; }
    public String getLastUpdateDt                 () { return this.lastUpdateDt           ; }
    public String getLoanInfoMore                 () { return this.loanInfoMore           ; }
    public String getLoanInfoTotCnt               () { return this.loanInfoTotCnt         ; }
    public String getLoanInfoReptCnt              () { return this.loanInfoReptCnt        ; }
    public List   getDsrInfoArry                  () { return this.dsrInfoArry            ; }

    public void setRegNo                ( String regNo                ){ this.regNo                  = regNo                ; }
    public void setReason               ( String reason               ){ this.reason                 = reason               ; }
    public void setViewAgreeFg          ( String viewAgreeFg          ){ this.viewAgreeFg            = viewAgreeFg          ; }
    public void setDsrStndDt            ( String dsrStndDt            ){ this.dsrStndDt              = dsrStndDt            ; }
    public void setComName              ( String comName              ){ this.comName                = comName              ; }
    public void setName                 ( String name                 ){ this.name                   = name                 ; }
    public void setJCode                ( String jCode                ){ this.jCode                  = jCode                ; }
    public void setUpCode               ( String upCode               ){ this.upCode                 = upCode               ; }
    public void setLoan100MillionOverDiv( String loan100MillionOverDiv){ this.loan100MillionOverDiv  = loan100MillionOverDiv; }
    public void setBrwrUnitDsrAplyDiv   ( String brwrUnitDsrAplyDiv   ){ this.brwrUnitDsrAplyDiv     = brwrUnitDsrAplyDiv   ; }
    public void setUnUse1               ( String unUse1               ){ this.unUse1                 = unUse1               ; }
    public void setLastUpdateDt         ( String lastUpdateDt         ){ this.lastUpdateDt           = lastUpdateDt         ; }
    public void setLoanInfoMore         ( String loanInfoMore         ){ this.loanInfoMore           = loanInfoMore         ; }
    public void setLoanInfoTotCnt       ( String loanInfoTotCnt       ){ this.loanInfoTotCnt         = loanInfoTotCnt       ; }
    public void setLoanInfoReptCnt      ( String loanInfoReptCnt      ){ this.loanInfoReptCnt        = loanInfoReptCnt      ; }
    // 대출･단기카드대출 정보 회보 사항 (1 to 20 Times) → (120 × 20 = 2,400)
    public void setDsrInfoArry(String data){
        dsrInfoArry = new ArrayList();

        byte[] convData = data.getBytes();
        int dalyCnt = Integer.parseInt(getLoanInfoReptCnt());
        int totlByte = -1;

        for (int i=0; i<dalyCnt; i++){
            String[] dsrData = new String[17];
            dsrData[0]  = new String(convData,totlByte+= 1 ,  1);       // 등록 코드  (4)
            dsrData[1]  = new String(convData,totlByte+= 1 ,  7);       // 점포 코드  (7)
            dsrData[2]  = new String(convData,totlByte+= 7 ,  8);       // 발생일  (8)
            dsrData[3]  = new String(convData,totlByte+= 8 , 10);       // 대출 금액 (단위 : 천원)  (10)
            dsrData[4]  = new String(convData,totlByte+= 10,  8);       // 변동일  (8)
            dsrData[5]  = new String(convData,totlByte+= 10, 20);       // 계좌번호 (20)
            dsrData[6]  = new String(convData,totlByte+= 2 ,  3);       // 대출(담보)종류 구분 (3)
            dsrData[7]  = new String(convData,totlByte+= 3 ,  2);       // 산정미산정 코드 (2)
            dsrData[8]  = new String(convData,totlByte+= 2 ,  8);       // 금리 등 정보 변동일  (8)
            dsrData[9]  = new String(convData,totlByte+= 8 , 10);       // 미사용  (10)
            dsrData[10] = new String(convData,totlByte+= 10,  2);       // DSR 규제대상 주택담보대출 구분 (2)
            dsrData[11] = new String(convData,totlByte+= 2 ,  2);       // 담보 세부 종류(코드) (2)
            dsrData[12] = new String(convData,totlByte+= 2 ,  7);       // 미사용  (7)
            dsrData[13] = new String(convData,totlByte+= 7 , 10);       // [신정원 산정]선진화방안에 따른연간 상환 예정액  (10)
            dsrData[14] = new String(convData,totlByte+= 10, 10);       // [신정원 산정]선진화방안에 따른연간 상환 예정액(스트레스 금리 가산)  (10)
            dsrData[15] = new String(convData,totlByte+= 10,  1);       // 연계대출 및 집단대출 구분 (1)
            dsrData[16] = new String(convData,totlByte+= 1 ,  6);       // SPACE  (6)

            dsrInfoArry.add(dsrData);
        }
    }


    /**
     * Send 보낼 문자열을 생성한다.
     */
    public String getSendStr() {
        StringBuffer sendBuff = new StringBuffer();

        sendBuff.append(getRegNo                        ());
        sendBuff.append(getReason                       ());
        sendBuff.append(getViewAgreeFg                  ());
        sendBuff.append(getDsrStndDt                    ());
        sendBuff.append(getComName                      ());
        sendBuff.append(getName                         ());
        sendBuff.append(getJCode                        ());
        sendBuff.append(getUpCode                       ());
        sendBuff.append(getLoan100MillionOverDiv        ());
        sendBuff.append(getBrwrUnitDsrAplyDiv           ());
        sendBuff.append(getUnUse1                       ());
        sendBuff.append(getLastUpdateDt                 ());
        sendBuff.append(getLoanInfoMore                 ());
        sendBuff.append(getLoanInfoTotCnt               ());
        sendBuff.append(getLoanInfoReptCnt              ());
        //sendBuff.append(getDsrInfoArry                  ());

        return (sendBuff.toString());
    }

    public void setRecvObj(String recvData) {
        int totlByte = 0;
        byte[] convData = recvData.getBytes();

        setRegNo                    (new String(convData,totlByte+=0 ,  13 ).trim());      // 주주(사업자)등록번호 (13)
        setReason                   (new String(convData,totlByte+=13,   2 ).trim());      // 자료이용목적 (2)
        setViewAgreeFg              (new String(convData,totlByte+=2 ,   1 ).trim());      // 조회 동의 여부 (1)
        setDsrStndDt                (new String(convData,totlByte+=1 ,   8 ).trim());      // DSR 산정만기 기준일자 (DSR 기준일자) (8)
        setComName                  (new String(convData,totlByte+=8 ,  40 ).trim());      // 상호(기업체명) (40)
        setName                     (new String(convData,totlByte+=40,  20 ).trim());      // 성명(대표자) (20)
        setJCode                    (new String(convData,totlByte+=20,   2 ).trim());      // 직업 코드(미사용) (2)
        setUpCode                   (new String(convData,totlByte+=2 ,   4 ).trim());      // 업종 코드 (4)
        setLoan100MillionOverDiv    (new String(convData,totlByte+=4 ,   2 ).trim());      // 신용대출 1억초과 구분 (2)
        setBrwrUnitDsrAplyDiv       (new String(convData,totlByte+=2 ,   2 ).trim());      // 차주단위 DSR적용 신용대출 차주 구분 (2)
        setUnUse1                   (new String(convData,totlByte+=2 ,  10 ).trim());      // 미사용 (10)
        setLastUpdateDt             (new String(convData,totlByte+=10,   8 ).trim());      // 대출정보 Update 최근 일자 (8)
        setLoanInfoMore             (new String(convData,totlByte+=8 ,   1 ).trim());      // 대출･단기카드대출 정보 More (1)
        setLoanInfoTotCnt           (new String(convData,totlByte+=1 ,   4 ).trim());      // 대출･단기카드대출 정보 총 건수 (4)
        setLoanInfoReptCnt          (new String(convData,totlByte+=4 ,   2 ).trim());      // 대출.현금서비스 정보 회보 건수 (2)
        setDsrInfoArry              (new String(convData,totlByte+=2 ,  convData.length-totlByte).trim());  // 대출･단기카드대출 정보 회보 사항 (1 to 20 Times) → (120 × 20 = 2,400)
    }
}
