package hanalife.util;

import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Properties;

import org.apache.log4j.Logger;
import org.springframework.util.StringUtils;

import hanalife.c.co.util.StringUtil;

/**
 * config.properties에 해당하는 내용을 추가한후 매소드를 추가한다.
 */
public class ConfigUtils {
    private static Properties prop = null;
    private static Logger log = Logger.getLogger(ConfigUtils.class.getName());

    private ConfigUtils(){}

    /**
     * FAX 업로드 파일 경로
     * @return
     */
    public static String getFaxSendFilePath(){
        return getValue("fax.upload.path");
    }
    /**
     * FAX 타겟 파일 경로(anylink호출전
     * @return
     */
    public static String getFaxTargetPath(){
        return getValue("fax.target.path");
    }


    /**
     * Fax 송신 경로
     * @return
     */
    public static String getFaxSendPath(){
    	String faxSendPath = "fax.send.path";

        try {

        	faxSendPath = getKey(faxSendPath);

            return getValue(faxSendPath);
        }catch(Exception e){
            throw new BizException(faxSendPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    /**
     * FAX 수신 경로
     * @return
     */
    public static String getFaxRecvPath(){
    	String faxRecvPath = "fax.recv.path";

        try {

        	faxRecvPath = getKey(faxRecvPath);

            return getValue(faxRecvPath);
        }catch(Exception e){
            throw new BizException(faxRecvPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }

    }

    /**
     * SMS 송신 경로
     * @return
     */
    public static String getSmsSendPath(){
    	String smsSendPath = "sms.send.path";

        try {

        	smsSendPath = getKey(smsSendPath);

            return getValue(smsSendPath);
        }catch(Exception e){
            throw new BizException(smsSendPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }

    }

    /**
     * SMS 수신 경로
     * @return
     */
    public static String getSmsRecvPath(){
    	String smsRecvPath = "sms.recv.path";

        try {

        	smsRecvPath = getKey(smsRecvPath);

            return getValue(smsRecvPath);
        }catch(Exception e){
            throw new BizException(smsRecvPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }

    }


    /**
     * 서버모드
     *
     * L : 로컬
     * T : 테스트
     * R : 운영
     *
     * @return
     */
    public static String getServerMode(){
    	String mode = StringUtil.trim(System.getProperty("server.mode"));
    	if ( StringUtil.isNull( mode ) ) {
    		mode = "L";
    	}

    	return mode;

    	//return getValue("server.mode");
    }

    /**
     * 운영서버여부
     * @return
     */
    public static boolean isRealServer() {
        return "R".equals(getServerMode());
    }

    /**
     * 파일upload경로
     * @return
     */
    public static String getFileUploadPath() {
    	String fileUploadPath = "file.upload.path";

        try {

        	fileUploadPath = getKey(fileUploadPath);

            return getValue(fileUploadPath);
        }catch(Exception e){
            throw new BizException(fileUploadPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    /**
     * 채널 코드 upload경로
     * @return
     */
    public static String getCodeUploadPath() {
    	String codeUploadPath 	= "code.upload.path";
        try {

        	codeUploadPath = getKey(codeUploadPath);

            return getValue(codeUploadPath);
        }catch(Exception e){
            throw new BizException( codeUploadPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    /**
     * ECM IP:PORT
     * @return
     */
    public static String getEcmIpPort() {
    	String ecmIpPort = "ecm.ip";

        try {
        	ecmIpPort = getKey(ecmIpPort);

            return getValue(ecmIpPort);
        }catch(Exception e){
            throw new BizException(ecmIpPort + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    /**
     * ECM ID/PW
     * @return
     */
    public static String getEcmUser() {
    	String ecmUser 	= "ecm.user";
        try {

        	ecmUser = getKey(ecmUser);

            return getValue(ecmUser);
        }catch(Exception e){
            throw new BizException( ecmUser + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    public static String getEcmPath() {
    	String ecmPath 	= "ecm.path";
    	try {

        	ecmPath = getKey(ecmPath);

            return getValue(ecmPath);
        }catch(Exception e){
            throw new BizException( ecmPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    public static String getCryptoPath() {
    	String cryptoPath 	= "crypto.path";

        try {

        	cryptoPath = getKey(cryptoPath);

            return getValue(cryptoPath);
        }catch(Exception e){
            throw new BizException( cryptoPath + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    /**
     *
     * @return
     */
    public static String getLinkMciUrl() {
    	String linkMciUrlKey 	= "link.mci.url";
        try {

        	linkMciUrlKey = getKey(linkMciUrlKey);

            return getValue(linkMciUrlKey);
        }catch(Exception e){
            throw new BizException( linkMciUrlKey + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }


    /**
     * Css URL을 가져온다.
     * @return
     */
    public static String getLinkCssUrl() {
    	String linkCssUrlKey 	= "link.css.url";
        try {

        	linkCssUrlKey = getKey(linkCssUrlKey);

            return getValue(linkCssUrlKey);
        }catch(Exception e){
            throw new BizException( linkCssUrlKey + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    private static String getValue(String key) {
        try {
            return prop.getProperty(key);
        }catch(Exception e){
            throw new BizException("config.properties 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }


    // 설정파일 초기화
    static{
        InputStream inputStream = null;
        try {
            // 설정파일 경로를 알려주거나, 클래스 패스에서 읽는 방식 사용
            String configFileNm = System.getProperty("conf.file");
            if( StringUtils.isEmpty(configFileNm) ){
                String propFileName = "config.properties";
                inputStream = ConfigUtils.class.getClassLoader().getResourceAsStream(propFileName);
                if (inputStream != null) {
                    prop = new Properties();
                    prop.load(inputStream);
                } else {
                    throw new BizException("설정파일을 찾을수 없습니다.");
                }
            } else {
                // 배치에서 클래스 패스 방식을 처리 못하는 현상으로 직접 경로를 알려줘서 처리
                prop = new Properties();
                prop.load(new FileInputStream(configFileNm));
            }
        }catch(Exception ignore){
            log.error(ignore.getMessage(), ignore);
            // ignore.printStackTrace();
        } finally {
            try{
                if( inputStream != null ) inputStream.close();
            }catch(Exception e){

            }
        }
    }


    public static String getBaseUrl() {
    	String baseUrl 	= "base.url";
    	try {

        	baseUrl = getKey(baseUrl);

            return getValue(baseUrl);
        }catch(Exception e){
            throw new BizException(baseUrl + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }
    public static String getReportUrl() {
    	String reportUrl 	= "report.url";

    	try {

        	reportUrl = getKey(reportUrl);

            return getValue(reportUrl);
        }catch(Exception e){
            throw new BizException(reportUrl + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    public static String getUbiServer() {
    	String ubiServer 	= "ubi.server";
    	try {

        	ubiServer = getKey(ubiServer);

            return getValue(ubiServer);
        }catch(Exception e){
            throw new BizException( ubiServer + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    public static String getReportBase() {
    	String reportBase 	= "report.base";

    	try {

        	reportBase = getKey(reportBase);

            return getValue(reportBase);
        }catch(Exception e){
            throw new BizException( reportBase + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }

    public static String getVoiceUrl() {
    	String voiceUrl 	= "voice.url";
    	try {

    		voiceUrl = getKey(voiceUrl);

            return getValue(voiceUrl);
        }catch(Exception e){
            throw new BizException( voiceUrl + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }


    public static String getAddrUrl() {
    	String addrUrl 	= "addr.url";
    	try {

    		addrUrl = getKey(addrUrl);

            return getValue(addrUrl);
        }catch(Exception e){
            throw new BizException( addrUrl + " 속성 읽기 실패(" + e.getMessage() + ")", e);
        }
    }





    private static String getKey(String key) {
    	String rtnVal = key;
    	String svrMode 	= getServerMode();
    	if ( svrMode != null) {
    		rtnVal = rtnVal + "." + svrMode.trim();
    	}else {
    		rtnVal = rtnVal + ".L";
    	}
    	return rtnVal;
    }

}
