package hanalife.util;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import hanalife.c.co.contants.Constants;
import hanalife.c.co.util.DateUtil;
import hanalife.c.co.util.StringUtil;
import hanalife.r.co.as.vo.AskUnrcvVO;
import hanalife.r.co.as.vo.BndVO;
import hanalife.r.co.rc.service.RcptRCService;
import hanalife.r.co.rc.vo.IamtUnrcvObjVO;
import hanalife.r.co.rc.vo.IamtUnrcvVO;

@SuppressWarnings({"rawtypes"})
/**
 * <pre>
 * 클래스명    : IamtUtil
 * 클래스설명 : 입금미수공통 유틸리티
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class IamtUtil {
	//private static Logger log = Logger.getLogger(IamtUtil.class.getName());
    private static final Logger log = LoggerFactory.getLogger(IamtUtil.class);

	@Autowired
	private RcptRCService rcptService;

	private static final String BLANK = "";

	private IamtUtil(){
	}

	/**
	 * <p>메소드명		: getBndVO</p>
	 * <p>설명			: 입금정보(대출번호,순번)에 해당하는 BndVO</p>
	 * <p>메소드인수1	: AskUnrcvVO</p>
	 * <p>메소드인수2	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: BndVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static BndVO getBndVO(AskUnrcvVO askUnrcvVO, IamtUnrcvObjVO iamtUnrcvObjVO) {
		if ((askUnrcvVO == null) || (iamtUnrcvObjVO == null)) {
			return null;
		}
		return askUnrcvVO.getBndVO(iamtUnrcvObjVO.loanNo, iamtUnrcvObjVO.loanSeq);
	}

	/**
	 * <p>메소드명		: isSuccess</p>
	 * <p>설명			: 결과코드 성공여부</p>
	 * <p>메소드인수1	: IamtUnrcvVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isSuccess(IamtUnrcvVO iamtUnrcvVO) {
		return Constants.SUCCESS.equals(iamtUnrcvVO.rsltCd);
	}

	/**
	 * <p>메소드명		: isLease</p>
	 * <p>설명			: 리스여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isLease(IamtUnrcvObjVO iamtUnrcvObjVO) {
		return isLease(iamtUnrcvObjVO.prdtLrgeClasCd);
	}
	public static boolean isLease(String prdtLrgeClasCd){
		if (StringUtil.in(prdtLrgeClasCd, new String[]{"3", "4"})) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * <p>메소드명		: isAutoOprLease</p>
	 * <p>설명			: 운용리스여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isAutoOprLease(IamtUnrcvObjVO iamtUnrcvObjVO) {
		return isAutoOprLease(iamtUnrcvObjVO.prdtLrgeClasCd);
	}
	public static boolean isAutoOprLease(String prdtLrgeClasCd) {
		return (prdtLrgeClasCd.equals("4"))?true:false;
	}

	/**
	 * <p>메소드명		: isFincAutoLease</p>
	 * <p>설명			: 금융리스여부
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isFincAutoLease(IamtUnrcvObjVO iamtUnrcvObjVO) {
		return isFincAutoLease(iamtUnrcvObjVO.prdtLrgeClasCd);
	}
	public static boolean isFincAutoLease(String prdtLrgeClasCd) {
		return (prdtLrgeClasCd.equals("3"))?true:false;
	}

	/**
	 * <p>메소드명		: isFinModify</p>
	 * <p>설명			: 금융리스 모디파이여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isFinModify(IamtUnrcvObjVO iamtUnrcvObjVO){
		return isFinModify(iamtUnrcvObjVO.prdtLrgeClasCd, iamtUnrcvObjVO.asymmAcctFg);
	}
	public static boolean isFinModify(String prdtLrgeClasCd, String asymmAcctFg) {
		if (prdtLrgeClasCd.equals("3") && asymmAcctFg.equals("1")) {
			return true;
		} else {
			return false;
		}
	}

	/**
	 * <p>메소드명		: isPiamt</p>
	 * <p>설명			: 원리금 수납여부</p>
	 * <p>메소드인수1	: String setlDivCd</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isPiamt(String setlDivCd) {
		if (StringUtil.in(setlDivCd, new String[]{Constants.SETL_DIV_PIAMT
				, Constants.SETL_DIV_MIDRMBR_P, Constants.SETL_DIV_MIDRMBR_T})) {
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isMidRmbr</p>
	 * <p>설명			: 중도상환여부</p>
	 * <p>메소드인수1	: String setlDivCd</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isMidRmbr(String setlDivCd) {
		if (StringUtil.in(setlDivCd, Constants.SETL_DIV_MIDRMBR_P, Constants.SETL_DIV_MIDRMBR_T)) {
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isLoanNorm</p>
	 * <p>설    명		: 대출정상여부 ( 2% )</p>
	 * <p>메소드 인수1	: String loanStatCd</p>
	 * <p>메소드 리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isLoanNorm(String loanStatCd){
		String tmpLoanStatCd = StringUtil.trim(loanStatCd);
		if (tmpLoanStatCd.length()==2 && StringUtil.like(tmpLoanStatCd, "2%")) {
				return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isBrcvAmtLeasTrnsRcpt</p>
	 * <p>설명			: 선수금리스료 대체수납 인지 여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isBrcvAmtLeasTrnsRcpt(IamtUnrcvObjVO iamtUnrcvObjVO){
		if (isPiamt(iamtUnrcvObjVO.setlDivCd) && iamtUnrcvObjVO.rcptTpCd.equals(Constants.RCPT_DIV_BRCV_LEAS_TRNS_RCPT)) {
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isSucsRcpt</p>
	 * <p>설명			: 승계수납 여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isSucsRcpt(IamtUnrcvObjVO iamtUnrcvObjVO) {
		if (isPiamt(iamtUnrcvObjVO.setlDivCd) && iamtUnrcvObjVO.rcptTpCd.equals(Constants.RCPT_DIV_SUCS_RCPT)) {
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isLtrmBrcv</p>
	 * <p>설명			: 장기선수금 대체여부</p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isLtrmBrcv(IamtUnrcvObjVO iamtUnrcvObjVO){
		if (isPiamt(iamtUnrcvObjVO.setlDivCd) && iamtUnrcvObjVO.rcptTpCd.equals(Constants.RCPT_DIV_LTRM_BRCV)){
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: isIvltClsBnd</p>
	 * <p>설명			: 강제해지상품여부 </p>
	 * <p>메소드인수1	: IamtUnrcvObjVO</p>
	 * <p>메소드리턴값	: boolean</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean isIvltClsBnd(IamtUnrcvObjVO iamtUnrcvObjVO){
		if (iamtUnrcvObjVO.prdtSmClasCd.equals("6")) {
			return true;
		}
		return false;
	}

	/**
	 * <p>메소드명		: makeResult</p>
	 * <p>설명			: 결과코드, 내용..등 셋팅 </p>
	 * <p>메소드인수1	: IamtUnrcvVO</p>
	 * <p>메소드인수2	: IamtUnrcvException</p>
	 * <p>메소드리턴값	: IamtUnrcvVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	/* TODO
	public static IamtUnrcvVO makeResult(IamtUnrcvVO iamtUnrcvVO, IamtUnrcvException ie) {
		if (ie != null) {
			iamtUnrcvVO.rsltCd = ie.getRsltCd();
			iamtUnrcvVO.rsltCntn = ie.getRsltCntn();
			iamtUnrcvVO.errLoanNo = ie.getErrLoanNo();
			iamtUnrcvVO.errLoanSeq = ie.getErrLoanSeq();
			iamtUnrcvVO.errObjIdx = ie.getErrObjIdx();
			log.error(ie.getMessage(), ie);
		}
		return iamtUnrcvVO;
	}
	*/

	/**
	 * <p>메소드명		: makeResult</p>
	 * <p>설명			: 결과코드, 내용..등 셋팅 </p>
	 * <p>메소드인수1	: IamtUnrcvVO</p>
	 * <p>메소드인수2	: Exception</p>
	 * <p>메소드리턴값	: IamtUnrcvVO</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static IamtUnrcvVO makeResult(IamtUnrcvVO iamtUnrcvVO, Exception e) {
		if (e != null) {
			iamtUnrcvVO.rsltCd = Constants.COMM_ERR_CD;
			iamtUnrcvVO.rsltCntn = e.getMessage();
			log.error(e.getMessage(), e);
		}
		return iamtUnrcvVO;
	}

	/**
	 * <p>메소드명		: compareTo</p>
	 * <p>설명			: 두문자간 크기 비교</p>
	 * <p>메소드인수1	: String left</p>
	 * <p>메소드인수2	: String right</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static int compareTo(String left, String right) {
		return StringUtil.trim(left).compareTo(StringUtil.trim(right));
	}

	/**
	 * <p>메소드명		: equals</p>
	 * <p>설명			: 문자열 동등비교</p>
	 * <p>메소드인수1	: String left</p>
	 * <p>메소드인수2	: String right</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static boolean equals(String left, String right) {
		return StringUtil.trim(left).equals(StringUtil.trim(right));
	}

	/**
	 * <p>메소드명		: sizeOfList</p>
	 * <p>설명			: List size</p>
	 * <p>메소드인수1	: List</p>
	 * <p>메소드리턴값	: int</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static int sizeOfList(List inList) {
		return (inList == null) ? 0 : inList.size();
	}

	/**
	 * <p>메소드명		: intervalTime</p>
	 * <p>설명			: 시작 - 종료 시간의 interval 구하기</p>
	 * <p>메소드인수1	: 시작시간</p>
	 * <p>메소드인수2	: 종료시간</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static String intervalTime(long start, long end) {
        long inteval = end-start;
        long minute = (inteval/1000/60);
        long second = ((inteval/1000)%60);
        long msec   = (inteval%1000);
        return minute+" M "+second+" S "+msec+" MS";
	}

	/**
	 * <p>메소드명		: gvnoDsrcNo</p>
	 * <p>설명			: 예가수번호채번</p>
	 * <p>메소드인수1	: String acctDt</p>
	 * <p>메소드인수2	: Connection</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	/* TODO CommBizServiceImpl 변경
	public String gvnoDsrcNo(String acctDt, Connection con) {
		if (IamtUtil.equals(BLANK, acctDt) || (acctDt.length() < 8)) {
			IamtExceptionHandler.throwIamtException("예가수 번호 채번중 에러발생 : 회계일자가 입력되지 않았습니다.");
		}
		return "S" + StringUtil.getFormatDt(acctDt,"").substring(2,6) + rcptService.getNextNum();
	}
	*/

	/**
	 * <p>메소드명		: gvnoLoanNo</p>
	 * <p>설명			: 미확인 대출번호 채번(입금인불명일때)
	 * 						U0601000001, 11자리, [S] + [YYMM] + [00000X]</p>
	 * <p>메소드인수1	: String acctDt</p>
	 * <p>메소드인수2	: Connection</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	/* TODO CommBizServiceImpl 변경
	public static String gvnoLoanNo(String acctDt, Connection con){
		if (IamtUtil.equals(BLANK, acctDt) || (acctDt.length() < 8)) {
			IamtExceptionHandler.throwIamtException("미확인 대출번호 채번중 에러발생 : 회계일자가 입력되지 않았습니다.");
		}
		return "U" + StringUtil.getFormatDt(acctDt,"").substring(2,6) + RcptDao.getNextNum(con);
	}


	/**
	 * <p>메소드명		: addListString</p>
	 * <p>설명			: List 값을StringBuffer에 append </p>
	 * <p>메소드인수1	: String voName</p>
	 * <p>메소드인수2	: StringBuffer buff</p>
	 * <p>메소드인수3	: List voList</p>
	 * <p>메소드리턴값	: N/A</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static void addListString(String voName, StringBuffer buff, List voList) {
		if( voList != null && voList.size() > 0 ){
			buff.append( voName + " (" + voList.size()+") \n" );
			for( int i=0; i < voList.size(); i++){
				buff.append( voList.get(i) + "\n");
			}
		}
	}

	/**
	 * <p>메소드명		: calcPdueDiscDfee</p>
	 * <p>설명			: 선납할인연체료 구하기</p>
	 * <p>메소드인수1	: String setlDt</p>
	 * <p>메소드인수2	: String dueDt</p>
	 * <p>메소드인수3	: long mmPamt</p>
	 * <p>메소드인수4	: long mmInt</p>
	 * <p>메소드인수5	: double loanIntRt</p>
	 * <p>메소드리턴값	: long</p>
	 * <p>예외처리		: N/A</p>
	 */
	public static long calcPdueDiscDfee(String setlDt, String dueDt, long mmPamt, long mmInt, double loanIntRt) {
		//날짜비교시 납입일자가 결제일자보다 크면 -값이 나오지만 원호출시 작을때만 호출하므로 추가로 처리를 안함.
		int dayBetween = DateUtil.daysBetween(setlDt, dueDt, DateUtil.YYYYMMDD_FM);
		return (long) (((mmPamt + mmInt) * loanIntRt * dayBetween) / 365 / 100);
	}

}
