package hanalife.util.gram;

/**
 * <pre>
 * 클래스명    : GramException
 * 클래스설명 : 전문 에러 처리를 위한 예외 클래스 Exception
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class GramException extends Exception {
	private static final long serialVersionUID = 1L;

	private String gramKind;		//전문종류
	private String gramFunc;		//기능구분

	private String gramErrorCode;	//오류코드
	private String gramProgName;	//프로그램명
	private String gramFuncName;	//함수명
	private String gramLineNo;		//줄번호
	private String gramMessage;		//메시지내용
	private String gramEtc;			//조치사항

	/**
	 * 기본 생성자
	 */
	public GramException(String msg) {
		super(msg);
	}

	/**
	 * 생성자
	 *
	 * @param gramKind 전문종류
	 * @param gramFunc 기능구분
	 * @param rcvGram 에러 전문
	 * @throws Exception
	 */
	public GramException(String gramKind, String gramFunc, String rcvGram) throws Exception {
		this(gramKind, gramFunc, rcvGram, (Throwable)null);
	}

	/**
	 * 생성자
	 *
	 * @param gramKind 전문종류
	 * @param gramFunc 기능구분
	 * @param gramErrors 파싱된 에러 전문
	 */
	public GramException(String gramKind, String gramFunc, String[] gramErrors) {
		this(gramKind, gramFunc, gramErrors, (Throwable)null);
	}

	/**
	 * 생성자
	 *
	 * @param gramKind 전문종류
	 * @param gramFunc 기능구분
	 * @param rcvGram 응답전문
	 * @param cause {@link Throwable}
	 * @throws Exception
	 */
	public GramException(String gramKind, String gramFunc, String rcvGram, Throwable cause) throws Exception {
		this(gramKind, gramFunc, GramUtil.parseError(rcvGram), cause);
	}

	/**
	 * 생성자
	 *
	 * @param gramKind 전문종류
	 * @param gramFunc 기능구분
	 * @param gramErrors 파싱된 에러 전문
	 * @param cause {@link Throwable}
	 */
	public GramException(String gramKind, String gramFunc, String[] gramErrors, Throwable cause) {
		if (gramErrors == null || gramErrors.length != 6) {
			throw new IllegalArgumentException("'GramErrors'의 배열 크기는 6 이어야 합니다");
		}
		this.gramKind = gramKind;
		this.gramFunc = gramFunc;

		gramErrorCode = gramErrors[0].trim();
		gramProgName = gramErrors[1].trim();
		gramFuncName = gramErrors[2].trim();
		gramLineNo = gramErrors[3].trim();
		gramMessage = gramErrors[4].trim();
		gramEtc = gramErrors[5].trim();
	}


	/**
	 * 전문종류
	 */
	public String getGramKind() {
		return gramKind;
	}

	/**
	 * 기능구분
	 */
	public String getGramFunc() {
		return gramFunc;
	}

	/**
	 * 오류코드
	 */
	public String getGramErrorCode() {
		return gramErrorCode;
	}

	/**
	 * 프로그램명
	 */
	public String getGramProgName() {
		return gramProgName;
	}

	/**
	 * 함수명
	 */
	public String getGramFuncName() {
		return gramFuncName;
	}

	/**
	 * 줄번호
	 */
	public String getGramLineNo() {
		return gramLineNo;
	}

	/**
	 * 메시지내용
	 */
	public String getGramMessage() {
		return gramMessage;
	}

	/**
	 * 조치사항
	 */
	public String getGramEtc() {
		return gramEtc;
	}

	@Override
	public String getMessage() {
		return "FSB["+gramKind+gramFunc+"] : ("+gramErrorCode+")"+gramMessage;
	}
}
