package hanalife.util.gram;

import java.io.UnsupportedEncodingException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import hanalife.util.BizException;

/**
 * <pre>
 * 클래스명    : OnLineUtil
 * 클래스설명 : 널데이터나 널종료 문자열에 대한 처리
 * 프로젝트명 : DOBSCAP
 * 작성일자    : 2018-08-01
 * 변경이력
 * -----------------------------------------------------------------------------
 * [변경일자 ][변경자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [20180801][두비스][캐피탈패키지-최초작성]
 * -----------------------------------------------------------------------------
 * </pre>
 */
public class OnLineUtil{

    private final static Logger log = Logger.getLogger(OnLineUtil.class.getName());

	//왼쪽정렬, 모자라는 길이만큼 스페이스를 채워넣는다.
    public static String fillSpace(String s, int leng)  {
    	if(s==null || s.equals("")){
    		s = " ";
    	}
    	return fill(s, leng, " ");
    }


    //왼쪽정렬, 모자라는 길이만큼 fillStr을 채워넣는다.
    public static String fill(String inStr, int size, String fillStr)  {

        String tmp = (inStr == null) ? "" : inStr.trim();
        byte[] inByte = tmp.getBytes();
        int inStrLen = inByte.length;
        if (inStrLen > size) {
        	return subString(inByte, 0, size );
        }

        StringBuilder buff = new StringBuilder(size);
        buff.append(tmp);
        for( int i= inStrLen; i < size; i++) {
        	buff.append(fillStr);
        }
        return buff.toString();
    }

    //오른쪽 정렬, 모자라는 길이만큼 "0"을 채워넣는다.
    public static String fixEndZero(String s, int leng)  {
        return fillEnd(s, leng, "0");
    }

    //오른쪽 정렬, 모자라는 길이만큼  fillStr을 채워넣는다.
    //이때, 소수점두비스리 절삭.
    public static String fillEnd(String inStr, int size, String fillStr) {
//        StringBuffer st = new StringBuffer();
//        for (int i=s.length() ; i<leng ; i++ ) {
//        	st.append(c) ;
//        }
//        st.append(s);
//        return st.toString();
    	String tmp = (inStr == null) ? "" : inStr.trim();
        byte[] inByte = tmp.getBytes();
        int inStrLen = inByte.length;
        if (inStrLen > size) {
        	return subString(inByte, 0, size );
        }

        StringBuilder buff = new StringBuilder(size);
        for( int i= inStrLen; i < size; i++) {
        	buff.append(fillStr);
        }
        buff.append(tmp);
        return buff.toString();
    }

    public static String cnvNum(String s) throws Exception
    {
        BigInteger bi = new BigInteger("0");
        try{
            if(s==null || "".equals(s.trim())){
               s = "0";
            }
            bi = new BigInteger(s);
        }catch(Exception e){
            throw new Exception( "숫자포맷 에러 : " + s );
        }

    	return bi.toString();
    }

    public static String subString(byte[] cToBytes, int start, int end) {
        return subString(cToBytes, start, end, "");
    }

	public static String[] parseString(byte[] byteArr, int[] len) {
        return parseString(byteArr, len, "");
	}

    public static String[] parseString(byte[] byteArr, int[] len, String charSet) {
        int itmp = 0;
        int[] lenStart = new int[len.length];
        int[] lenEnd   = new int[len.length];
        for(int i=0;i<len.length;i++){
            if(i==0){
                lenStart[i] = 0;
            }else{
                lenStart[i] = lenStart[i-1] + len[i-1];
            }
            lenEnd[i] = lenStart[i] + len[i];
        }

        String[] strArr = new String[len.length];
        for(int i=0;i<len.length;i++){
            strArr[i] = OnLineUtil.subString(byteArr, lenStart[i], lenEnd[i], charSet);
        }
        return strArr;
    }

    /**
     * 전문을 자릿수로 잘라서 리스트를 만들어 리턴한다.
     * @param gram
     * @param size
     * @return
     */
    public static List<String> parseGram(String gram, int size){
        return parseGram(gram, size, "");
    }


    public static List<String> parseGram(String gram, int size, String charSet){
        List<String> strings = new ArrayList<>();
        int index = 0;
        byte[] gramByte = new byte[0];
        try {
            gramByte = StringUtils.isNotBlank(charSet) ?gram.getBytes(charSet) : gram.getBytes();
        } catch (UnsupportedEncodingException e) {
            throw new BizException("encode 실패("+e.getMessage()+")",e);
        }

        while (index < gramByte.length) {
            strings.add(subString(gramByte, index,  index + size, charSet ));
            index += size;
        }

        return strings;
    }

    public static String subString(byte[] cToBytes, int start, int end, String charSet) {
        String strRtn = "";
        byte[]   bOut = new byte[end - start];

        try {
            for (int i = start; i < end; i++) {
                bOut[i - start] = cToBytes[i];
            }

            if(StringUtils.isNotBlank(charSet)){
                strRtn = new String(bOut, charSet);
            } else {
                strRtn = new String(bOut);
            }

            return strRtn;
        } catch (Exception e) {
            throw new BizException("문자자르기 실패 (" + e.getMessage() + ")",e);
        }
    }

}
