package hanalife.util.log;

import java.io.PrintWriter;
import java.io.StringWriter;



/**
* <pre>
* 클래스명    : CallerInfo
* 클래스설명 : 에러메시지처리의 위치정보에 사용할 Util클래스
* (예 : "ESC9999"+CallerInfo.getPath(new Throwable())+"^마감 되었습니다.")
* 프로젝트명 : DOBSCAP
* 작성일자    : 2018-08-01
* 변경이력
* -----------------------------------------------------------------------------
* [변경일자 ][변경자][변경사유-수정내용]
* -----------------------------------------------------------------------------
* [20180801][두비스][캐피탈패키지-최초작성]
* -----------------------------------------------------------------------------
* </pre>
*/
public class CallerInfo implements java.io.Serializable {
    private static StringWriter sw = new StringWriter();
    private static PrintWriter pw = new PrintWriter(sw);

    /**
     * 인수가 null이거나 원하는 Index가 없을때 <b>null</b> 문자열을 반환한다.
     */
    private final static String NA = "null";

    /**
     * <p>메소드명     : getPath</p>
     * <p>설명         : 인수로 받은 Throwable의 메시지를 String(s)으로 받아서</p>
     * <p>               첫번째 "at " 다음에서 "(" 까지의 경로명을 반환한다.</p>
     * <p>메소드인수 1 : Throwable t - 호출한 곳에서 발생시킨 Throwable</p>
     * <p>메소드리턴값 : String      - 호출한 Full경로명(메소드명)</p>
     */
    public static String getPath(Throwable t) {
        if (t == null) {
            return NA;
        }

        String s;

        synchronized (sw) {
            t.printStackTrace(pw);
            s = sw.toString();
            sw.getBuffer().setLength(0);
        }

        /*
        인수로 받은 Throwable에 담겨있는 메시지 예.

        java.lang.Throwable
            at com.cbcommon.action.bc.u.e.a.OutCoAction.inquireMat(Unknown Source)
            at com.cbcommon.action.bc.u.e.a.OutCoAction.searchMat(Unknown Source)
            at com.cbcommon.action.bc.u.e.a.OutCoMatActionWrapper.search(Unknown Source)
        */

        // substring 할 시작과 끝 Index
        int ibegin;

        /*
        인수로 받은 Throwable에 담겨있는 메시지 예.

        java.lang.Throwable
            at com.cbcommon.action.bc.u.e.a.OutCoAction.inquireMat(Unknown Source)
            at com.cbcommon.action.bc.u.e.a.OutCoAction.searchMat(Unknown Source)
            at com.cbcommon.action.bc.u.e.a.OutCoMatActionWrapper.search(Unknown Source)
        */

        // substring 할 시작과 끝 Index
        int iend;

        // 시작Index 찾기. 처음나오는 "at "
        ibegin = s.indexOf("at ");

        if (ibegin == -1) {
            return NA;
        }

        // "at " 만큼 뒤로 시작Index 조정
        ibegin += 3;

        // 끝Index 찾기. 시작Index 이후에 처음 나오는 "("
        iend = s.indexOf("(", ibegin);

        if (iend == -1) {
            return NA;
        }

        // "at " 과 "(" 사이의 문자열을 반환한다.
        return s.substring(ibegin, iend);
    }
}
