﻿
/*
 * 공통 유틸성 함수를 만든다.
 */
function callFunc(AScr) {
	return SYSVar.MODULE_MEMBER.callFunc(AScr);
}

/**
 * 스크립트 오류 처리 콜백, CALLBACK_SCRIPT_ERROR 실행 파라미터에서 지정
 * 스크립트 실행시 try/catch 문으로 검출 가능한 오류에 대해서만 호출됨
 * @param objScreen 화면 오브젝트
 * @param strEventName 이벤트 이름
 * @param strFuncName 함수 이름
 * @param strErrorName 에러 이름
 * @param strErrMsg 에러 메시지
 * @returns 1 - 엔진에서 스크립트 오류 메시지 박스를 표시하지 않음
 *          그외 - 엔진에서 오류 메시지 박스 표시
 */
function CallbackScriptError(objScreen, strEventName, strFuncName, strErrorName, strErrMsg) {
	console.log("CallbackScriptError> objScreen.url = " + objScreen.getscreenurl());
	console.log("> strEventName = " + strEventName);
	console.log("CallbackScriptError> strFuncName = " + strFuncName);
	console.log("CallbackScriptError> strErrorName = " + strErrorName);
	console.log("CallbackScriptError> strErrMsg = " + strErrMsg);

	// 1 - 엔진에서 스크립트 오류 메시지 박스를 표시하지 않음, 그외 - 엔진에서 오류 메시지 박스 표시
	// return 1;
}

/**
 * 거래 송수신 로그 추적기 실행
 * @returns 없
 */
function CallbackXTranLog(objXTranLogInfo) {
	var objPopupScreen, objPopupMember;

	objPopupScreen = factory.findpopup("XTRANLOG");
	if (objPopupScreen) {
		objPopupMember = objPopupScreen.getmembers();
		if (objPopupMember) {
			objPopupMember.process_xtranloginfo(objXTranLogInfo);
		}
	}
}

/**
 * 알림메세지를 출력한다..
 * @param strMsg 보여줄 메세지
 */
function comAlert(strMsg) {
	this.alert(strMsg);
}

/**
 * 알림메세지를 출력한다..
 * @param strMsg 보여줄 메세지
 */
function comConfirm(strMsg) {
	return this.confirm(strMsg);
}

/**
 * XFRAME5에서 제공하는 콘솔창에 로그를 출력한다.
 * @param strLog 로그
 */
function consoleprint(strLog) {
	factory.consoleprint(strLog);
}

/**
 * 슬라이드뷰 아이템을 동적 생성한다.
 * @param {Object} objScreen 호출하는 부모화면
 * @param {Object} objSVCtrl 슬라이드뷰 오브젝트
 * @param {Object} objSVCtrl 슬라이드뷰 타이틀 오브젝트
 * @param {Object} objScreenInfo 화면정보 오브젝트
 * @param {Number} nShowIndex 생성후 보여줄 화면 인덱스(제로베이스)
 */
function createSlideTab(objScreen, objSVCtrl, objSVTCtrl, objScreenInfo, nShowIndex) {
	var itemIndex;
	var screenIndex;
	var instNewTabObj;
	var objTabProp;

	if (!factory.isobject(objSVCtrl) || !factory.isobject(objSVTCtrl)) {
		this.alert("슬라이드뷰 객체 설정이 올바르지 않습니다.");
		return;
	}

	// 슬라이드뷰의 모든 아이템을 삭제한다.
	objSVCtrl.deleteallitem();
	objSVTCtrl.deletealltab();

	// 생성될 탭 오브젝트 프로퍼티
	objTabProp = {
		x: 0,
		y: 0,
		width: 100,
		width_unit: 1,
		height: 100,
		height_unit: 1,
		border: 0,
		tabitem_hidden: true,
	};

	for (screenIndex = 0; screenIndex < objScreenInfo.length; screenIndex++) {
		// 슬라이드뷰에 아이템을 생성한다.
		itemIndex = objSVCtrl.additem();
		//itemIndex = objSVCtrl.additem("", true);
		console.log("[SYSLOG]createSlideTab itemIndex : " + itemIndex);

		var objInfo = objScreenInfo[screenIndex];

		// 슬라이드뷰에 탭을 생성한다.
		instNewTabObj = objSVCtrl.createobjectex(itemIndex, XFD_CTRLKIND_TAB, objTabProp);
		if (instNewTabObj != null) {
			// 탭 타이틀 탭에 아이템을 생성한다.
			objSVTCtrl.addportlettab(objInfo.tabName, 1, 60, "", "SV_COM_TITLE" + itemIndex, true, "", true, false, false);

			// 생성된 TAB에 화면을 불러온다. (탭에 링크된 화면에 포커스 줄경우 슬라이드뷰가 이동하므로 포커스는 주지 않는다)
			instNewTabObj.addportlettab("", 1, 60, objInfo.screenUrl, "SV_COM_CONTENT_TAB" + itemIndex, true, objInfo.extraData, false, false, false);

			/*** 공통프레임 사용할경우
			var strFrameUrl = "/SYS/FRAME/mainFrame";
			// mainFrame 전달 데이터 셋팅
			var objExtra_data = {
					SCR_ID     : "",
					SCR_PATH   : "/SBT/TEMP/COM_EDITOR",
					MENU_ID    : "",
					MENU_NM    : "템플릿화면",
					P_MENU_ID  : "",
					PARENT_SCR : null,
					BIZ_EXT    : screen
			};
			instNewTabObj.addportlettab("", 0, 60, strFrameUrl, "", true, objExtra_data);
			*/
		} else {
			// TODO : 등록실패할경우 처리
		}
	}

	// 초기화면 인덱스 설정
	nShowIndex == undefined ? objSVCtrl.moveat(0) : objSVCtrl.moveat(nShowIndex);
	nShowIndex == undefined ? objSVTCtrl.settabitemfocus(0) : objSVTCtrl.settabitemfocus(nShowIndex, false, false);
}

/**
 * 화면내 패널에 속한 오브젝트를 CLEAR한다.
 * @param objBizScreen 부모화면 인스턴스 업무 화면 오브젝트
 * @param objPanel 패널 오브젝트
 * @return 없음
 */
function clearPanel(objBizScreen, objPanel) {
	if (this.isObjCtrlEx(objPanel, XFD_CTRLKIND_PANEL) == false || objPanel.getparentscrinstance() != objBizScreen) {
		return;
	}

	var componentTarget = null;
	var objCnt = 0;
	var objFirst = null;
	var objCtrl = null;
	var nCtrlIdx = 0;
	var objtype = -1;
	var scrTabCnt, TabSCR;

	try {
		componentTarget = objPanel;
		objCnt = componentTarget.getchildcontrolcount();
		objFirst = componentTarget.getinstancefirst();
		objCtrl = objFirst;
		nCtrlIdx = 0;
		objtype = -1;

		do {
			try {
				// 오브젝트의 타입을 구한다.
				objtype = objCtrl.getcontrolkind();
			} catch (EXCP) {
				nCtrlIdx++;
				objCtrl = componentTarget.getinstancenext(objCtrl);
				continue;
			}
			switch (objtype) {
				case XFD_CTRLKIND_FIELD:
					objCtrl.settextex("", false, false);
					break;
				case XFD_CTRLKIND_MULTILINE:
					objCtrl.settext("");
					break;
				case XFD_CTRLKIND_GRID:
					objCtrl.deleteall();
					break;
				case XFD_CTRLKIND_MULTILINEGRID:
					objCtrl.deleteallrows();
					break;
				case XFD_CTRLKIND_CHECKBOX:
					objCtrl.setcheck(false);
					break;
				case XFD_CTRLKIND_RADIOBUTTON:
					objCtrl.setcheck(false);
					break;
				case XFD_CTRLKIND_COMBOBOX:
					objCtrl.settext("");
					break;
				case XFD_CTRLKIND_PANEL:
					this.clearPanel(objBizScreen, objCtrl);
					break;
				case XFD_CTRLKIND_TAB:
					this.clearAllTabObjectData(objBizScreen, objCtrl);
					break;
				default:
					break;
			}
			// 다음번째 오브젝트를 구한다.
			objCtrl = componentTarget.getinstancenext(objCtrl);
			nCtrlIdx++;
		} while (nCtrlIdx < objCnt && objCtrl != objFirst);
	} catch (e) {
		console.log("[SYSLOG] clearPanel Error :" + e.message);
	}
}

/**
 * 전체 탭 아이템의 링크된 화면 및 패널내의 오브젝트 데이터를 CLEAR 한다.
 * @param objBizScreen 업무 화면 오브젝트
 * @param objTab 탭 오브젝트
 * @return 없음
 */
function clearAllTabObjectData(objBizScreen, objTab) {
	try {
		for (var nTabItem = 0; nTabItem < objTab.gettabitemcount(); nTabItem++) {
			this.clearTabObjectData(objBizScreen, objTab, nTabItem);
		}
	} catch (e) {
		console.log("[SYS_CORE_Module] (clearAllTabObjectData) Error :" + e.message);
	}
}

/**
 * 선택된 탭 아이템의 링크된 화면 및 패널내의 오브젝트 데이터를 CLEAR 한다.
 * @param objBizScreen 업무 화면 오브젝트
 * @param objTab 탭 오브젝트
 * @param nTabItem 탭아이템 인덱스
 * @return 없음
 */
function clearTabObjectData(objBizScreen, objTab, nTabItem) {
	var objFirst = objTab.getchildinstancefirst(nTabItem);
	var objCnt = objTab.getchildcontrolcount(nTabItem);
	var objCtrl = objFirst;
	var nCtrlIdx = 0;
	var objtype = -1;
	var objParent = null;

	if (this.isObjCtrlEx(objTab, XFD_CTRLKIND_TAB) == false) {
		return;
	}
	try {
		do {
			try {
				// 오브젝트의 타입을 구한다.
				objtype = objCtrl.getcontrolkind();
			} catch (EXCP) {
				nCtrlIdx++;
				objCtrl = objTab.getchildinstancenext(nTabItem, objCtrl);
				continue;
			}
			switch (objtype) {
				case XFD_CTRLKIND_FIELD:
					objCtrl.settextex("", false, false);
					break;
				case XFD_CTRLKIND_MULTILINE:
					objCtrl.settext("");
					break;
				case XFD_CTRLKIND_GRID:
					objCtrl.deleteall();
					break;
				case XFD_CTRLKIND_MULTILINEGRID:
					objCtrl.deleteallrows();
					break;
				case XFD_CTRLKIND_CHECKBOX:
					objCtrl.setcheck(false);
					break;
				case XFD_CTRLKIND_RADIOBUTTON:
					objCtrl.setcheck(false);
					break;
				case XFD_CTRLKIND_COMBOBOX:
					objCtrl.settext("");
					break;
				case XFD_CTRLKIND_PANEL:
					objParent = objCtrl.getparentscrinstance();
					if (objParent.getobjectkind() == XFD_OBJKIND_SCREEN) {
						this.clearPanel(objParent, objCtrl);
					}
					break;
				case XFD_CTRLKIND_TAB:
					objParent = objCtrl.getparentscrinstance();
					this.clearAllTabObjectData(objParent, objCtrl);
					break;
				default:
					break;
			}
			// 다음번째 오브젝트를 구한다.
			objCtrl = objTab.getchildinstancenext(nTabItem, objCtrl);
			nCtrlIdx++;
		} while (nCtrlIdx < objCnt && objCtrl != objFirst);
	} catch (e) {
		console.log("[SYSLOG] clearTabObjectData Error :" + e.message);
	}
	return true;
}

/**
 * 오브젝트의 데이터를 CLEAR 한다.
 * @param objBizScreen 부모화면 인스턴스 업무 화면 오브젝트
 * @param objCtrl 오브젝트
 * @return 없음
 */
function clearObjectData(objBizScreen, objArguments) {
	var arrArgs = new Array();
	var nType = 0;
	try {
		for (var nIdx = 1; nIdx < objArguments.length; nIdx++) {
			try {
				// 오브젝트의 타입을 구한다.
				objtype = objArguments[nIdx].getcontrolkind();
			} catch (EXCP) {
				continue;
			}
			switch (objtype) {
				case XFD_CTRLKIND_FIELD:
					objArguments[nIdx].settextex("", false, false);
					break;
				case XFD_CTRLKIND_MULTILINE:
					objArguments[nIdx].settext("");
					break;
				// 20170923 PJS 그리드와 멀티라인그리드 분리처리
				case XFD_CTRLKIND_GRID:
					objArguments[nIdx].deleteall();
					break;
				case XFD_CTRLKIND_MULTILINEGRID:
					objArguments[nIdx].deleteallrows();
					break;
				case XFD_CTRLKIND_CHECKBOX:
					objArguments[nIdx].setcheck(false);
					break;
				case XFD_CTRLKIND_RADIOBUTTON:
					objArguments[nIdx].setcheck(false);
					break;
				case XFD_CTRLKIND_COMBOBOX:
					objArguments[nIdx].settext("");
					break;
				default:
					break;
			}
		}
	} catch (e) {
		console.log("[SYSLOG] clearObjectData Error :" + e.message);
	}
}

/**
 *	초기화면 숨김해제
 **/
function closeHomeScreen() {
	SYSVar.WINMAIN_MEMBER.showHome(false);
}

/**
 * xFrame Console 및 브라우저 Console 에 로그
 * @param objScreen : screen : 호출한 화면
 * @param strMsg : string : 로그 메시지
 * @param objPrint : object : console.log에 찍힐 오브젝트
 * @return
 * @remark
 * 	Ex)SYSUtil.debug(this.screen, "로그를 출력합니다.");
 */
function debug(objScreen, strMsg, objPrint) {
	// index.js 파일에 SERVER_MODE 설정 : 운영에서는 동작하지 않도록 제어
	if (SYSVar.SERVER_MODE != "PROD") {
		var sysTime = "[" + factory.getsystemtime("%Y-%M-%D %h:%m:%s %ms") + "]";
		var screenUrl = "";
		if (factory.isobject(objScreen)) {
			screenUrl = "[" + objScreen.getscreenurl() + "] ";
		}

		if (objPrint == undefined) {
			console.log(sysTime + screenUrl + strMsg);
		} else {
			console.log(sysTime + screenUrl + strMsg, objPrint);
		}
		factory.consoleprint(sysTime + screenUrl + strMsg);
	}
}

/**
 * 패널에 속한 모든 항목에 대하여 Disable 처리
 * @param panel_name 패널명
 * @param objBizScreen 해당 화면
 * @param type_name 특정 타입의 컨포넌트만 Disable 하고 싶은 경우 (Option)
 * @return 없음
 */
function disableAll(objBizScreen, panel_name, type_name) {
	var components = this.getallcomponent(objBizScreen, panel_name);
	var size = components.length;
	var styleid = "";
	for (var i = 0; i < size; i++) {
		components[i].setenable(false);
	}
}

/**
 * 패널에 속한 모든 항목에 대하여 Enable 처리
 * @param panel_name 패널명
 * @param objBizScreen 해당 화면
 * @param type_name 특정 타입의 컨포넌트만 enable하고 싶은 경우 (Option)
 * @return 없음
 */
function enableAll(objBizScreen, panel_name, type_name) {
	var components = this.getallcomponent(objBizScreen, panel_name);
	var size = components.length;
	var styleid = "";

	for (var i = 0; i < size; i++) {
		components[i].setenable(true);
	}
}

/**
 * 패널안의 컨트롤들을 탭오더 기준으로 Array에 저장 후 반환
 * @param panel_name 패널명
 * @param objBizScreen 해당 화면
 * @return arrControls 패널 안의 컴포넌트 리스트
 */
function getallcomponent(objBizScreen, panel_name) {
	var panel = objBizScreen.getinstancebyname(panel_name);
	var arrControls = new Array();

	// 1. 패널의 첫 컴포넌트 조회
	var instFirst = panel.getinstancefirstex(0);

	// 2. 패널 내부의 컴포넌트가 없는 경우 빈 배열 반환
	if (factory.isobject(instFirst) == false) {
		return arrControls;
	}

	// 3. 다음 컴포넌트 조회 후 Object가 맞는 경우 Array에 추가
	//	do {
	arrControls.push(instFirst);
	instFirst = panel.getinstancenextex(instFirst, 0);
	//	}
	while (factory.isobject(instFirst)) {
		if (instFirst != null) {
			arrControls.push(instFirst);
			instFirst = panel.getinstancenextex(instFirst, 0);
		}
	}
	return arrControls;
}

/**
 * 업무별 공통 라이브러리를 로드하여 멤버 오브젝트를 반환한다.
 * @param objScreen 업무화면 오브젝트
 * @param strBizCd 업무코드
 * @param strLibNm 라이브러리 화면ID
 * @return 성공시 Library 화면 멤버, 실패시 null
 */
function getLibMember(objScreen, strBizCd, strLibNm) {
	/**
	 * 업무 시스템코드에 해당하는 해당공통화면을 오픈하고 해당화면 오브젝트를 반환한다.
	 */
	function getPartCommonScreen(objTab, strBizCd, strLibScreenUrl) {
		var objPartScreen = null; // 오픈할 공통화면
		var nTabIndex = -1; //

		// 이미 열려있다면..
		nTabIndex = getPartCommonTabIndex(objTab, strLibScreenUrl);
		console.log("strLibScreenUrl:" + strLibScreenUrl);
		if (nTabIndex >= 0) {
			objPartScreen = objTab.getchildscreeninstance(nTabIndex);
		}
		return objPartScreen;
	}

	/**
	 * 업무 시스템코드 탭 인덱스를 가져온다.
	 */
	function getPartCommonTabIndex(objTab, strLibScreenUrl) {
		var nTabIdx = -1;

		for (var i = 0; i < objTab.gettabitemcount(); i++) {
			// 업무 시스템별 여러개의 공통화면을 띄울 수 있어서 full path로 확인한다.
			if (objTab.getinnerscreenurl(i) == strLibScreenUrl) {
				nTabIdx = i;
				break;
			}
		}

		return nTabIdx;
	}

	var strLibScreenUrl = "/" + strBizCd + "/LIB/" + strLibNm;
	var objPartScreen = getPartCommonScreen(this.tabLib, strBizCd, strLibScreenUrl);
	if (isPortletObject(objPartScreen) == false || objPartScreen == null) {
		return null;
	}
	console.log("objPartScreen:" + objPartScreen.getscreenid());
	return objPartScreen.getmembers();
}

function getActiveScreen() {
	return SYSVar.ACTIVE_SCREEN;
}

/**
 *	기준 날짜를 기준으로 계산된 간격을 반환한다.
 **/
function getDateDiff(objScreen, objStartComponent, objEndComponent) {
	if (factory.isobject(objStartComponent) && factory.isobject(objEndComponent)) {
		return factory.datediff("day", objStartComponent.gettext(), objEndComponent.gettext());
	}
}

/**
 * 업무화면의 프레임 스크립트 멤버을 구한다.(portlet 화면에서 사용)
 * @param objScreen 업무화면 오브젝트 or this
 * @return objFrameMembers [스크립트 멤버 | null]
 */
//function getFrameMembers(objParam) {
//	// TODO : 메인프레임 또는 팝업프레임을 찾을때까지 while 문으로 변경처리
//	// MAIN_PORTLET , POPUP_FRAME
//	var objFrameMembers = null;
//	var objparent;
//	if (isScrObject(objParam) == true) {
//		objparent = objParam.getparent();
//		if (objparent) {
//			objFrameMembers = objparent.getmembers();
//
//			if (factory.isobject(objFrameMembers)) {
//				if (factory.isfunction(objFrameMembers["_getFrameType"])) {
//					let strTemp = objFrameMembers["_getFrameType"]();
//				} else {
//					objparent = objparent.getparent();
//					objFrameMembers = objparent.getmembers();
//					if (factory.isfunction(objFrameMembers["_getFrameType"])) {
//						let strTemp = objFrameMembers["_getFrameType"]();
//						return objFrameMembers;
//					}
//				}
//			}
//		}
//	} else {
//		objFrameMembers = objParam.screen.getparent().getmembers();
//	}
//	return objFrameMembers;
//}

/**
 * 업무화면의 프레임 스크립트 멤버을 구한다.(portlet 화면에서 사용)
 * @param objScreen 업무화면 오브젝트 or this
 * @return objFrameMembers [스크립트 멤버 | null]
 */
function getFrameMembers(objParam)
{
	// TODO : 메인프레임 또는 팝업프레임을 찾을때까지 while 문으로 변경처리 
	// MAIN_PORTLET , POPUP_FRAME
	var objFrameMembers = null;
	var objScreen;
	var objparent;
	var bLoof = true;
	if(isScrObject(objParam) == true) {
		
		objScreen = objParam;
		let nCnt = 0;
		let nMaxCnt = 10;
				
		while(bLoof){
			
			objparent = objScreen.getparent();
			if (objparent ==  null || objScreen.getobjectkind() != XFD_OBJKIND_SCREEN) {
				//부모화면이 없다.
				bLoof = false;
				return null;			
				//break;
			}
			objFrameMembers = objparent.getmembers();

			if (factory.isobject(objFrameMembers) && factory.isfunction(objFrameMembers["_getFrameType"])) {
				nCnt ++;
				return objFrameMembers;
			}else{
				nCnt ++;
				objScreen = objparent;
				if (nCnt > nMaxCnt){
					console.log("[SYSLOG]SYSUtil 화면의 프레임멤버를 찾을수 없습니다. 10회 초과로 중지");
					bLoof = false;
					return null;
					//break;
				}
			}
		}
			
	} else {
		objFrameMembers = objParam.screen.getparent().getmembers();
	}
	return objFrameMembers;
}


/**
 * 해당값이 비어있는지 확인
 * @param obj : object : 확인할 값
 * @return boolean : 빈값여부
 * @remark
 */
function isEmpty(obj) {
	return obj == undefined || obj == null || obj.length == 0;
}

/**
 * 해당값이 배열인지 확인
 * @param obj : object : 확인할 값
 * @return boolean : 배열여부
 * @remark
 */
function isArray(obj) {
	return Array.isArray(obj);
}
/**
 * 해당값이 JSON인지 확인
 * @param obj : object : 확인할 값
 * @return boolean : JSON여부
 * @remark
 */
function isJSON(obj) {
	return (typeof factory.jsonparse(factory.jsonstringify(obj))) != "string";
}
/**
 * 문자열을 JSON Obejct로 전환
 * @param obj : json String..
 * @return boolean : JSON
 * @remark
 */
function strToJSON(str){
	return factory.jsonparse(str);
}
/**
 * 문자열을 JSON Obejct로 전환
 * @param obj : json String..
 * @return boolean : JSON
 * @remark
 */
function stringToJSON(str){
	return factory.jsonparse(str);
}
/**
 * 해당값이 숫자인지 여부 확인
 * @param obj : object : 확인할 값
 * @return boolean : 숫자여부
 * @remark
 */
function isNumber(obj) {
	//return (typeof obj === "number" || obj instanceof Number || (typeof obj === "string" && !isNaN(obj))) && isFinite(obj);
	// "11"같은 string값은 배제해야 할듯.
	return (typeof obj === "number" || obj instanceof Number) && isFinite(obj);
}
/**
 * replaceAll
 * @param str : string : 대상 문자열
 * @param strSearch : string : 검색문자열
 * @param strReplace : string : replace할 문자열
 * @param bCase : boolean : [옵션] 대소문자 구분여부(Default:true)
 * @return string : replace된 문자열
 * @remark
 */
function replaceAll(str, strSearch, strReplace, bCase) {
	if (isEmpty(bCase)) {
		bCase = false;
	}
	var reg = bCase ? new RegExp(strSearch, "g") : new RegExp(strSearch, "gi");

	return str.replace(reg, strReplace);
}

/**
 * 컴포넌트 여부를 확인한다
 * @param objCtrl 컴포넌트
 * @return true, false
 */
function isObjCtrl(objCtrl) {
	try {
		if (factory.isobject(objCtrl) == true && objCtrl.getobjectkind() == XFD_OBJKIND_CONTROL && objCtrl.isexpired() == false) {
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] isObjCtrl Error :" + e.message);
	}
	return false;
}

/**
 * 컴포넌트 여부를 확인한다
 * @param objCtrl 컴포넌트
 * @param nControlKind 컴포넌트 종류
 * @return true, false
 */
function isObjCtrlEx(objCtrl, nControlKind) {
	try {
		if (factory.isobject(objCtrl) == true && objCtrl.getobjectkind() == XFD_OBJKIND_CONTROL && objCtrl.getcontrolkind() == nControlKind && objCtrl.isexpired() == false) {
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] (isObjCtrlEx) Error :" + e.message);
	}
	return false;
}

/**
 * 도형 여부를 확인 한다.
 * @param objShape 도형 컴포넌트
 * @return true, false
 */
function isObjShape(objShape) {
	try {
		if (factory.isobject(objShape) == true && objShape.getobjectkind() == XFD_OBJKIND_SHAPE && objShape.isexpired() == false) {
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] (isObjShape) Error :" + e.message);
	}
	return false;
}

/**
 * 화면에 스크립트 메서드가 있는지 확인한다.
 * @param objScreen 확인 하고자 하는 화면
 * @param strScriptMethod 스크립트 메서드
 * @return true, false
 */
function isScriptMethod(objScreen, strScriptMethod) {
	try {
		if (this.isScrObject(objScreen) == true) {
			return objScreen.findscriptmethod(XFD_JAVASCRIPT, strScriptMethod);
		}
	} catch (e) {
		console.log("[SYSLOG] (isScriptMethod) Error :" + e.message);
	}
	return false;
}

/**
 * 화면 오브젝트인지 검증한다.
 * @param objScreen 업무화면 오브젝트
 * @return true, false
 */
function isScrObject(objScreen) {
	try {
		if (factory.isobject(objScreen) == true && objScreen.getobjectkind() == XFD_OBJKIND_SCREEN) {
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] (isScrObject) Error :" + e.message);
	}
	return false;
}

/**
 * 포틀릿 화면 오브젝트인지 검증한다.
 * @param objScreen 업무화면 오브젝트
 * @return true, false
 */
function isPortletObject(objScreen) {
	try {
		if (factory.isobject(objScreen) == true && objScreen.getobjectkind() == XFD_OBJKIND_SCREEN && objScreen.getscreentype() == 1) {
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] (isPortletObject) Error :" + e.message);
	}
	return false;
}

/**
 * 화면에 이벤트처리 함수가 링크되어 있는지 확인 한다.
 * @param objScreen 업무화면 오브젝트
 * @param strEventName 이벤트명
 * @return true, false
 */
function isScrEventHandler(objScreen, strEventName) {
	var strRetData = "";
	try {
		if (this.isScrObject(objScreen) == true) {
			strRetData = objScreen.geteventhandler(strEventName);
			if (strRetData == "") {
				return false;
			}
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] (isScrEventHandler) Error :" + e.message);
	}
	return false;
}

/**
 * 컴포넌트에 이벤트처리 함수가 링크되어 있는지 확인 한다.
 * @param objScreen 업무화면 오브젝트
 * @param strEventName 이벤트명
 * @return true, false
 */
function isCtrlEventHandler(objCtrl, strEventName) {
	var strRetData = "";
	try {
		if (this.isObjCtrl(objCtrl) == true) {
			strRetData = objCtrl.geteventhandler(strEventName);
			if (strRetData == "") {
				return false;
			}
			return true;
		}
	} catch (e) {
		console.log("[SYSLOG] (isCtrlEventHandler) Error :" + e.message);
	}
	return false;
}

/**
 * POPUP 화면을 로드처리한다.
 * @param {Object} popupTitle : 팝업창 Title
 * @param {Object} popupPath : 팝업창 경로
 * @param {Object} param : 팝업창에서 사용될 parameter
 */
function loadPopup(AParentScr, popupTitle, popupPath, param) {
	
	//console.log("##############"+AParentScr.getscreenid());
	
	var objFrameInfo = [
		{ FrameUrl: "/SYS/FRAME/popupFrame", isPortlet: true },
		{ FrameUrl: "/SYS/FRAME/popupContainer", isPortlet: false },
		{ FrameUrl: "/SYS/FRAME/popupFrameMain", isPortlet: true },
	];
	
	var AExtraData = {};
	let objExtra_data = {};
	
	var winPopGbn = false;
	
	if(param != null && param != undefined){
		param.BIZSCREENID = AParentScr.getscreenid();
		if( param.WINPOPGBN == undefined){
			param.WINPOPGBN = false;
		}
		if( param.WINPOPGBN == true){
			winPopGbn = true;
		}
	}else{
		param = {"WINPOPGBN":false};
	}

	AExtraData.RESIZE = false;
	AExtraData.MODAL = true;

	objExtra_data.SEND_DATA = param; // 업무화면으로 전달할 데이터
	
	if(popupPath=="/SYS/UTIL/sessionMessage"){
		objExtra_data.RETURN_FUNCTION_NAME = "sessionCheckCallBack";
	}else{
		objExtra_data.RETURN_FUNCTION_NAME = "popupCallback"; // 팝업을 호출한 화면에서 data를 받는 function
	}
	
	// 공통팝업 구성 데이터
	AExtraData.SCR_ID     = "";
	AExtraData.SCR_PATH   = popupPath;
	AExtraData.MENU_ID    = "";
	AExtraData.MENU_NM    = popupTitle;
	AExtraData.P_MENU_ID  = "";
	AExtraData.PARENT_SCR = AParentScr;
	AExtraData.EXT_DATA   = objExtra_data; 
	AExtraData.POPUP_NAME = AParentScr.getscreenid();
	
	
	AExtraData.SEND_DATA = param;
	
	// AFrameType 프레임 형식 0:포틀릿 방식(기본값), 1:일반 컨테이너방식
	// hafl 프로젝트에서는 포틀릿 방식 사용
	var AFrameType = 0;
	var objInfo = objFrameInfo[AFrameType];
	if (objInfo == undefined) {
		// 기본값 0번
		objInfo = objFrameInfo[0];
	}
	
	var strPopupName = AExtraData.POPUP_NAME;
	//AExtraData.POPUP_NAME = strPopupName;

	// 팝업이름이 없을경우 임의의값 설정
	if (this.isEmpty(strPopupName)) {
		strPopupName = "POPUP_" + factory.getsystemtime("%h%m%s%ms");
	}
	
	if(winPopGbn==true){
		objInfo.isPortlet = false;
		strPopupName =  popupPath.substring((popupPath.lastIndexOf("/")+1));
	}
	

	if (objInfo.isPortlet === true) {
		// 포틀릿 형식으로 로드한다.
		AParentScr.loadportletpopup(strPopupName, objInfo.FrameUrl, "POPUP_PORTLET", true, 0, 0, 0, 0, 0, true, false, false, AExtraData);
	} else {
		
		// 일반형식으로 로드한다.
		factory.loadpopupex(strPopupName, objInfo.FrameUrl, popupTitle , false, 0, 0, 0, 0, 0, true, true, false, AParentScr, AExtraData);
	}
	
	// 다중팝업상태를 체크하기 위해 팝업이름을 저장
	SYSVar.OPEN_POPUP_SCREEN.push(strPopupName);
}

/**
 * POPUP 화면을 로드처리한다.
 * @param {Object} AParentScr 호출하는 부모화면
 * @param {Object} AExtraData 호출할때 넘겨주는 데이터값
 * @param {Number} AFrameType 프레임 형식 0:포틀릿 방식(기본값), 1:일반 컨테이너방식
 */
function loadPopupEx(AParentScr, AExtraData, AFrameType) {
	let resize = AExtraData.RESIZE;
	let modal = AExtraData.MODAL;
	if (modal !== false) modal = true;
	if (!resize) resize = false;
	var objFrameInfo = [
		{ FrameUrl: "/SYS/FRAME/popupFrame", isPortlet: true },
		{ FrameUrl: "/SYS/FRAME/popupContainer", isPortlet: false },
		{ FrameUrl: "/SYS/FRAME/popupFrameMain", isPortlet: true },
	];
	var objInfo = objFrameInfo[AFrameType];
	if (objInfo == undefined) {
		// 기본값 0번
		objInfo = objFrameInfo[0];
	}
	var strPopupName = "POPUP_" + factory.getsystemtime("%h%m%s%ms");
	AExtraData.POPUP_NAME = strPopupName;

	if (objInfo.isPortlet === true) {
		// 포틀릿 형식으로 로드한다.
		AParentScr.loadportletpopup(strPopupName, objInfo.FrameUrl, "POPUP_PORTLET", true, resize == true ? XFD_BORDER_RESIZE : 0, 0, 0, 0, 0, false, false, false, AExtraData);
	} else {
		// 일반형식으로 로드한다.
		factory.loadpopupex(strPopupName, objInfo.FrameUrl, "POPUP_SCREEN", true, resize == true ? XFD_BORDER_RESIZE : 0, 0, 0, 0, 0, true, false, modal == true ? true : false, AParentScr, AExtraData);
	}
	// 다중팝업상태를 체크하기 위해 팝업이름을 저장
	SYSVar.OPEN_POPUP_SCREEN.push(strPopupName);
}

/**
 * 주소검색 팝업 화면을 로드처리한다.
 */
function loadPopupAddr(AParentScr, strCallScript) {
	var objPopup_data = {};
	let objExtra_data = {};

	// 검색팝업으로 전달할 데이터
	objExtra_data.RETURN_FUNCTION_NAME = strCallScript;
	objExtra_data.PARENT_SCR = AParentScr;

	// 공통팝업 구성 데이터
	objPopup_data.SCR_ID = "";
	objPopup_data.SCR_PATH = "/SBT/TEMP/COM_POPUP_ADDR";
	objPopup_data.MENU_ID = "COM_POPUP_ADDR";
	objPopup_data.MENU_NM = "주소검색";
	objPopup_data.P_MENU_ID = "";
	objPopup_data.PARENT_SCR = AParentScr;
	objPopup_data.EXT_DATA = objExtra_data;

	this.loadPopup(AParentScr, objPopup_data, 2);
	
}

/**
 * 주소검색 팝업 화면을 로드처리한다.
 */
function loadPopupAddrApi(AParentScr, strCallScript) {
	var objPopup_data = {};
	let objExtra_data = {};

	// 검색팝업으로 전달할 데이터
	objExtra_data.RETURN_FUNCTION_NAME = strCallScript;
	objExtra_data.PARENT_SCR = AParentScr;

	// 공통팝업 구성 데이터
	objPopup_data.SCR_ID = "";
	objPopup_data.SCR_PATH = "/SBT/TEMP/COM_POPUP_ADDR_API";
	objPopup_data.MENU_ID = "COM_POPUP_ADDR";
	objPopup_data.MENU_NM = "주소검색 (juso.go.kr API)";
	objPopup_data.P_MENU_ID = "";
	objPopup_data.PARENT_SCR = AParentScr;
	objPopup_data.EXT_DATA = objExtra_data;

	this.loadPopup(AParentScr, objPopup_data, 2);
}

/**
 * 팝업 화면 호출
 * @param {object} objScreen  화면 오브젝트
 * @param {string} strMenuId 호출할 메뉴ID
 * @return 없음
 */
function loadPopupByMenuId(objScreen, strMenuId, objMenuInfo, objExtdata) {
	var objExtra_data = {
		SCR_ID: "",
		SCR_PATH: "",
		MENU_ID: "",
		MENU_NM: "",
		P_MENU_ID: "",
		PARENT_SCR: null,
		BIZ_EXT: null,
	};

	//var objMenuInfo = SYSVar.MENU_BY_ID[strMenuId];

	objExtra_data.SCR_ID = "";
	objExtra_data.SCR_PATH = objMenuInfo.menu_path;
	objExtra_data.MENU_ID = objMenuInfo.menu_id;
	objExtra_data.MENU_NM = objMenuInfo.menu_nm;
	objExtra_data.P_MENU_ID = "";
	objExtra_data.PARENT_SCR = objScreen;
	objExtra_data.EXT_DATA = objExtdata;

	this.loadPopup(objScreen, objExtra_data, 2);
}

/**
 * 화면 호출 (메뉴PATH 기준)
 * @param {object} objScreen  화면 오브젝트
 * @param {string} strScrUrl  호출할 메뉴PATH
 * @param {string} strItemTitle 메뉴타이틀
 */
function loadPortletByPath(objScreen, strScrUrl, strItemTitle) {
	console.log("[SYSLOG] loadPortletByPath() Call");
	var strFrameUrl = "/SYS/FRAME/mainFrame";
	if (strItemTitle == undefined) strItemTitle = "";

	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;
	// 화면 정보가 있는지 체크

	var objExtra_data = {
		SCR_ID: "",
		SCR_PATH: strScrUrl,
		MENU_ID: "",
		MENU_NM: strItemTitle,
		P_MENU_ID: "",
		PARENT_SCR: factory.getmainscrinstance(),
		BIZ_EXT: null,
	};

	SYSVar.SELECTED_MIDDLE_TAB.addportlettab("", 0, 60, strFrameUrl, "", true, objExtra_data);
}

/**
 * 화면 호출 (메뉴ID 기준)
 * @param {object} objScreen  화면 오브젝트
 * @param {string} strMenuId  호출할 메뉴ID
 * @param {object} objMenuInfo 메뉴정보 오브젝트
 */
function loadPortletByMenuId(objScreen, strMenuId, objMenuInfo) {
	
	//console.log("# [SYS LOG] loadPortletByMenuId() Call");
	//console.log("# [SYS LOG] loadPortletByMenuId() objScreen :"+objScreen.getscreenid());
	//console.log("# [SYS LOG] loadPortletByMenuId() objMenuInfo ");
	//console.log(objMenuInfo);
	
	var strFrameUrl = "/SYS/FRAME/mainFrame";
	
	// 임시 : 수당메뉴일경우 프레임분기 
	//if ( strMenuId.substr(0,2) == "SD") {
	//	strFrameUrl = "/SYS/FRAME/mainFrameSudang";
	//}
	
	
	//SYSVar.SELECTED_MIDDLE_TAB ??= SYSVar.MIDDLE_TAB;
	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;

	var objExtra_data = {
		SCR_ID: "",
		SCR_PATH: "",
		MENU_ID: "",
		MENU_NM: "",
		P_MENU_ID: "",
		PARENT_SCR: null,
		BIZ_EXT: null,
	};

	objExtra_data.SCR_ID    = objMenuInfo.scr_id;
	objExtra_data.SCR_PATH  = objMenuInfo.menu_path;
	objExtra_data.MENU_ID   = objMenuInfo.menu_id;
	objExtra_data.MENU_NM   = objMenuInfo.menu_nm;
	objExtra_data.NAVI_PATH = objMenuInfo.navi_path;
	objExtra_data.P_MENU_ID = "";
	
	//	SYSVar.LEFTMAIN_SCREEN.eventlock(true, true);
	SYSVar.SELECTED_MIDDLE_TAB.addportlettab(objMenuInfo.menu_nm, 0, 0, strFrameUrl, "", true, objExtra_data);
	//	return SYSVar.SELECTED_MIDDLE_TAB.addportlettab("", 0, 60, strFrameUrl, "", true, objExtra_data);
}

/**
 * 이전에 열려있던 화면 호출
 * @param 없음
 * @return 없음
 */
function loadOpenHistoryMenu(){
	
	if (SYSVar.OPEN_MENU_INFO_USE) {
		
		let objOpenMenuInfoList;
		if (sessionStorage.getItem("menuInfoHistory") != null && sessionStorage.getItem("menuInfoHistory") != "") {
			objOpenMenuInfoList = JSON.parse(sessionStorage.getItem("menuInfoHistory"));
		}

		for (nIdx in objOpenMenuInfoList) {
			
			let objOpenMenuInfo = objOpenMenuInfoList[nIdx];
			console.log(objOpenMenuInfo);
			let strMenuId = objOpenMenuInfo.MENU_ID;
			
			var strFrameUrl = "/SYS/FRAME/mainFrame";
			// 임시 : 수당메뉴일경우 프레임분기 
			if ( strMenuId.substr(0,2) == "SD") {
				strFrameUrl = "/SYS/FRAME/mainFrameSudang";
			}
			
			
			SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;
		
			var objExtra_data = {};
		
			objExtra_data.SCR_ID = "";
			objExtra_data.SCR_PATH = objOpenMenuInfoList[nIdx].SCR_PATH;
			objExtra_data.MENU_ID = objOpenMenuInfoList[nIdx].MENU_ID;
			objExtra_data.MENU_NM = objOpenMenuInfoList[nIdx].MENU_NM;
			objExtra_data.NAVI_PATH = objOpenMenuInfoList[nIdx].NAVI_PATH;
			objExtra_data.P_MENU_ID = "";

			SYSVar.SELECTED_MIDDLE_TAB.addportlettab(objOpenMenuInfoList[nIdx].MENU_NM, 0, 0, strFrameUrl, "", true, objExtra_data, false, false, false);		
		} 
		
	}
	
}


/**
 * 팝업 화면 호출
 * @param {object} objScreen  화면 오브젝트
 * @param {string} strMenuId 호출할 메뉴ID
 * @return 없음
 */
function loadPortletPopupByMenuId(objScreen, strMenuId, objMenuInfo, objExtdata) {
	var objExtra_data = {
		SCR_ID: "",
		SCR_PATH: "",
		MENU_ID: "",
		MENU_NM: "",
		P_MENU_ID: "",
		PARENT_SCR: null,
		BIZ_EXT: null,
	};

	// {menu_id: l_MenuId, menu_nm : l_MenuNm, menu_path : l_MenuPath, menu_level: l_MenuLevel, sort_no: l_SortNo, menu_row: iIdx, child: [] }
	//	var objMenuInfo = SYSVar.MENU_BY_ID[strMenuId];

	objExtra_data.SCR_ID = "";
	objExtra_data.SCR_PATH = objMenuInfo.menu_path;
	objExtra_data.MENU_ID = objMenuInfo.menu_id;
	objExtra_data.MENU_NM = objMenuInfo.menu_nm;
	objExtra_data.P_MENU_ID = "";
	objExtra_data.PARENT_SCR = objScreen;
	objExtra_data.EXT_DATA = objExtdata;

	this.loadPopup(objScreen, objExtra_data, PORTLET_FRAME);
}

/*
 * 업무화면 로드 처리한다.
 * @param {Object} AParentScr 호출하는 부모화면
 * @param {Object} AExtraData 호출할때 넘겨주는 데이터값
 * @param {Number} AFrameType 프레임 형식 0:포틀릿(기본값), 1:컨테이너 방식
 */
function loadScreen(AParentScr, AExtraData, AFrameType) {
	var nRet = 0;
	//SYSVar.SELECTED_MIDDLE_TAB ??= SYSVar.MIDDLE_TAB;
	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;

	var objFrameInfo = [
		{ FrameUrl: "/SYS/FRAME/mainFrame", isPortlet: true },
		{ FrameUrl: "/SYS/FRAME/mainContainer", isPortlet: false },
	];
	var objInfo = objFrameInfo[AFrameType];
	if (objInfo == undefined) {
		// 범위 외면은 기본값 0번
		objInfo = objFrameInfo[0];
	}
	if (objInfo.isPortlet === true) {
		// 포틀릿 형식으로 로드한다.
		//= 파라미터 bVisible 값은 true 로 주어야 신규 생성된 탭으로 포커스가 이동됨
		nRet = SYSVar.SELECTED_MIDDLE_TAB.addportlettab("", 0, 120, objInfo.FrameUrl, "", true, AExtraData);
	} else {
		// 일반형식으로 로드한다.
		//= 파라미터 bVisible 값은 true 로 주어야 신규 생성된 탭으로 포커스가 이동됨
		nRet = SYSVar.SELECTED_MIDDLE_TAB.addtab("", 0, 120, objInfo.FrameUrl, true, AExtraData);
	}

	if (nRet == -1) {
		screen.alert("화면 호출 오류[" + nRet + "]");
	}
}

/**
 * 메시지 팝업 화면 호출(화면 on_messagebox 이벤트 호출)
 * @param {object} objScreen  화면 오브젝트
 * @param {object} strTitle  메시지 팝업 타이틀
 * @param {object} nMsgType  메시지 팝업 타입
  							XFD_MB_INFORMATION or 1
	  						XFD_MB_ERROR       or 2
		  					XFD_MB_QUESTION    or 3
			  				XFD_MB_STOP        or 4
 * @param {object} nBtnType  화면 오브젝트
	  						XFD_MB_OK                  or 1
		  					XFD_MB_OKCANCEL            or 2
					  		XFD_MB_YESNOCANCEL         or 3
 * @param {object} strMsg    메시지 내용
 * @param {object} nFocus    화면 오브젝트
							  XFD_MB_FOCUSBUTTON1 or 0
							  XFD_MB_FOCUSBUTTON2 or 1
							  XFD_MB_FOCUSBUTTON3 or 2
 * @param {object} strMsgId  on_messagebox에서 받을 메시지 ID
 * @return 없음
 */
                        
function loadMessageBox(objScreen, strTitle, nBtnType, strMsg, strMsgId) {
	// ExcelDownInfo
	var strPopupName = strMsgId;
	var strUrl = "/SYS/UTIL/messageBox";
	var extraData = {
		CALLTYPE: 1,
		TITLE: strTitle,
		MSG_TYPE: 1,
		BTN_TYPE: nBtnType,
		MSG: strMsg,
		FOCUS: 1,
		MSG_ID: strMsgId,
	};
	objScreen.loadportletpopup(strPopupName, strUrl, "MESSAGE_PORTLET", true, 0, 0, 0, 0, 0, true, true, false, extraData);
}

/**
 ※ 사용안하는 것으로 확정 2023-03-13
 * 메시지 팝업 화면 호출(화면 내 callback 호출)
 * @param {object} objScreen  화면 오브젝트
 * @param {object} strTitle  메시지 팝업 타이틀
 * @param {object} nMsgType  메시지 팝업 타입
  							XFD_MB_INFORMATION or 1
	  						XFD_MB_ERROR       or 2
		  					XFD_MB_QUESTION    or 3
			  				XFD_MB_STOP        or 4
 * @param {object} nBtnType  화면 오브젝트
  							XFD_MB_ABORTRETRYIGNORE    or 1
	  						XFD_MB_OK                  or 2
		  					XFD_MB_OKCANCEL            or 3
			  				XFD_MB_RETRYCANCEL         or 4
				  			XFD_MB_YESNO               or 5
					  		XFD_MB_YESNOCANCEL         or 6
						  	XFD_MB_CANCELRETRYCONTINUE or 7
 * @param {object} strMsg    메시지 내용
 * @param {object} nFocus    화면 오브젝트
							  XFD_MB_FOCUSBUTTON1 or 0
							  XFD_MB_FOCUSBUTTON2 or 1
							  XFD_MB_FOCUSBUTTON3 or 2
 * @param {object} strCallScript  callback 화면내 수신 받을 함수
 * @return 없음

function loadMessageBoxEx(objScreen, strTitle, nBtnType, strMsg, strCallScript) {
	var strPopupName = "MessagBox";
	var strUrl = "/SYS/UTIL/messageBox";
	var extraData = {
		CALLTYPE: 2,
		TITLE: strTitle,
		MSG_TYPE: 1,
		BTN_TYPE: nBtnType,
		MSG: strMsg,
		FOCUS: 1,
		CALLFUNC: strCallScript,
	};
	objScreen.loadportletpopup(strPopupName, strUrl, "MESSAGE_PORTLET", true, 0, 0, 0, 0, 0, true, true, false, extraData);
}
 */
function loadCommonButtonGroup(frameScreenInst) {
	if (!_BizCommonBtnJsLoaded) screen.loadjs(_xf_param.SCREENBASEURL + "/SYS/EXPAND/BizCommonButtonGroup.js");
	console.log("	");

	let xdataset = frameScreenInst.getxdataset("_ds_common_btn");

	let screenInfo = frameScreenInst.getmembers().getScreenInfo();

	xdataset.copy(G_COMM_BTN, '"MENU_ID":=:"' + screenInfo.MENU_ID + '"', false);
	
	console.log("MENU_ID  >>>>> " + screenInfo.MENU_ID);

	let defHiddenArray = [];
	let defDisable = [];
	let defButtons = [];
	let idx;

	if (xdataset.getrowcount() > 0) {
		for (idx = 0; idx < SYSVar.COMMON_BUTTON_LIST.length; idx++) {
			let colIdx = xdataset.getcolumn("BUTTON_ID");
			let commonBtnInfo = SYSVar.COMMON_BUTTON_LIST[idx];
			let findIdx = xdataset.findrow(0, colIdx + ':=:"' + commonBtnInfo.ID + '":1:&');
			if (findIdx > -1) {
				defButtons.push(commonBtnInfo);

				let useYn = xdataset.getdatabyname(findIdx, "USE_YN");
				let btnTyCd = xdataset.getdatabyname(findIdx, "BUTTON_TY_CD");
				if (btnTyCd !== "01") {
					if (useYn == 1 || useYn === 1) {
						defHiddenArray.push(false);
						defDisable.push(false);
					} else {
						defHiddenArray.push(false);
						defDisable.push(true);
					}
				} else {
					if (useYn == 1 || useYn === 1) {
						defHiddenArray.push(false);
						defDisable.push(false);
					} else {
						defHiddenArray.push(true);
						defDisable.push(true);
					}
				}
			}
		}
	}

	let hiddenInfo = defHiddenArray;
	let disableInfo = defDisable;

	return new clsBizCommonButtonGroup(frameScreenInst, undefined, defButtons, hiddenInfo, disableInfo, "BTN_COMMON");
}

/**
 * 로그아웃 처리
 */
function logOut(objScreen){
	// TODO : 로그아웃 처리전 비지니스 로직 처리
	
	// 현재 열린 업무화면을 모두 삭제한다.
	SYSVar.MIDDLE_TAB.deletealltab(true, false);
	// 로그인 여부값을 변경
	SYSVar.LOGINCOMPLETE = false;
	// 로그인 화면으로 포커스 이동
	SYSVar.STARTMAIN_TAB.settabitemfocus(0); 
	
	/*
	var popupid =SYSVar.ACTIVE_POPUP_SCREEN.getscreenid();
	if(popupid!=null && popupid!=undefined && popupid!=""){
		console.log("########## log out... popup close... ######");
		SYSVar.ACTIVE_POPUP_SCREEN.getmembers()._btnPopClose_on_mouseup();
	}
	*/
}

/**
 * 메뉴정보데이타 가공처리
 * 로그인 완료시 글로벌 데이타셋에 정보를 셋팅 필요
 * Module 에서 SYSUtil 로 이동처리
 * @param 없음
 * @return 없음
 */
function makeUpMenuData() {
	//console.log("[SYSLOG]makeUpMenuData()");
	SYSVar.MENU_BY_ID = [];
	SYSVar.MENU_BY_ID_LEFT = []; // LEFT 메뉴를 별도로 설정한다.
	SYSVar.MENU_BY_ID_TEMPLET = []; // 템플릿용 LEFT 메뉴를 별도로 설정한다.
	SYSVar.MENU_TREE = [];
	SYSVar.MENU_TREE_LEFT = []; // LEFT 메뉴를 별도로 설정한다.
	SYSVar.MENU_TREE_TEMPLET = []; // 템플릿용 LEFT 메뉴를 별도로 설정한다.

	var l_ParentTempNode = null;
	var l_ParentNode = null;
	var iIdx;

	/**
	 *	AS-IS 메뉴 조회시 상위메뉴 코드를 가저오지않기 때문에 임의로 추가 로직을 수행함.
	 *	SQL 변경하여 상위코드를 가저올수 있다면 불필요한 코드임.
	 **/
	var t_parentCode = []; /* 상위메뉴코드를 담을 배열 추가 */

	var l_MenuId, l_MenuLevel, l_HighMenuId, l_SortNo, l_MenuNm, l_MenuPath, l_SelfNode, l_isDisplay, l_Icon, l_popup, l_NaviPath;

	// 임시 : 수당 메뉴를 1레벨에 추가한다. 
	// DATASET : G_SUDANG_MENU
	// G_MENU + G_SUDANG_MENU 
	
	
	//G_MENU.init();
	//G_MENU.copyinsert(-1, G_A_MENU, "", false, false);  // 회계
	//G_MENU.copyinsert(-1, G_S_MENU, "", false, false);  // 영업관리(구) => 심사실행
	//G_MENU.copyinsert(-1, G_C_MENU, "", false, false);  // 공통(구) => 일반관리
	//G_MENU.copyinsert(-1, G_R_MENU, "", false, false);  // 정산관리(구) => 계좌관리
	//G_MENU.copyinsert(-1, G_B_MENU, "", false, false);  // 채권관리(구) => 사후관리
	
	
	//console.log(SYSVar.loginUserInfo.USER_NO);
	//console.log(SYSVar.loginUserInfo.USER_NO);
	//console.log(SYSVar.loginUserInfo.USER_NO);
	
	//if( SYSVar.loginUserInfo.USER_NO == "system" ){
	//	G_MENU.copyinsert(-1, G_DEV_MENU, "", false, false);  // 개발참고
	//}
	
	//G_MENU.copyinsert(-1, G_SUDANG_MENU, "", false, false); // 수당메뉴
	
	for (iIdx = 0; iIdx < G_MENU.getrowcount(); iIdx++) {
//		l_MenuId = GDS_MENU.getdatabyname(iIdx, "MENU_ID");
//		l_MenuLevel = GDS_MENU.getdatabyname(iIdx, "MENU_LEVEL");
//		//l_HighMenuId = GDS_MENU.getdatabyname(iIdx, "MENU_GROUP");  /* 상위메뉴 코드가 없다. */
//		l_HighMenuId = "";
//		l_SortNo = "";
//		l_MenuNm = GDS_MENU.getdatabyname(iIdx, "MENU_NM");
//		l_MenuPath = GDS_MENU.getdatabyname(iIdx, "URL");
//		l_NaviPath = GDS_MENU.getdatabyname(iIdx, "MENU_PATH");
		
		l_MenuId = G_MENU.getdatabyname(iIdx, "menuId");
		l_MenuLevel = G_MENU.getdatabyname(iIdx, "menuLevel");
		l_HighMenuId = G_MENU.getdatabyname(iIdx, "highMenuId");
		l_SortNo = G_MENU.getdatabyname(iIdx, "sortNo");
		l_MenuNm = G_MENU.getdatabyname(iIdx, "menuName");
		l_MenuPath = G_MENU.getdatabyname(iIdx, "programPath");
		l_isDisplay = G_MENU.getdatabyname(iIdx, "isDisplay");
		l_Icon = G_MENU.getdatabyname(iIdx, "Icon");
		l_popup = G_MENU.getdatabyname(iIdx, "isPopup");
		l_NaviPath = G_MENU.getdatabyname(iIdx, "navi");
		
		// 메뉴 별 붙이는곳...
		/*
		if(!this.isEmpty(l_MenuPath)) {
			if(l_MenuPath.indexOf("/BIZ/dev") != 0){
				l_MenuNm = l_MenuNm + " (퍼블완료)";
			}
			
		}
		*/

		//l_isDisplay = "Y";
		l_Icon = "";

		l_MenuLevel = parseInt(l_MenuLevel, 10);

		if (l_isDisplay == "Y") {
			if (l_HighMenuId != "-1" && l_HighMenuId != "") {
				// 상위메뉴가 지정되었다 상위 메뉴를 찾아온다.
				l_ParentNode = SYSVar.MENU_BY_ID[l_HighMenuId];
				if (l_ParentNode == undefined || l_ParentNode == null) {
					// 상위메뉴가 생성되지 않았다. 새로 만들자.
					l_ParentNode = { menu_id: l_HighMenuId, menu_nm: l_MenuNm, menu_level: -1, sort_no: "", menu_row: -1, child: [], pmenu_id: l_HighMenuId };
					// 상위 로드를 등록한다.
					SYSVar.MENU_BY_ID[l_HighMenuId] = l_ParentNode;
				}
			} else {
				/* 상위메뉴코드를 계산해서 강제로 입력한다. */
				/* 상위메뉴 코드 초기화 */
				if (t_parentCode[l_MenuLevel - 1] == undefined || t_parentCode[l_MenuLevel - 1] == null) {
					t_parentCode[l_MenuLevel - 1] = "";
					l_HighMenuId = "";
				} else {
					/* 상위메뉴 배열에서 메뉴코드 설정 */
					l_HighMenuId = t_parentCode[l_MenuLevel - 1];
				}
				/* 자기자신도 상위메뉴가 될수 있으므로 상위메뉴 배열에 추가 */
				t_parentCode[l_MenuLevel] = l_MenuId;
				/* 상위메뉴 코드추가 수정 종료 */
			}

			l_SelfNode = SYSVar.MENU_BY_ID[l_MenuId];
			if (l_SelfNode == undefined || l_SelfNode == null) {
				// 없다 새로 만들자.
				l_SelfNode = { menu_id: l_MenuId, menu_nm: l_MenuNm, menu_path: l_MenuPath, menu_level: l_MenuLevel, sort_no: l_SortNo, menu_row: iIdx, child: [], pmenu_id: l_HighMenuId, icon: l_Icon, navi_path: l_NaviPath };
				SYSVar.MENU_BY_ID[l_MenuId] = l_SelfNode;
				// 부모화면에 추가한다.
				if (l_ParentNode != undefined) {
					l_ParentNode.child.push(l_SelfNode);
				} else {
					// 어라 부모가 없네 그러면은 최상단이다.
					SYSVar.MENU_TREE.push(l_SelfNode);
				}
			} else {
				// 어라 기존에 있네 그러면은 값을 보정하자.
				if (l_SelfNode.menu_row == -1) {
					l_SelfNode.menu_id = l_MenuId;
					l_SelfNode.menu_level = l_MenuLevel;
					l_SelfNode.sort_no = l_SortNo;
					l_SelfNode.menu_row = iIdx;
					l_SelfNode.pmenu_id = l_HighMenuId;
					l_SelfNode.icon = l_Icon;
				} else {
					// 기존정보가 기록되어 있다 어떻게 하지
				}
			}
		}
	}

	SYSVar.MENU_BY_ID_LEFT = SYSVar.MENU_BY_ID;

	// LEFT 메뉴 : TOP 메뉴와 LEFT 메뉴를 별도로 처리할때 사용
	// TOP메뉴 구조와 LEFT 메뉴 구조가 같다면 사용안해도 무방 G_MENU_LEFT 를 G_MENU 로 대체 사용

	//for (iIdx = 0; iIdx < G_MENU_LEFT.getrowcount(); iIdx++) {
	//    for (var iIdx = 0; iIdx < GDS_MENU.getrowcount(); iIdx++) {
	//		l_MenuId     = GDS_MENU.getdatabyname(iIdx, "MENU_ID");
	//		l_MenuLevel  = GDS_MENU.getdatabyname(iIdx, "MENU_LEVEL");
	//		l_HighMenuId = GDS_MENU.getdatabyname(iIdx, "MENU_GROUP");
	//		l_SortNo     = "";
	//		l_MenuNm     = GDS_MENU.getdatabyname(iIdx, "MENU_NM");
	//		l_MenuPath   = GDS_MENU.getdatabyname(iIdx, "URL");
	//		l_isDisplay   = "Y";
	//		l_Icon		= "";
	//
	//		l_MenuLevel = parseInt(l_MenuLevel, 10);
	//		if(l_isDisplay == "Y"){
	//			if (l_HighMenuId != "-1" && l_HighMenuId != "") {
	//				l_ParentNode = SYSVar.MENU_BY_ID_LEFT[l_HighMenuId];
	//				if (l_ParentNode == undefined || l_ParentNode == null) {
	//					l_ParentNode = { menu_id: l_HighMenuId, menu_nm : l_MenuNm, menu_level: -1, sort_no: "", menu_row: -1, child: [], pmenu_id : l_HighMenuId };
	//					SYSVar.MENU_BY_ID_LEFT[l_HighMenuId] = l_ParentNode;
	//				}
	//			} else {
	//				l_ParentNode = l_ParentTempNode;
	//				if (l_ParentNode != null) {
	//					l_HighMenuId = l_ParentNode.menuId;
	//				}
	//			}
	//			l_SelfNode = SYSVar.MENU_BY_ID_LEFT[l_MenuId];
	//			if (l_SelfNode == undefined || l_SelfNode == null) {
	//				l_SelfNode = {menu_id: l_MenuId, menu_nm : l_MenuNm, menu_path : l_MenuPath, menu_level: l_MenuLevel, sort_no: l_SortNo, menu_row: iIdx, child: [], pmenu_id : l_HighMenuId , icon : l_Icon};
	//				SYSVar.MENU_BY_ID_LEFT[l_MenuId] = l_SelfNode;
	//				if (l_ParentNode != undefined) {
	//					l_ParentNode.child.push(l_SelfNode);
	//				} else {
	//					SYSVar.MENU_TREE_LEFT.push(l_SelfNode);
	//				}
	//			} else {
	//				if (l_SelfNode.menu_row == -1) {
	//					l_SelfNode.menu_id    = l_MenuId;
	//					l_SelfNode.menu_level = l_MenuLevel;
	//					l_SelfNode.sort_no    = l_SortNo;
	//					l_SelfNode.menu_row   = iIdx;
	//					l_SelfNode.pmenu_id   = l_HighMenuId;
	//					l_SelfNode.icon		= l_Icon;
	//				} else {
	//				}
	//			}
	//		}
	//	}

	// (임시)템플릿용 LEFT 메뉴
	for (iIdx = 0; iIdx < G_MENU_TEMPLET.getrowcount(); iIdx++) {
		l_MenuId = G_MENU_TEMPLET.getdatabyname(iIdx, "menuId");
		l_MenuLevel = G_MENU_TEMPLET.getdatabyname(iIdx, "menuLevel");
		l_HighMenuId = G_MENU_TEMPLET.getdatabyname(iIdx, "highMenuId");
		l_SortNo = G_MENU_TEMPLET.getdatabyname(iIdx, "sortNo");
		l_MenuNm = G_MENU_TEMPLET.getdatabyname(iIdx, "menuName");
		l_MenuPath = G_MENU_TEMPLET.getdatabyname(iIdx, "programPath");
		l_isDisplay = G_MENU_TEMPLET.getdatabyname(iIdx, "isDisplay");
		l_Icon = G_MENU_TEMPLET.getdatabyname(iIdx, "Icon");
		l_popup = G_MENU_TEMPLET.getdatabyname(iIdx, "isPopup");

		l_MenuLevel = parseInt(l_MenuLevel, 10);
		if (l_isDisplay == "Y") {
			if (l_HighMenuId != "-1" && l_HighMenuId != "") {
				l_ParentNode = SYSVar.MENU_BY_ID_TEMPLET[l_HighMenuId];
				if (l_ParentNode == undefined || l_ParentNode == null) {
					l_ParentNode = { menu_id: l_HighMenuId, menu_nm: l_MenuNm, menu_level: -1, sort_no: "", menu_row: -1, child: [], pmenu_id: l_HighMenuId };
					SYSVar.MENU_BY_ID_TEMPLET[l_HighMenuId] = l_ParentNode;
				}
			} else {
				l_ParentNode = l_ParentTempNode;
				if (l_ParentNode != null) {
					l_HighMenuId = l_ParentNode.menuId;
				}
			}
			l_SelfNode = SYSVar.MENU_BY_ID_TEMPLET[l_MenuId];
			if (l_SelfNode == undefined || l_SelfNode == null) {
				l_SelfNode = { menu_id: l_MenuId, menu_nm: l_MenuNm, menu_path: l_MenuPath, menu_level: l_MenuLevel, sort_no: l_SortNo, menu_row: iIdx, child: [], pmenu_id: l_HighMenuId, icon: l_Icon, popup: l_popup };
				SYSVar.MENU_BY_ID_TEMPLET[l_MenuId] = l_SelfNode;
				if (l_ParentNode != undefined) {
					l_ParentNode.child.push(l_SelfNode);
				} else {
					SYSVar.MENU_TREE_TEMPLET.push(l_SelfNode);
				}
			} else {
				if (l_SelfNode.menu_row == -1) {
					l_SelfNode.menu_id = l_MenuId;
					l_SelfNode.menu_level = l_MenuLevel;
					l_SelfNode.sort_no = l_SortNo;
					l_SelfNode.menu_row = iIdx;
					l_SelfNode.pmenu_id = l_HighMenuId;
					l_SelfNode.icon = l_Icon;
				} else {
					//
				}
			}
		}
	}

	// DEMO용 로직
	// 템플릿 메뉴로 설정한다.
	//SYSVar.MENU_BY_ID = SYSVar.MENU_BY_ID_TEMPLET;
	//SYSVar.MENU_BY_ID_LEFT = SYSVar.MENU_BY_ID_TEMPLET;

	if (SYSVar.TOPMAIN_MEMBER != undefined && SYSVar.TOPMAIN_MEMBER != null) {
		SYSVar.TOPMAIN_MEMBER.setTopMenu();
	}

	if (SYSVar.WINMAIN_MEMBER != undefined && SYSVar.WINMAIN_MEMBER != null) {
		if (SYSVar.WINMAIN_MEMBER["topMenuMake"] != undefined) {
			SYSVar.WINMAIN_MEMBER.topMenuMake();
		}
	}

	if (SYSVar.LEFTMAIN_MEMBER != undefined && SYSVar.LEFTMAIN_MEMBER != null) {
		SYSVar.LEFTMAIN_MEMBER.setLeftMenu();
		SYSVar.LEFTMAIN_MEMBER.setLeftQuickMenu(SYSVar.LEFT_QUICK_USE);
	}
}

/**
 * callscriptmethod 에 파라메터로 전달할 값들을 문자열로 변환하는 API
 * @param arrParams  문자열로 변환할 파라메터
 * @return 파라메터로 넘길 문자열
 */
function makeParamString(arrParams) {
	var arr = [];

	for (var i = 0; i < arrParams.length; i++) {
		switch (typeof arrParams[i]) {
			case "string":
				arr.push(parseStringVarWithQuote(arrParams[i]));
				break;
			case "number":
				arr.push(arrParams[i]);
				break;
			default:
				arr.push("''");
				break;
		}
	}

	return "(" + arr.join(",") + ")";
}


function openHomeScreen() {
	SYSVar.WINMAIN_MEMBER.showHome(true);
}

function printConsoleLog(logObj) {
	if (SYSVar.SHOW_CONSOLELOG) {
		console.log(logObj);
	}
}

/**
 * 팝업호출시 지정한 콜백함수를 호출한다.
 * @param objScreen  화면오브젝트
 * @param objParam   전달할 오브젝트
 */
function popCloseCallBack(objScreen, objParam) {
	var srcParent;
	var scrParentMember;
	srcParent = objScreen.getparent();
	
	if(objParam==null){
		objParam ={"popId":""};
	}
	objParam.popId = objScreen.getscreenid();
	
	if (factory.isobject(srcParent)) {
		// 부모화면의 멤버 오브젝트 구하기
		scrParentMember = srcParent.getmembers();
		if (factory.isfunction(scrParentMember["_popCloseCallBack"])) {
			// 부모화면의 함수를 통하여 값 전달
			scrParentMember["_popCloseCallBack"](objParam);
		}
	}
}
/**
 * 패턴 처리 사용자 정의 함수
 * @param objScreen 화면 인스턴스
 * @param objComponent 컴포넌트 인스턴스
 * @param nEventType 함수가 호출된 이벤트 유형 (1: API
 * @param strValue 패턴이 포함되지 않은 값
 * @param nRow 행 인덱스 (Zero-Based) (필드인 경우, -1)
 * @param nSubRow 서브행 인덱스 (Zero-Based) (필드인 경우, -1)
 * @param nColumn 열 인덱스 (Zero-Based) (필드인 경우, -1)
 */
function patternTelNoFunc(objScreen, objComponent, nEventType, strValue, nRow, nSubRow, nColumn) {
	var objPatternInfo;

	objPatternInfo = {
		pattern: undefined, // pattern 속성에 해당하는 문자열
		pattern_mask: undefined, // pattern_mask 속성에 해당하는 문자열
		pattern_front_symbol: undefined, // pattern_front_symbol 속성에 해당하는 문자열
		pattern_rear_symbol: undefined, // pattern_rear_symbol 속성에 해당하는 문자열
	};

	if (strValue.substring(0, 2) == "02") {
		objPatternInfo.pattern = "99-9999-9999";
		objPatternInfo.pattern_mask = "99-9XXX-9999";
	} else {
		objPatternInfo.pattern = "999-9999-9999";
		objPatternInfo.pattern_mask = "999-9XXX-9999";
	}

	return objPatternInfo;
}

/**
 * 패턴 처리 사용자 정의 함수
 * @param objScreen 화면 인스턴스
 * @param objComponent 컴포넌트 인스턴스
 * @param nEventType 함수가 호출된 이벤트 유형 (1: API
 * @param strValue 패턴이 포함되지 않은 값
 * @param nRow 행 인덱스 (Zero-Based) (필드인 경우, -1)
 * @param nSubRow 서브행 인덱스 (Zero-Based) (필드인 경우, -1)
 * @param nColumn 열 인덱스 (Zero-Based) (필드인 경우, -1)
 */
function patternJuminNoFunc(objScreen, objComponent, nEventType, strValue, nRow, nSubRow, nColumn) {
	var objPatternInfo;

	objPatternInfo = {
		pattern: undefined, // pattern 속성에 해당하는 문자열
		pattern_mask: undefined, // pattern_mask 속성에 해당하는 문자열
		pattern_front_symbol: undefined, // pattern_front_symbol 속성에 해당하는 문자열
		pattern_rear_symbol: undefined, // pattern_rear_symbol 속성에 해당하는 문자열
	};

	if (strValue.length > 10) {
		objPatternInfo.pattern = "999999-9999999";
		objPatternInfo.pattern_mask = "999999-9999999";
	} else {
		objPatternInfo.pattern = "999-99-99999";
		objPatternInfo.pattern_mask = "999-99-99999";
	}

	return objPatternInfo;
}

/**
 * 파라메터로 받은 컨트롤에 대해 enable 또는 disable 시킨다.
 * @param {screen}  objScreen 화면
 * @param {Boolean} bEnable   enable여부 true, false
 * @param {array}   arrCtrls  enable 또는 disable 시킬 컨트롤오브젝트들
 * @return 없음
 */
function setEnable(objScreen, bEnable, arrCtrls) {
	for (var i = 0; i < arrCtrls.length; i++) {
		if (this.isObjCtrl(arrCtrls[i]) == true) {
			arrCtrls[i].setenable(bEnable);
		}
	}
}

/**
 *  필드 밸리데이션 효과 처리 예제
 */
function setErrorObject(objInst, bState, strText) {
	var prop_obj = {
		effect_duration: 0,
		effect_type: 3,
		border_color: [240, 55, 55],
		border_width: 2,
		margin_top: 0,
		margin_right: 0,
		margin_bottom: 0,
		margin_left: 0,
	};

	if (bState) {
		objInst.setbordereffect(prop_obj);
	} else {
		objInst.setbordereffect(null);
	}

	prop_obj = {
		effect_duration: 0,
		focusout_font: ["나눔고딕", 9, 0, 0, 0, 0],
		text: strText,
		fontsize_gap: 2,
		focusin_horz_gap: 8,
		focusin_vert_gap: 4,
		focusout_horz_gap: 2,
		focusout_vert_gap: 2,
		focusin_fore_color: [240, 55, 55],
		focusout_fore_color: [240, 55, 55],
		focusout_horz_align: "left",
		focusin_horz_align: 0,
		focusin_vert_align: 2,
	};

	if (bState) {
		objInst.setplaceholdereffect(prop_obj);
	} else {
		objInst.setplaceholdereffect(null);
	}

	objInst.setfocus();
}

/**
 * 파라메터로 받은 컨트롤에 대해 보이기 또는 숨기기한다.
 * @param objScreen 화면
 * @param arrCtrls   visible 시킬 컨트롤오브젝트
 * @param bShow  	visible 여부 true, false
 * @return 없음
 */
function setVisibleCtrls(objScreen, arrCtrls, bShow) {
	for (var nIdx = 0; nIdx < arrCtrls.length; nIdx++) {
		if (factory.isobject(arrCtrls[nIdx]) == true) {
			arrCtrls[nIdx].setvisible(bShow);
		}
	}
}

/**
 *  분할 화면으로 구동시 하단 스크린 네비 버튼으로 화면을 활성화 시킬시에 사용한다
 *  #분할 화면이 아닐경우도 사용이 가능하나 분할 화면에서는 일반적인 탭형태로 사용하기 때문에 사용할 필요가 없어보임
 */
function setActiveScreen(menuId) {
	var idx;
	let tabMiddleInst = SYSVar.MIDDLE_TAB;
	let isFind = false;
	let tabItemCnt = tabMiddleInst.gettabitemcount();

	for (idx = 0; idx < tabItemCnt; idx++) {
		let screenInst = tabMiddleInst.getchildscreeninstance(idx);
		screenInst = screenInst == null ? false : screenInst;
		//screenInst ??= false;

		if (!screenInst) continue;
		else {
			let screenMembers = screenInst.getmembers();
			//screenMembers ?? false;
			screenMembers = screenMembers == null ? false : screenMembers;

			if (!screenMembers) continue;
			else {
				if (screenMembers.m_ScrInfo.MENU_ID === menuId) {
					tabMiddleInst.settabitemfocus(idx);
					isFind = true;
					break;
				}
			}
		}
	}

	if (!isFind && SYSVar.USE_SUB_MIDDLE_TAB) {
		tabMiddleInst = SYSVar.SUB_MIDDLE_TAB;
		tabItemCnt = tabMiddleInst.gettabitemcount();
		for (idx = 0; idx < tabItemCnt; idx++) {
			let screenInst = tabMiddleInst.getchildscreeninstance(idx);
			//screenInst ??= false;
			screenInst = screenInst == null ? false : screenInst;
			if (!screenInst) continue;
			else {
				let screenMembers = screenInst.getmembers();
				//screenMembers ??= false;
				screenMembers = screenMembers == null ? false : screenMembers;

				if (!screenMembers) continue;
				else {
					if (screenMembers.m_ScrInfo.MENU_ID === menuId) {
						tabMiddleInst.settabitemfocus(idx);
						break;
					}
				}
			}
		}
	}
}

/**
 * 년/월/일 날짜 처리 공통 함수
 * "년,월" 인스턴스에서 날짜를 전달받아 적용할 "일자" 콤보박스에 데이터를 설정
 * @param objY 년단위 데이트피커 인스턴스
 * @param objM 월단위 데이트피커 인스턴스
 * @param objD 일단위 콤보박스 인스턴스
 * @return 성공실패여부
 */
function setDayCombobox(objY, objM, objD) {
	var idx;
	var yVal;
	var mVal;
	var lastDayVal;

	if (factory.isobject(objY) && factory.isobject(objM) && factory.isobject(objD)) {
		yVal = objY.gettext();
		mVal = objM.gettext();
		if (yVal == "" || mVal == "") {
			return false;
		} else {
			let lastDateVal = factory.datelastdayofmonth(yVal + mVal + "01");

			console.log(lastDateVal);

			console.log(lastDateVal.substr(6));
			lastDayVal = lastDateVal.substr(6);
			for (idx = 1; idx <= lastDayVal; idx++) {
				objD.addstring(idx + ":" + idx);
			}

			return true;
		}
	} else {
		return false;
	}
}

/**
 * 날짜 처리 공통 함수
 * @param objScreen 화면 인스턴스
 * @param objComponent 컴포넌트 인스턴스
 * @param nEventType 함수가 호출된 이벤트 유형
 * @param strValue 패턴이 포함되지 않은 값
 * @return 성공실패여부
 */
function setDateToObject(objScreen, objComponent, nEventType, strValue) {
	if (!factory.isobject(objComponent)) {
		return;
	}

	switch (nEventType) {
		case "TODAY":
			objComponent.settext(factory.datetoday());
			break;
		case "DAY":
			objComponent.settext(factory.datefrom("day", strValue, objComponent.gettext()));
			break;
		case "WEEK":
			objComponent.settext(factory.datefrom("day", strValue * 7, objComponent.gettext()));
			break;
		case "MONTH":
			objComponent.settext(factory.datefrom("month", strValue, objComponent.gettext()));
			break;

		default:
			break;
	}
	return true;
}

/**
 * 탭 화면을 고정/해제(LOCK/UNLOCK) 한다.(TOGGLE)
 * @param {Number} MIDDLE 탭 인덱스(옵션)
 * @return 없음
 */
function setTabScreenLock(nFocusIdx) {
	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;
	var tabMiddle = SYSVar.SELECTED_MIDDLE_TAB;
	if (nFocusIdx == undefined) {
		nFocusIdx = SYSVar.SELECTED_MIDDLE_TAB.gettabitemfocus();
	}

	if (tabMiddle.gettabitemlock(nFocusIdx) == true) {
		tabMiddle.settabitemlock(nFocusIdx, false);
	} else {
		tabMiddle.settabitemlock(nFocusIdx, true);
	}
}

/**
 * 업무화면 잠금 처리 공통 함수
 * @param objScreen 화면 인스턴스
 * @param state 잠금상태
 * @return 성공실패여부
 */
function setScreenLock(objScreen, state) {
	var is_protected;
	var parentScreen;
	var parentScreenid;
	var lockscreen;


	parentScreen = objScreen.getparent();
	
	if(parentScreen != null && parentScreen != undefined && parentScreen.getobjectkind() == XFD_OBJKIND_SCREEN) {
		parentScreenid == parentScreen.getscreenid();
		if (parentScreenid == "mainFrame") {
			//
		}
	}
	
	

	// SYSVar.OPEN_POPUP_SCREEN
	//lockscreen = SYSVar.WINMAIN_SCREEN;
	lockscreen = objScreen;

	if (state) {
		is_protected = lockscreen.getscreenprotect();
		if (is_protected == true) {
			return false;
		} else {
			return lockscreen.setscreenprotect(true);
		}
	} else {
		is_protected = lockscreen.getscreenprotect();
		if (is_protected == false) {
			return false;
		} else {
			return lockscreen.setscreenprotect(false);
		}
	}
}

/**
 * 메인화면 잠금 처리 공통 함수
 * @param state 잠금상태
 * @return 성공실패여부
 * 업무영역을 포함한 화면에 보이는 전부를 잠금처리한다(팝업제외).
 */
function setScreenLockMain(state) {
	var is_protected;
	var lockscreen;

	// SYSVar.OPEN_POPUP_SCREEN
	lockscreen = SYSVar.WINMAIN_SCREEN;

	if (state) {
		is_protected = lockscreen.getscreenprotect();
		if (is_protected == true) {
			return false;
		} else {
			return lockscreen.setscreenprotect(true);
		}
	} else {
		is_protected = lockscreen.getscreenprotect();
		if (is_protected == false) {
			return false;
		} else {
			return lockscreen.setscreenprotect(false);
		}
	}
}

/**
 * Frame 에러메세지 처리 공통 함수
 * @param objScreen 화면 인스턴스
 * @param arrMsgTitle 메세지타이틀배열
 * @param arrMsg 메세지배열
 * @param msgNumber 보여줄메세지 수
 * @param duration 보여주는 시간(초)
 */
function setTaskMessage(objScreen, arrMsgTitle, arrMsg, msgNumber, duration) {
	this.getFrameMembers(objScreen).setTaskMessage(arrMsgTitle, arrMsg, msgNumber, duration);
}

function setStatusMsg(strMsg) {
	SYSVar.BOTTOMMAIN_MEMBER._setStatusMsg(strMsg);
}

function setSystemId(strId) {
	SYSVar.BOTTOMMAIN_MEMBER._setSystemId(strId);
}

/**
 * Frame 에러메세지 처리 공통 함수
 * @param objScreen 화면 인스턴스
 * @param strTitle 변경할 팝업타이틀
 */
function setPopupTitle(objScreen, strTitle) {
	var srcParent;
	var scrParentMember;
	srcParent = objScreen.getparent();

	if (factory.isobject(srcParent)) {
		// 부모화면의 멤버 오브젝트 구하기
		scrParentMember = srcParent.getmembers();
		if (factory.isfunction(scrParentMember["setPopupTitle"])) {
			// 부모화면의 함수를 통하여 값 전달
			scrParentMember["setPopupTitle"](strTitle);
		}
	}
}

function setCommonBtnRegistEvent(frameScreenInst, btnGrpObject) {
	btnGrpObject.getCommonBtnArr().forEach(function (curItem, index, array) {
		curItem.registerevent("on_mouseup", curItem.getname() + "_on_mouseup(objInst)");
	}, frameScreenInst);
}

/**
 * XFRAME5에서 제공하는 콘솔창을 컨트롤한다.
 * @param bEnable 활성화 여부
 */
function showXFrame5ConsoleTrace(bEnable) {
	factory.showconsoletrace(bEnable);
}

/**
 * 데이터셋 거래로그를 추적할수 있는 로그창을 보여준다.
 * @param 없음
 * @return XTRANLOG 팝업 로드 결과 메세지 리턴. .
 */
function showXTranLog() {
	var bEnable;
	factory.setxtrandatalog(3);

	if (factory.findpopup("XTRANLOG")) {
		return "[SYSLOG]XTRANLOG 이미 실행중 입니다. ";
	}

	bEnable = factory.loadpopup("XTRANLOG", "/SYS/UTIL/xtran_log", "XTRANLOG", false, XFD_BORDER_NONE, 0, 0, true, false, SYSVar.WINMAIN_SCREEN);
	if (bEnable) {
		return "[SYSLOG]XTRANLOG 실행완료 ";
	} else {
		return "[SYSLOG]XTRANLOG 실행실패";
	}
}

/**
 * UI에서 설정한 세션 타임아웃 시간이 경과될경우 세션연장 팝업을 보여준다.
 * @param 없음
 * @return 
 */
function showSessionPopup(AParentScr , strCallScript)
{
	//console.log("########## LOG OUT POPUP CALL ###########");
	//console.log(AParentScr.getscreenid()); winMain 
	//console.log(strCallScript);   sessionCheckCallBack
	
	var activeScreenId = SYSVar.ACTIVE_SCREEN.getscreenid();
	
	if( activeScreenId != null && activeScreenId != "LoginMain"){
			//팝업이 열려 있는게 있으면, 닫는다..
			if(SYSVar.ACTIVE_POPUP_SCREEN != null && SYSVar.ACTIVE_POPUP_SCREEN != undefined ){
				var popupid =SYSVar.ACTIVE_POPUP_SCREEN.getscreenid();
				console.log("########## log out... popup close... ######");
				SYSVar.ACTIVE_POPUP_SCREEN.getmembers()._btnPopClose_on_mouseup();
			}
	
			var objPopup_data = {};
			let objExtra_data = {};
			
			// 검색팝업으로 전달할 데이터
			objExtra_data.RETURN_FUNCTION_NAME = strCallScript;
			objExtra_data.PARENT_SCR = AParentScr;
			
			// 공통팝업 구성 데이터
			objPopup_data.SCR_ID     = "";
			objPopup_data.SCR_PATH   = "/SYS/UTIL/sessionMessage";
			objPopup_data.MENU_ID    = "COM_SESSION_POP";
			objPopup_data.MENU_NM    = "로그인 연장확인";
			objPopup_data.P_MENU_ID  = "";
			objPopup_data.PARENT_SCR = AParentScr;
			objPopup_data.EXT_DATA   = objExtra_data; 
			
			var param = {};
			
			//this.loadPopup(AParentScr, "로그인 연장확인" , objPopup_data, 2);
			this.loadPopup(AParentScr, "로그인 연장확인" , objPopup_data.SCR_PATH, param);
	}else{
		console.log("[SYSLOG] Login Page ..");
	}
}

/**
 * 팝업프레임 닫기 버튼 보임여부 설정
 * @param bShow : true 보임, false 숨김
 * @return 
 */
function showPopupFrameCloseButton(objScreen, bShow)
{
	// 팝업프레임의 닫기버튼 비활성화
	var srcParent;
	var scrParentMember;
	srcParent = objScreen.getparent();
	if (factory.isobject(srcParent)) {
		scrParentMember = srcParent.getmembers();
		if (factory.isfunction(scrParentMember["showCloseButton"])) {
			scrParentMember["showCloseButton"](bShow);
		}
	}
	
}


/**
 * 메시지 팝업 화면 호출(화면 on_messagebox 이벤트 호출)
 * @param {object} objScreen  화면 오브젝트
 * @param {object} strTitle  메시지 팝업 타이틀
 * @param {object} nMsgType  메시지 팝업 타입
  							XFD_MB_INFORMATION or 1
	  						XFD_MB_ERROR       or 2
		  					XFD_MB_QUESTION    or 3
			  				XFD_MB_STOP        or 4
							  0 or null 
 * @param {object} nBtnType  화면 오브젝트
  							XFD_MB_ABORTRETRYIGNORE    or 1
	  						XFD_MB_OK                  or 2
		  					XFD_MB_OKCANCEL            or 3
			  				XFD_MB_RETRYCANCEL         or 4
				  			XFD_MB_YESNO               or 5
					  		XFD_MB_YESNOCANCEL         or 6
						  	XFD_MB_CANCELRETRYCONTINUE or 7
 * @param {object} strMsg    메시지 내용
 * @param {object} nFocus    화면 오브젝트
							  XFD_MB_FOCUSBUTTON1 or 0
							  XFD_MB_FOCUSBUTTON2 or 1
							  XFD_MB_FOCUSBUTTON3 or 2
 * @param {object} strMsgId  on_messagebox에서 받을 메시지 ID
 * @return 없음
 */
function showMessagebox(objScreen, strTitle, nMsgType, nBtnType, strMsg, nFocus, strMsgId){
	
	
	// SYSUtil window 객체가 다르기 때문에 screen 의 window 객체를 별로도 구함.
	let objWindowMember = objScreen.getmembers();
	
	// 버튼 타입에 맞게 리턴 상수값을 보정한다.(첫번째 버튼 1, 두번째 버튼 2, 세번째 버튼 3)
	switch (nBtnType) {
		case XFD_MB_ABORTRETRYIGNORE :
			objWindowMember.XFD_MB_RESABORT = 1;
			objWindowMember.XFD_MB_RESRETRY = 2;
			objWindowMember.XFD_MB_RESIGNORE = 3;
			break;
		case XFD_MB_OK:
			objWindowMember.XFD_MB_RESOK = 1;
			break;
		case XFD_MB_OKCANCEL :
			objWindowMember.XFD_MB_RESOK = 1;
			objWindowMember.XFD_MB_RESCANCEL = 2;
			break;
		case XFD_MB_RETRYCANCEL :
			objWindowMember.XFD_MB_RESRETRY = 1;
			objWindowMember.XFD_MB_RESCANCEL = 2;
			break;
		case XFD_MB_YESNO :
			objWindowMember.XFD_MB_RESYES = 1;
			objWindowMember.XFD_MB_RESNO = 2;
			break;
		case XFD_MB_YESNOCANCEL :
			objWindowMember.XFD_MB_RESYES = 1;
			objWindowMember.XFD_MB_RESNO = 2;
			objWindowMember.XFD_MB_RESCANCEL = 3;
			break;
		case XFD_MB_CANCELRETRYCONTINUE  :
			objWindowMember.XFD_MB_RESCANCEL = 1;
			objWindowMember.XFD_MB_RESRETRY = 2;
			objWindowMember.XFD_MB_RESCONTINUE = 3;
			break;
		default:
			
	}
	
	// 메세지 박스 로딩
	objScreen.messagebox(strMsg, strTitle, nMsgType, nBtnType, nFocus, strMsgId);
	
	// CSS 변경 처리
	// XFD_MB_STOP 일경우 엔진에서 클래스를 따로 적용하지 않기 때문에 강제로 적용처리
	if (nMsgType == XFD_MB_STOP) {
		// javascript
		objWindowMember.document.querySelector("._xf_popup_msgbox_icon").classList.remove("_xf_popup_msgbox_icon_error");
		objWindowMember.document.querySelector("._xf_popup_msgbox_icon").classList.add("_xf_popup_msgbox_icon_stop");
		// jquery
		//$("._xf_popup_msgbox_icon").removeClass('_xf_popup_msgbox_icon_error');
		//$("._xf_popup_msgbox_icon").addClass('_xf_popup_msgbox_icon_stop');
	} else if(nMsgType == 0 || nMsgType == null) {	// 아이콘이지미가 없는경우 처리
		// javascript
		objWindowMember.document.querySelector("._xf_popup_msgbox_msg_scrollbox").style.padding = "10px 40px 10px 40px";
		// jquery
		//$("._xf_popup_msgbox_msg_scrollbox").css("padding" , "10px 40px 10px 40px");
	}
	
}

/**
 *	메시지 팝업 화면 호출(화면 on_messagebox 이벤트 호출)
 *	objBtnArray : 버튼으로 생성할 문자배열(최대 3개)
 */
function showMessageboxCustom(objScreen, strTitle, nMsgType, objBtnArray, strMsg, nFocus, strMsgId){
	
	if (objBtnArray.length < 1 || objBtnArray.length > 3) {
		// 에러 메세지 처리 
		console.log("버튼배열 길이값 오류 : 1 ~ 3 ");
		objScreen.messagebox("버튼배열 길이값 오류 : 1 ~ 3 ", "오류", XFD_MB_ERROR, XFD_MB_OK, 0, "SYSTEM_ERROR");
		return;
	}
	
	// SYSUtil window 객체가 다르기 때문에 screen 의 window 객체를 별로도 구함.
	let objWindowMember = objScreen.getmembers();
	
	// 버튼 타입에 맞게 리턴 상수값을 보정한다.(첫번째 버튼 1, 두번째 버튼 2, 세번째 버튼 3)
	let nBtnType = XFD_MB_CANCELRETRYCONTINUE;
	objWindowMember.XFD_MB_RESCANCEL = 1;
	objWindowMember.XFD_MB_RESRETRY = 2;
	objWindowMember.XFD_MB_RESCONTINUE = 3;
	
	
	
	// 메세지 박스 로딩
	objScreen.messagebox(strMsg, strTitle, nMsgType, nBtnType, nFocus, strMsgId);
	
	// CSS 변경 처리
	// XFD_MB_STOP 일경우 엔진에서 클래스를 따로 적용하지 않기 때문에 강제로 적용처리
	if (nMsgType == XFD_MB_STOP) {
		// javascript
		objWindowMember.document.querySelector("._xf_popup_msgbox_icon").classList.remove("_xf_popup_msgbox_icon_error");
		objWindowMember.document.querySelector("._xf_popup_msgbox_icon").classList.add("_xf_popup_msgbox_icon_stop");
		// jquery
		//$("._xf_popup_msgbox_icon").removeClass('_xf_popup_msgbox_icon_error');
		//$("._xf_popup_msgbox_icon").addClass('_xf_popup_msgbox_icon_stop');
	} else if(nMsgType == 0 || nMsgType == null) {	// 아이콘이지미가 없는경우 처리
		// javascript
		objWindowMember.document.querySelector("._xf_popup_msgbox_msg_scrollbox").style.padding = "10px 40px 10px 40px";
		// jquery
		//$("._xf_popup_msgbox_msg_scrollbox").css("padding" , "10px 40px 10px 40px");
	}
	
	let nIdx;
	for (nIdx in objBtnArray) {
		objWindowMember.document.getElementsByClassName("_xf_popup_msgbox_btn")[nIdx].textContent = objBtnArray[nIdx];
	}
	
}

function unloadPopup(screenInst, rtnValue) {
	let parentScreen = screenInst.getparent();
	if (parentScreen) {
		let parentMembers = parentScreen.getmembers();
		if (parentMembers._getFrameType != undefined && parentMembers._getFrameType() === "POPUP_FRAME_MAIN") {
			parentScreen.unloadpopup(rtnValue);
		} else {
			unloadPopup(parentScreen, rtnValue);
		}
	}
}

/**
 * 화면을 닫는다.
 * @param {Number} MIDDLE 탭 인덱스(옵션)
 * @return 없음
 */
function unloadScreen(nFocusIdx) {
	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;
	if (nFocusIdx == undefined) {
		nFocusIdx = SYSVar.SELECTED_MIDDLE_TAB.gettabitemfocus();
	}
	SYSVar.SELECTED_MIDDLE_TAB.deletetab(nFocusIdx);
}

/**
 * 화면을 모두 닫는다.
 * @param {Boolean} 고정화면을 닫을지 여부[true:모두 닫음 | false:고정화면제외]
 * @return 없음
 */
function unloadScreenAll(bForce) {
	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;
	SYSVar.SELECTED_MIDDLE_TAB.deletealltab(bForce, false);
}

/**
 * TODO 해당화면에 다음페이지 처리 여부를 리턴한다.
 * @param objScreen : screen : 대상화면
 * @return boolean : 다음페이지 처리여부
 */
function isNextPage(objScreen) {
	let mem = this.getFrameMembers(objScreen);
	if (mem._getFrameType() == "MAIN_PORTLET") {
		return mem.m_NextPage;
	} 
	return false;	
}
function setNextPage(objScreen, bNextPage) {
	let mem = this.getFrameMembers(objScreen);
	if (mem._getFrameType() == "MAIN_PORTLET") {
		mem.m_NextPage = bNextPage;
	} 	
}
function setCommonButtonVisible(objScreen, strName, bVisible) {
	let mem = this.getFrameMembers(objScreen);
	if (mem._getFrameType() == "MAIN_PORTLET") {
		mem.setCommonButtonVisible(objScreen, strName, bVisible);
	}
}
function setCommonButtonEnable(objScreen, strName, bEnable) {
	let mem = this.getFrameMembers(objScreen);
	if (mem._getFrameType() == "MAIN_PORTLET") {
		mem.setCommonButtonEnable(objScreen, strName, bEnable);
	}
}
/**
 * 공통버튼 영역을 전체 감추거나 보여준다
 * @param objScreen : screen : 대상화면
 */
function setCommonButtonZoneVisible(objScreen, bEnable) {
	let mem = this.getFrameMembers(objScreen);
	if (mem._getFrameType() == "MAIN_PORTLET") {
		mem.btnZoneVisible(bEnable);
	}
}
/**
 * 현재화면에 활성화 XDataSet을 설정한다.
 * @param objScreen : screen : 대상화면
 * @param objXDataSet : xdataset : 데이터셋
 * @return 
 */
function setActiveXDataSet(objScreen, objXDataSet) {
	let objMembers = this.getFrameMembers(objScreen);
	if (!this.isEmpty(objMembers) && objMembers._getFrameType() == "MAIN_PORTLET") {		
		let objPrev = this.getActiveXDataSet(objScreen);
		if (objPrev == null || objPrev.getid() != objXDataSet.getid()) {
			// 활성데이터셋 설정
			objMembers.setActiveXDataSet(objXDataSet);
			
			// 공통버튼 초기화
			console.log("공통버튼 초기화..."); 
			// TODO as-is로직 좀더 체크해야함.
			if (objScreen.findscriptmethod(XFD_JAVASCRIPT, objXDataSet.getid() + "_ue_init_menu")) {
				objMembers.restoreCommonButton();
				// 활성데이터셋에 따른 공통버튼 설정
				objScreen.callscriptmethodparam(objXDataSet.getid() + "_ue_init_menu", []);	
			}
			
			// 다음버튼 처리
			if (objXDataSet.getcustomprop("next") == "Y") {
				objMembers.setCommonButtonEnable(objScreen, "NEXT", true);
			} else {
				objMembers.setCommonButtonEnable(objScreen, "NEXT", false);
			}			
		}
	}
}
/**
 * 현재화면에 활성화된 XDataSet을 리턴
 * @param objScreen : screen : 대상화면
 * @return 
 */
function getActiveXDataSet(objScreen) {
	
	let objMembers = this.getFrameMembers(objScreen);
	if (!this.isEmpty(objMembers) && objMembers._getFrameType() == "MAIN_PORTLET") {
		return objMembers.getActiveXDataSet();
	}	
	return null;
}


/**
 * 데이터셋에 링크되어있는 최상위 오브젝트를 리턴한다.
 * @param objXDataSet : xdataset : 데이터셋
 * @return object : 그리드 or 테이블뷰 or 패널
 * @remark
 */
function getLinkMasterObject(objXDataSet) {
	let obj = getLinkGridObject(objXDataSet);
	if (obj != null) {
		return obj;
	}
	let arrObj = objXDataSet.getlinkobjects(0);
	
	if (arrObj.length == 0) {
		return null;
	}
	obj = arrObj[0];
	// 단일 오브젝트 링크인경우
	if (arrObj.length == 1) {
		return obj;	
	}
	
	obj = obj.getparent();
	while (obj.getobjectkind() == XFD_OBJKIND_CONTROL) {
		if (obj.getcontrolkind() == XFD_CTRLKIND_TABLEVIEW || obj.getcontrolkind() == XFD_CTRLKIND_PANEL) {
			if (obj.getname().indexOf(objXDataSet.getid()) >= 0) {
				return obj;
			}
		}
		obj = obj.getparent();
	}
	return null;	
}
/**
 * XSS Decode
 * @param str : string : 문자열
 * @return string : decoding된 문자열
 * @remark
 */
function decodeXSS(str) {
	//let objXSS = GM.Util.divXSS;
	//objXSS.settext(str);
	//return objXSS.getdom().innerHTML;
	
	/**
 * replaceAll
 * @param str : string : 대상 문자열
 * @param strSearch : string : 검색문자열
 * @param strReplace : string : replace할 문자열
 * @param bCase : boolean : [옵션] 대소문자 구분여부(Default:true)
 * @return string : replace된 문자열
 * @remark
 */
	
	str = this.replaceAll(str , "&lt;"   ,  "<" );
	str = this.replaceAll(str , "&gt;"   ,  ">" );
	str = this.replaceAll(str , "&amp;"  ,  "&" );
	str = this.replaceAll(str , "&quot;" ,  '"' );
	str = this.replaceAll(str , "&apos;" ,  "'" );
	
	return str;
}

// TODO 콜백파라미터 Set
function setCallbackParam(objScreen, strMapId, objParam) {
	let objMembers = getFrameMembers(objScreen);
	if (objMembers.m_CallbackParam != undefined) {
		objMembers.m_CallbackParam[strMapId] = objParam;
	}	
}	
// TODO 콜백파라미터 Get
function getCallbackParam(objScreen, strMapId) {
	let objMembers = getFrameMembers(objScreen);
	if (objMembers.m_CallbackParam != undefined) {
		let objParam = objMembers.m_CallbackParam[strMapId];
		delete objMembers.m_CallbackParam[strMapId];
		return objParam;
	}
	return {};
}

/*************************************************************************
= 함수명: gfnLogOut
 *  로그아웃처리
 *************************************************************************/
function gfnLogOut() {
	this.comAlert("장시간동안 사용하지 않아 로그아웃됩니다.");

	// 세션에 처리할 데이터가 있다면 처리
	//Initsession(false);
	
	// 로그인 페이지로 이동
	SYSVar.STARTMAIN_TAB.settabitemfocus(0);
}

/*
 * 함수명: lpad()
 * 기능  : 문자열 사이즈설정하고 공백이 발생하면 좌측에 원하는 문자 추가
 * 인수  :
 */
function lpad(str, padLen, padStr) {
	str += "";
	padStr += "";
	while (str.length < padLen) {
		str = padStr + str;
		str = str.length >= padLen ? str.substr(0, padLen) : str;
	}
	return str;
}






/*
 * 함수명: loadToastBox(objScreen, strMsg, viewTime)
 * 기능  : Toast 메시지를 출력한다.
 * 인수  :
 */
function loadToastBox(objScreen, strMsg, viewTime){
	objScreen.toastmessage("안내", strMsg, viewTime, 0, 3);
}


/*
 * 함수명: getLoginUserInfo()
 * 기능  : Toast 메시지를 출력한다.
 * @return object : JSON (사용자정보)
 */
function getLoginUserInfo(){
	
	var loginUser = {
		USER_NO     :"",
		USER_NM     :"",
		EMP_NO      :"",
		DEPT_CD     :"",
		DEPT_NM     :""
	};
	var xdataset = G_EMP_INFO;
	
	loginUser.USER_NO     = xdataset.getdatabyname(0, "USER_NO");
	loginUser.USER_NM     = xdataset.getdatabyname(0, "USER_NM");
	loginUser.EMP_NO      = xdataset.getdatabyname(0, "EMP_NO");
	loginUser.DEPT_CD     = xdataset.getdatabyname(0, "DEPT_CD");
	loginUser.DEPT_NM     = xdataset.getdatabyname(0, "DEPT_NM");
	//loginUser.USER_FG     = xdataset.getdatabyname(0, "USER_FG");
	//loginUser.USER_DIV_CD = xdataset.getdatabyname(0, "USER_DIV_CD");
	//loginUser.EMAIL_ADDR  = xdataset.getdatabyname(0, "EMAIL_ADDR");
	
	if(loginUser.DEPT_CD == ""){
		loginUser.DEPT_CD = SYSVar.WINMAIN_MEMBER.getSessionByAttr("DEPT_CD");
		loginUser.DEPT_NM = SYSVar.WINMAIN_MEMBER.getSessionByAttr("DEPT_NM");
	}
	
	return loginUser;
}

// 개발 참조용 Function 
function viewSource(contentObj , option){
	var content = contentObj.gettext();
	var inText = "<form id='viewFrm' method='post'><input type='hidden' id='popContent' name='popContent' value='aaa'  /></form>";
	document.body.innerHTML = inText;
	document.querySelector("#popContent").value =  contentObj.gettext();
	
	window.open("","viewPopup", option);
	
	var frm = document.querySelector("#viewFrm");
	frm.action ='/viewPopup.jsp';
	frm.target ='viewPopup';
	frm.submit();
}




/*
 * 함수명: LogInputDataSetInfo()
 * 기능  : tranmap id의 정보를 출력한다.
 */
function LogInputDataSetInfo(objScreen ,  xtranmap_id){
	console.log("##### LogInputDataSetInfo Start .... ");
	var xdataset_id_arr, column_id_arr, i, j;
	
	xdataset_id_arr = objScreen.getxtranmapinputxdataset(xtranmap_id, true);
	
	for (i = 0; i < xdataset_id_arr.length; i++) {		
		console.log("##### XDATASET >>>>  "+xdataset_id_arr[i]);
		factory.consoleprint("XDATASET: " + xdataset_id_arr[i]);
		column_id_arr = objScreen.getxtranmapinputcols(xtranmap_id, xdataset_id_arr[i]);
		for (j = 0; j < column_id_arr.length; j++) {
			factory.consoleprint("COLUMN: " + column_id_arr[i]);
		}
	}
}

/*
 * 함수명: Trim(str)
 * 기능  : 입력받은 문자열의 공백을 제거하여 리턴한다.
 */
function Trim(str) {
	return factory.stringtrim(str);
}

/*
 * 함수명: getToday(divStr)
 * 기능  : 오늘날짜를 년월일 단위로 리던 divStr을 Field Seperator로 사용
 */
function getToday(divStr){
	return factory.getsystemtime("%Y"+divStr+"%M"+divStr+"%D");
}


/**
 * 업무 화면 이동 (메뉴PATH 기준)
 * @param {object} objScreen    화면 오브젝트
 * @param {string} strScrUrl    호출할 메뉴PATH
 * @param {string} strItemTitle 메뉴타이틀
 * @param {string} sendData     업무화면에 전달할 데이터
 */
function goToWorkPage(objScreen, strScrUrl, strTitle, sendData) {
	
	console.log(SYSVar.ssoSendParm);
	
	var strFrameUrl = "/SYS/FRAME/mainFrame";

	SYSVar.SELECTED_MIDDLE_TAB = SYSVar.SELECTED_MIDDLE_TAB == null ? SYSVar.MIDDLE_TAB : SYSVar.SELECTED_MIDDLE_TAB;
	// 화면 정보가 있는지 체크
	
	var gotoPageId = strScrUrl.substring(strScrUrl.lastIndexOf("/")+1);

	var objExtra_data = {
		SCR_ID: gotoPageId,
		SCR_PATH: strScrUrl,
		MENU_ID: "",
		MENU_NM: strTitle,
		P_MENU_ID: "",
		PARENT_SCR: factory.getmainscrinstance(),
		BIZ_EXT: sendData,
		MOVE_GBN: "goToPage",
	};

	SYSVar.SELECTED_MIDDLE_TAB.addportlettab("", 0, 60,  strFrameUrl, "", true, objExtra_data);
}

function jsonConsoleView(jsonData){
	console.log(JSON.stringify(jsonData));
}


function jsonDataView(jsonData){
	return JSON.stringify(jsonData);
}

/**
 * xDataset의 Operatiaon 정보를 console 창에 출력한다
 * @param xDataSet    xDataSet
 */
function xDataSetOperationView(xDataSet){
	for(var j=0; j < xDataSet.getrowcount(); j++){
		var strOperation = xDataSet.getrowoperation(j);
		console.log("##### "+xDataSet.getid()+" >>>> ["+j+"] : "+strOperation);
	}
}

/**
 * 기능  : 상수정보의 ID를 받아서 상수값을 리턴한다.
 * @param str  카멜케이스 대상 문자열
 * 
 */
function getCntnValue(cnstNm){
	var DS_CNST_INFO = this.G_CNST_INF;
	var cnt  = DS_CNST_INFO.getrowcount();
	var cnstCntn ="";
	for(var i=0; i< cnt; i++){
		var tempCnstNm = DS_CNST_INFO.getdatabyname(i , "cnstNm");
		if(cnstNm == tempCnstNm){
			cnstCntn = DS_CNST_INFO.getdatabyname(i , "cnstCntn");
			break;
			
		}
	}
	return cnstCntn;
}



/**
 * 기능  : 전체가 없는 콤보박스에 전체 항목을 추가 한다.
 * @param str  카멜케이스 대상 문자열
 */
function addComboAllColumn(comboBox){
	comboBox.addstring(":- 선택 -");
	comboBox.sortpicklistviewlist(1);
	comboBox.setselectedcode("");
}

/**
 * 기능  : 포커스가 되어 있는 screen 을 리턴
 * @param str  카멜케이스 대상 문자열
 */
function getFocusScreen(){
	return factory.getfocusscreen();	
}

/**
 * 기능  : 포커스가 되어 있는 screenid 을 리턴
 * @param str  카멜케이스 대상 문자열
 */
function getFocusScreenId(){
	return factory.getfocusscreen().getscreenid();	
}


/*
 * 함수명: showDataSetLog(xdataset)
 * 기능  : 데이타셋의 모든 데이터를 console 창에 출력한다.
 * 인수  :
 */
function showDataSetLog(xdataset){
	for(var i =0; i <xdataset.getrowcount() ; i++){
		var tempRow =  "{ ";
		for(var j=0; j < xdataset.getcolumncount();j++){
			//console.log("["+i+"]"+xdataset.getcolumnid(j) +":"+xdataset.getdata(i, j));
			if(j!=(xdataset.getcolumncount()-1)){
				tempRow += xdataset.getcolumnid(j) +" : '"+xdataset.getdata(i, j)+"', ";
			}else{
				tempRow += xdataset.getcolumnid(j) +" : '"+xdataset.getdata(i, j)+"' }";
			}
		}
		console.log(tempRow);
	}
}

/*
 * 함수명: getActiveWorkScreen
 * 기능  : 활성화 되어 있는 screen Object 를 return 한다.
 * 인수  :
 */
function getActiveWorkScreen(){
	var mainFrameId = SYSVar.ACTIVE_SCREEN.getscreenid();
	if(mainFrameId=="mainFrame"){
		return SYSVar.ACTIVE_SCREEN.getmembers().getScreenObj();
	}else{
		return SYSVar.ACTIVE_SCREEN;
	}
}

/*
 * 함수명: getActiveWorkScreen
 * 기능  : 활성화 되어 있는 screenid 를 return 한다.
 * 인수  :
 */
function getActiveWorkScreenId(){
	var mainFrameId = SYSVar.ACTIVE_SCREEN.getscreenid();
	if(mainFrameId=="mainFrame"){
		return SYSVar.ACTIVE_SCREEN.getmembers().getScreenObj().getscreenid();
	}else{
		return SYSVar.ACTIVE_SCREEN.getscreenid();
	}
}

/*
 * 함수명: getUserRollGbn
 * 기능  : 권한을 담고 있는 데이터 셋에서 권한 유무를 판별한다.
 * @param paramRoleNo 권한 번호
 * @return 사용자가 권한 유무 true/false
 */
function getUserRollGbn(paramRoleNo){
	var g_user_role = G_USER_ROLE;
	for(var i=0;i<g_user_role.getrowcount();i++){
		var roleNo = g_user_role.getdatabyname(i, "roleNo");
		if(roleNo==paramRoleNo){
			return true;
		}
	}
	return false;
}


/**
 * 기능  : 문자열을 카멜케이로 전환하여 리턴한다.
 * @param str  카멜케이스 대상 문자열
 * 
 */
function toCamelCase(str){
	return str.toLowerCase().replace(/[^a-zA-Z0-9]+(.)/g, (m, chr) => chr.toUpperCase());
}


function saveOpenHistoryMenu(objOpenMenuInfo){
	
	if (SYSVar.OPEN_MENU_INFO_USE) {
		let objOpenMenuInfoList;

		if (sessionStorage.getItem("menuInfoHistory") == null || sessionStorage.getItem("menuInfoHistory") == "") {
			objOpenMenuInfoList = new Array();
		} else {
			objOpenMenuInfoList = JSON.parse(sessionStorage.getItem("menuInfoHistory"));
		}
		
		if (objOpenMenuInfoList.find(v => v.MENU_ID == objOpenMenuInfo.MENU_ID) == undefined){		
//			let objOpenMenuInfo= {
//				MENU_NM : objMenuInfo.menu_nm
//				,MENU_ID : objMenuInfo.menu_id
//				,ALIGN : 0
//				,ITEM_SIZE : 0
//				//,SCREENURL : strFrameUrl
//				//,PORTLET_NAME : ""
//				//,VISIBLE : true
//				,EXTRA_DATA : objExtra_data
//			}
			
			objOpenMenuInfoList.push(objOpenMenuInfo);
			//console.log(objOpenMenuInfoList);
			//console.log(JSON.stringify(objOpenMenuInfoList));
			//sessionStorage.setItem("menuInfoHistory", JSON.stringify(objOpenMenuInfoList));
		}
		// window 객체는 세션스토리지에 저장할수 없음.
		// 일반 업무화면에서 다른 업무화면을 호출할 경우가 있는지 확인 필요.
		//objExtra_data.PARENT_SCR = objScreen;
		
		//console.log("### saveOpenHistoryMenu if (SYSVar.OPEN_MENU_INFO_USE) END ");

	} else {
		sessionStorage.removeItem("menuInfoHistory");
		//console.log("### saveOpenHistoryMenu else (SYSVar.OPEN_MENU_INFO_USE) END ");
	}
}

function deleteOpenHistoryMenu(objOpenMenuInfo){
	
	if (SYSVar.OPEN_MENU_INFO_USE) {
		let objOpenMenuInfoList;

		if (sessionStorage.getItem("menuInfoHistory") == null || sessionStorage.getItem("menuInfoHistory") == "") {
			objOpenMenuInfoList = new Array();
		} else {
			objOpenMenuInfoList = JSON.parse(sessionStorage.getItem("menuInfoHistory"));
		}
		
		let nIndex = objOpenMenuInfoList.findIndex(v => v.MENU_ID == objOpenMenuInfo.MENU_ID);
		//console.log(nIndex);
		if(nIndex > -1) {
			objOpenMenuInfoList.splice(nIndex, 1);
		}
		sessionStorage.setItem("menuInfoHistory", JSON.stringify(objOpenMenuInfoList));
		
	}
}

/**
 * 데이터셋에 링크되어있는 그리드 오브젝트를 리턴
 * @param objXDataSet : xdataset : 데이터셋
 * @return object : 그리드 오브젝트
 * @remark
 */
function getLinkGridObject(objXDataSet) {
	let arrObj = objXDataSet.getlinkobjects(0);
	let objGrid = null;
	for (let i = 0; i < arrObj.length; i++) {
		if (arrObj[i].getcontrolkind() == XFD_CTRLKIND_GRID || arrObj[i].getcontrolkind() == XFD_CTRLKIND_MULTILINEGRID || arrObj[i].getcontrolkind() == XFD_CTRLKIND_TREEGRID) {
			objGrid = arrObj[i];
			break;
		}
	}
	return objGrid;
}



/**
 * 프로그램 사용권한 체크
 * @param strPgmId : string : 권한체크 대상 프로그램
 * @return String : '0'(권한없음),'1'(read only),'2'(read/write), '9'(프로그램 미등록건/DB ERROR)
 * @remark 
 */
function of_ChkAuthority(strPgmId) {
	
	//console.log("strPgmId >> "+strPgmId);
	//if (this.UserInfo.loginUser.USER_NO == "master") {
	//	return "2";
	//}

	//TODO 화면이 메뉴에 없다면 거래 날려야함.
	//let nFindRow = GDS_MENU.findrow(0, 'menuCode:=:"' + strPgmId + '":1:&');
	//if (nFindRow == -1) {
	//	return "9";
	//}
	//let strAuthLevel = GDS_MENU.getdatabyname(nFindRow, "authLevel");
	//if (strAuthLevel == "X") {
	//	GM.Util.of_ErrorHandle(screen, "TAINFXS012");
	//	return "9";
	//}
	return 2;
}



function korStringCheckAlert(objScreen, hanField, enCheck, numCheck){
	var str = hanField.gettext();
	console.log("str:"+str);
	
	var chkPoint = {
			alpha:		/[A-Z]/gi,
			numeric:	/[0-9]/g
	};
	
	if(enCheck){
		var alpha = (str.match(chkPoint['alpha']) || []).length > 0 ? true : false;
		if(alpha){
			this.loadMessageBox(objScreen, "안내", 1, "영문이 포함되어 있습니다.!!!", "enCheck");
			hanField.settext("");
			return;
		}
	}

	if(numCheck){
		var numeric = (str.match(chkPoint['numeric']) || []).length > 0 ? true : false;
		if(numeric){
			this.loadMessageBox(objScreen, "안내", 1, "숫자가 포함되어 있습니다.!!!", "numCheck");
			hanField.settext("");
			return;
		}
	}	

}

function korStrChkEvt(hanField , enCheck, numCheck){
	var chkPoint = {
			alpha:		/[A-Z]/gi,
			numeric:	/[0-9]/g
	};
	var str = hanField.gettext();
	//console.log("str:"+str);
	if(enCheck){
		str = str.replace(chkPoint['alpha'], "");
		//console.log("return en : "+str);
		hanField.settext( str);
	}
	if(numCheck){
		str = str.replace(chkPoint['numeric'], "");
		//console.log("return num : "+str);
		hanField.settext( str );
	}
}

// 부서장 승인 팝업 호출...
function requestDeptMgrAprv(excelDataInfo){
	var param =excelDataInfo;
	// 팝업 Title
	var popupTitle = "엑셀 다운로드 승인 요청";
    var popupPath = "/BIZ/C/CM/CM/CCMCMP06";
		
	this.loadPopup(SYSVar.ACTIVE_SCREEN, popupTitle, popupPath, param) ;
}


// 프로그래스 호출...
function showProgressBar(AParentScr, param){
	var extData =param;
	//AParentScr.loadportletpopup("ProgressBar", "/SYS/UTIL/progressbar", "POPUP_PORTLET", true, 0, 0, 0, 0, 0, true, false, false, extData);
	AParentScr.loadportletpopup("ProgressBar", "/SYS/UTIL/progressbar", "", true, XFD_BORDER_NONE, 0, 0, 0, 0, true, true, false, extData);
}

//세션에 있는값 가져오기
function getSessionById(attr){
	return SYSVar.WINMAIN_MEMBER.getSessionByAttr(attr);
}

//디플트 passwd
function getDefaultPwd(){
	return SYSVar.WINMAIN_MEMBER.getDefaultPwd();
}

function setLoignUserInfoBySession(){
	SYSVar.loginUserInfo.USER_NO = getSessionById("USER_ID");
	SYSVar.loginUserInfo.USER_NM = getSessionById("USER_NM");
	SYSVar.loginUserInfo.EMP_NO  = getSessionById("USER_ID");
	SYSVar.loginUserInfo.DEPT_CD = getSessionById("DEPT_CD");
	SYSVar.loginUserInfo.DEPT_NM = getSessionById("DEPT_NM");
	
	G_EMP_INFO.init();
	G_EMP_INFO.addrow();

	G_EMP_INFO.setdatabyname(0, "USER_NO",     SYSVar.loginUserInfo.USER_NO);
	G_EMP_INFO.setdatabyname(0, "USER_NM",     SYSVar.loginUserInfo.USER_NM);
	G_EMP_INFO.setdatabyname(0, "EMP_NO",      SYSVar.loginUserInfo.USER_NO);
	G_EMP_INFO.setdatabyname(0, "DEPT_CD",     SYSVar.loginUserInfo.DEPT_CD);
	G_EMP_INFO.setdatabyname(0, "DEPT_NM",     SYSVar.loginUserInfo.DEPT_NM);
}